<?php

 
namespace App\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\ResponseHeaderBag;
 
use App\Entity\User;
use App\Entity\Tracking;
use App\Entity\Task;
use App\Form\AmbassadorType;
use App\Form\AmbassadorEditType;
use App\Form\UserPasswordEditType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\AmbassadorDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
 
/**
 * Class AmbassadorController
 *
 * @Route("/ambassador")
 */
class AmbassadorController extends FOSRestController
{
    
 
    /**
     * @Rest\Get("/", name="ambassadors_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all ambassadors."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador ambassadors."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="Ambassador ID"
     * )
     *
     *
     * @SWG\Tag(name="Ambassador")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $ambassadors = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            //$ambassadorId = $this->getAmbassador()->getId();
            $ambassadors = $em->getRepository("App:User")->getAmbassadors();
            $this->forward('App\Controller\InitializationController::ambassadorCreateAction', []);
 
            if (is_null($ambassadors)) {
                $ambassadors = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Ambassadors - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $ambassadors : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array("ambassador_list"))));
    }

    /**
     * @Rest\Post("/pagination", name="ambassador_pagination_list")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all groups."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all groups."
     * )
     *
     * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="path",
     *     type="string",
     *     description="The ID of Ambassador"
     * )
     * 
     * @SWG\Parameter(
     *     name="role",
     *     in="path",
     *     type="string",
     *     description="The role of user"
     * )
     *
     * @SWG\Parameter(
     *     name="keyword",
     *     in="path",
     *     type="string",
     *     description="The search keyword"
     * )
     * 
     * @SWG\Parameter(
     *     name="page",
     *     in="path",
     *     type="string",
     *     description="The search Page"
     * )
     * 
     * @SWG\Parameter(
     *     name="page_size",
     *     in="path",
     *     type="string",
     *     description="The number of records for page"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_column",
     *     in="path",
     *     type="string",
     *     description="Search order Column"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_direction",
     *     in="path",
     *     type="string",
     *     description="Search order Direction"
     * )
     *
     * @SWG\Tag(name="Ambassador")
     */
    public function paginationAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $ambassador_list = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
            
            $id     = $request->request->get('id_ambassador');
            $keyword    = $request->request->get('keyword');
            $role   = $request->request->get('role');
            $page   = $request->request->get('page');
            $page_size = $request->request->get('page_size');
            $order_column = $request->request->get('order_column');
            $order_direction = $request->request->get('order_direction');

            $ambassadors = $em->getRepository("App:User")->getAmbassadorsPagination($keyword, $page, $page_size, $order_column, $order_direction);
            
            foreach ($ambassadors['list'] as $amb) { 
                $ambassador_list[] = [
                    'id'                => $amb['id'],
                    'username'          => $amb['username'],
                    'country'           => $amb['country'],
                    'language'          => $amb['language'],
                    'code'              => $amb['code'],
                    'ambassador_name'   => $amb['ambassador_name'],
                    'last_graduated'    => $this->lastMbsGraduated($amb['id'])
                ];
            }

            $data = [
                'list' => $ambassador_list,
                'items_total' => $ambassadors['items_total'],
                'pages_total' => $ambassadors['pages_total'],
            ];
           
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('group_list'))));
    }

    
    /**
     * @Rest\Get("/contract", name="contract_ambassadors_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all ambassadors."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador ambassadors."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="Ambassador ID"
     * )
     *
     *
     * @SWG\Tag(name="Ambassador")
     */
    public function contractAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $ambassadors = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            //$ambassadorId = $this->getAmbassador()->getId();
            $ambassadors = $em->getRepository("App:User")->getAmbassadorsContract();
            $this->forward('App\Controller\InitializationController::ambassadorCreateAction', []);
 
            if (is_null($ambassadors)) {
                $ambassadors = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Ambassadors - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $ambassadors : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array("ambassador_list"))));
    }

     /**
     * @Rest\Get("/lastgraduated", name="ambassadors_last_graduated", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all ambassadors."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador ambassadors."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="Ambassador ID"
     * )
     *
     *
     * @SWG\Tag(name="Ambassador")
     */
    public function lastGraduatedAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $list = [];
        $message = "";
        
 
        try {
            $code = 200;
            $error = false;
 
            //$ambassadorId = $this->getAmbassador()->getId();
            $ambassadors = $em->getRepository("App:User")->getAmbassadors();
            foreach ($ambassadors as $amb) {
                $last_graduate = "Never";
                $whatsapp = "";
                $graduate = $em->getRepository('App:StudentGroup')->lastMbsGraduatedByEmbassador($amb->getId(), 'state.approved');
                if($graduate > 0){
                    $last_graduate = $em->getRepository('App:StudentGroup')->lastMbsGraduatedByEmbassadorDate($amb->getId(), 'state.approved');
                    if(!is_null($last_graduate )){
                        $last_graduate = $last_graduate->format('Y-d-m');
                    }
                     
                }
              
                if($amb->getAreacode() == "USA +1"){
                    $whatsapp = $amb->getWhatsapp();
                }
                else{
                    $whatsapp = substr($amb->getAreacode(), 3).$amb->getWhatsapp();
                }
                $list[] = [
                    "Name"     => $amb->getFirstName(). " " .$amb->getLastName(),
                    "Email"    => $amb->getUsername(),
                    "Whatsapp" => $whatsapp,
                    "Country"  => $amb->getCountry(),
                    "Code"     => $amb->getCode(),
                    "Language" => $amb->getLanguage(),
                    "Last Graduated Date" => $last_graduate
                ];
            }


 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Ambassadors - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $list : $message,
        ];
 
        return new Response($serializer->serialize($list, "json", SerializationContext::create()->setGroups(array('project_list'))));
    }

    /**
     * @Rest\Post("/new", name="ambassador_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="User was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="User was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="firtName",
     *     in="body",
     *     type="string",
     *     description="The first Name",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="lasName",
     *     in="body",
     *     type="string",
     *     description="The last name",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="username",
     *     in="body",
     *     type="string",
     *     description="The username",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="password",
     *     in="query",
     *     type="string",
     *     description="The password"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="query",
     *     type="string",
     *     description="The language"
     * )
     * 
     * @SWG\Parameter(
     *     name="country",
     *     in="query",
     *     type="string",
     *     description="The country code"
     * )
     * 
     * @SWG\Parameter(
     *     name="city",
     *     in="query",
     *     type="string",
     *     description="The city"
     * )
     * 
     * @SWG\Parameter(
     *     name="whatsapp",
     *     in="query",
     *     type="integer",
     *     description="The whatsapp"
     * )
     * 
     * @SWG\Parameter(
     *     name="code",
     *     in="query",
     *     type="string",
     *     description="The code"
     * )
     *
     * @SWG\Tag(name="Ambassador")
     */ 
    public function newAction(Request $request, UserPasswordEncoderInterface $encoder) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";

        $ambassador=new User();
        //Create a form
        $form=$this->createForm(AmbassadorType::class, $ambassador);
        $form->submit($request->request->all());
        $user = $em->getRepository('App:User')->findOneBy(array('username' => $ambassador->getUsername()));
 
        try {
            $code = 200;
            $error = false;

            if(! is_null($user)){
                $code = 500;
                $error = true;
                $message = "The user already exist";
            }
            else{

                $password = "123";

    
                $ambassador->setPlainPassword($password);
                $ambassador->setPassword($encoder->encodePassword($ambassador, $password));
                $ambassador->setRoles(['ROLE_EMBASSADOR']);
    
                $em->persist($ambassador);
                $em->flush();
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the ambassador - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $ambassador : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="ambassador_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The ambassador was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the ambassador."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The ambassador ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="firtName",
     *     in="body",
     *     type="string",
     *     description="The first Name",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="lasName",
     *     in="body",
     *     type="string",
     *     description="The last name",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="username",
     *     in="body",
     *     type="string",
     *     description="The username",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="password",
     *     in="query",
     *     type="string",
     *     description="The password"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="query",
     *     type="string",
     *     description="The language"
     * )
     * 
     * @SWG\Parameter(
     *     name="country",
     *     in="query",
     *     type="string",
     *     description="The country code"
     * )
     * 
     * @SWG\Parameter(
     *     name="city",
     *     in="query",
     *     type="string",
     *     description="The city"
     * )
     * 
     * @SWG\Parameter(
     *     name="whatsapp",
     *     in="query",
     *     type="integer",
     *     description="The whatsapp"
     * )
     * 
     * @SWG\Parameter(
     *     name="code",
     *     in="query",
     *     type="string",
     *     description="The code" 
     * )
     *
     *
     *
     * @SWG\Tag(name="Ambassador")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $ambassador = [];
        $message = "";

        
 
        try {
            $code = 200;
            $error = false;
            $ambassador = $em->getRepository("App:User")->find($id);
 
            if (!is_null($ambassador)) {
                $form = $this->createForm(AmbassadorEditType::class, $ambassador);
                $form->submit($request->request->all());
                //$ambassador->setName($name);
 
                $em->persist($ambassador);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Ambassador - Error: You must to provide fields ambassador or the ambassador id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the ambassador - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $ambassador : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="ambassador_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Ambassador was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the ambassador"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The ambassador ID"
     * )
     *
     * @SWG\Tag(name="Ambassador")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $ambassador = $em->getRepository("App:User")->find($id);

            $tracking = new Tracking();
 
            if (!is_null($ambassador)) {

                $log = str_replace ("-0001-", "2018-", $serializer->serialize($ambassador, "json", SerializationContext::create()->enableMaxDepthChecks() ) );
                
                $tracking->setUser($this->getUser());
                $tracking->setEntityId($ambassador->getId());
                $tracking->setEntity("label_user");
                $tracking->setAction("label_delete");
                $tracking->setName($ambassador->getFirstName()." ".$ambassador->getLastName());
                $tracking->setLog($log);
                $em->persist($tracking);
                $em->flush();
                
                $em->remove($ambassador);
                $em->flush();
 
                $message = "The ambassador was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent ambassador - Error: The ambassador id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current ambassador - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Get("/search/{key}.{_format}", name="ambassador_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets ambassador info based on passed key parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The ambassador with the passed key parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="key",
     *     in="path",
     *     type="string",
     *     description="The ambassador key"
     * )
     *
     *
     * @SWG\Tag(name="Ambassador")
     */
    public function searchAction(Request $request, $key ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $ambassador = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            
            $ambassador = $em->getRepository("App:User")->ambassadorSearch($key);
 
            if (is_null($ambassador)) {
                $code = 500;
                $error = true;
                $message = "The ambassador does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Ambassador - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $ambassador : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/active_ambassador", name="active_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Ambassador was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Ambassador was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="state",
     *     in="body",
     *     type="string",
     *     description="The state",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="query",
     *     type="string",
     *     description="The language",
     * )
     * @SWG\Tag(name="Ambassador")
     */ 

    public function activeambassadorAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
 
            $ambassador = $this->getAmbassador();
            $em = $this->getDoctrine()->getManager();
            $ambassador = $em->getRepository("App:User")->find($ambassador->getId());
            
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the ambassador - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $ambassador : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/show/{id}.{_format}", name="ambassador_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets ambassador info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The ambassador with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Ambassador ID"
     * )
     *
     * @SWG\Tag(name="Ambassador")
     */
    public function showAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $ambassador = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $ambassador_id = $id;
            $ambassador = $em->getRepository("App:User")->find($ambassador_id);
 
            if (is_null($ambassador)) {
                $code = 500;
                $error = true;
                $message = "The Ambassador does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Ambassador- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $ambassador : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/editpassword/{id}.{_format}", name="ambassador_editpassword", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The ambassador was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the ambassador."
     * )
     *
     * @SWG\Parameter(
     *     name="password",
     *     in="path",
     *     type="string",
     *     description="The ambassador password"
     * )
     *
     *
     *
     * @SWG\Tag(name="Ambassador")
     */
    public function editPasswordAction(Request $request, UserPasswordEncoderInterface $encoder, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $ambassador = [];
        $message = "";

        
 
        try {
            $code = 200;
            $error = false;
            $ambassador = $em->getRepository("App:User")->find($id);
 
            if (!is_null($ambassador)) {
                $form = $this->createForm(UserPasswordEditType::class, $ambassador);
                $form->submit($request->request->all());
                $password = $ambassador->getPassword();
 
                $ambassador->setPlainPassword($password);
                $ambassador->setPassword($encoder->encodePassword($ambassador, $password));
    
                $em->persist($ambassador);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Ambassador - Error: You must to provide fields ambassador or the ambassador id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the ambassador - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $ambassador : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/country/{id}.{_format}", name="ambassador_country", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets list ambassadors based on passed ID Country parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The ambassadors with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The country ID"
     * )
     *
     *
     * @SWG\Tag(name="Ambassador")
     */
    public function countryAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $ambassadors = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
  
            $country_id = $id;
            if($country_id == "WITHOUT_NGA"){
                $ambassadors = $em->getRepository('App:User')->userByRoleWithoutCountry('ROLE_EMBASSADOR', $country_id);
            }
            else{
                $ambassadors = $em->getRepository('App:User')->userByRoleCountry('ROLE_EMBASSADOR', $country_id);
            }            
            
  
            if (is_null($ambassadors)) {
                $code = 500;
                $error = true;
                $message = "The country ambassadors does not exist";
            }
  
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the ambassadors country - Error: {$ex->getMessage()}";
        }
  
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $ambassadors : $message,
        ];
  
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('future_ambassador'))));
    }

    /**
     * @Rest\Get("/state/{id}.{_format}", name="ambassador_state", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets ambassador status."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get amssador status."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="Ambassador ID"
     * )
     *
     *
     * @SWG\Tag(name="Ambassador")
     */
    public function stateAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $list = [];
        $message = "";
        $student_id = $id;
        $days_inverval = 366;
        $student_state = "state.inactive";
        $last_graduated_date = "never";
        
 
        try {
            $code = 200;
            $error = false;
 
            $total_graduates = $em->getRepository('App:StudentGroup')->lastMbsGraduatedByEmbassador($id, 'state.approved');
            if($total_graduates > 0 ){
                $current_date = new \DateTime();
                $last_graduated_date = $em->getRepository('App:StudentGroup')->lastMbsGraduatedByEmbassadorDate($id, 'state.approved');

                $init_date  = new \DateTime( $last_graduated_date->format('Y-m-d') );
                $final_date = new \DateTime( $current_date->format('Y-m-d') );

                $interval = date_diff($init_date, $final_date);
                $days_inverval = $interval->format('%a');

            }
          
            if($days_inverval < 365){   
                $student_state = "state.active";
                $course_progress = $em->getRepository('App:Course')->getCourseProgressByRequirements($student_id, "requirement.sa");
            }
            else if($days_inverval > 365 || $total_graduates == 0 ){
                $course_progress = $em->getRepository('App:Course')->getCourseProgressByRequirements($student_id, "requirement.sa");
                if($course_progress['enrolled_days'] > 365 ){
                    $student_state = "state.inactive";

                    $result = $em->getRepository('App:Progress')->deleteProgressByCourse($course_progress['course_id'], $student_id);
                    $result = $em->getRepository('App:Stop')->deleteStopByCourse($course_progress['course_id'], $student_id);
                }
                else if($course_progress['enrolled_days'] == 0){
                    $student_state = "state.inactive";
                    
                }
                else{
                    if($course_progress['progress_percentaje'] >= 100){
                        $student_state = "state.active";
                        $days_inverval = $course_progress['enrolled_days'];
                    }
                    else{
                        $student_state = "state.inactive";
                    }
                }
            }
           

            $data = [
                'state'                 => $student_state,
                'days_interval'         => $days_inverval,
                'last_graduated_date'   => $last_graduated_date,
                'results'               => $course_progress
            ];
            

        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Ambassadors - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Get("/spreadsheet/list", name="ambassador_spreadsheet_list", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets list ambassadors based on passed ID Country parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The ambassadors with the passed ID parameter was not found or doesn't exist."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Ambassador")
     */
    public function spreadsheetListAction(Request $request) {
        $em = $this->getDoctrine()->getManager();
        $ambassadors = $em->getRepository("App:User")->getAmbassadors();
        $spreadsheet = new Spreadsheet();
        
        /* @var $sheet \PhpOffice\PhpSpreadsheet\Writer\Xlsx\Worksheet */
        $sheet = $spreadsheet->getActiveSheet();

        $sheet->getStyle('A1:D2')->getAlignment()->setHorizontal('center');
        $sheet->getStyle('A1:D2')->getFont()->setBold( true );
        $sheet->getStyle('A1:D1')->getFill()->setFillType(\PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID)->getStartColor()->setARGB('C8DAF9');
        $sheet->getStyle('A1:D2')->getAlignment()->setVertical(\PhpOffice\PhpSpreadsheet\Style\Alignment::VERTICAL_CENTER);

        
        $sheet->getDefaultRowDimension()->setRowHeight(20);
        
        $sheet->getColumnDimension('A')->setWidth(40);
        $sheet->getColumnDimension('B')->setWidth(35);
        $sheet->getColumnDimension('C')->setWidth(20);
        $sheet->getColumnDimension('D')->setWidth(20);

        $sheet->setCellValue('A1', 'SUCCESS AMBASSADOR LIST');
        $sheet->setCellValue('A2', 'Name');
        $sheet->setCellValue('B2', 'Email');
        $sheet->setCellValue('C2', 'Country');
        $sheet->setCellValue('D2', 'Code');
      
        $sheet->setTitle("Success Ambassador List");
        $sheet->mergeCells("A1:D1");

        foreach ($ambassadors as $key => $ambassador) {
             $row = $key + 3;
             $sheet->setCellValue('A'.$row, $ambassador->getFirstName(). ' ' .$ambassador->getLastName());
             $sheet->setCellValue('B'.$row, $ambassador->getUserName());
             $sheet->setCellValue('C'.$row, $ambassador->getCountry());
             if($ambassador->getCode() != "undefined"){
                $sheet->setCellValue('D'.$row, $ambassador->getCode());
             }
             
        }

        
        // Crear tu archivo Office 2007 Excel (XLSX Formato)
        $writer = new Xlsx($spreadsheet);
        
        // Crear archivo temporal en el sistema
        $fileName = 'success_ambassador_list.Csv';
        $temp_file = tempnam(sys_get_temp_dir(), $fileName);
        
        // Guardar el archivo de excel en el directorio temporal del sistema
        $writer->save($temp_file);
        
        // Retornar excel como descarga
        return $this->file($temp_file, $fileName, ResponseHeaderBag::DISPOSITION_INLINE);
    }



    public function lastMbsGraduated($id){
        $em = $this->getDoctrine()->getManager();
        $days_inverval = 366;
        $student_id = $id;
        $student_state = "state.inactive";
        $last_graduated_date = "never";        

        $total_graduates = $em->getRepository('App:StudentGroup')->lastMbsGraduatedByEmbassador($id, 'state.approved');
        
        if($total_graduates > 0 ){
            $current_date = new \DateTime();
            $last_graduated_date = $em->getRepository('App:StudentGroup')->lastMbsGraduatedByEmbassadorDate($id, 'state.approved');

            $init_date  = new \DateTime( $last_graduated_date->format('Y-m-d') );
            $final_date = new \DateTime( $current_date->format('Y-m-d') );

            $interval = date_diff($init_date, $final_date);
            $days_inverval = $interval->format('%a');

        }
      
        if($days_inverval < 365){   
            $student_state = "state.active";
            $course_progress = $em->getRepository('App:Course')->getCourseProgressByRequirements($student_id, "requirement.sa");
        }
        else if($days_inverval > 365 || $total_graduates == 0 ){
            $course_progress = $em->getRepository('App:Course')->getCourseProgressByRequirements($student_id, "requirement.sa");
            if($course_progress['enrolled_days'] > 365 ){
                $student_state = "state.inactive";

                $result = $em->getRepository('App:Progress')->deleteProgressByCourse($course_progress['course_id'], $student_id);
                $result = $em->getRepository('App:Stop')->deleteStopByCourse($course_progress['course_id'], $student_id);
            }
            else if($course_progress['enrolled_days'] == 0){
                $student_state = "state.inactive";
                
            }
            else{
                if($course_progress['progress_percentaje'] >= 100){
                    $student_state = "state.active";
                    $days_inverval = $course_progress['enrolled_days'];
                }
                else{
                    $student_state = "state.inactive";
                }
            }
        }
       

        $data = [
            'state'                 => $student_state,
            'days_interval'         => $days_inverval,
            'last_graduated_date'   => $last_graduated_date,
            'results'               => $course_progress
        ];
        
        return $data;
    }

   
 
}