<?php

 
namespace App\Controller;
 
use App\Entity\Answer;
use App\Entity\ProgramMbs;
use App\Form\AnswerType;
use App\Form\AnswerEditType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Nelmio\UserDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
 
/**
 * Class AnswerController
 *
 * @Route("/answer")
 */
class AnswerController extends FOSRestController
{
    
    /**
     * @Rest\Get("/", name="answer_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all answers."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all answers."
     * )
     *   
     *
     *
     * @SWG\Tag(name="Answer")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $answers = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $area_codes = '[
                {
                    "alpha2": "DZ",
                    "alpha3": "DZA",
                    "code": "012",
                    "name": "Algeria"
                },
                {
                    "alpha2": "AO",
                    "alpha3": "AGO",
                    "code": "024",
                    "name": "Angola"
                },
                {
                    "alpha2": "BJ",
                    "alpha3": "BEN",
                    "code": "204",
                    "name": "Benin"
                },
                {
                    "alpha2": "BW",
                    "alpha3": "BWA",
                    "code": "072",
                    "name": "Botswana"
                },
                {
                    "alpha2": "BF",
                    "alpha3": "BFA",
                    "code": "854",
                    "name": "Burkina Faso"
                },
                {
                    "alpha2": "BI",
                    "alpha3": "BDI",
                    "code": "108",
                    "name": "Burundi"
                },
                {
                    "alpha2": "CM",
                    "alpha3": "CMR",
                    "code": "120",
                    "name": "Cameroon"
                },
                {
                    "alpha2": "CV",
                    "alpha3": "CPV",
                    "code": "132",
                    "name": "Cape Verde"
                },
                {
                    "alpha2": "CF",
                    "alpha3": "CAF",
                    "code": "140",
                    "name": "Central African Republic"
                },
                {
                    "alpha2": "TD",
                    "alpha3": "TCD",
                    "code": "148",
                    "name": "Chad"
                },
                {
                    "alpha2": "KM",
                    "alpha3": "COM",
                    "code": "174",
                    "name": "Comoros"
                },
                {
                    "alpha2": "CG",
                    "alpha3": "COG",
                    "code": "178",
                    "name": "Congo"
                },
                {
                    "alpha2": "CD",
                    "alpha3": "COD",
                    "code": "180",
                    "name": "Congo, the Democratic Republic of the"
                },
                {
                    "alpha2": "CI",
                    "alpha3": "CIV",
                    "code": "384",
                    "name": "Cote DIvoire"
                },
                {
                    "alpha2": "DJ",
                    "alpha3": "DJI",
                    "code": "262",
                    "name": "Djibouti"
                },
                {
                    "alpha2": "EG",
                    "alpha3": "EGY",
                    "code": "818",
                    "name": "Egypt"
                },
                {
                    "alpha2": "GQ",
                    "alpha3": "GNQ",
                    "code": "226",
                    "name": "Equatorial Guinea"
                },
                {
                    "alpha2": "ER",
                    "alpha3": "ERI",
                    "code": "232",
                    "name": "Eritrea"
                },
                {
                    "alpha2": "ET",
                    "alpha3": "ETH",
                    "code": "231",
                    "name": "Ethiopia"
                },
                {
                    "alpha2": "GA",
                    "alpha3": "GAB",
                    "code": "266",
                    "name": "Gabon"
                },
                {
                    "alpha2": "GM",
                    "alpha3": "GMB",
                    "code": "270",
                    "name": "Gambia"
                },
                {
                    "alpha2": "GH",
                    "alpha3": "GHA",
                    "code": "288",
                    "name": "Ghana"
                },
                {
                    "alpha2": "GN",
                    "alpha3": "GIN",
                    "code": "324",
                    "name": "Guinea"
                },
                {
                    "alpha2": "GW",
                    "alpha3": "GNB",
                    "code": "624",
                    "name": "Guinea-Bissau"
                },
                {
                    "alpha2": "KE",
                    "alpha3": "KEN",
                    "code": "404",
                    "name": "Kenya"
                },
                {
                    "alpha2": "LS",
                    "alpha3": "LSO",
                    "code": "426",
                    "name": "Lesotho"
                },
                {
                    "alpha2": "LR",
                    "alpha3": "LBR",
                    "code": "430",
                    "name": "Liberia"
                },
                {
                    "alpha2": "LY",
                    "alpha3": "LBY",
                    "code": "434",
                    "name": "Libyan Arab Jamahiriya"
                },
                {
                    "alpha2": "MG",
                    "alpha3": "MDG",
                    "code": "450",
                    "name": "Madagascar"
                },
                {
                    "alpha2": "MW",
                    "alpha3": "MWI",
                    "code": "454",
                    "name": "Malawi"
                },
                {
                    "alpha2": "ML",
                    "alpha3": "MLI",
                    "code": "466",
                    "name": "Mali"
                },
                {
                    "alpha2": "MR",
                    "alpha3": "MRT",
                    "code": "478",
                    "name": "Mauritania"
                },
                {
                    "alpha2": "MU",
                    "alpha3": "MUS",
                    "code": "480",
                    "name": "Mauritius"
                },
                {
                    "alpha2": "YT",
                    "alpha3": "MYT",
                    "code": "175",
                    "name": "Mayotte"
                },
                {
                    "alpha2": "MA",
                    "alpha3": "MAR",
                    "code": "504",
                    "name": "Morocco"
                },
                {
                    "alpha2": "MZ",
                    "alpha3": "MOZ",
                    "code": "508",
                    "name": "Mozambique"
                },
                {
                    "alpha2": "NA",
                    "alpha3": "NAM",
                    "code": "516",
                    "name": "Namibia"
                },
                {
                    "alpha2": "NE",
                    "alpha3": "NER",
                    "code": "562",
                    "name": "Niger"
                },
                {
                    "alpha2": "NG",
                    "alpha3": "NGA",
                    "code": "566",
                    "name": "Nigeria"
                },
                {
                    "alpha2": "RE",
                    "alpha3": "REU",
                    "code": "638",
                    "name": "Reunion"
                },
                {
                    "alpha2": "RW",
                    "alpha3": "RWA",
                    "code": "646",
                    "name": "Rwanda"
                },
                {
                    "alpha2": "SH",
                    "alpha3": "SHN",
                    "code": "654",
                    "name": "Saint Helena"
                },
                {
                    "alpha2": "ST",
                    "alpha3": "STP",
                    "code": "678",
                    "name": "Sao Tome and Principe"
                },
                {
                    "alpha2": "SN",
                    "alpha3": "SEN",
                    "code": "686",
                    "name": "Senegal"
                },
                {
                    "alpha2": "SC",
                    "alpha3": "SYC",
                    "code": "690",
                    "name": "Seychelles"
                },
                {
                    "alpha2": "SL",
                    "alpha3": "SLE",
                    "code": "694",
                    "name": "Sierra Leone"
                },
                {
                    "alpha2": "SO",
                    "alpha3": "SOM",
                    "code": "706",
                    "name": "Somalia"
                },
                {
                    "alpha2": "ZA",
                    "alpha3": "ZAF",
                    "code": "710",
                    "name": "South Africa"
                },
                {
                    "alpha2": "SS",
                    "alpha3": "SSD",
                    "code": "728",
                    "name": "South Sudan"
                },
                {
                    "alpha2": "SD",
                    "alpha3": "SDN",
                    "code": "729",
                    "name": "Sudan"
                },
                {
                    "alpha2": "SZ",
                    "alpha3": "SWZ",
                    "code": "748",
                    "name": "Swaziland"
                },
                {
                    "alpha2": "TZ",
                    "alpha3": "TZA",
                    "code": "834",
                    "name": "Tanzania"
                },
                {
                    "alpha2": "TG",
                    "alpha3": "TGO",
                    "code": "768",
                    "name": "Togo"
                },
                {
                    "alpha2": "TN",
                    "alpha3": "TUN",
                    "code": "788",
                    "name": "Tunisia"
                },
                {
                    "alpha2": "UG",
                    "alpha3": "UGA",
                    "code": "800",
                    "name": "Uganda"
                },
                {
                    "alpha2": "EH",
                    "alpha3": "ESH",
                    "code": "732",
                    "name": "Western Sahara"
                },
                {
                    "alpha2": "ZM",
                    "alpha3": "ZMB",
                    "code": "894",
                    "name": "Zambia"
                },
                {
                    "alpha2": "ZW",
                    "alpha3": "ZWE",
                    "code": "716",
                    "name": "Zimbabwe"
                },
                {
                    "alpha2": "AF",
                    "alpha3": "AFG",
                    "code": "004",
                    "name": "Afghanistan"
                },
                {
                    "alpha2": "AM",
                    "alpha3": "ARM",
                    "code": "051",
                    "name": "Armenia"
                },
                {
                    "alpha2": "AZ",
                    "alpha3": "AZE",
                    "code": "031",
                    "name": "Azerbaijan"
                },
                {
                    "alpha2": "BH",
                    "alpha3": "BHR",
                    "code": "048",
                    "name": "Bahrain"
                },
                {
                    "alpha2": "BD",
                    "alpha3": "BGD",
                    "code": "050",
                    "name": "Bangladesh"
                },
                {
                    "alpha2": "BT",
                    "alpha3": "BTN",
                    "code": "064",
                    "name": "Bhutan"
                },
                {
                    "alpha2": "IO",
                    "alpha3": "IOT",
                    "code": "086",
                    "name": "British Indian Ocean Territory"
                },
                {
                    "alpha2": "BN",
                    "alpha3": "BRN",
                    "code": "096",
                    "name": "Brunei Darussalam"
                },
                {
                    "alpha2": "KH",
                    "alpha3": "KHM",
                    "code": "116",
                    "name": "Cambodia"
                },
                {
                    "alpha2": "CN",
                    "alpha3": "CHN",
                    "code": "156",
                    "name": "China"
                },
                {
                    "alpha2": "CX",
                    "alpha3": "CXR",
                    "code": "162",
                    "name": "Christmas Island"
                },
                {
                    "alpha2": "CC",
                    "alpha3": "CCK",
                    "code": "166",
                    "name": "Cocos (Keeling) Islands"
                },
                {
                    "alpha2": "GE",
                    "alpha3": "GEO",
                    "code": "268",
                    "name": "Georgia"
                },
                {
                    "alpha2": "HK",
                    "alpha3": "HKG",
                    "code": "344",
                    "name": "Hong Kong"
                },
                {
                    "alpha2": "IN",
                    "alpha3": "IND",
                    "code": "356",
                    "name": "India"
                },
                {
                    "alpha2": "ID",
                    "alpha3": "IDN",
                    "code": "360",
                    "name": "Indonesia"
                },
                {
                    "alpha2": "IR",
                    "alpha3": "IRN",
                    "code": "364",
                    "name": "Iran, Islamic Republic of"
                },
                {
                    "alpha2": "IQ",
                    "alpha3": "IRQ",
                    "code": "368",
                    "name": "Iraq"
                },
                {
                    "alpha2": "JP",
                    "alpha3": "JPN",
                    "code": "392",
                    "name": "Japan"
                },
                {
                    "alpha2": "JO",
                    "alpha3": "JOR",
                    "code": "400",
                    "name": "Jordan"
                },
                {
                    "alpha2": "KZ",
                    "alpha3": "KAZ",
                    "code": "398",
                    "name": "Kazakhstan"
                },
                {
                    "alpha2": "KP",
                    "alpha3": "PRK",
                    "code": "408",
                    "name": "North Korea"
                },
                {
                    "alpha2": "KR",
                    "alpha3": "KOR",
                    "code": "410",
                    "name": "South Korea"
                },
                {
                    "alpha2": "KW",
                    "alpha3": "KWT",
                    "code": "414",
                    "name": "Kuwait"
                },
                {
                    "alpha2": "KG",
                    "alpha3": "KGZ",
                    "code": "417",
                    "name": "Kyrgyzstan"
                },
                {
                    "alpha2": "LB",
                    "alpha3": "LBN",
                    "code": "422",
                    "name": "Lebanon"
                },
                {
                    "alpha2": "MO",
                    "alpha3": "MAC",
                    "code": "446",
                    "name": "Macao"
                },
                {
                    "alpha2": "MY",
                    "alpha3": "MYS",
                    "code": "458",
                    "name": "Malaysia"
                },
                {
                    "alpha2": "MV",
                    "alpha3": "MDV",
                    "code": "462",
                    "name": "Maldives"
                },
                {
                    "alpha2": "MN",
                    "alpha3": "MNG",
                    "code": "496",
                    "name": "Mongolia"
                },
                {
                    "alpha2": "MM",
                    "alpha3": "MMR",
                    "code": "104",
                    "name": "Myanmar"
                },
                {
                    "alpha2": "NP",
                    "alpha3": "NPL",
                    "code": "524",
                    "name": "Nepal"
                },
                {
                    "alpha2": "OM",
                    "alpha3": "OMN",
                    "code": "512",
                    "name": "Oman"
                },
                {
                    "alpha2": "PK",
                    "alpha3": "PAK",
                    "code": "586",
                    "name": "Pakistan"
                },
                {
                    "alpha2": "PS",
                    "alpha3": "PSE",
                    "code": "275",
                    "name": "Palestinian Territory, Occupied"
                },
                {
                    "alpha2": "PH",
                    "alpha3": "PHL",
                    "code": "608",
                    "name": "Philippines"
                },
                {
                    "alpha2": "QA",
                    "alpha3": "QAT",
                    "code": "634",
                    "name": "Qatar"
                },
                {
                    "alpha2": "SA",
                    "alpha3": "SAU",
                    "code": "682",
                    "name": "Saudi Arabia"
                },
                {
                    "alpha2": "SG",
                    "alpha3": "SGP",
                    "code": "702",
                    "name": "Singapore"
                },
                {
                    "alpha2": "LK",
                    "alpha3": "LKA",
                    "code": "144",
                    "name": "Sri Lanka"
                },
                {
                    "alpha2": "SY",
                    "alpha3": "SYR",
                    "code": "760",
                    "name": "Syrian Arab Republic"
                },
                {
                    "alpha2": "TW",
                    "alpha3": "TWN",
                    "code": "158",
                    "name": "Taiwan"
                },
                {
                    "alpha2": "TJ",
                    "alpha3": "TJK",
                    "code": "762",
                    "name": "Tajikistan"
                },
                {
                    "alpha2": "TH",
                    "alpha3": "THA",
                    "code": "764",
                    "name": "Thailand"
                },
                {
                    "alpha2": "TR",
                    "alpha3": "TUR",
                    "code": "792",
                    "name": "Turkey"
                },
                {
                    "alpha2": "TM",
                    "alpha3": "TKM",
                    "code": "795",
                    "name": "Turkmenistan"
                },
                {
                    "alpha2": "AE",
                    "alpha3": "ARE",
                    "code": "784",
                    "name": "United Arab Emirates"
                },
                {
                    "alpha2": "UZ",
                    "alpha3": "UZB",
                    "code": "860",
                    "name": "Uzbekistan"
                },
                {
                    "alpha2": "VN",
                    "alpha3": "VNM",
                    "code": "704",
                    "name": "Viet Nam"
                },
                {
                    "alpha2": "YE",
                    "alpha3": "YEM",
                    "code": "887",
                    "name": "Yemen"
                },
                {
                    "alpha2": "AX",
                    "alpha3": "ALA",
                    "code": "248",
                    "name": "Åland Islands"
                },
                {
                    "alpha2": "AL",
                    "alpha3": "ALB",
                    "code": "008",
                    "name": "Albania"
                },
                {
                    "alpha2": "AD",
                    "alpha3": "AND",
                    "code": "020",
                    "name": "Andorra"
                },
                {
                    "alpha2": "AT",
                    "alpha3": "AUT",
                    "code": "040",
                    "name": "Austria"
                },
                {
                    "alpha2": "BY",
                    "alpha3": "BLR",
                    "code": "112",
                    "name": "Belarus"
                },
                {
                    "alpha2": "BE",
                    "alpha3": "BEL",
                    "code": "056",
                    "name": "Belgium"
                },
                {
                    "alpha2": "BA",
                    "alpha3": "BIH",
                    "code": "070",
                    "name": "Bosnia and Herzegovina"
                },
                {
                    "alpha2": "BG",
                    "alpha3": "BGR",
                    "code": "100",
                    "name": "Bulgaria"
                },
                {
                    "alpha2": "HR",
                    "alpha3": "HRV",
                    "code": "191",
                    "name": "Croatia"
                },
                {
                    "alpha2": "CY",
                    "alpha3": "CYP",
                    "code": "196",
                    "name": "Cyprus"
                },
                {
                    "alpha2": "CZ",
                    "alpha3": "CZE",
                    "code": "203",
                    "name": "Czech Republic"
                },
                {
                    "alpha2": "DK",
                    "alpha3": "DNK",
                    "code": "208",
                    "name": "Denmark"
                },
                {
                    "alpha2": "EE",
                    "alpha3": "EST",
                    "code": "233",
                    "name": "Estonia"
                },
                {
                    "alpha2": "FO",
                    "alpha3": "FRO",
                    "code": "234",
                    "name": "Faroe Islands"
                },
                {
                    "alpha2": "FI",
                    "alpha3": "FIN",
                    "code": "246",
                    "name": "Finland"
                },
                {
                    "alpha2": "FR",
                    "alpha3": "FRA",
                    "code": "250",
                    "name": "France"
                },
                {
                    "alpha2": "GE",
                    "alpha3": "GEO",
                    "code": "268",
                    "name": "Georgia"
                },
                {
                    "alpha2": "DE",
                    "alpha3": "DEU",
                    "code": "276",
                    "name": "Germany"
                },
                {
                    "alpha2": "GI",
                    "alpha3": "GIB",
                    "code": "292",
                    "name": "Gibraltar"
                },
                {
                    "alpha2": "GR",
                    "alpha3": "GRC",
                    "code": "300",
                    "name": "Greece"
                },
                {
                    "alpha2": "VA",
                    "alpha3": "VAT",
                    "code": "336",
                    "name": "Holy See (Vatican City State)"
                },
                {
                    "alpha2": "HU",
                    "alpha3": "HUN",
                    "code": "348",
                    "name": "Hungary"
                },
                {
                    "alpha2": "IS",
                    "alpha3": "ISL",
                    "code": "352",
                    "name": "Iceland"
                },
                {
                    "alpha2": "IE",
                    "alpha3": "IRL",
                    "code": "372",
                    "name": "Ireland"
                },
                {
                    "alpha2": "IL",
                    "alpha3": "ISR",
                    "code": "376",
                    "name": "Israel"
                },
                {
                    "alpha2": "IT",
                    "alpha3": "ITA",
                    "code": "380",
                    "name": "Italy"
                },
                {
                    "alpha2": "LV",
                    "alpha3": "LVA",
                    "code": "428",
                    "name": "Latvia"
                },
                {
                    "alpha2": "LI",
                    "alpha3": "LIE",
                    "code": "438",
                    "name": "Liechtenstein"
                },
                {
                    "alpha2": "LT",
                    "alpha3": "LTU",
                    "code": "440",
                    "name": "Lithuania"
                },
                {
                    "alpha2": "LU",
                    "alpha3": "LUX",
                    "code": "442",
                    "name": "Luxembourg"
                },
                {
                    "alpha2": "MK",
                    "alpha3": "MKD",
                    "code": "807",
                    "name": "Macedonia, the Former Yugoslav Republic of"
                },
                {
                    "alpha2": "MT",
                    "alpha3": "MLT",
                    "code": "470",
                    "name": "Malta"
                },
                {
                    "alpha2": "MD",
                    "alpha3": "MDA",
                    "code": "498",
                    "name": "Moldova, Republic of"
                },
                {
                    "alpha2": "MC",
                    "alpha3": "MCO",
                    "code": "492",
                    "name": "Monaco"
                },
                {
                    "alpha2": "ME",
                    "alpha3": "MNE",
                    "code": "499",
                    "name": "Montenegro"
                },
                {
                    "alpha2": "NL",
                    "alpha3": "NLD",
                    "code": "528",
                    "name": "Netherlands"
                },
                {
                    "alpha2": "NO",
                    "alpha3": "NOR",
                    "code": "578",
                    "name": "Norway"
                },
                {
                    "alpha2": "PL",
                    "alpha3": "POL",
                    "code": "616",
                    "name": "Poland"
                },
                {
                    "alpha2": "PT",
                    "alpha3": "PRT",
                    "code": "620",
                    "name": "Portugal"
                },
                {
                    "alpha2": "RO",
                    "alpha3": "ROU",
                    "code": "642",
                    "name": "Romania"
                },
                {
                    "alpha2": "RU",
                    "alpha3": "RUS",
                    "code": "643",
                    "name": "Russian Federation"
                },
                {
                    "alpha2": "SM",
                    "alpha3": "SMR",
                    "code": "674",
                    "name": "San Marino"
                },
                {
                    "alpha2": "RS",
                    "alpha3": "SRB",
                    "code": "688",
                    "name": "Serbia"
                },
                {
                    "alpha2": "SK",
                    "alpha3": "SVK",
                    "code": "703",
                    "name": "Slovakia"
                },
                {
                    "alpha2": "SI",
                    "alpha3": "SVN",
                    "code": "705",
                    "name": "Slovenia"
                },
                {
                    "alpha2": "ES",
                    "alpha3": "ESP",
                    "code": "724",
                    "name": "Spain"
                },
                {
                    "alpha2": "SE",
                    "alpha3": "SWE",
                    "code": "752",
                    "name": "Sweden"
                },
                {
                    "alpha2": "CH",
                    "alpha3": "CHE",
                    "code": "756",
                    "name": "Switzerland"
                },
                {
                    "alpha2": "TR",
                    "alpha3": "TUR",
                    "code": "792",
                    "name": "Turkey"
                },
                {
                    "alpha2": "UA",
                    "alpha3": "UKR",
                    "code": "804",
                    "name": "Ukraine"
                },
                {
                    "alpha2": "GB",
                    "alpha3": "GBR",
                    "code": "826",
                    "name": "United Kingdom"
                },
                {
                    "alpha2": "AI",
                    "alpha3": "AIA",
                    "code": "660",
                    "name": "Anguilla"
                },
                {
                    "alpha2": "AG",
                    "alpha3": "ATG",
                    "code": "028",
                    "name": "Antigua and Barbuda"
                },
                {
                    "alpha2": "AW",
                    "alpha3": "ABW",
                    "code": "533",
                    "name": "Aruba"
                },
                {
                    "alpha2": "BS",
                    "alpha3": "BHS",
                    "code": "044",
                    "name": "Bahamas"
                },
                {
                    "alpha2": "BB",
                    "alpha3": "BRB",
                    "code": "052",
                    "name": "Barbados"
                },
                {
                    "alpha2": "BZ",
                    "alpha3": "BLZ",
                    "code": "084",
                    "name": "Belize"
                },
                {
                    "alpha2": "BM",
                    "alpha3": "BMU",
                    "code": "060",
                    "name": "Bermuda"
                },
                {
                    "alpha2": "VG",
                    "alpha3": "VGB",
                    "code": "092",
                    "name": "Virgin Islands, British"
                },
                {
                    "alpha2": "CA",
                    "alpha3": "CAN",
                    "code": "124",
                    "name": "Canada"
                },
                {
                    "alpha2": "KY",
                    "alpha3": "CYM",
                    "code": "136",
                    "name": "Cayman Islands"
                },
                {
                    "alpha2": "CR",
                    "alpha3": "CRI",
                    "code": "188",
                    "name": "Costa Rica"
                },
                {
                    "alpha2": "CU",
                    "alpha3": "CUB",
                    "code": "192",
                    "name": "Cuba"
                },
                {
                    "alpha2": "DM",
                    "alpha3": "DMA",
                    "code": "212",
                    "name": "Dominica"
                },
                {
                    "alpha2": "DO",
                    "alpha3": "DOM",
                    "code": "214",
                    "name": "Dominican Republic"
                },
                {
                    "alpha2": "SV",
                    "alpha3": "SLV",
                    "code": "222",
                    "name": "El Salvador"
                },
                {
                    "alpha2": "GL",
                    "alpha3": "GRL",
                    "code": "304",
                    "name": "Greenland"
                },
                {
                    "alpha2": "GD",
                    "alpha3": "GRD",
                    "code": "308",
                    "name": "Grenada"
                },
                {
                    "alpha2": "GP",
                    "alpha3": "GLP",
                    "code": "312",
                    "name": "Guadeloupe"
                },
                {
                    "alpha2": "GT",
                    "alpha3": "GTM",
                    "code": "320",
                    "name": "Guatemala"
                },
                {
                    "alpha2": "HT",
                    "alpha3": "HTI",
                    "code": "332",
                    "name": "Haiti"
                },
                {
                    "alpha2": "HN",
                    "alpha3": "HND",
                    "code": "340",
                    "name": "Honduras"
                },
                {
                    "alpha2": "JM",
                    "alpha3": "JAM",
                    "code": "388",
                    "name": "Jamaica"
                },
                {
                    "alpha2": "MQ",
                    "alpha3": "MTQ",
                    "code": "474",
                    "name": "Martinique"
                },
                {
                    "alpha2": "MX",
                    "alpha3": "MEX",
                    "code": "484",
                    "name": "Mexico"
                },
                {
                    "alpha2": "NI",
                    "alpha3": "NIC",
                    "code": "558",
                    "name": "Nicaragua"
                },
                {
                    "alpha2": "PA",
                    "alpha3": "PAN",
                    "code": "591",
                    "name": "Panama"
                },
                {
                    "alpha2": "PR",
                    "alpha3": "PRI",
                    "code": "630",
                    "name": "Puerto Rico"
                },
                {
                    "alpha2": "KN",
                    "alpha3": "KNA",
                    "code": "659",
                    "name": "Saint Kitts and Nevis"
                },
                {
                    "alpha2": "LC",
                    "alpha3": "LCA",
                    "code": "662",
                    "name": "Saint Lucia"
                },
                {
                    "alpha2": "PM",
                    "alpha3": "SPM",
                    "code": "666",
                    "name": "Saint Pierre and Miquelon"
                },
                {
                    "alpha2": "VC",
                    "alpha3": "VCT",
                    "code": "670",
                    "name": "Saint Vincent and the Grenadines"
                },
                {
                    "alpha2": "BL",
                    "alpha3": "BLM",
                    "code": "652",
                    "name": "Saint Barthélemy"
                },
                {
                    "alpha2": "TT",
                    "alpha3": "TTO",
                    "code": "780",
                    "name": "Trinidad and Tobago"
                },
                {
                    "alpha2": "TC",
                    "alpha3": "TCA",
                    "code": "796",
                    "name": "Turks and Caicos Islands"
                },
                {
                    "alpha2": "US",
                    "alpha3": "USA",
                    "code": "840",
                    "name": "United States of America"
                },
                {
                    "alpha2": "VI",
                    "alpha3": "VIR",
                    "code": "850",
                    "name": "Virgin Islands, U.S."
                },
                {
                    "alpha2": "AS",
                    "alpha3": "ASM",
                    "code": "016",
                    "name": "American Samoa"
                },
                {
                    "alpha2": "AU",
                    "alpha3": "AUS",
                    "code": "036",
                    "name": "Australia"
                },
                {
                    "alpha2": "CK",
                    "alpha3": "COK",
                    "code": "184",
                    "name": "Cook Islands"
                },
                {
                    "alpha2": "FJ",
                    "alpha3": "FJI",
                    "code": "242",
                    "name": "Fiji"
                },
                {
                    "alpha2": "PF",
                    "alpha3": "PYF",
                    "code": "258",
                    "name": "French Polynesia"
                },
                {
                    "alpha2": "GU",
                    "alpha3": "GUM",
                    "code": "316",
                    "name": "Guam"
                },
                {
                    "alpha2": "KI",
                    "alpha3": "KIR",
                    "code": "296",
                    "name": "Kiribati"
                },
                {
                    "alpha2": "MH",
                    "alpha3": "MHL",
                    "code": "584",
                    "name": "Marshall Islands"
                },
                {
                    "alpha2": "FM",
                    "alpha3": "FSM",
                    "code": "583",
                    "name": "Micronesia, Federated States of"
                },
                {
                    "alpha2": "NR",
                    "alpha3": "NRU",
                    "code": "520",
                    "name": "Nauru"
                },
                {
                    "alpha2": "NC",
                    "alpha3": "NCL",
                    "code": "540",
                    "name": "New Caledonia"
                },
                {
                    "alpha2": "NZ",
                    "alpha3": "NZL",
                    "code": "554",
                    "name": "New Zealand"
                },
                {
                    "alpha2": "NU",
                    "alpha3": "NIU",
                    "code": "570",
                    "name": "Niue"
                },
                {
                    "alpha2": "NF",
                    "alpha3": "NFK",
                    "code": "574",
                    "name": "Norfolk Island"
                },
                {
                    "alpha2": "MP",
                    "alpha3": "MNP",
                    "code": "580",
                    "name": "Northern Mariana Islands"
                },
                {
                    "alpha2": "PW",
                    "alpha3": "PLW",
                    "code": "585",
                    "name": "Palau"
                },
                {
                    "alpha2": "PG",
                    "alpha3": "PNG",
                    "code": "598",
                    "name": "Papua New Guinea"
                },
                {
                    "alpha2": "PN",
                    "alpha3": "PCN",
                    "code": "612",
                    "name": "Pitcairn"
                },
                {
                    "alpha2": "WS",
                    "alpha3": "WSM",
                    "code": "882",
                    "name": "Samoa"
                },
                {
                    "alpha2": "SB",
                    "alpha3": "SLB",
                    "code": "090",
                    "name": "Solomon Islands"
                },
                {
                    "alpha2": "TL",
                    "alpha3": "TLS",
                    "code": "626",
                    "name": "Timor-Leste"
                },
                {
                    "alpha2": "TO",
                    "alpha3": "TON",
                    "code": "776",
                    "name": "Tonga"
                },
                {
                    "alpha2": "VU",
                    "alpha3": "VUT",
                    "code": "548",
                    "name": "Vanuatu"
                },
                {
                    "alpha2": "AR",
                    "alpha3": "ARG",
                    "code": "032",
                    "name": "Argentina"
                },
                {
                    "alpha2": "BO",
                    "alpha3": "BOL",
                    "code": "068",
                    "name": "Bolivia"
                },
                {
                    "alpha2": "BR",
                    "alpha3": "BRA",
                    "code": "076",
                    "name": "Brazil"
                },
                {
                    "alpha2": "CL",
                    "alpha3": "CHL",
                    "code": "152",
                    "name": "Chile"
                },
                {
                    "alpha2": "CO",
                    "alpha3": "COL",
                    "code": "170",
                    "name": "Colombia"
                },
                {
                    "alpha2": "EC",
                    "alpha3": "ECU",
                    "code": "218",
                    "name": "Ecuador"
                },
                {
                    "alpha2": "FK",
                    "alpha3": "FLK",
                    "code": "238",
                    "name": "Falkland Islands (Malvinas)"
                },
                {
                    "alpha2": "GF",
                    "alpha3": "GUF",
                    "code": "254",
                    "name": "French Guiana"
                },
                {
                    "alpha2": "GY",
                    "alpha3": "GUY",
                    "code": "328",
                    "name": "Guyana"
                },
                {
                    "alpha2": "PY",
                    "alpha3": "PRY",
                    "code": "600",
                    "name": "Paraguay"
                },
                {
                    "alpha2": "PE",
                    "alpha3": "PER",
                    "code": "604",
                    "name": "Peru"
                },
                {
                    "alpha2": "UY",
                    "alpha3": "URY",
                    "code": "858",
                    "name": "Uruguay"
                },
                {
                    "alpha2": "VE",
                    "alpha3": "VEN",
                    "code": "862",
                    "name": "Venezuela"
                }
            ]';

            $codes = '[
                {
                "name": "Afghanistan",
                "dial_code": "+93",
                "code": "AF"
                },
                {
                "name": "Aland Islands",
                "dial_code": "+358",
                "code": "AX"
                },
                {
                "name": "Albania",
                "dial_code": "+355",
                "code": "AL"
                },
                {
                "name": "Algeria",
                "dial_code": "+213",
                "code": "DZ"
                },
                {
                "name": "AmericanSamoa",
                "dial_code": "+1684",
                "code": "AS"
                },
                {
                "name": "Andorra",
                "dial_code": "+376",
                "code": "AD"
                },
                {
                "name": "Angola",
                "dial_code": "+244",
                "code": "AO"
                },
                {
                "name": "Anguilla",
                "dial_code": "+1264",
                "code": "AI"
                },
                {
                "name": "Antarctica",
                "dial_code": "+672",
                "code": "AQ"
                },
                {
                "name": "Antigua and Barbuda",
                "dial_code": "+1268",
                "code": "AG"
                },
                {
                "name": "Argentina",
                "dial_code": "+54",
                "code": "AR"
                },
                {
                "name": "Armenia",
                "dial_code": "+374",
                "code": "AM"
                },
                {
                "name": "Aruba",
                "dial_code": "+297",
                "code": "AW"
                },
                {
                "name": "Australia",
                "dial_code": "+61",
                "code": "AU"
                },
                {
                "name": "Austria",
                "dial_code": "+43",
                "code": "AT"
                },
                {
                "name": "Azerbaijan",
                "dial_code": "+994",
                "code": "AZ"
                },
                {
                "name": "Bahamas",
                "dial_code": "+1242",
                "code": "BS"
                },
                {
                "name": "Bahrain",
                "dial_code": "+973",
                "code": "BH"
                },
                {
                "name": "Bangladesh",
                "dial_code": "+880",
                "code": "BD"
                },
                {
                "name": "Barbados",
                "dial_code": "+1246",
                "code": "BB"
                },
                {
                "name": "Belarus",
                "dial_code": "+375",
                "code": "BY"
                },
                {
                "name": "Belgium",
                "dial_code": "+32",
                "code": "BE"
                },
                {
                "name": "Belize",
                "dial_code": "+501",
                "code": "BZ"
                },
                {
                "name": "Benin",
                "dial_code": "+229",
                "code": "BJ"
                },
                {
                "name": "Bermuda",
                "dial_code": "+1441",
                "code": "BM"
                },
                {
                "name": "Bhutan",
                "dial_code": "+975",
                "code": "BT"
                },
                {
                "name": "Bolivia, Plurinational State of",
                "dial_code": "+591",
                "code": "BO"
                },
                {
                "name": "Bosnia and Herzegovina",
                "dial_code": "+387",
                "code": "BA"
                },
                {
                "name": "Botswana",
                "dial_code": "+267",
                "code": "BW"
                },
                {
                "name": "Brazil",
                "dial_code": "+55",
                "code": "BR"
                },
                {
                "name": "British Indian Ocean Territory",
                "dial_code": "+246",
                "code": "IO"
                },
                {
                "name": "Brunei Darussalam",
                "dial_code": "+673",
                "code": "BN"
                },
                {
                "name": "Bulgaria",
                "dial_code": "+359",
                "code": "BG"
                },
                {
                "name": "Burkina Faso",
                "dial_code": "+226",
                "code": "BF"
                },
                {
                "name": "Burundi",
                "dial_code": "+257",
                "code": "BI"
                },
                {
                "name": "Cambodia",
                "dial_code": "+855",
                "code": "KH"
                },
                {
                "name": "Cameroon",
                "dial_code": "+237",
                "code": "CM"
                },
                {
                "name": "Canada",
                "dial_code": "+1",
                "code": "CA"
                },
                {
                "name": "Cape Verde",
                "dial_code": "+238",
                "code": "CV"
                },
                {
                "name": "Cayman Islands",
                "dial_code": "+ 345",
                "code": "KY"
                },
                {
                "name": "Central African Republic",
                "dial_code": "+236",
                "code": "CF"
                },
                {
                "name": "Chad",
                "dial_code": "+235",
                "code": "TD"
                },
                {
                "name": "Chile",
                "dial_code": "+56",
                "code": "CL"
                },
                {
                "name": "China",
                "dial_code": "+86",
                "code": "CN"
                },
                {
                "name": "Christmas Island",
                "dial_code": "+61",
                "code": "CX"
                },
                {
                "name": "Cocos (Keeling) Islands",
                "dial_code": "+61",
                "code": "CC"
                },
                {
                "name": "Colombia",
                "dial_code": "+57",
                "code": "CO"
                },
                {
                "name": "Comoros",
                "dial_code": "+269",
                "code": "KM"
                },
                {
                "name": "Congo",
                "dial_code": "+242",
                "code": "CG"
                },
                {
                "name": "Congo, The Democratic Republic of the Congo",
                "dial_code": "+243",
                "code": "CD"
                },
                {
                "name": "Cook Islands",
                "dial_code": "+682",
                "code": "CK"
                },
                {
                "name": "Costa Rica",
                "dial_code": "+506",
                "code": "CR"
                },
                {
                "name": "Cote dIvoire",
                "dial_code": "+225",
                "code": "CI"
                },
                {
                "name": "Croatia",
                "dial_code": "+385",
                "code": "HR"
                },
                {
                "name": "Cuba",
                "dial_code": "+53",
                "code": "CU"
                },
                {
                "name": "Cyprus",
                "dial_code": "+357",
                "code": "CY"
                },
                {
                "name": "Czech Republic",
                "dial_code": "+420",
                "code": "CZ"
                },
                {
                "name": "Denmark",
                "dial_code": "+45",
                "code": "DK"
                },
                {
                "name": "Djibouti",
                "dial_code": "+253",
                "code": "DJ"
                },
                {
                "name": "Dominica",
                "dial_code": "+1767",
                "code": "DM"
                },
                {
                "name": "Dominican Republic",
                "dial_code": "+1849",
                "code": "DO"
                },
                {
                "name": "Ecuador",
                "dial_code": "+593",
                "code": "EC"
                },
                {
                "name": "Egypt",
                "dial_code": "+20",
                "code": "EG"
                },
                {
                "name": "El Salvador",
                "dial_code": "+503",
                "code": "SV"
                },
                {
                "name": "Equatorial Guinea",
                "dial_code": "+240",
                "code": "GQ"
                },
                {
                "name": "Eritrea",
                "dial_code": "+291",
                "code": "ER"
                },
                {
                "name": "Estonia",
                "dial_code": "+372",
                "code": "EE"
                },
                {
                "name": "Ethiopia",
                "dial_code": "+251",
                "code": "ET"
                },
                {
                "name": "Falkland Islands (Malvinas)",
                "dial_code": "+500",
                "code": "FK"
                },
                {
                "name": "Faroe Islands",
                "dial_code": "+298",
                "code": "FO"
                },
                {
                "name": "Fiji",
                "dial_code": "+679",
                "code": "FJ"
                },
                {
                "name": "Finland",
                "dial_code": "+358",
                "code": "FI"
                },
                {
                "name": "France",
                "dial_code": "+33",
                "code": "FR"
                },
                {
                "name": "French Guiana",
                "dial_code": "+594",
                "code": "GF"
                },
                {
                "name": "French Polynesia",
                "dial_code": "+689",
                "code": "PF"
                },
                {
                "name": "Gabon",
                "dial_code": "+241",
                "code": "GA"
                },
                {
                "name": "Gambia",
                "dial_code": "+220",
                "code": "GM"
                },
                {
                "name": "Georgia",
                "dial_code": "+995",
                "code": "GE"
                },
                {
                "name": "Germany",
                "dial_code": "+49",
                "code": "DE"
                },
                {
                "name": "Ghana",
                "dial_code": "+233",
                "code": "GH"
                },
                {
                "name": "Gibraltar",
                "dial_code": "+350",
                "code": "GI"
                },
                {
                "name": "Greece",
                "dial_code": "+30",
                "code": "GR"
                },
                {
                "name": "Greenland",
                "dial_code": "+299",
                "code": "GL"
                },
                {
                "name": "Grenada",
                "dial_code": "+1473",
                "code": "GD"
                },
                {
                "name": "Guadeloupe",
                "dial_code": "+590",
                "code": "GP"
                },
                {
                "name": "Guam",
                "dial_code": "+1671",
                "code": "GU"
                },
                {
                "name": "Guatemala",
                "dial_code": "+502",
                "code": "GT"
                },
                {
                "name": "Guernsey",
                "dial_code": "+44",
                "code": "GG"
                },
                {
                "name": "Guinea",
                "dial_code": "+224",
                "code": "GN"
                },
                {
                "name": "Guinea-Bissau",
                "dial_code": "+245",
                "code": "GW"
                },
                {
                "name": "Guyana",
                "dial_code": "+595",
                "code": "GY"
                },
                {
                "name": "Haiti",
                "dial_code": "+509",
                "code": "HT"
                },
                {
                "name": "Holy See (Vatican City State)",
                "dial_code": "+379",
                "code": "VA"
                },
                {
                "name": "Honduras",
                "dial_code": "+504",
                "code": "HN"
                },
                {
                "name": "Hong Kong",
                "dial_code": "+852",
                "code": "HK"
                },
                {
                "name": "Hungary",
                "dial_code": "+36",
                "code": "HU"
                },
                {
                "name": "Iceland",
                "dial_code": "+354",
                "code": "IS"
                },
                {
                "name": "India",
                "dial_code": "+91",
                "code": "IN"
                },
                {
                "name": "Indonesia",
                "dial_code": "+62",
                "code": "ID"
                },
                {
                "name": "Iran",
                "dial_code": "+98",
                "code": "IR"
                },
                {
                "name": "Iraq",
                "dial_code": "+964",
                "code": "IQ"
                },
                {
                "name": "Ireland",
                "dial_code": "+353",
                "code": "IE"
                },
                {
                "name": "Isle of Man",
                "dial_code": "+44",
                "code": "IM"
                },
                {
                "name": "Israel",
                "dial_code": "+972",
                "code": "IL"
                },
                {
                "name": "Italy",
                "dial_code": "+39",
                "code": "IT"
                },
                {
                "name": "Jamaica",
                "dial_code": "+1876",
                "code": "JM"
                },
                {
                "name": "Japan",
                "dial_code": "+81",
                "code": "JP"
                },
                {
                "name": "Jersey",
                "dial_code": "+44",
                "code": "JE"
                },
                {
                "name": "Jordan",
                "dial_code": "+962",
                "code": "JO"
                },
                {
                "name": "Kazakhstan",
                "dial_code": "+77",
                "code": "KZ"
                },
                {
                "name": "Kenya",
                "dial_code": "+254",
                "code": "KE"
                },
                {
                "name": "Kiribati",
                "dial_code": "+686",
                "code": "KI"
                },
                {
                "name": "Korea, Democratic People Republic of Korea",
                "dial_code": "+850",
                "code": "KP"
                },
                {
                "name": "Korea, Republic of South Korea",
                "dial_code": "+82",
                "code": "KR"
                },
                {
                "name": "Kuwait",
                "dial_code": "+965",
                "code": "KW"
                },
                {
                "name": "Kyrgyzstan",
                "dial_code": "+996",
                "code": "KG"
                },
                {
                "name": "Laos",
                "dial_code": "+856",
                "code": "LA"
                },
                {
                "name": "Latvia",
                "dial_code": "+371",
                "code": "LV"
                },
                {
                "name": "Lebanon",
                "dial_code": "+961",
                "code": "LB"
                },
                {
                "name": "Lesotho",
                "dial_code": "+266",
                "code": "LS"
                },
                {
                "name": "Liberia",
                "dial_code": "+231",
                "code": "LR"
                },
                {
                "name": "Libyan Arab Jamahiriya",
                "dial_code": "+218",
                "code": "LY"
                },
                {
                "name": "Liechtenstein",
                "dial_code": "+423",
                "code": "LI"
                },
                {
                "name": "Lithuania",
                "dial_code": "+370",
                "code": "LT"
                },
                {
                "name": "Luxembourg",
                "dial_code": "+352",
                "code": "LU"
                },
                {
                "name": "Macao",
                "dial_code": "+853",
                "code": "MO"
                },
                {
                "name": "Macedonia",
                "dial_code": "+389",
                "code": "MK"
                },
                {
                "name": "Madagascar",
                "dial_code": "+261",
                "code": "MG"
                },
                {
                "name": "Malawi",
                "dial_code": "+265",
                "code": "MW"
                },
                {
                "name": "Malaysia",
                "dial_code": "+60",
                "code": "MY"
                },
                {
                "name": "Maldives",
                "dial_code": "+960",
                "code": "MV"
                },
                {
                "name": "Mali",
                "dial_code": "+223",
                "code": "ML"
                },
                {
                "name": "Malta",
                "dial_code": "+356",
                "code": "MT"
                },
                {
                "name": "Marshall Islands",
                "dial_code": "+692",
                "code": "MH"
                },
                {
                "name": "Martinique",
                "dial_code": "+596",
                "code": "MQ"
                },
                {
                "name": "Mauritania",
                "dial_code": "+222",
                "code": "MR"
                },
                {
                "name": "Mauritius",
                "dial_code": "+230",
                "code": "MU"
                },
                {
                "name": "Mayotte",
                "dial_code": "+262",
                "code": "YT"
                },
                {
                "name": "Mexico",
                "dial_code": "+52",
                "code": "MX"
                },
                {
                "name": "Micronesia, Federated States of Micronesia",
                "dial_code": "+691",
                "code": "FM"
                },
                {
                "name": "Moldova",
                "dial_code": "+373",
                "code": "MD"
                },
                {
                "name": "Monaco",
                "dial_code": "+377",
                "code": "MC"
                },
                {
                "name": "Mongolia",
                "dial_code": "+976",
                "code": "MN"
                },
                {
                "name": "Montenegro",
                "dial_code": "+382",
                "code": "ME"
                },
                {
                "name": "Montserrat",
                "dial_code": "+1664",
                "code": "MS"
                },
                {
                "name": "Morocco",
                "dial_code": "+212",
                "code": "MA"
                },
                {
                "name": "Mozambique",
                "dial_code": "+258",
                "code": "MZ"
                },
                {
                "name": "Myanmar",
                "dial_code": "+95",
                "code": "MM"
                },
                {
                "name": "Namibia",
                "dial_code": "+264",
                "code": "NA"
                },
                {
                "name": "Nauru",
                "dial_code": "+674",
                "code": "NR"
                },
                {
                "name": "Nepal",
                "dial_code": "+977",
                "code": "NP"
                },
                {
                "name": "Netherlands",
                "dial_code": "+31",
                "code": "NL"
                },
                {
                "name": "Netherlands Antilles",
                "dial_code": "+599",
                "code": "AN"
                },
                {
                "name": "New Caledonia",
                "dial_code": "+687",
                "code": "NC"
                },
                {
                "name": "New Zealand",
                "dial_code": "+64",
                "code": "NZ"
                },
                {
                "name": "Nicaragua",
                "dial_code": "+505",
                "code": "NI"
                },
                {
                "name": "Niger",
                "dial_code": "+227",
                "code": "NE"
                },
                {
                "name": "Nigeria",
                "dial_code": "+234",
                "code": "NG"
                },
                {
                "name": "Niue",
                "dial_code": "+683",
                "code": "NU"
                },
                {
                "name": "Norfolk Island",
                "dial_code": "+672",
                "code": "NF"
                },
                {
                "name": "Northern Mariana Islands",
                "dial_code": "+1670",
                "code": "MP"
                },
                {
                "name": "Norway",
                "dial_code": "+47",
                "code": "NO"
                },
                {
                "name": "Oman",
                "dial_code": "+968",
                "code": "OM"
                },
                {
                "name": "Pakistan",
                "dial_code": "+92",
                "code": "PK"
                },
                {
                "name": "Palau",
                "dial_code": "+680",
                "code": "PW"
                },
                {
                "name": "Palestinian Territory, Occupied",
                "dial_code": "+970",
                "code": "PS"
                },
                {
                "name": "Panama",
                "dial_code": "+507",
                "code": "PA"
                },
                {
                "name": "Papua New Guinea",
                "dial_code": "+675",
                "code": "PG"
                },
                {
                "name": "Paraguay",
                "dial_code": "+595",
                "code": "PY"
                },
                {
                "name": "Peru",
                "dial_code": "+51",
                "code": "PE"
                },
                {
                "name": "Philippines",
                "dial_code": "+63",
                "code": "PH"
                },
                {
                "name": "Pitcairn",
                "dial_code": "+872",
                "code": "PN"
                },
                {
                "name": "Poland",
                "dial_code": "+48",
                "code": "PL"
                },
                {
                "name": "Portugal",
                "dial_code": "+351",
                "code": "PT"
                },
                {
                "name": "Puerto Rico",
                "dial_code": "+1939",
                "code": "PR"
                },
                {
                "name": "Qatar",
                "dial_code": "+974",
                "code": "QA"
                },
                {
                "name": "Romania",
                "dial_code": "+40",
                "code": "RO"
                },
                {
                "name": "Russia",
                "dial_code": "+7",
                "code": "RU"
                },
                {
                "name": "Rwanda",
                "dial_code": "+250",
                "code": "RW"
                },
                {
                "name": "Reunion",
                "dial_code": "+262",
                "code": "RE"
                },
                {
                "name": "Saint Barthelemy",
                "dial_code": "+590",
                "code": "BL"
                },
                {
                "name": "Saint Helena",
                "dial_code": "+290",
                "code": "SH"
                },
                {
                "name": "Saint Kitts and Nevis",
                "dial_code": "+1869",
                "code": "KN"
                },
                {
                "name": "Saint Lucia",
                "dial_code": "+1758",
                "code": "LC"
                },
                {
                "name": "Saint Martin",
                "dial_code": "+590",
                "code": "MF"
                },
                {
                "name": "Saint Pierre and Miquelon",
                "dial_code": "+508",
                "code": "PM"
                },
                {
                "name": "Saint Vincent and the Grenadines",
                "dial_code": "+1784",
                "code": "VC"
                },
                {
                "name": "Samoa",
                "dial_code": "+685",
                "code": "WS"
                },
                {
                "name": "San Marino",
                "dial_code": "+378",
                "code": "SM"
                },
                {
                "name": "Sao Tome and Principe",
                "dial_code": "+239",
                "code": "ST"
                },
                {
                "name": "Saudi Arabia",
                "dial_code": "+966",
                "code": "SA"
                },
                {
                "name": "Senegal",
                "dial_code": "+221",
                "code": "SN"
                },
                {
                "name": "Serbia",
                "dial_code": "+381",
                "code": "RS"
                },
                {
                "name": "Seychelles",
                "dial_code": "+248",
                "code": "SC"
                },
                {
                "name": "Sierra Leone",
                "dial_code": "+232",
                "code": "SL"
                },
                {
                "name": "Singapore",
                "dial_code": "+65",
                "code": "SG"
                },
                {
                "name": "Slovakia",
                "dial_code": "+421",
                "code": "SK"
                },
                {
                "name": "Slovenia",
                "dial_code": "+386",
                "code": "SI"
                },
                {
                "name": "Solomon Islands",
                "dial_code": "+677",
                "code": "SB"
                },
                {
                "name": "Somalia",
                "dial_code": "+252",
                "code": "SO"
                },
                {
                "name": "South Africa",
                "dial_code": "+27",
                "code": "ZA"
                },
                {
                "name": "South Sudan",
                "dial_code": "+211",
                "code": "SS"
                },
                {
                "name": "South Georgia and the South Sandwich Islands",
                "dial_code": "+500",
                "code": "GS"
                },
                {
                "name": "Spain",
                "dial_code": "+34",
                "code": "ES"
                },
                {
                "name": "Sri Lanka",
                "dial_code": "+94",
                "code": "LK"
                },
                {
                "name": "Sudan",
                "dial_code": "+249",
                "code": "SD"
                },
                {
                "name": "Suriname",
                "dial_code": "+597",
                "code": "SR"
                },
                {
                "name": "Svalbard and Jan Mayen",
                "dial_code": "+47",
                "code": "SJ"
                },
                {
                "name": "Swaziland",
                "dial_code": "+268",
                "code": "SZ"
                },
                {
                "name": "Sweden",
                "dial_code": "+46",
                "code": "SE"
                },
                {
                "name": "Switzerland",
                "dial_code": "+41",
                "code": "CH"
                },
                {
                "name": "Syrian Arab Republic",
                "dial_code": "+963",
                "code": "SY"
                },
                {
                "name": "Taiwan",
                "dial_code": "+886",
                "code": "TW"
                },
                {
                "name": "Tajikistan",
                "dial_code": "+992",
                "code": "TJ"
                },
                {
                "name": "Tanzania",
                "dial_code": "+255",
                "code": "TZ"
                },
                {
                "name": "Thailand",
                "dial_code": "+66",
                "code": "TH"
                },
                {
                "name": "Timor-Leste",
                "dial_code": "+670",
                "code": "TL"
                },
                {
                "name": "Togo",
                "dial_code": "+228",
                "code": "TG"
                },
                {
                "name": "Tokelau",
                "dial_code": "+690",
                "code": "TK"
                },
                {
                "name": "Tonga",
                "dial_code": "+676",
                "code": "TO"
                },
                {
                "name": "Trinidad and Tobago",
                "dial_code": "+1868",
                "code": "TT"
                },
                {
                "name": "Tunisia",
                "dial_code": "+216",
                "code": "TN"
                },
                {
                "name": "Turkey",
                "dial_code": "+90",
                "code": "TR"
                },
                {
                "name": "Turkmenistan",
                "dial_code": "+993",
                "code": "TM"
                },
                {
                "name": "Turks and Caicos Islands",
                "dial_code": "+1649",
                "code": "TC"
                },
                {
                "name": "Tuvalu",
                "dial_code": "+688",
                "code": "TV"
                },
                {
                "name": "Uganda",
                "dial_code": "+256",
                "code": "UG"
                },
                {
                "name": "Ukraine",
                "dial_code": "+380",
                "code": "UA"
                },
                {
                "name": "United Arab Emirates",
                "dial_code": "+971",
                "code": "AE"
                },
                {
                "name": "United Kingdom",
                "dial_code": "+44",
                "code": "GB"
                },
                {
                "name": "United States",
                "dial_code": "+1",
                "code": "US"
                },
                {
                "name": "Uruguay",
                "dial_code": "+598",
                "code": "UY"
                },
                {
                "name": "Uzbekistan",
                "dial_code": "+998",
                "code": "UZ"
                },
                {
                "name": "Vanuatu",
                "dial_code": "+678",
                "code": "VU"
                },
                {
                "name": "Venezuela",
                "dial_code": "+58",
                "code": "VE"
                },
                {
                "name": "Vietnam",
                "dial_code": "+84",
                "code": "VN"
                },
                {
                "name": "Virgin Islands, British",
                "dial_code": "+1284",
                "code": "VG"
                },
                {
                "name": "Virgin Islands, U.S.",
                "dial_code": "+1340",
                "code": "VI"
                },
                {
                "name": "Wallis and Futuna",
                "dial_code": "+681",
                "code": "WF"
                },
                {
                "name": "Yemen",
                "dial_code": "+967",
                "code": "YE"
                },
                {
                "name": "Zambia",
                "dial_code": "+260",
                "code": "ZM"
                },
                {
                "name": "Zimbabwe",
                "dial_code": "+263",
                "code": "ZW"
                }
                ]';



            $array = json_decode( $area_codes, true );
            $codes_array = json_decode( $codes, true );
            $list = [];

            foreach ($array as $country) {
                
                foreach ($codes_array as $cod) {
                    if($cod['code'] == $country['alpha2']){
                        $list[] = [
                            "id"=> $country['alpha3']." ".$cod["dial_code"],
                             "name"=> $country['name'],
                              "displayText"=> $country['alpha3']." ".$cod["dial_code"],
                               "locale"=> 'en-US',
                                "englishName"=> $cod["dial_code"],
                                 "flag"=> $country['alpha2']."Flag"
                        ];
                    }
                }
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Answer - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $list : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Post("/new/list", name="answer_new_list")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Answer was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Answer was not successfully registered"
     * )
     *
     * 
     * 
     * @SWG\Parameter(
     *     name="principle_id",
     *     in="body",
     *     type="integer",
     *     description="The Principle id of the new answer",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="answer_list",
     *     in="body",
     *     type="string",
     *     description="answer list array",
     *     schema={}
     * )
     * 
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="selected",
     *     in="body",
     *     type="string",
     *     description="selected item",
     *     schema={}
     * )
     * @SWG\Parameter(
     *     name="content",
     *     in="body",
     *     type="string",
     *     description="The content",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="position",
     *     in="body",
     *     type="string",
     *     description="The position of answer",
     *     schema={}
     * )
     *     
     * 
     * @SWG\Tag(name="Answer")
     */ 

    public function newListAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";
        $principle_id= $request->request->get("principle_id");

        $nam = "name";

        $answer_array = $request->request->get($nam);

        $answer=new ProgramMbs();

        $answer->setPaperwork4(json_decode($answer_array));
        //Create a form
     
        $principle = [];
        //$answer->setPrinciple($principle);

        

        try {
            $code = 200;
            $error = false;

            if (!is_null($principle)) {
                //$form = $this->createForm(AnswerEditType::class, $answer);
                //$form->submit($request->request->all());
    
                //$em->persist($answer);
                //$em->flush();
    
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Answer - Error: You must to provide fields user or the Answer id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Answer - Error: {$ex->getMessage()}";
        }

        
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $answer : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }


    /**
     * @Rest\Put("/edit/{id}.{_format}", name="Answer_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The Answer was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the Answer."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Answer ID"
     * )
     *
     * @SWG\Tag(name="Answer")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $answer = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $answer = $em->getRepository("App:Answer")->find($id);
 
            if (!is_null($answer)) {
                $form = $this->createForm(AnswerEditType::class, $answer);
                $form->submit($request->request->all());
 
                $em->persist($answer);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Answer - Error: You must to provide fields user or the Answer id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the Answer - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $answer : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/edit/position/{id}.{_format}", name="Answer_edit_position", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The Answer was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the Answer."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Answer ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="position",
     *     in="path",
     *     type="string",
     *     description="new position"
     * )
     *     
     *
     * @SWG\Tag(name="Answer")
     */
    public function editPositionAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $answer = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $answer = $em->getRepository("App:Answer")->find($id);
 
            if (!is_null($answer)) {
                $answer->setPosition($request->request->get("position"));
 
                $em->persist($answer);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Answer - Error: You must to provide fields user or the Answer id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the Answer - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $answer : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/show/{id}.{_format}", name="answer_show_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Answer info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Answer with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Answer ID"
     * )
     *
     * @SWG\Tag(name="Answer")
     */
    public function showAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $answer = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $answer_id = $id;
            $answer = $em->getRepository("App:Answer")->find($answer_id);
 
            if (is_null($answer)) {
                $code = 500;
                $error = true;
                $message = "The Answer does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Answer- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $answer : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/show/list/{id}.{_format}", name="answer_show_list_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all Answers of Principle Id Parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The list Answers the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Principle ID"
     * )
     *
     * @SWG\Tag(name="Answer")
     */
    public function showListAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $answer = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $principle_id = $id;
            $principle = $em->getRepository("App:Principle")->find($principle_id);
            $answers = $em->getRepository("App:Answer")->findBy(array("principle" => $principle_id), array("position" => "ASC"));
 
            if (is_null($principle)) {
                $code = 500;
                $error = true;
                $message = "The Principle does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Answer- Error: {$ex->getMessage()}";
        }

        $data = [
            "answers"  => $answers,
            "principle" => $principle 
        ];
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="Answer_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Answer was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the Answer"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Answer ID"
     * )
     *
     * @SWG\Tag(name="Answer")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $answer = $em->getRepository("App:Answer")->find($id);
 
            if (!is_null($answer)) {
                $em->remove($answer);
                $em->flush();
 
                $message = "The Answer was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent Answer - Error: The Answer id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current Answer - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }
 
}