<?php
 
namespace App\Controller;
 
use App\Entity\User;
use App\Entity\Category;
use App\Form\CategoryType;
use App\Form\UserPasswordEditType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\AdminDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class CategoryController
 *
 * @Route("/category")
 */
class CategoryController extends FOSRestController
{
    
 
    /**
     * @Rest\Get("/", name="category_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all categories."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all category categories."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Category")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $categories = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $categories = $em->getRepository("App:Category")->findAll(array(), array("language" => 'DESC', 'position' => 'ASC'));
 
            if (is_null($categories)) {
                $categories = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Admins - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $categories : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/showlist/{language}.{_format}", name="category_show_list_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets category info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The category with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="lang",
     *     in="path",
     *     type="string",
     *     description="The Category language"
     * )
     * 
     *
     * @SWG\Tag(name="Category")
     */
    public function showListAction(Request $request, $language ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $category = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
            
            if($language == "ALL"){
                $category = $em->getRepository("App:Category")->findBy(array(), array('position' => 'ASC'));
            }
            else{
                $category = $em->getRepository("App:Category")->findBy(array('language' => $language), array('position' => 'ASC'));
            }
            
 
            if (is_null($category)) {
                $code = 500;
                $error = true;
                $message = "The Category does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Category- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $category : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/show/available", name="category_show_available_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets category info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The category with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="string",
     *     description="The Category language"
     * )
     * 
     * @SWG\Parameter(
     *     name="role",
     *     in="body",
     *     type="string",
     *     description="The User Role"
     * )
     * 
     *
     * @SWG\Tag(name="Category")
     */
    public function showAvailableAction(Request $request ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $category = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
            $role = $request->request->get('role');
            $language = $request->request->get('language');
 
            $category = $em->getRepository("App:Category")->getAvailableCategories($role, $language);
 
            if (is_null($category)) {
                $code = 500;
                $error = true;
                $message = "The Category does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Category- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $category : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

 

    /**
     * @Rest\Post("/new", name="category_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="User was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="User was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The category name",
     *     schema={}
     * )
     *    
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     *     
     *    
     * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="array",
     *     description="The language assigned to this category",
     *     schema={}
     * ) 
     * 
     * @SWG\Parameter(
     *     name="picture",
     *     in="body",
     *     type="array",
     *     description="The picture assigned to this category",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="roles",
     *     in="body",
     *     type="array",
     *     description="The roles assigned to this category",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="position",
     *     in="body",
     *     type="integer",
     *     description="The resource position",
     *     schema={}
     * )
     * 
     *       
     *
     * @SWG\Tag(name="Category")
     */ 
    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $roles = explode(',', $request->request->get('roles'));
 
        $message = "";

        $category = new Category();
        //Create a form
        $form=$this->createForm(CategoryType::class, $category);
        $form->submit($request->request->all());
       
        try {
            $code = 200;
            $error = false;
            $category->setRoles($roles);
            $em->persist($category);
            $em->flush();
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the category - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $category : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }


    /**
     * @Rest\Get("/show/{id}.{_format}", name="category_show_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets category info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The category with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Category ID"
     * )
     * 
     *
     * @SWG\Tag(name="Category")
     */
    public function showAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $category = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $category_id = $id;
            $category = $em->getRepository("App:Category")->find($category_id);
 
            if (is_null($category)) {
                $code = 500;
                $error = true;
                $message = "The Category does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Category- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $category : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="category_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The category was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the category."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The category ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The category name",
     *     schema={}
     * )
     *    
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     *     
     *    
     * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="array",
     *     description="The language assigned to this category",
     *     schema={}
     * ) 
     * 
     * @SWG\Parameter(
     *     name="picture",
     *     in="body",
     *     type="array",
     *     description="The picture assigned to this category",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="roles",
     *     in="body",
     *     type="array",
     *     description="The roles assigned to this category",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="position",
     *     in="body",
     *     type="integer",
     *     description="The resource position",
     *     schema={}
     * )
     *
     * 
     * @SWG\Tag(name="Category")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $roles = explode(',', $request->request->get('roles'));
        $message = "";
        

        try {
            $code = 200;
            $error = false;
            $category = $em->getRepository("App:Category")->find($id);
 
            if (!is_null($category)) {
                $form = $this->createForm(CategoryType::class, $category);
                $form->submit($request->request->all()); 
                
                $category->setRoles($roles);
                $em->persist($category);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Admin - Error: You must to provide fields category or the category id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the category - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $category : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Put("/edit/position/{id}.{_format}", name="category_edit_position", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The category was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the category."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The category ID"
     * )
     * 
     * 
     * @SWG\Parameter(
     *     name="position",
     *     in="body",
     *     type="integer",
     *     description="The resource position",
     *     schema={}
     * )
     *
     * 
     * @SWG\Tag(name="Category")
     */
    public function editPositionAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $position = $request->request->get('position');
        $message = "";
        

        try {
            $code = 200;
            $error = false;
            $category = $em->getRepository("App:Category")->find($id);
 
            if (!is_null($category)) {
                
                $category->setPosition($position);
                $em->persist($category);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Admin - Error: You must to provide fields category or the category id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the category - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $category : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

   

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="category_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="resource category was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the category"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The category ID"
     * )
     *
     * @SWG\Tag(name="Category")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $category = $em->getRepository("App:Category")->find($id);
 
            if (!is_null($category)) {
                $em->remove($category);
                $em->flush();
 
                $message = "The category was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent category - Error: The category id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current category - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

}