<?php
namespace App\Controller;
 
use App\Entity\User;
use App\Entity\Task;
use App\Form\UserType;
use App\Form\UserEditType;
use Doctrine\Common\Collections\ArrayCollection;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\UserDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class CertificateController
 *
 * @Route("/contract")
 */
class ContractController extends FOSRestController
{
    
  
    /**
     * @Rest\Get("/ambassador/es/{id}.{_format}", name="ambassador_es_contract", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets students of group info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The students with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Group ID"
     * )
     *
     * @SWG\Tag(name="Contract")
     */
    public function contractEsAction(Request $request, $id ) {

      $em = $this->getDoctrine()->getManager(); 

      $ambassador = $em->getRepository('App:User')->find($id);
      if(is_null($ambassador->getContractDate())){
        $ambassador->setContractDate(new \DateTime('now', (new \DateTimeZone('America/New_York'))));
        $em->persist($ambassador);
        $em->flush();
      }

      $pdf = $this->get('white_october.tcpdf.public')->create('horizontal', PDF_UNIT, PDF_PAGE_FORMAT, true, 'UTF-8', false);
      
      $pdf->SetAuthor('Interweave Solutions');
      $pdf->SetTitle(('MBS Contract'));
      $pdf->SetSubject('MBS Contract');
      $pdf->setFontSubsetting(true);

      
      $pdf->SetFont("minionc", '', 8);


        $html = '<h2></h2>
        <table border="0"  >
            <tr>
                <td colspan="8" align="right" style="color:black;text-align:center;font-weight:bold;font-size:30pt;height:60pt;"></td>
            </tr>
            <tr>
                <td colspan="8" align="center" style="color:black;text-align:center;font-weight:bold;font-size:14pt;height:22pt;">ACUERDO DE CONTRATO ENTRE INTERWEAVE SOLUTIONS Y </td>
            </tr>
            <tr>
                <td colspan="8" align="center" style="color:black;text-align:center;font-weight:bold;font-size:14pt;height:1pt;">'.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).'</td>
            </tr>         

        </table>';

        $html2 = '
        <table border="0" >          
            <tr>
                <td colspan="2" align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold;>Entre las partes oficiales de este documento, a saber: Dean H. Curtis, con identificación de pasaporte
                estadounidense Nº 561402486, con residencia y domicilio en la ciudad de Provo, Utah, quien actúa en nombre y representación de la organización INTERWEAVE SOLUTIONS, con residencia principal de
                la organización en Provo, Utah, Estados Unidos, quien de ahora en adelante y a todos los efectos de este contrato será conocida simplemente como INTERWEAVE; y la otra parte '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).', , mayor de edad, con
                residencia y domicilio en la ciudad de '.$ambassador->getCity().', '.$this->getParameter($this->getParameter($ambassador->getCountry())).',
                , identificada con la documentación de ciudadanía '.$ambassador->getIdnumber().' expedida en '.$this->getParameter($this->getParameter($ambassador->getCountry())).',  que actúa en nombre propio y con representación legal, que a
                partir de ahora y a todos los efectos del presente contrato se denominará simplemente '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).'.
                </td>
            </tr> 
               

        </table>';

        $html3 = '<h2></h2>
        <table border="0"  >          
            <tr>
                <td colspan="8" align="center" style="color:black;text-align:center;font-weight:bold;font-size:14pt;height:22pt;">CONSIDERACIONES:</td>
            </tr>               

        </table>';

        $html4 = '
        <table border="0" >         
            
            <tr>
                <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' ha completado y presentado honesta y minuciosamente los requisitos
                establecidos por Interweave para convertirse en Embajador de Éxito, incluyendo la certificación en el
                curso MBS, la certificación en el curso de Embajador de Éxito, la enseñanza y el entrenamiento de por
                lo menos un grupo de MBS, el pago de los honorarios aplicables a Interweave, y cualquier otro requisito
                especificado previamente por Interweave.
                </td>               
            </tr>       
            <tr>
                <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' ,  con el apoyo de INTERWEAVE, ofrecerá el programa MBS (MASTER OF
                BUSINESS IN THE STREETS) cuyo objetivo principal es mejorar la calidad de vida de las personas en
                condiciones vulnerables mediante la promoción de ideas de negocio y el fortalecimiento de las empresas
                existentes, llevando así a las personas a la autosuficiencia.                  
                </td>               
            </tr>
            <tr>
                <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' , con el apoyo de INTERWEAVE, capacitará a grupos de personas, en las regiones
                de '.$this->getParameter($this->getParameter($ambassador->getCountry())).' para ayudarles a ser autosuficientes en las àreas de negocios, hogar y comunidad.                  
                </td>               
            </tr>
            <tr>
                <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">4.</td>
                <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' , buscará fortalecer el tejido social de la comunidad en las regiones de
                '.$this->getParameter($this->getParameter($ambassador->getCountry())).' a través de programas educativos de autosuficiencia, facilitando la creación de ideas de
                negocios y el fortalecimiento de las empresas actuales para que sean sostenibles y competitivas. 
                                 
                </td>               
            </tr> 
            <tr>
                <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">5.</td>
                <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' , e INTERWEAVE, entiendan y consideran que los funcionarios de los
                gobiernos locales y otras organizaciones, tanto públicas como privadas, también se esfurezan por lograr
                esos mismo objetivos y consideren firmemente la posibilidad de crear asociaciones contratadas y trabajar
                en colaboración con esas entidades.                  
                </td>               
            </tr>
            <tr>
                <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">6.</td>
                <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' , e INTERWEAVE han identificado elementos similares de cooperación
                dentro de sus propias organizaciones para desarrollar una cooperación entre las organizaciones,
                reconociendo que ningunas de las partes está acutando como empleado legal de la otra. Están de
                acuerdo en que es beneficioso para ambas organizaciones aunar esfuerzos y desarrollar mecanismos de
                cooperación y apoyo interinstitucional para los propósitos comunes de ambas organizaciones.                    
                </td>               
            </tr>
            <tr>
                <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">7.</td>
                <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que los derechos y materiales de Programa MBS, no pueden ser usados sin la autorización de
                INTERWEAVE.                   
                </td>               
            </tr>
        </table>';

        $html5 = '<h2></h2>
        <table border="0"  >          
            <tr>
                <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:13pt;height:22pt;">Teniendo en cuenta las consideraciones anteriores, las partes se comprometen a respetar los
                acuerdos y a regirse por las siguientes cláusulas: </td>
            </tr>               

        </table>';




          // add a page
          $resolution= array(248, 350);
          $pdf->SetMargins(20, 20, 20, true);
          $pdf->AddPage('P', $resolution);

          // get the current page break margin
          $bMargin = $pdf->getBreakMargin();
          // get current auto-page-break mode
          $auto_page_break = $pdf->getAutoPageBreak();
          // disable auto-page-break
          $pdf->SetAutoPageBreak(false, 0);
          // set bacground image


            $img_file = $this->container->getparameter('kernel.project_dir').'/web/img/contract_template.jpg';
            $pdf->Image($img_file, 0, 0, 248, 350, '', '', '', false, 600, '', false, false, 0);
         

          

          
          // restore auto-page-break status
          $pdf->SetAutoPageBreak($auto_page_break, $bMargin);
          // set the starting point for the page content
          $pdf->setPageMark();


          // Print a text
          // Print a text
          $pdf->writeHTML($html, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html2, true, false, true, false, '');
          $pdf->SetFont("minionc", '', 8);
          $pdf->writeHTML($html3, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html4, true, false, true, false, '');
          $pdf->writeHTML($html5, true, false, true, false, '');
          $pdf->SetFont("minionc", '', 8);

          // add a page
          $resolution= array(248, 350);
          $pdf->SetMargins(40, 20, 30, true);
          $pdf->AddPage('P', $resolution);

          // get the current page break margin
          $bMargin = $pdf->getBreakMargin();
          // get current auto-page-break mode
          $auto_page_break = $pdf->getAutoPageBreak();
          // disable auto-page-break
          $pdf->SetAutoPageBreak(false, 0);
          // set bacground image

          $img_file = $this->container->getparameter('kernel.project_dir').'/web/img/contract_template.jpg';
          $pdf->Image($img_file, 0, 0, 248, 350, '', '', '', false, 600, '', false, false, 0);

          $html6 = '
            <table border="0">
                <tr>
                    <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:30pt;height:60pt;"></td>
                </tr>
                <tr>
                    <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">PRIMERO: PROPÓSITO DEL CONTRATO:  </td>
                </tr>                   

            </table>';

          $html7 = '
          <table border="0"  >          
              <tr>
                  <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:13pt;height:80pt;">El propósito general de este contrato es establecer
                  las acciones, esfuerzos, habilidades y conocimientos necesarios para desarrollar mejor los
                  NEGOCIOS, CASAS y COMUNIDADES. Esto ayudará a mejorar la calidad de vida de las
                  poblaciones vulnerables de '.$this->getParameter($this->getParameter($ambassador->getCountry())).'.  Los temas de capacitación incluyen la creación y
                  el mejoramiento de negocios sostenibles, el mejoramiento de la vida familiar y del hogar, y la
                  participación en iniciativas de desarrollo comunitario.  </td>
              </tr>               
  
          </table>';

          $html8 = '
            <table border="0">
                <tr>
                    <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">SEGUNDO: OBLIGACIONES ESPECÍFICAS DE CADA PARTE                    
                    </td>
                </tr>    
                <tr>
                    <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">A. EN NOMBRE DE INTERWEAVE: 
                    </td>
                </tr>               
            </table>';

          $html9 = '
            <table border="0" >         
                
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Proporcionar una certificación oficial y autorizada a
                    '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' como Embajador de
                    Éxito.
                    </td>               
                </tr>       
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Transferir la metodología del Programa MBS de Interweave a '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' mediante
                    un entrenamiento personal previamente acordado por ambas partes. 
                                      
                    </td>               
                </tr>
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Proporcionar acceso a los materiales de capacitación del MBS a los participantes y
                    facilitadores de los grupos de autosuficiencia, incluyendo cursos, manuales, conferencias y
                    webinars.                    
                    </td>               
                </tr>
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">4.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">. Proporcione una copia de la Guía de Embajador del Éxito a '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' para la revisión
                    continua de las especificaciones incluidas en este contrato.                 
                    </td>               
                </tr> 
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">5.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Publicar el nombre y la información de contacto de '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' en el sitio web
                    oficial de Interweave.                  
                    </td>               
                </tr>
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">6.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Entregue el certificado de graduación de MASTER OF BUSINESS IN THE STREETS a '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' en nombre de cada participante que haya completado todos los requisitos
                    del programa a través de las plataformas especificadas de Interweave. ( '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' será
                    responsable de proporcionar el contrato dado en forma impresa o digital al participante)                   
                    </td>               
                </tr>
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">7.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Ofrecer materiales y capacitación adicionales operando bajo las consideraciones especificadas
                    en la Guía del Embajador de Éxito.
                                    
                    </td>               
                </tr>
            </table>';

            $html10 = '
            <table border="0">
                <tr>
                    <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:5pt;"> 
                    </td>
                </tr>    
                <tr>
                    <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">B. EN NOMBRE DE '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).': 
                    </td>
                </tr>               
            </table>';

          $html11 = '
            <table border="0" >         
                
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Crear grupos de autosuficiencia para participar en el curso de Master of Business in the
                    Streets, facilitando al menos un grupo dentro de los primeros seis meses de la autorización
                    como Embajador de Éxito, con un grupo adicional que se facilitará cada año a partir de
                    entonces.
                    </td>               
                </tr>       
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Asumir la responsabilidad de participar en la capacitación periódica, los adelantos de
                    productos y las actualizaciones de los términos y condiciones de la asociación y las
                    políticas, así como de revisar periódicamente los requisitos y normas esbozados en la
                    Guía de los Embajadores de Éxito, y reconocer que no es responsabilidad de Interweave 
                    garantizar que el Embajador conozca y siga las políticas y procedimientos originales o actualizados,
                    siempre y cuando los cambios se pongan a disposición de todos los embajadores y sean accesibles
                    para ellos a nivel universal.                  
                    </td>               
                </tr>
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Si la capacitación se realiza a través de una organización tercera, '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).'  tiene la
                    responsabilidad de seleccionar a las personas de la organización tercera que recibirán la
                    capacitación en metodología de Interweave para los programas de autosuficiencia.                     
                    </td>               
                </tr>
                
                
            </table>';

            

        $pdf->writeHTML($html6, true, false, true, false, '');
        $pdf->SetFont("minionpro-regular", '', 8);
        $pdf->writeHTML($html7, true, false, true, false, '');
        $pdf->SetFont("minionc", '', 8);
        $pdf->writeHTML($html8, true, false, true, false, '');
        $pdf->SetFont("minionpro-regular", '', 8);
        $pdf->writeHTML($html9, true, false, true, false, '');
        $pdf->SetFont("minionc", '', 8);
        $pdf->writeHTML($html10, true, false, true, false, '');
        $pdf->SetFont("minionpro-regular", '', 8);
        $pdf->writeHTML($html11, true, false, true, false, '');

          // add a page
          $resolution= array(248, 350);
          $pdf->SetMargins(40, 20, 30, true);
          $pdf->AddPage('P', $resolution);

          // get the current page break margin
          $bMargin = $pdf->getBreakMargin();
          // get current auto-page-break mode
          $auto_page_break = $pdf->getAutoPageBreak();
          // disable auto-page-break
          $pdf->SetAutoPageBreak(false, 0);
          // set bacground image

          $img_file = $this->container->getparameter('kernel.project_dir').'/web/img/contract_template.jpg';
          $pdf->Image($img_file, 0, 0, 248, 350, '', '', '', false, 600, '', false, false, 0);

          $html12 = '
            <table border="0">
                <tr>
                    <td colspan="8" align="right" style="color:black;text-align:center;font-weight:bold;font-size:30pt;height:60pt;"></td>
                </tr>
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">4.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Presentar una pre y post evaluación de cada participante antes de su graduación y completar un
                    formulario de autoevaluación del Embajador de Éxito, de acuerdo con las reglas y directrices
                    de Interweave Solutions, y entender que Interweave no emitirá bajo ninguna circunstancia un
                    certificado o materiales a los graduados del MBS hasta que esto se complete a través de plataformas
                    específicas.                 
                    </td>               
                </tr> 
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">5.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Otorgar a Interweave Solutions acceso y derechos para utilizar todas las fotografías, vídeos,
                    historias y nombres compartidos en plataformas públicas o a través de la comunicación personal
                    con los representantes de Interweave con fines de comercialización, creación de activos, desarrollo
                    de planes de estudios o cualquier otro que se considere apropiado por Interweave Solutions, así
                    como el consentimiento para publicar información de contacto personal en línea, y garantiza que
                    cualquier medio compartido con Interweave ha sido autorizado para su uso por el Embajador de
                    Éxito.                  
                    </td>               
                </tr>
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">6.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Ofrecer la formación MBS tal y como se establece en los materiales publicados, sin alteraciones en
                    la metodología o los procesos, a menos que la autorización sea concedida por Interweave a través
                    de un consentimiento escrito. 
                    </td>               
                </tr>       
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">7.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Mantener todos los acuerdos y obligaciones hechos a los participantes del MBS como parte del
                    curso, incluyendo la entrega de certificados y ceremonias de graduación.                  
                    </td>               
                </tr>
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">8.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Vivir y actuar de acuerdo con la misión, la visión y los valores de Interweave Solutions en todas las
                    acciones e interacciones tanto en relación con su trabajo como Embajador de Éxito como en su vida
                    personal, y defender y mantener estos valores en las interacciones con otros Embajadores de Éxito.                    
                    </td>               
                </tr>
                     

            </table>';

          $html13 = '
            <table border="0">
                 
                <tr>
                    <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">TERCERA: CONDICIONES DE LA DURACIÓN DEL CONTRATO: 
                    </td>
                </tr>               
            </table>';

          $html14 = '
            <table border="0">
                <tr>
                    <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">El presente contrato tendrá una
                    duración de cinco años, contados a partir de la fecha de su firma por ambas partes. Esto seguirá siendo
                    así siempre y cuando el embajador cumpla con los requisitos establecidos por Interweave para ser
                    un embajador de éxito. Sin embargo, podrá ser prorrogado de común acuerdo, siempre que medien
                    comunicaciones mutuas de ambas partes con la intención de prorrogar y suscribir el acto respectivo.
                    Además, Interweave mantiene el derecho de rescindir el contrato en cualquier momento si se considera
                    que la otra parte no está en condiciones de continuar como embajador de éxito, sin especificar las
                    causas precisas. 
                    </td>
                </tr>               
            </table>';

          $html15 = '
            <table border="0">
                 
                <tr>
                    <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">CUARTO: CAUSAS DE LA TERMINACIÓN DEL CONTRATO: 
                    </td>
                </tr>               
            </table>';

            $html16 = '
            <table border="0">
                <tr>
                    <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">Las siguientes serían razones para rescindir el presente contrato:  
                    </td>
                </tr>               
            </table>';

          $html17 = '
            <table border="0" >         
                
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">La expiración del período acordado, salvo lo dispuesto en la cláusula anterior.  
                    </td>               
                </tr>       
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">El acuerdo mutuo entre las partes, expresado en un documento firmado por los
                    representantes legales de las entidades.                    
                    </td>               
                </tr>
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">La imposibilidad técnica, administrativa o jurídica de continuar con la ejecución del
                    contrato.                    
                    </td>               
                </tr>
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">4.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">. La aparición de circunstancias de un caso fortuito o de fuerza mayor que impida la
                    continuación del contrato.                  
                    </td>               
                </tr> 
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">5.</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">El incumplimiento por cualquiera de las partes de los términos del contrato descrito
                    anteriormente.                   
                    </td>               
                </tr>
                
            </table>';

            

        $pdf->writeHTML($html12, true, false, true, false, '');
        $pdf->SetFont("minionc", '', 8);
        $pdf->writeHTML($html13, true, false, true, false, '');
        $pdf->SetFont("minionpro-regular", '', 8);
        $pdf->writeHTML($html14, true, false, true, false, '');
        $pdf->SetFont("minionc", '', 8);
        $pdf->writeHTML($html15, true, false, true, false, '');
        $pdf->SetFont("minionpro-regular", '', 8);
        $pdf->writeHTML($html16, true, false, true, false, '');
        $pdf->SetFont("minionpro-regular", '', 8);
        $pdf->writeHTML($html17, true, false, true, false, '');

         // add a page
         $resolution= array(248, 350);
         $pdf->SetMargins(20, 20, 20, true);
         $pdf->AddPage('P', $resolution);

         // get the current page break margin
         $bMargin = $pdf->getBreakMargin();
         // get current auto-page-break mode
         $auto_page_break = $pdf->getAutoPageBreak();
         // disable auto-page-break
         $pdf->SetAutoPageBreak(false, 0);
         // set bacground image

         $img_file = $this->container->getparameter('kernel.project_dir').'/web/img/contrato_firma.jpg';
         $pdf->Image($img_file, 0, 0, 248, 350, '', '', '', false, 600, '', false, false, 0);

        

         $html18 = '
           <table border="0">
               <tr>
                    <td colspan="8" align="right" style="color:black;text-align:center;font-weight:bold;font-size:30pt;height:60pt;"></td>
               </tr>
               <tr>
                   <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">QUINTA: RELACIÓN CON TERCEROS: 
                   </td>
               </tr>               
           </table>';

         $html19 = '
           <table border="0">
               <tr>
                   <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">Como resultado del presente contrato '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' puede ofrecer el Programa de
                   autosuficiencia de Interweave para su uso por terceros. Los valores de este programa serán
                   medidos por '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' según los criterios de negociación, siempre que no se alteren
                   los valores que INTERWEAVE ha establecido.  
                   </td>
               </tr>               
           </table>';

         $html20 = '
           <table border="0">
                
               <tr>
                   <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">SEXTA: USO DE IDENTIDADES CORPORATIVAS: 
                   </td>
               </tr>               
           </table>';

           $html21 = '
           <table border="0">
               <tr>
                   <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;"> Las comunicaciones y documentos que
                   resulten de la aplicación de este contrato permitirán el uso de su imagen corporativa, pero esto
                   no implica la asunción de obligaciones de solidaridad entre ellos. Los límites para el uso del
                   nombre y los logotipos oficiales son los siguientes: 
                   </td>
               </tr>               
           </table>';

         $html22 = '
           <table border="0" >         
               
               <tr>
                   <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                   <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">En la creacion de una entidad legal, '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' no está autorizado a utilizar el nombre
                   Interweave Solutions, o cualquier nombre que se le parezca (Interweave Business
                   Solutions, Embajadores Interweave Solutions, etc.) 
                   </td>               
               </tr>       
               <tr>
                   <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                   <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">'.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' no cambiará ni alterará los logotipos y gráficos oficiales de Interweave.                   
                   </td>               
               </tr>
               <tr>
                   <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                   <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">El nombre y la marca de Interweave no serán utilizados por ninguna otra parte en
                   materiales o tratos que no sean coherentes con la misión, la visión y los valores de
                   Interweave, ya sea para fines comerciales o personales.                    
                   </td>               
               </tr>
              
               
           </table>';

           $html23 = '
           <table border="0">
                
               <tr>
                   <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">SÉPTIMO: ACTUALIZACIÓN DE LOS TÉRMINOS DE ESTE CONTRATO: 
                   </td>
               </tr>               
           </table>';

           $html24 = '
           <table border="0">
               <tr>
                   <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">Todos los términos y
                   condiciones de este contrato están condicionados al mantenimiento de la Guía del Embajador
                   de Éxito y otros materiales de capacitación. Los términos pueden modificarse o actualizarse
                   según sea necesario sin la aprobación de Embajador, siempre que se hagan públicos y se
                   anuncien claramente a través de las plataformas de comunicación de los Embajadores de Éxito,
                   incluyendo el correo electrónico, Facebook y WhatsApp, y de los seminarios web mensuales. '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' es responsable de su propia congruencia con las normas de Interweave a este
                   respecto. 
                   </td>
               </tr>               
           </table>';


           $html25 = '
           <table border="0">
                
               <tr>
                   <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">OCTAVO: LA PERFECCIÓN Y LA EJECUCIÓN. 
                   </td>
               </tr>               
           </table>';

           $html26 = '
           <table border="0">
               <tr>
                   <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">El presente contrato se entiende perfeccionado
                   sobre la base de su suscripción. En constancia, se firma en la ciudad de '.$this->getParameter($this->getParameter($ambassador->getCountry())).' en el día '.date("d/m/Y").'. 
                   </td>
               </tr>               
           </table>';

           $html27 = '
           <table border="0">
                <tr>
                    <td align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:90pt;">
                    </td>
                </tr>
               <tr>
                   <td align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">FIRMAS DE LAS PARTES OFICIALES 
                   </td>
               </tr>               
           </table>';

           $html28 = '
           <table border="0">
                <tr>
                    <td align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:40pt;">
                    </td>
                </tr>
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">Dean H. Curtis</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">'.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).'
                    </td>               
                </tr>   
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">Executive Director</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">_______________________________
                    </td>               
                </tr>
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">Interweave Solutions</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">SUCCESS AMBASSADOR
                    </td>               
                </tr>
                <tr>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">EIN 26-0870014</td>
                    <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">ID '.$ambassador->getIdnumber().'
                    </td>               
                </tr>            
           </table>';


           
       $pdf->SetFont("minionc", '', 8);
       $pdf->writeHTML($html18, true, false, true, false, '');
       $pdf->SetFont("minionpro-regular", '', 8);
       $pdf->writeHTML($html19, true, false, true, false, '');
       $pdf->SetFont("minionc", '', 8);
       $pdf->writeHTML($html20, true, false, true, false, '');
       $pdf->SetFont("minionpro-regular", '', 8);
       $pdf->writeHTML($html21, true, false, true, false, '');
       $pdf->SetFont("minionpro-regular", '', 8);
       $pdf->writeHTML($html22, true, false, true, false, '');
       $pdf->SetFont("minionc", '', 8);
       $pdf->writeHTML($html23, true, false, true, false, '');
       $pdf->SetFont("minionpro-regular", '', 8);
       $pdf->writeHTML($html24, true, false, true, false, '');
       $pdf->SetFont("minionc", '', 8);
       $pdf->writeHTML($html25, true, false, true, false, '');
       $pdf->SetFont("minionpro-regular", '', 8);
       $pdf->writeHTML($html26, true, false, true, false, '');
       $pdf->SetFont("minionc", '', 8);
       $pdf->writeHTML($html27, true, false, true, false, '');
       $pdf->SetFont("minionpro-regular", '', 8);
       $pdf->writeHTML($html28, true, false, true, false, '');



      //Close and output PDF document
      $pdf->Output('sa_contract.pdf', 'I');
    }

    /**
     * @Rest\Get("/ambassador/en/{id}.{_format}", name="ambassador_en_contract", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets students of group info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The students with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Group ID"
     * )
     *
     * @SWG\Tag(name="Contract")
     */
    public function contractEnAction(Request $request, $id ) {

        $em = $this->getDoctrine()->getManager(); 
  
        $ambassador = $em->getRepository('App:User')->find($id);

        if(is_null($ambassador->getContractDate())){
            $ambassador->setContractDate(new \DateTime('now', (new \DateTimeZone('America/New_York'))));
            $em->persist($ambassador);
            $em->flush();
        }
        
  
        $pdf = $this->get('white_october.tcpdf.public')->create('horizontal', PDF_UNIT, PDF_PAGE_FORMAT, true, 'UTF-8', false);
        
        $pdf->SetAuthor('Interweave Solutions');
        $pdf->SetTitle(('MBS Contract'));
        $pdf->SetSubject('MBS Contract');
        $pdf->setFontSubsetting(true);
  
        
        $pdf->SetFont("minionc", '', 8);
  
  
          $html = '<h2></h2>
          <table border="0"  >
              <tr>
                  <td colspan="8" align="right" style="color:black;text-align:center;font-weight:bold;font-size:30pt;height:60pt;"></td>
              </tr>
              <tr>
                  <td colspan="8" align="center" style="color:black;text-align:center;font-weight:bold;font-size:14pt;height:22pt;">COOPERATION FRAMEWORK AGREEMENT BETWEEN INTERWEAVE SOLUTIONS AND </td>
              </tr>
              <tr>
                  <td colspan="8" align="center" style="color:black;text-align:center;font-weight:bold;font-size:14pt;height:1pt;">'.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).'</td>
              </tr>         
  
          </table>';
  
          $html2 = '
          <table border="0" >          
              <tr>
                  <td colspan="2" align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold;>Between the official parties of this document, namely: INTERWEAVE SOLUTIONS, with identification
                  number EIN 26-0870014, with primary residence of organization in Provo, Utah, United States, who from
                  now on and for all intents and purposes of this contract will be known simply as INTERWEAVE; and
                  the other party '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).', of legal age, with residence and address in the city of '.$ambassador->getCity().', '.$this->getParameter($this->getParameter($ambassador->getCountry())).',
                  identified with citizenship documentation '.$ambassador->getIdnumber().' issued in '.$this->getParameter($this->getParameter($ambassador->getCountry())).', who acts in their own
                  name and legal representation, who will from now on for all intents and purposes of this contract will be
                  referred to as '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).'.
                  </td>
              </tr> 
                 
  
          </table>';
  
          $html3 = '<h2></h2>
          <table border="0"  >          
              <tr>
                  <td colspan="8" align="center" style="color:black;text-align:center;font-weight:bold;font-size:14pt;height:22pt;">CONSIDERATIONS:</td>
              </tr>               
  
          </table>';
  
          $html4 = '
          <table border="0" >         
              
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">That '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' has honestly and thoroughly completed and submitted the requirements set forth by
                  Interweave to become a Success Ambassador, including certification in the MBS course, certification in
                  the Success Ambassador course, teaching and training of at least one MBS group, payment of applicable
                  fees to Interweave, and any other requirements as specified previously by Interweave.
                  </td>               
              </tr>       
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">That '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' , with the support of INTERWEAVE, will offer the MBS (MASTER OF BUSINESS
                  IN THE STREETS) program, whose main objective is to improve the quality of life of individuals in
                  vulnerable conditions by promoting business ideas and strengthening existing businesses, thus leading
                  individuals to self-reliance.                 
                  </td>               
              </tr>
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">That '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' , with the support of INTERWEAVE, will train groups of people, in the regions of 
                  '.$this->getParameter($this->getParameter($ambassador->getCountry())).' in order to help them become self-reliant in the areas of business, home, and the community.                  
                  </td>               
              </tr>
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">4.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">That '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' , will seek to strengthen the social fabric of the community in the regions of
                  '.$this->getParameter($this->getParameter($ambassador->getCountry())).' through educational programs of self-reliance, facilitating the creation of business ideas and the strengthening of current businesses to be sustainable and competitive.                 
                  </td>               
              </tr> 
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">5.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">That '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' , and INTERWEAVE, understand and consider that local government officials and
                   other organizations, both public and private, also strive to accomplish these same objectives and will strongly consider creating contracted partnerships and working in collaboration with these entities.                  
                  </td>               
              </tr>
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">6.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">That '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' , and INTERWEAVE have identified similar elements of cooperation within their
                   own selves/organizations to develop a cooperation between the organizations, recognizing that neither party is acting as a legal employee of the other. They are in agreement that it is for the benefit of both organizations to join forces and develop mechanisms of cooperation and inter-agency
                    support for the joined purposes of both organizations.                   
                  </td>               
              </tr>
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">7.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">That the rights and materials from the MBS Program, cannot be used without the authorization of INTERWEAVE.                   
                  </td>               
              </tr>
          </table>';
  
          $html5 = '<h2></h2>
          <table border="0"  >          
              <tr>
                  <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:13pt;height:22pt;">Taking into account the previous considerations, the parties agree to uphold the agreements and be governed by the following clauses: </td>
              </tr>               
  
          </table>';
  
  
  
  
            // add a page
            $resolution= array(248, 350);
            $pdf->SetMargins(20, 20, 20, true);
            $pdf->AddPage('P', $resolution);
  
            // get the current page break margin
            $bMargin = $pdf->getBreakMargin();
            // get current auto-page-break mode
            $auto_page_break = $pdf->getAutoPageBreak();
            // disable auto-page-break
            $pdf->SetAutoPageBreak(false, 0);
            // set bacground image
  
  
              $img_file = $this->container->getparameter('kernel.project_dir').'/web/img/contract_template.jpg';
              $pdf->Image($img_file, 0, 0, 248, 350, '', '', '', false, 600, '', false, false, 0);
           
  
            
  
            
            // restore auto-page-break status
            $pdf->SetAutoPageBreak($auto_page_break, $bMargin);
            // set the starting point for the page content
            $pdf->setPageMark();
  
  
            // Print a text
            // Print a text
            $pdf->writeHTML($html, true, false, true, false, '');
            $pdf->SetFont("minionpro-regular", '', 8);
            $pdf->writeHTML($html2, true, false, true, false, '');
            $pdf->SetFont("minionc", '', 8);
            $pdf->writeHTML($html3, true, false, true, false, '');
            $pdf->SetFont("minionpro-regular", '', 8);
            $pdf->writeHTML($html4, true, false, true, false, '');
            $pdf->writeHTML($html5, true, false, true, false, '');
            $pdf->SetFont("minionc", '', 8);
  
            // add a page
            $resolution= array(248, 350);
            $pdf->SetMargins(40, 20, 30, true);
            $pdf->AddPage('P', $resolution);
  
            // get the current page break margin
            $bMargin = $pdf->getBreakMargin();
            // get current auto-page-break mode
            $auto_page_break = $pdf->getAutoPageBreak();
            // disable auto-page-break
            $pdf->SetAutoPageBreak(false, 0);
            // set bacground image
  
            $img_file = $this->container->getparameter('kernel.project_dir').'/web/img/contract_template.jpg';
            $pdf->Image($img_file, 0, 0, 248, 350, '', '', '', false, 600, '', false, false, 0);
  
            $html6 = '
              <table border="0">
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:30pt;height:60pt;"></td>
                  </tr>
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">FIRST: PURPOSE OF THE CONTRACT:  </td>
                  </tr>                   
  
              </table>';
  
            $html7 = '
            <table border="0"  >          
                <tr>
                    <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:13pt;height:80pt;">The general purpose of this contract is to state actions,
                     efforts, abilities, and knowledge required in order to better develop BUSINESSES, HOMES, and COMMUNITIES. This will help improve the quality of life among the vulnerable populations of '.$this->getParameter($this->getParameter($ambassador->getCountry())).'. Training topics include creating and improving sustainable businesses, improving home and family life, and participating in community development initiatives.  </td>
                </tr>               
    
            </table>';
  
            $html8 = '
              <table border="0">
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">SECOND: SPECIFIC OBLIGATIONS OF EACH PARTY. 
                      </td>
                  </tr>    
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">A. ON BEHALF OF INTERWEAVE: 
                      </td>
                  </tr>               
              </table>';
  
            $html9 = '
              <table border="0" >         
                  
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Provide official and authorized certification to
                      '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' as a Success Ambassador.
                      </td>               
                  </tr>       
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Transfer the methodology of Interweave’s MBS Program to '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' through personal
                      training previously agreed upon by both parties.                  
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Provide access to MBS training materials for participants and facilitators of the self-reliance
                      groups, including courses, manuals, conferences and webinars.                   
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">4.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Provide a copy of the Success Ambassador Guide to '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' for continual review of
                      the specifications included in this contract.                 
                      </td>               
                  </tr> 
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">5.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Publish the name and contact information of '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' on Interweave’s official website.                  
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">6.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Deliver the MASTER OF BUSINESS IN THE STREETS graduation certificate to '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' in behalf of each participant who has completed all of the requirements of the
                      program through Interweave’s specified platforms. ( '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' will be responsible to
                      provide given MBS Certificate in printed or digital form to the participant.)                   
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">7.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Offer additional materials and training operating under the considerations specified in the
                      Success Ambassador Guide.
                                      
                      </td>               
                  </tr>
              </table>';
  
              $html10 = '
              <table border="0">
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:5pt;"> 
                      </td>
                  </tr>    
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">B. ON BEHALF OF '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).': 
                      </td>
                  </tr>               
              </table>';
  
            $html11 = '
              <table border="0" >         
                  
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Create self-reliance groups to participate in the MASTER OF BUSINESS IN THE
                      STREETS course, facilitating at minimum one group within the first six months of
                      authorization as a Success Ambassador with an additional group being facilitated each year
                      thereafter.
                      </td>               
                  </tr>       
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Assume responsibility to participate in regular training, product advancements and updates
                      to terms and conditions of the partnership and policies, as well as regularly review the
                      requirements and standards outlined in the Success Ambassador Guide, and acknowledge
                      that it is not the responsibility of Interweave to ensure that the Ambassador is aware of and
                      following any original or updated policies and procedures, granted that any changes are
                      made widely available and accessible to Ambassadors on a universal level.                  
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">If training through a third party organization, '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' has the responsibility to select
                      the people from the third party organization who will be receiving the methodology
                      training from Interweave for the Self-Reliance Programs.                    
                      </td>               
                  </tr>
                  
                  
              </table>';
  
              
  
          $pdf->writeHTML($html6, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html7, true, false, true, false, '');
          $pdf->SetFont("minionc", '', 8);
          $pdf->writeHTML($html8, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html9, true, false, true, false, '');
          $pdf->SetFont("minionc", '', 8);
          $pdf->writeHTML($html10, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html11, true, false, true, false, '');
  
            // add a page
            $resolution= array(248, 350);
            $pdf->SetMargins(40, 20, 30, true);
            $pdf->AddPage('P', $resolution);
  
            // get the current page break margin
            $bMargin = $pdf->getBreakMargin();
            // get current auto-page-break mode
            $auto_page_break = $pdf->getAutoPageBreak();
            // disable auto-page-break
            $pdf->SetAutoPageBreak(false, 0);
            // set bacground image
  
            $img_file = $this->container->getparameter('kernel.project_dir').'/web/img/contract_template.jpg';
            $pdf->Image($img_file, 0, 0, 248, 350, '', '', '', false, 600, '', false, false, 0);
  
            $html12 = '
              <table border="0">
                  <tr>
                      <td colspan="8" align="right" style="color:black;text-align:center;font-weight:bold;font-size:30pt;height:60pt;"></td>
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">4.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Submit a Pre and Post evaluation from each participant prior to their graduation and complete
                      a Success Ambassador self-evaluation form, in accordance with the rules and guidelines of
                      Interweave Solutions, and understand that Interweave will not under any circumstances issue a
                      certificate or materials to MBS graduates until this is completed through specified platforms.                 
                      </td>               
                  </tr> 
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">5.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Grants Interweave Solutions access to and rights to use all photographs, videos, stories and names
                      shared on public platforms or through personal communication with Interweave representatives
                      for purposes of marketing, asset creation, curriculum development or any others as deemed
                      appropriate by Interweave Solutions, as well as consent to publish personal contact information
                      online, and ensures that any media shared with Interweave has been authorized for use by the
                      Success Ambassador.                  
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">6.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Offer MBS training as provided in published materials, without alterations to the methodology or
                      processes, unless authorization is granted by Interweave through written consent. 
                      </td>               
                  </tr>       
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">7.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Uphold all agreements and obligations made to MBS participants as part of the course, including
                      delivery of certificates and graduation ceremonies.                  
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">8.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Live and act in accordance with the mission, vision and values of Interweave Solutions in all actions
                      and interactions both relating to his/her work as a Success Ambassador and in his/her personal life
                      and advocate and uphold these values in interactions with other Success Ambassadors.                    
                      </td>               
                  </tr>
                       
  
              </table>';
  
            $html13 = '
              <table border="0">
                   
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">THIRD: TERMS OF THE DURATION OF CONTRACT: 
                      </td>
                  </tr>               
              </table>';
  
            $html14 = '
              <table border="0">
                  <tr>
                      <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">The present contract will have a term of
                      duration of four years, counted from the date of signature of both parties. This remains true as
                      long as the ambassador complies with the requirements established by Interweave to be a Success
                      Ambassador. However, it may be extended by mutual agreement, provided that they mediate mutual
                      communications from both parties with the intent of extension and subscription of the respective act.
                      Furthermore, Interweave maintains the right to terminate the contract at any time if the other party is
                      deemed unfit to continue as a Success Ambassador, without specifying precise causes. 
                      </td>
                  </tr>               
              </table>';
  
            $html15 = '
              <table border="0">
                   
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">FOURTH: CAUSES OF THE TERMINATION OF CONTRACT: 
                      </td>
                  </tr>               
              </table>';
  
              $html16 = '
              <table border="0">
                  <tr>
                      <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">The following would be reasons to
                      terminate the present contract: 
                      </td>
                  </tr>               
              </table>';
  
            $html17 = '
              <table border="0" >         
                  
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">The expiration of the agreed period, except for the provisions of the previous clause. 
                      </td>               
                  </tr>       
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">The mutual agreement between the parties, expressed in a document signed by the legal
                      representatives of the entities.                   
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">The technical, administrative or legal impossibility to continue with the implementation of the
                      contract.                    
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">4.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">The occurrence of circumstances of a fortuitous case or greater force that impedes the continuation
                      of the contract.                  
                      </td>               
                  </tr> 
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">5.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Failure by either party to uphold any terms of the contract previously described.                   
                      </td>               
                  </tr>
                  
              </table>';
  
              
  
          $pdf->writeHTML($html12, true, false, true, false, '');
          $pdf->SetFont("minionc", '', 8);
          $pdf->writeHTML($html13, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html14, true, false, true, false, '');
          $pdf->SetFont("minionc", '', 8);
          $pdf->writeHTML($html15, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html16, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html17, true, false, true, false, '');
  
           // add a page
           $resolution= array(248, 350);
           $pdf->SetMargins(20, 20, 20, true);
           $pdf->AddPage('P', $resolution);
  
           // get the current page break margin
           $bMargin = $pdf->getBreakMargin();
           // get current auto-page-break mode
           $auto_page_break = $pdf->getAutoPageBreak();
           // disable auto-page-break
           $pdf->SetAutoPageBreak(false, 0);
           // set bacground image
  
           $img_file = $this->container->getparameter('kernel.project_dir').'/web/img/contrato_firma.jpg';
           $pdf->Image($img_file, 0, 0, 248, 350, '', '', '', false, 600, '', false, false, 0);
  
          
  
           $html18 = '
             <table border="0">
                 <tr>
                      <td colspan="8" align="right" style="color:black;text-align:center;font-weight:bold;font-size:30pt;height:60pt;"></td>
                 </tr>
                 <tr>
                     <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">FIFTH: RELATIONSHIP TO THIRD PARTIES: 
                     </td>
                 </tr>               
             </table>';
  
           $html19 = '
             <table border="0">
                 <tr>
                     <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">As a result of the present contract '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' can offer Interweave’s Self-Reliance Program
                     for use by third parties. The values of this program will be measured by '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' according
                     to the criterias of negotiation, as long as the values that INTERWEAVE has set forth are not
                     altered.  
                     </td>
                 </tr>               
             </table>';
  
           $html20 = '
             <table border="0">
                  
                 <tr>
                     <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">SIXTH: USE OF CORPORATE IDENTITIES: 
                     </td>
                 </tr>               
             </table>';
  
             $html21 = '
             <table border="0">
                 <tr>
                     <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">The communications and documents that result
                     from the implementation of this contract will allow the use of its corporate image, but this does
                     not imply the assumption of solidarity obligations between them. Limits on the use of name
                     and official logos are as follows: 
                     </td>
                 </tr>               
             </table>';
  
           $html22 = '
             <table border="0" >         
                 
                 <tr>
                     <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                     <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">In the creation of a legal entity, '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' is not authorized to use the name Interweave
                     Solutions, or any name resembling it (Interweave Business Solutions, Interweave Solutions
                     Ambassadors, etc.) 
                     </td>               
                 </tr>       
                 <tr>
                     <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                     <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">'.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' will not change or alter official logos and graphics of Interweave.                   
                     </td>               
                 </tr>
                 <tr>
                     <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                     <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">The name and brand of Interweave will not be used by any other party in materials or
                     dealings that are not consistent with the mission, vision and values of Interweave, whether
                     for business or personal endeavors.                    
                     </td>               
                 </tr>
                
                 
             </table>';
  
             $html23 = '
             <table border="0">
                  
                 <tr>
                     <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">SEVENTH: UPDATES TO TERMS OF THIS CONTRACT: 
                     </td>
                 </tr>               
             </table>';
  
             $html24 = '
             <table border="0">
                 <tr>
                     <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">All terms and conditions in this
                     contract are conditional upon the maintenance of the Success Ambassador Guide and
                     other training materials. Terms may be changed or updated as needed without approval
                     from the Ambassador, provided they are made publicly and are clearly announced through
                     Success Ambassador communication platforms including email, Facebook, and WhatsApp,
                     and monthly webinar trainings. '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' is responsible for their own congruence with
                     Interweave standards in this regard. 
                     </td>
                 </tr>               
             </table>';
  
  
             $html25 = '
             <table border="0">
                  
                 <tr>
                     <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">EIGHTH: PERFECTION AND EXECUTION. 
                     </td>
                 </tr>               
             </table>';
  
             $html26 = '
             <table border="0">
                 <tr>
                     <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">This contract is understood to be perfected on the
                     basis of its subscription. It is signed in the country of '.$this->getParameter($this->getParameter($ambassador->getCountry())).' on the day '.date("d/m/Y").'. 
                     </td>
                 </tr>               
             </table>';
  
             $html27 = '
             <table border="0">
                  <tr>
                      <td align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:90pt;">
                      </td>
                  </tr>
                 <tr>
                     <td align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">SIGNATURES OF THE OFFICIAL PARTIES 
                     </td>
                 </tr>               
             </table>';
  
             $html28 = '
             <table border="0">
                  <tr>
                      <td align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:40pt;">
                      </td>
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">Dean H. Curtis</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">'.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).'
                      </td>               
                  </tr>   
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">Executive Director</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">_______________________________
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">Interweave Solutions</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">SUCCESS AMBASSADOR
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">EIN 26-0870014</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">ID '.$ambassador->getIdnumber().'
                      </td>               
                  </tr>            
             </table>';
  
  
             
         $pdf->SetFont("minionc", '', 8);
         $pdf->writeHTML($html18, true, false, true, false, '');
         $pdf->SetFont("minionpro-regular", '', 8);
         $pdf->writeHTML($html19, true, false, true, false, '');
         $pdf->SetFont("minionc", '', 8);
         $pdf->writeHTML($html20, true, false, true, false, '');
         $pdf->SetFont("minionpro-regular", '', 8);
         $pdf->writeHTML($html21, true, false, true, false, '');
         $pdf->SetFont("minionpro-regular", '', 8);
         $pdf->writeHTML($html22, true, false, true, false, '');
         $pdf->SetFont("minionc", '', 8);
         $pdf->writeHTML($html23, true, false, true, false, '');
         $pdf->SetFont("minionpro-regular", '', 8);
         $pdf->writeHTML($html24, true, false, true, false, '');
         $pdf->SetFont("minionc", '', 8);
         $pdf->writeHTML($html25, true, false, true, false, '');
         $pdf->SetFont("minionpro-regular", '', 8);
         $pdf->writeHTML($html26, true, false, true, false, '');
         $pdf->SetFont("minionc", '', 8);
         $pdf->writeHTML($html27, true, false, true, false, '');
         $pdf->SetFont("minionpro-regular", '', 8);
         $pdf->writeHTML($html28, true, false, true, false, '');
  
  
  
        //Close and output PDF document
        $pdf->Output('sa_contract.pdf', 'I');
      }

      /**
     * @Rest\Get("/ambassador/fr/{id}.{_format}", name="ambassador_fr_contract", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets students of group info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The students with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Group ID"
     * )
     *
     * @SWG\Tag(name="Contract")
     */
    public function contractFrAction(Request $request, $id ) {

        $em = $this->getDoctrine()->getManager(); 
  
        $ambassador = $em->getRepository('App:User')->find($id);
        if(is_null($ambassador->getContractDate())){
            $ambassador->setContractDate(new \DateTime('now', (new \DateTimeZone('America/New_York'))));
            $em->persist($ambassador);
            $em->flush();
        }
  
        $pdf = $this->get('white_october.tcpdf.public')->create('horizontal', PDF_UNIT, PDF_PAGE_FORMAT, true, 'UTF-8', false);
        
        $pdf->SetAuthor('Interweave Solutions');
        $pdf->SetTitle(('MBS Contract'));
        $pdf->SetSubject('MBS Contract');
        $pdf->setFontSubsetting(true);
  
        
        $pdf->SetFont("minionc", '', 8);
  
  
          $html = '<h2></h2>
          <table border="0"  >
              <tr>
                  <td colspan="8" align="right" style="color:black;text-align:center;font-weight:bold;font-size:30pt;height:60pt;"></td>
              </tr>
              <tr>
                  <td colspan="8" align="center" style="color:black;text-align:center;font-weight:bold;font-size:14pt;height:22pt;">ACCORD-STRUCTURE DE COOPÉRATION ENTRE
                  INTERWEAVE SOLUTIONS ET </td>
              </tr>
              <tr>
                  <td colspan="8" align="center" style="color:black;text-align:center;font-weight:bold;font-size:14pt;height:1pt;">'.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).'</td>
              </tr>         
  
          </table>';
  
          $html2 = '
          <table border="0" >          
              <tr>
                  <td colspan="2" align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold;>Entre les parties officielles de ce document, à savoir : Dean Curtis, avec identification de Passeport américain
                  N˚ 56140402486, avec résidence et adresse dans la ville de Provo, Utah, qui agit en nom et en
                  représentation de l’organisation INTERWEAVE SOLUTIONS, avec résidence principale de l’organisation à
                  Provo, Utah, États-Unis, qui, à partir de maintenant et à toutes les intentions et objectifs de ce contrat, sera
                  connu simplement sous le nom de INTERWEAVE; et l’autre partie '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).', d’âge légal, avec résidence et
                  adresse dans la ville de '.$ambassador->getCity().', '.$this->getParameter($this->getParameter($ambassador->getCountry())).',
                  identifier avec les documents de citoyenneté '.$ambassador->getIdnumber().' émis au '.$this->getParameter($this->getParameter($ambassador->getCountry())).', qui agit en son propre nom et représentation légale, qui sera dorénavant désignée par le
                  présent contrat sous le nom de '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).'.
                  </td>
              </tr> 
                 
  
          </table>';
  
          $html3 = '<h2></h2>
          <table border="0"  >          
              <tr>
                  <td colspan="8" align="center" style="color:black;text-align:center;font-weight:bold;font-size:14pt;height:22pt;">CONSIDÉRATIONS:</td>
              </tr>               
  
          </table>';
  
          $html4 = '
          <table border="0" >         
              
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' a honnêtement et complètement rempli et soumis les exigences établies par Interweave
                  pour devenir un Ambassadeur du Succès, y compris la certification dans le cours MBS, la certification dans le
                  cours Ambassadeur du succès, l’enseignement et la formation d’au moins un groupe MBS, le paiement des frais
                  applicables à Interweave et toute autre exigence précisée précédemment par Interweave.
                  </td>               
              </tr>       
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' , avec le soutien de INTERWEAVE, offrira le programme MBS (MAÎTRISE EN
                  ADMINISTRATION DES AFFAIRES DANS LA RUE), dont l’objectif principal est de combiner
                  les efforts pour améliorer la qualité de vie de la population dans des conditions vulnérables, tout en
                  encourageant des idées commerciales, renforçant ainsi des entreprises existantes et les menant vers une
                  autonomie par une démarche pédagogique.                  
                  </td>               
              </tr>
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' , avec le soutien de INTERWEAVE, formera des groupes de personnes, dans toutes
                  les régions du '.$this->getParameter($this->getParameter($ambassador->getCountry())).' afin de les aider à devenir autonomes dans les domaines des affaires, le
                  foyer, et la communauté.                  
                  </td>               
              </tr>
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">4.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' , s’efforcera de contribuer au renforcement du développement social de la ville de leurs
                  régions au '.$this->getParameter($this->getParameter($ambassador->getCountry())).' par le biais du programmes éducatifs d’autonomie pour la création d’idées d’affaires et
                  le renforcement des entreprises actuelles afin que les entreprises soient durables et compétitives.                 
                  </td>               
              </tr> 
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">5.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' , et INTERWEAVE, comprennent et considèrent que les autorités gouvernementales
                  et les gouvernements travaillent également avec ces mêmes objectifs à l’esprit et envisageront de créer des
                  contrats et de travailler avec les personnes dans ce domaine.                  
                  </td>               
              </tr>
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">6.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' ,  et INTERWEAVE ont identifié des éléments similaires de coopération au sein de leurs
                  propres organisations/personnes pour développer une coopération entre ces organisations. Ils conviennent
                  qu’ils sont dans l’intérêt des deux organisations d’unir leurs forces et de mettre au point des mécanismes de
                  coopération et d’appui inter-institutions dans l’intérêt commun des deux organisations.                   
                  </td>               
              </tr>
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">7.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que les droits et matériels du programme MBS ne peuvent pas être utilisé sans l’autorisation de
                  INTERWEAVE.                   
                  </td>               
              </tr>
          </table>';
  
          $html5 = '<h2></h2>
          <table border="0"  >          
              <tr>
                  <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:13pt;height:22pt;">Compte tenu des considérations qui précèdent, les parties conviennent de respecter les ententes
                  et d’être assujetties aux clauses qui suivent: </td>
              </tr>               
  
          </table>';
  
  
  
  
            // add a page
            $resolution= array(248, 350);
            $pdf->SetMargins(20, 20, 20, true);
            $pdf->AddPage('P', $resolution);
  
            // get the current page break margin
            $bMargin = $pdf->getBreakMargin();
            // get current auto-page-break mode
            $auto_page_break = $pdf->getAutoPageBreak();
            // disable auto-page-break
            $pdf->SetAutoPageBreak(false, 0);
            // set bacground image
  
  
              $img_file = $this->container->getparameter('kernel.project_dir').'/web/img/contract_template.jpg';
              $pdf->Image($img_file, 0, 0, 248, 350, '', '', '', false, 600, '', false, false, 0);
           
  
            
  
            
            // restore auto-page-break status
            $pdf->SetAutoPageBreak($auto_page_break, $bMargin);
            // set the starting point for the page content
            $pdf->setPageMark();
  
  
            // Print a text
            // Print a text
            $pdf->writeHTML($html, true, false, true, false, '');
            $pdf->SetFont("minionpro-regular", '', 8);
            $pdf->writeHTML($html2, true, false, true, false, '');
            $pdf->SetFont("minionc", '', 8);
            $pdf->writeHTML($html3, true, false, true, false, '');
            $pdf->SetFont("minionpro-regular", '', 8);
            $pdf->writeHTML($html4, true, false, true, false, '');
            $pdf->writeHTML($html5, true, false, true, false, '');
            $pdf->SetFont("minionc", '', 8);
  
            // add a page
            $resolution= array(248, 350);
            $pdf->SetMargins(40, 20, 30, true);
            $pdf->AddPage('P', $resolution);
  
            // get the current page break margin
            $bMargin = $pdf->getBreakMargin();
            // get current auto-page-break mode
            $auto_page_break = $pdf->getAutoPageBreak();
            // disable auto-page-break
            $pdf->SetAutoPageBreak(false, 0);
            // set bacground image
  
            $img_file = $this->container->getparameter('kernel.project_dir').'/web/img/contract_template.jpg';
            $pdf->Image($img_file, 0, 0, 248, 350, '', '', '', false, 600, '', false, false, 0);
  
            $html6 = '
              <table border="0">
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:30pt;height:60pt;"></td>
                  </tr>
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">PREMIER: OBJET DU CONTRAT:  </td>
                  </tr>                   
  
              </table>';
  
            $html7 = '
            <table border="0"  >          
                <tr>
                    <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:13pt;height:80pt;"> L’objectif général de ce contrat est d’énoncer les actions, les
                    efforts, les capacités et les connaissances, en mettant l’accent sur l’autonomie et les capacités
                    requises afin de mieux développer les ENTREPRISES, FOYERS, et COMMUNAUTÉS.
                    Cela contribuera à améliorer la qualité de vie des populations vulnérables de la région du '.$this->getParameter($this->getParameter($ambassador->getCountry())).'. Les sujets de formation comprennent les affaires, la création et l’amélioration des
                    entreprises, la création d’entreprises durables et toute autre formation commerciale en rapport avec ces sujets. 
                      </td>
                </tr>               
    
            </table>';
  
            $html8 = '
              <table border="0">
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">DEUXIÈMEMENT: LES OBLIGATIONS SPÉCIFIQUES DE CHAQUE PARTIE. 
                      </td>
                  </tr>    
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">A. AU NOM DE INTERWEAVE: 
                      </td>
                  </tr>               
              </table>';
  
            $html9 = '
              <table border="0" >         
                  
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Fournir une certification officielle et autorisée à 
                      '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' en tant qu’Ambassadeur du
                      Succès.
                      </td>               
                  </tr>       
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Transférer la méthodologie du programme d’autonomie MBS de Interweave à '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).'  par le biais d’une formation personnelle préalablement convenue par les
                      deux parties.                   
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Fournir l’accès au matériel de formation MBS pour les participants et les animateurs des
                      groupes d’autonomie, y compris les cours, manuels, conférences et webinaires.                    
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">4.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Fournir une copie du Guide de l’Ambassadeur du Succès à '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' pour l’examen
                      continu des spécifications incluses dans le présent contrat.                 
                      </td>               
                  </tr> 
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">5.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Publier le nom et les coordonnées de '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).'  sur le site Web officiel
                      d’Interweave.                 
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">6.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Remettre le certificat de graduation MAÎTRISE EN ADMINISTRATION DES AFFAIRES
                      DANS LA RUE à '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' au nom de chaque participant qui a satisfait à toutes les
                      exigences du programme à travers les plateformes spécifiées d’Interweave. ( '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' sera responsable de fournir un contrat donné sous forme imprimée ou numérique au
                      participant.)                   
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">7.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Offrez du matériel et de la formation supplémentaires en tenant compte des considérations
                      précisées dans le Guide de l’Ambassadeur du Succès.
                                      
                      </td>               
                  </tr>
              </table>';
  
              $html10 = '
              <table border="0">
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:5pt;"> 
                      </td>
                  </tr>    
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">B. AU NOM DE '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).': 
                      </td>
                  </tr>               
              </table>';
  
            $html11 = '
              <table border="0" >         
                  
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">. Créer des groupes d’autonomie pour participer au cours MAÎTRISE EN
                      ADMINISTRATION DES AFFAIRES DANS LA RUE, en animant au moins un groupe au
                      cours des six premiers mois suivant l’autorisation à titre d’Ambassadeur du Succès, un autre
                      groupe étant animé chaque année par la suite. 
                      </td>               
                  </tr>       
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Assumer la responsabilité de participer régulièrement aux formations, à l’évolution des
                      matériels et aux mises à jour des termes et conditions du partenariat et des politiques,
                      ainsi que d’examiner régulièrement les exigences et les normes décrites dans le Guide 
                      www.inteweavesolutions.org 734 North 1890 West Provo, Utah 84601 (801) 710-9885
                      de l’Ambassadeur du Succès, et reconnaître qu’il n’incombe pas à Interweave de s’assurer que
                      l’Ambassadeur est au courant de toute politique ou procédure originale ou mise à jour et qu’il s’y
                      conforme, pourvu que tout changement soit largement diffusé et accessible aux Ambassadeurs à un
                      niveau universel.                  
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">S’il s’agit d’une formation offerte par une troisième organisation, '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' a la responsabilité
                      de choisir les personnes de la troisième organisation qui recevront la formation en méthodologie
                      d’Interweave pour les Programmes d’Autonomie.                    
                      </td>               
                  </tr>
                  
                  
              </table>';
  
              
  
          $pdf->writeHTML($html6, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html7, true, false, true, false, '');
          $pdf->SetFont("minionc", '', 8);
          $pdf->writeHTML($html8, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html9, true, false, true, false, '');
          $pdf->SetFont("minionc", '', 8);
          $pdf->writeHTML($html10, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html11, true, false, true, false, '');
  
            // add a page
            $resolution= array(248, 350);
            $pdf->SetMargins(40, 20, 30, true);
            $pdf->AddPage('P', $resolution);
  
            // get the current page break margin
            $bMargin = $pdf->getBreakMargin();
            // get current auto-page-break mode
            $auto_page_break = $pdf->getAutoPageBreak();
            // disable auto-page-break
            $pdf->SetAutoPageBreak(false, 0);
            // set bacground image
  
            $img_file = $this->container->getparameter('kernel.project_dir').'/web/img/contract_template.jpg';
            $pdf->Image($img_file, 0, 0, 248, 350, '', '', '', false, 600, '', false, false, 0);
  
            $html12 = '
              <table border="0">
                  <tr>
                      <td colspan="8" align="right" style="color:black;text-align:center;font-weight:bold;font-size:30pt;height:60pt;"></td>
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">4.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Soumettre une évaluation préalable et postérieure de chaque participant avant l’obtention de son
                      diplôme et remplir un formulaire d’auto-évaluation des Ambassadeurs du Succès, conformément
                      aux règles et directives d’Interweave Solutions, et comprendre que Interweave ne délivre aucun
                      certificat ou matériel aux diplômés MBS tant que ce formulaire d’auto-évaluation ne sera pas rempli
                      sous des plateformes spécifiques.                 
                      </td>               
                  </tr> 
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">5.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Donne à Interweave Solutions l’accès et le droit d’utiliser toutes les photographies, vidéos, histoires
                      et noms partagés sur des plateformes publiques ou par communication personnelle avec des
                      représentants d’Interweave à des fins de marketing, de création d’actifs, de développement de
                      curriculum ou autres, tel que jugé approprié par Interweave Solutions, ainsi que le consentement de
                      publier les coordonnées personnelles en ligne, et assure que tout média partagé avec Interweave a
                      été autorisé pour utilisation par l’Ambassadeur du Success.                  
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">6.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Offrir la formation MBS telle que prévue dans les documents publiés, sans modification de la
                      méthodologie ou des processus, à moins que l’autorisation d’Interweave ne soit accordée par
                      consentement écrit. 
                      </td>               
                  </tr>       
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">7.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Respecter toutes les ententes et obligations conclues avec les participants du MBS dans le cadre du
                      cours, y compris la remise des certificats et les cérémonies de remise des diplômes.                  
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">8.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Vivre et agir en accord avec la mission, la vision et les valeurs d’Interweave Solutions dans toutes
                      les actions et interactions liées à son travail en tant qu’Ambassadeur du Succès et dans sa vie
                      personnelle, et défendre et soutenir ces valeurs dans ses interactions avec les autres Ambassadeurs
                      du Succès. 
                                          
                      </td>               
                  </tr>
                       
  
              </table>';
  
            $html13 = '
              <table border="0">
                   
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">TROISIÈMEMENT: CONDITIONS DE DURÉE DU CONTRAT: 
                      </td>
                  </tr>               
              </table>';
  
            $html14 = '
              <table border="0">
                  <tr>
                      <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">Le présent contrat aura une durée de
                      quatre ans à compter de la date de signature des deux parties. Cela reste vrai tant que l’Ambassadeur
                      respecte les exigences établies par Interweave pour devenir un Ambassadeur du Succès. Toutefois,
                      elle peut être prorogée d’un commun accord, à condition qu’elles assurent la médiation des
                      communications mutuelles des deux parties dans l’intention de proroger et de souscrire l’acte
                      correspondant. De plus, Interweave se réserve le droit de résilier le contrat à tout moment si l’autre
                      partie est jugée inapte à poursuivre son mandat d’Ambassadeur du Succès, sans en préciser les raisons. 
                      </td>
                  </tr>               
              </table>';
  
            $html15 = '
              <table border="0">
                   
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">QUATRIÈMEMENT: CAUSES DE LA RÉSILIATION DU CONTRAT:
                      </td>
                  </tr>               
              </table>';
  
              $html16 = '
              <table border="0">
                  <tr>
                      <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">Les raisons suivantes justifient la
                      résiliation du présent contrat: 
                      </td>
                  </tr>               
              </table>';
  
            $html17 = '
              <table border="0" >         
                  
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">L’expiration du délai convenu, à l’exception des dispositions de la clause précédent.  
                      </td>               
                  </tr>       
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">L’accord mutuel entre les parties, exprimé dans un document signé par les représentants
                      légaux des entités.                   
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">L’impossibilité technique, administrative ou légale de poursuivre l’exécution du contrat.                    
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">4.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">La survenance de circonstances fortuites ou d’un cas de plus grave qui empêche la poursuite
                      de l’enquête du contrat.                  
                      </td>               
                  </tr> 
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">5.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Non-respect par l’une ou l’autre des parties des conditions du contrat décrites précédemment.                   
                      </td>               
                  </tr>
                  
              </table>';
  
              
  
          $pdf->writeHTML($html12, true, false, true, false, '');
          $pdf->SetFont("minionc", '', 8);
          $pdf->writeHTML($html13, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html14, true, false, true, false, '');
          $pdf->SetFont("minionc", '', 8);
          $pdf->writeHTML($html15, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html16, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html17, true, false, true, false, '');
  
           // add a page
           $resolution= array(248, 350);
           $pdf->SetMargins(20, 20, 20, true);
           $pdf->AddPage('P', $resolution);
  
           // get the current page break margin
           $bMargin = $pdf->getBreakMargin();
           // get current auto-page-break mode
           $auto_page_break = $pdf->getAutoPageBreak();
           // disable auto-page-break
           $pdf->SetAutoPageBreak(false, 0);
           // set bacground image
  
           $img_file = $this->container->getparameter('kernel.project_dir').'/web/img/contrato_firma.jpg';
           $pdf->Image($img_file, 0, 0, 248, 350, '', '', '', false, 600, '', false, false, 0);
  
          
  
           $html18 = '
             <table border="0">
                 <tr>
                      <td colspan="8" align="right" style="color:black;text-align:center;font-weight:bold;font-size:30pt;height:60pt;"></td>
                 </tr>
                 <tr>
                     <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">CINQUIÈME: LES RELATIONS ENTRE LES PARTIES:  
                     </td>
                 </tr>               
             </table>';
  
           $html19 = '
             <table border="0">
                 <tr>
                     <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">En conséquence du présent contrat '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' peut offrir le programme d’autonomie de
                     Interweave à des tiers. Les valeurs de ce programme seront mesurées par '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' selon les
                     critères de négociation, tant que les valeurs que INTERWEAVE a énoncées ne sont pas modifiées.  
                     </td>
                 </tr>               
             </table>';
  
           $html20 = '
             <table border="0">
                  
                 <tr>
                     <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">SIXIEMEMENT: L’UTILISATION DE L’IDENTITÉ DE L’ORGANIZATION: 
                     </td>
                 </tr>               
             </table>';
  
             $html21 = '
             <table border="0">
                 <tr>
                     <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">Les communications
                     et documents qui résultent de l’exécution du présent contrat permettront l’utilisation de son
                     image corporative, mais cela n’implique pas l’acceptation d’obligations de solidarité entre eux.
                     Les limites sur l’utilisation du nom et des logos officiels sont les suivantes: 
                     </td>
                 </tr>               
             </table>';
  
           $html22 = '
             <table border="0" >         
                 
                 <tr>
                     <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                     <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Lors de la création d’une entité juridique, '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).'  n’est pas autorisé à utiliser le nom
                     Interweave Solutions, ou tout nom lui ressemblant (Interweave Business Solutions,
                     Interweave Solutions Ambassadors, etc.). 
                     </td>               
                 </tr>       
                 <tr>
                     <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                     <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">'.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' ne changera ni ne modifiera les logos et graphiques officiels d’Interweave.                   
                     </td>               
                 </tr>
                 <tr>
                     <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                     <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%"> Le nom et la marque d’Interweave ne seront pas utilisés par d’autres parties dans des
                     documents ou des transactions qui ne sont pas conformes à la mission, à la vision et aux
                     valeurs d’Interweave, que ce soit pour des affaires ou des activités personnelles.                    
                     </td>               
                 </tr>
                
                 
             </table>';
  
             $html23 = '
             <table border="0">
                  
                 <tr>
                     <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">SEPTIÈMEMENT: LES MISES À JOUR DES MODALITÉS DU PRÉSENT CONTRAT:
                     </td>
                 </tr>               
             </table>';
  
             $html24 = '
             <table border="0">
                 <tr>
                     <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">Toutes les modalités
                     du présent contrat sont conditionnelles à la tenue à jour du Guide de l’Ambassadeur du Succès et
                     d’autres documents de formation. Les conditions peuvent être modifiées ou mises à jour au besoin sans
                     l’approbation de l’ambassadeur, à condition qu’elles soient rendues publiques et clairement annoncées
                     par le biais des plateformes de communication de l’Ambassadeur du Succès, dont le courriel, Facebook
                     et WhatsApp, et des webinaires de formation mensuels. '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' est responsable de leur propre
                     conformité avec les normes d’Interweave à cet égard. 
                     </td>
                 </tr>               
             </table>';
  
  
             $html25 = '
             <table border="0">
                  
                 <tr>
                     <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">HUITIÈMEMENT: LA PERFECTION ET L’EXÉCUTION. 
                     </td>
                 </tr>               
             </table>';
  
             $html26 = '
             <table border="0">
                 <tr>
                     <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">. Le présent contrat s’entend parfaire sur
                     la base de sa souscription. Il est signé dans la ville de '.$this->getParameter($this->getParameter($ambassador->getCountry())).' au jour '.date("d/m/Y").'. 
                     </td>
                 </tr>               
             </table>';
  
             $html27 = '
             <table border="0">
                  <tr>
                      <td align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:90pt;">
                      </td>
                  </tr>
                 <tr>
                     <td align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">SIGNATURES DES PARTIES OFFICIELLES
                     </td>
                 </tr>               
             </table>';
  
             $html28 = '
             <table border="0">
                  <tr>
                      <td align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:40pt;">
                      </td>
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">Dean H. Curtis</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">'.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).'
                      </td>               
                  </tr>   
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">Executive Director</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">_______________________________
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">Interweave Solutions</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">SUCCESS AMBASSADOR
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">EIN 26-0870014</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">ID '.$ambassador->getIdnumber().'
                      </td>               
                  </tr>            
             </table>';
  
  
             
         $pdf->SetFont("minionc", '', 8);
         $pdf->writeHTML($html18, true, false, true, false, '');
         $pdf->SetFont("minionpro-regular", '', 8);
         $pdf->writeHTML($html19, true, false, true, false, '');
         $pdf->SetFont("minionc", '', 8);
         $pdf->writeHTML($html20, true, false, true, false, '');
         $pdf->SetFont("minionpro-regular", '', 8);
         $pdf->writeHTML($html21, true, false, true, false, '');
         $pdf->SetFont("minionpro-regular", '', 8);
         $pdf->writeHTML($html22, true, false, true, false, '');
         $pdf->SetFont("minionc", '', 8);
         $pdf->writeHTML($html23, true, false, true, false, '');
         $pdf->SetFont("minionpro-regular", '', 8);
         $pdf->writeHTML($html24, true, false, true, false, '');
         $pdf->SetFont("minionc", '', 8);
         $pdf->writeHTML($html25, true, false, true, false, '');
         $pdf->SetFont("minionpro-regular", '', 8);
         $pdf->writeHTML($html26, true, false, true, false, '');
         $pdf->SetFont("minionc", '', 8);
         $pdf->writeHTML($html27, true, false, true, false, '');
         $pdf->SetFont("minionpro-regular", '', 8);
         $pdf->writeHTML($html28, true, false, true, false, '');
  
  
  
        //Close and output PDF document
        $pdf->Output('sa_contract.pdf', 'I');
      }

      /**
     * @Rest\Get("/ambassador/pt/{id}.{_format}", name="ambassador_contract_pt", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets students of group info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The students with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Group ID"
     * )
     *
     * @SWG\Tag(name="Contract")
     */
    public function contractPtAction(Request $request, $id ) {

        $em = $this->getDoctrine()->getManager(); 
  
        $ambassador = $em->getRepository('App:User')->find($id);
        if(is_null($ambassador->getContractDate())){
            $ambassador->setContractDate(new \DateTime('now', (new \DateTimeZone('America/New_York'))));
            $em->persist($ambassador);
            $em->flush();
        }
  
        $pdf = $this->get('white_october.tcpdf.public')->create('horizontal', PDF_UNIT, PDF_PAGE_FORMAT, true, 'UTF-8', false);
        
        $pdf->SetAuthor('Interweave Solutions');
        $pdf->SetTitle(('MBS Contract'));
        $pdf->SetSubject('MBS Contract');
        $pdf->setFontSubsetting(true);
  
        
        $pdf->SetFont("minionc", '', 8);
  
  
          $html = '<h2></h2>
          <table border="0"  >
              <tr>
                  <td colspan="8" align="right" style="color:black;text-align:center;font-weight:bold;font-size:30pt;height:60pt;"></td>
              </tr>
              <tr>
                  <td colspan="8" align="center" style="color:black;text-align:center;font-weight:bold;font-size:14pt;height:22pt;">CONTRATO DE COOPERAÇÃO ENTRE INTERWEAVE SOLUTIONS E  </td>
              </tr>
              <tr>
                  <td colspan="8" align="center" style="color:black;text-align:center;font-weight:bold;font-size:14pt;height:1pt;">'.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).'</td>
              </tr>         
  
          </table>';
  
          $html2 = '
          <table border="0" >          
              <tr>
                  <td colspan="2" align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold;>Entre as partes oficiais deste documento, a saber: Dean Curtis, identificado com Passaporte US número
                  561402486, residente e domiciliado na cidade de Provo, Utah, Estados Unidos da América que atua
                  em nome e em representação da organização Não-Governamental INTERWEAVE SOLUTIONS, com
                  sede principal de organização em Provo, Utah, Estados Unidos da América que a partir de agora e
                  para todos os efeitos deste contrato será conhecido simplesmente como INTERWEAVE; e a outra parte '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).', com idade legal, residente e domiciliado (a) na cidade de '.$ambassador->getCity().', '.$this->getParameter($this->getParameter($ambassador->getCountry())).',
                  com identificação número '.$ambassador->getIdnumber().', que age em seu próprio
                  nome e representação legal, que doravante, para todos os efeitos deste contrato, será referido (a) como  '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).'.
                  </td>
              </tr> 
                 
  
          </table>';
  
          $html3 = '<h2></h2>
          <table border="0"  >          
              <tr>
                  <td colspan="8" align="center" style="color:black;text-align:center;font-weight:bold;font-size:14pt;height:22pt;">CONSIDERAÇÕES</td>
              </tr>               
  
          </table>';
  
          $html4 = '
          <table border="0" >         
              
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).' concluiu e enviou todos os requisitos estabelecidos pela Interweave para
                  se tornar um Embaixador de Sucesso, incluindo certificação no curso MBS, certificação no curso de
                  Embaixador de Sucesso, ensino e treinamento de pelo menos um grupo MBS, pagamento de taxas
                  aplicáveis à Interweave, e quaisquer outros requisitos especificados anteriormente pela Interweave.
                  </td>               
              </tr>       
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).', com o apoio da INTERWEAVE, oferecerá o programa MBS (MASTER
                  OF BUSINESS IN THE STREETS), cujo principal objetivo é melhorar a qualidade de vida das pessoas
                  em condições vulneráveis, promovendo ideias comerciais e fortalecendo as empresas existentes, levando
                  essas pessoas à autossuficiência.                  
                  </td>               
              </tr>
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).', com o apoio da INTERWEAVE, treinará grupos de pessoas na região de 
                  '.$this->getParameter($this->getParameter($ambassador->getCountry())).' l levando essas pessoas a se tornarem autossuficientes nas áreas de negócios,
                  do lar e da comunidade.                  
                  </td>               
              </tr>
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">4.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).', procurará fortalecer o quadro social da comunidade nas regiões de
                  '.$this->getParameter($this->getParameter($ambassador->getCountry())).' através de programas educacionais de autossuficiência, facilitando a criação
                  de ideias empresariais e o fortalecimento das empresas atuais para serem sustentáveis e competitivas.                 
                  </td>               
              </tr> 
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">5.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).', e INTERWEAVE, compreendam e considerem que os funcionários do governo local
                  e outras organizações, tanto públicas quanto privadas, também se esforçarão para atingir esses mesmos
                  objetivos, e considerem fortemente a criação de parcerias contratadas e o trabalho em colaboração com
                  essas entidades.                   
                  </td>               
              </tr>
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">6.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que '.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).', e INTERWEAVE identificarāo elementos similares de cooperação dentro
                  de suas próprias organizações para desenvolver uma cooperação entre essas organizações, reconhecendo
                  que nenhuma das partes está agindo como um funcionário legal da outra. Ambos concordam que, é para
                  o benefício dessas organizações unir forças e desenvolver mecanismos de cooperação e apoio com os
                  mesmos propósitos dessas organizações.                    
                  </td>               
              </tr>
              <tr>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">7.</td>
                  <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Que os direitos e materiais do MBS, não podem ser utilizados sem a autorização da INTERWEAVE.                  
                  </td>               
              </tr>
          </table>';
  
          $html5 = '<h2></h2>
          <table border="0"  >          
              <tr>
                  <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:13pt;height:22pt;">Levando-se em conta as considerações anteriores, as partes concordam em manter os
                  compromissos e serem regidas pelas seguintes cláusulas:  </td>
              </tr>               
  
          </table>';
  
  
  
  
            // add a page
            $resolution= array(248, 350);
            $pdf->SetMargins(20, 20, 20, true);
            $pdf->AddPage('P', $resolution);
  
            // get the current page break margin
            $bMargin = $pdf->getBreakMargin();
            // get current auto-page-break mode
            $auto_page_break = $pdf->getAutoPageBreak();
            // disable auto-page-break
            $pdf->SetAutoPageBreak(false, 0);
            // set bacground image
  
  
              $img_file = $this->container->getparameter('kernel.project_dir').'/web/img/contract_template.jpg';
              $pdf->Image($img_file, 0, 0, 248, 350, '', '', '', false, 600, '', false, false, 0);
           
  
            
  
            
            // restore auto-page-break status
            $pdf->SetAutoPageBreak($auto_page_break, $bMargin);
            // set the starting point for the page content
            $pdf->setPageMark();
  
  
            // Print a text
            // Print a text
            $pdf->writeHTML($html, true, false, true, false, '');
            $pdf->SetFont("minionpro-regular", '', 8);
            $pdf->writeHTML($html2, true, false, true, false, '');
            $pdf->SetFont("minionc", '', 8);
            $pdf->writeHTML($html3, true, false, true, false, '');
            $pdf->SetFont("minionpro-regular", '', 8);
            $pdf->writeHTML($html4, true, false, true, false, '');
            $pdf->writeHTML($html5, true, false, true, false, '');
            $pdf->SetFont("minionc", '', 8);
  
            // add a page
            $resolution= array(248, 350);
            $pdf->SetMargins(40, 20, 30, true);
            $pdf->AddPage('P', $resolution);
  
            // get the current page break margin
            $bMargin = $pdf->getBreakMargin();
            // get current auto-page-break mode
            $auto_page_break = $pdf->getAutoPageBreak();
            // disable auto-page-break
            $pdf->SetAutoPageBreak(false, 0);
            // set bacground image
  
            $img_file = $this->container->getparameter('kernel.project_dir').'/web/img/contract_template.jpg';
            $pdf->Image($img_file, 0, 0, 248, 350, '', '', '', false, 600, '', false, false, 0);
  
            $html6 = '
              <table border="0">
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:30pt;height:60pt;"></td>
                  </tr>
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">PRIMEIRA: OBJETIVO DO CONTRATO:   </td>
                  </tr>                   
  
              </table>';
  
            $html7 = '
            <table border="0"  >          
                <tr>
                    <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:13pt;height:80pt;">O objetivo geral deste contrato é declarar as ações,
                    esforços, habilidades e conhecimentos necessários para melhor desenvolver NEGÓCIO, LAR e
                    COMUNIDADES. Isto ajudará a melhorar a qualidade de vida entre as populações vulneráveis
                    de  '.$this->getParameter($this->getParameter($ambassador->getCountry())).'. Os tópicos de treinamento incluem a criação e melhoria de
                    negócios sustentáveis, a melhoria da vida no lar e em família e a participação em iniciativas de
                    desenvolvimento comunitário.  </td>
                </tr>               
    
            </table>';
  
            $html8 = '
              <table border="0">
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">SEGUNDA: OBRIGAÇÕES ESPECÍFICAS DE CADA PARTE. 
                      </td>
                  </tr>    
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">A. A SABER, DA INTERWEAVE: 
                      </td>
                  </tr>               
              </table>';
  
            $html9 = '
              <table border="0" >         
                  
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Fornecer certificação oficial e autorizada para
                      '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' como Embaixador de Sucesso.
                      </td>               
                  </tr>       
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Transmitir a metodologia do Programa MBS da Interweave para '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' através de
                      treinamento pessoal previamente acordado por ambas as partes.                  
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Fornecer o acesso aos materiais de treinamento do Programa MBS para participantes
                      e Facilitadores dos grupos de autossuficiência, incluindo cursos, manuais, conferências e
                      seminários.                   
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">4.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Fornecer uma cópia do Manual do Facilitador - Embaixador de Sucesso para  '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' para revisão contínua das especificações incluídas neste contrato.                 
                      </td>               
                  </tr> 
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">5.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Publicar o nome e informações de contato de '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' on Interweave’s official website.                  
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">6.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">no site oficial da Interweave.
                      6. Disponibilizar no formato digital o certificado de MASTER OF BUSINESS IN THE
                      STREETS (MBS) para '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' em nome de cada participante que tenha
                      completado todos os requisitos do programa MBS através das plataformas especificadas pela
                      Interweave. ( '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' será responsável por fornecer o Certificado em forma impressa ao
                      participante.)                   
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">7.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Oferecer materiais adicionais e treinamento operando sob as considerações especificadas
                      no Manual do Facilitador - Embaixador de Sucesso.
                                      
                      </td>               
                  </tr>
              </table>';
  
              $html10 = '
              <table border="0">
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:5pt;"> 
                      </td>
                  </tr>    
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">B. A SABER, DE '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).': 
                      </td>
                  </tr>               
              </table>';
  
            $html11 = '
              <table border="0" >         
                  
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Criar grupos de autossuficiência para participar do curso MASTER OF BUSINESS IN
                      THE STREETS (MBS), promovendo no mínimo um grupo durante os primeiros seis meses de
                      autorização como Embaixador de Sucesso e, posteriormente organizar um grupo adicional a
                      cada ano.
                      </td>               
                  </tr>       
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Assumir a responsabilidade de participar de treinamentos regulares, melhoria de produtos,
                      atualizações dos termos e condições da parceria e normas, bem como rever regularmente os
                      requisitos e diretrizes descritas no Manual do Facilitador - Embaixador de Sucesso. Reconhecer
                      que não é responsabilidade da Interweave assegurar que o Embaixador de Sucesso esteja 
                      ciente e seguindo quaisquer políticas e procedimentos originais ou atualizados, desde que quaisquer
                      mudanças estejam facilmente disponíveis e acessíveis aos Embaixadores em nível universal.                  
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Se o treinamento for feito através de uma organização terceirizada, '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' é
                      responsável por selecionar as pessoas desta organização que receberão o treinamento metodológico da
                      INTERWEAVE para os Programas de Autossuficiência MBS.                    
                      </td>               
                  </tr>
                  
                  
              </table>';
  
              
  
          $pdf->writeHTML($html6, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html7, true, false, true, false, '');
          $pdf->SetFont("minionc", '', 8);
          $pdf->writeHTML($html8, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html9, true, false, true, false, '');
          $pdf->SetFont("minionc", '', 8);
          $pdf->writeHTML($html10, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html11, true, false, true, false, '');
  
            // add a page
            $resolution= array(248, 350);
            $pdf->SetMargins(40, 20, 30, true);
            $pdf->AddPage('P', $resolution);
  
            // get the current page break margin
            $bMargin = $pdf->getBreakMargin();
            // get current auto-page-break mode
            $auto_page_break = $pdf->getAutoPageBreak();
            // disable auto-page-break
            $pdf->SetAutoPageBreak(false, 0);
            // set bacground image
  
            $img_file = $this->container->getparameter('kernel.project_dir').'/web/img/contract_template.jpg';
            $pdf->Image($img_file, 0, 0, 248, 350, '', '', '', false, 600, '', false, false, 0);
  
            $html12 = '
              <table border="0">
                  <tr>
                      <td colspan="8" align="right" style="color:black;text-align:center;font-weight:bold;font-size:30pt;height:60pt;"></td>
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">4.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%"Submeter uma pré e pós avaliação de cada participante antes de sua graduação e preencher um
                      formulário de auto-avaliação de Embaixador de Sucesso, de acordo com as regras e diretrizes da
                      INTERWEAVE, e entender que a Interweave não emitirá, em nenhuma circunstância, um certificado
                      ou materiais para os graduados da MBS até que isto seja concluído através de plataformas especificadas.                 
                      </td>               
                  </tr> 
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">5.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Ceder à INTERWEAVE acesso e direitos de uso de todas as fotografias, vídeos, histórias e nomes
                      compartilhados em plataformas públicas ou através de comunicação pessoal com representantes da
                      Interweave para fins de marketing, criação de ativos, desenvolvimento de currículo ou quaisquer
                      outros, conforme considerado apropriado pela INTERWEAVE, bem como consentimento para
                      publicar informações de contato pessoal on-line, e assegura que qualquer mídia compartilhada com a
                      INTERWEAVE foi autorizada para uso pelo Embaixador de Sucesso.                  
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">6.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Oferecer treinamento do curso MBS de conformidade com os materiais publicados pela
                      INTERWEAVE, sem alterações na metodologia ou processos, a não ser que seja concedida autorização
                      por escrito da Interweave 
                      </td>               
                  </tr>       
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">7.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Manter todos os acordos e obrigações estabelecidos para os participantes do curso MBS, incluindo a
                      entrega de certificados e cerimônias de graduação.                  
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">8.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Viver e agir de acordo com a Missão, Visão e Valores da INTERWEAVE em todas as ações e
                      interações, quer relacionadas ao seu trabalho como Embaixador de Sucesso, quer em sua vida pessoal,
                      e defender e manter esses valores no convívio com outros Embaixadores de Sucesso.                    
                      </td>               
                  </tr>
                       
  
              </table>';
  
            $html13 = '
              <table border="0">
                   
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">TERCEIRA: TERMOS DA DURAÇÃO DO CONTRATO: 
                      </td>
                  </tr>               
              </table>';
  
            $html14 = '
              <table border="0">
                  <tr>
                      <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">O presente contrato terá um prazo de duração de quatro anos, contados a partir da data de assinatura
                      de ambas as partes. Isto permanece válido enquanto o Embaixador cumprir com os requisitos
                      estabelecidos pela Interweave para ser um Embaixador de Sucesso. Entretanto, poderá ser prorrogado
                      de comum acordo, desde que haja a intenção de ambas as partes na prorrogação e assinatura do
                      respectivo contrato. Além disso, a Interweave mantém o direito de rescindir o contrato a qualquer
                      momento se a outra parte for considerada inadequada para continuar como um Embaixador de
                      Sucesso, sem especificar os motivos. 
                      </td>
                  </tr>               
              </table>';
  
            $html15 = '
              <table border="0">
                   
                  <tr>
                      <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">QUARTA: MOTIVOS PARA O ENCERRAMENTO DO CONTRATO: 
                      </td>
                  </tr>               
              </table>';
  
              $html16 = '
              <table border="0">
                  <tr>
                      <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">
                      </td>
                  </tr>               
              </table>';
  
            $html17 = '
              <table border="0" >         
                  
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Expiração do período acordado, exceto pelas disposições da cláusula anterior. 
                      </td>               
                  </tr>       
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Acordo mútuo entre as partes, expresso em documento assinado por representantes das instituições.                   
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%"> A impossibilidade técnica, administrativa ou legal de continuar com a realização deste contrato.                    
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">4.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">A ocorrência de circunstâncias de um caso fortuito ou força maior que impeça a prorrogação deste
                      contrato.                  
                      </td>               
                  </tr> 
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">5.</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Falha de qualquer uma das partes no cumprimento de quaisquer termos previamente
                      descritos neste contrato.                   
                      </td>               
                  </tr>
                  
              </table>';
  
              
  
          $pdf->writeHTML($html12, true, false, true, false, '');
          $pdf->SetFont("minionc", '', 8);
          $pdf->writeHTML($html13, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html14, true, false, true, false, '');
          $pdf->SetFont("minionc", '', 8);
          $pdf->writeHTML($html15, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html16, true, false, true, false, '');
          $pdf->SetFont("minionpro-regular", '', 8);
          $pdf->writeHTML($html17, true, false, true, false, '');
  
           // add a page
           $resolution= array(248, 350);
           $pdf->SetMargins(20, 20, 20, true);
           $pdf->AddPage('P', $resolution);
  
           // get the current page break margin
           $bMargin = $pdf->getBreakMargin();
           // get current auto-page-break mode
           $auto_page_break = $pdf->getAutoPageBreak();
           // disable auto-page-break
           $pdf->SetAutoPageBreak(false, 0);
           // set bacground image
  
           $img_file = $this->container->getparameter('kernel.project_dir').'/web/img/contrato_firma.jpg';
           $pdf->Image($img_file, 0, 0, 248, 350, '', '', '', false, 600, '', false, false, 0);
  
          
  
           $html18 = '
             <table border="0">
                 <tr>
                      <td colspan="8" align="right" style="color:black;text-align:center;font-weight:bold;font-size:30pt;height:60pt;"></td>
                 </tr>
                 <tr>
                     <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">QUINTA: RELAÇÃO COM TERCEIROS: 
                     </td>
                 </tr>               
             </table>';
  
           $html19 = '
             <table border="0">
                 <tr>
                     <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">Como resultado do presente contrato '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' pode oferecer o Programa de
                     Autossuficiência da Interweave para terceiros. Os valores deste programa serão calculados
                     por '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' de acordo com os critérios de negociação, desde que os valores
                     estabelecidos pela INTERWEAVE não sejam alterados.  
                     </td>
                 </tr>               
             </table>';
  
           $html20 = '
             <table border="0">
                  
                 <tr>
                     <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">SEXTA: USO DE IMAGENS CORPORATIVAS: 
                     </td>
                 </tr>               
             </table>';
  
             $html21 = '
             <table border="0">
                 <tr>
                     <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;"> Os comunicados e documentos resultantes da
                     implementação deste contrato permitirão o uso de imagem corporativa, mas isto não implica
                     a aceitação de obrigações de solidariedade entre as partes. O critério para o uso do nome e dos
                     logotipos oficiais são os seguintes: 
                     </td>
                 </tr>               
             </table>';
  
           $html22 = '
             <table border="0" >         
                 
                 <tr>
                     <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">1.</td>
                     <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">Na criação de uma pessoa jurídica, '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' não está autorizado a usar o
                     nome da INTERWEAVE, ou qualquer nome semelhante (ex.: Interweave Business Solutions,
                     Interweave Solutions Ambassadors, etc.) 
                     </td>               
                 </tr>       
                 <tr>
                     <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">2.</td>
                     <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">'.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' não mudará ou modificará os logotipos e gráficos oficiais da Interweave.                   
                     </td>               
                 </tr>
                 <tr>
                     <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="4%">3.</td>
                     <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="96%">O nome e a marca INTERWEAVE não serão usados por nenhuma outra parte em
                     qualquer material ou transação que não seja consistente com a Missão, Visão e Valores da
                     INTERWEAVE, seja para negócios ou empreendimentos pessoais.                    
                     </td>               
                 </tr>
                
                 
             </table>';
  
             $html23 = '
             <table border="0">
                  
                 <tr>
                     <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">SÉTIMA: ATUALIZAÇÕES DESTE CONTRATO: 
                     </td>
                 </tr>               
             </table>';
  
             $html24 = '
             <table border="0">
                 <tr>
                     <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">Todos os termos e condições deste contrato
                     estão condicionados à atualização dos materiais de treinamento. Os termos podem ser
                     alterados ou atualizados conforme necessário sem a aprovação do Embaixador, desde que
                     sejam tornados públicos e claramente anunciados através das plataformas de comunicação. 
                      '.ucwords(mb_strtolower($ambassador->getFirstName(),'UTF-8')).' é responsável pela sua própria concordância com as normas da
                      Interweave a este respeito. 
                     </td>
                 </tr>               
             </table>';
  
  
             $html25 = '
             <table border="0">
                  
                 <tr>
                     <td colspan="8" align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;"> 
                     </td>
                 </tr>               
             </table>';
  
             $html26 = '
             <table border="0">
                 <tr>
                     <td colspan="8" align="justify" style="color:black;text-align:justify;font-weight:bold;font-size:14pt;height:0pt;">Este contrato é entendido como acordado com base em sua assinatura. É assinado no país de '.$this->getParameter($this->getParameter($ambassador->getCountry())).' no dia '.date("d/m/Y").'. 
                     </td>
                 </tr>               
             </table>';
  
             $html27 = '
             <table border="0">
                  <tr>
                      <td align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:90pt;">OITAVO: PERFEIÇÃO E EXECUÇÃO.  
                      </td>
                  </tr>
                 <tr>
                     <td align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:0pt;">ASSINATURAS DAS PARTES OFICIAIS
                     </td>
                 </tr>               
             </table>';
  
             $html28 = '
             <table border="0">
                  <tr>
                      <td align="left" style="color:black;text-align:left;font-weight:bold;font-size:14pt;height:40pt;">
                      </td>
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">Dean H. Curtis</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">'.ucwords(mb_strtolower($ambassador->getFirstName().' '.$ambassador->getLastName(),'UTF-8')).'
                      </td>               
                  </tr>   
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">Executive Director</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">_______________________________
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">Interweave Solutions</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">Embaixador de Sucesso 
                      </td>               
                  </tr>
                  <tr>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">EIN 26-0870014</td>
                      <td align="justify" style="color:black;text-align:justify;font-size:13pt;height:10pt;" font-weight:bold; width="50%">Número de identificação. '.$ambassador->getIdnumber().'
                      </td>               
                  </tr>            
             </table>';
  
  
             
         $pdf->SetFont("minionc", '', 8);
         $pdf->writeHTML($html18, true, false, true, false, '');
         $pdf->SetFont("minionpro-regular", '', 8);
         $pdf->writeHTML($html19, true, false, true, false, '');
         $pdf->SetFont("minionc", '', 8);
         $pdf->writeHTML($html20, true, false, true, false, '');
         $pdf->SetFont("minionpro-regular", '', 8);
         $pdf->writeHTML($html21, true, false, true, false, '');
         $pdf->SetFont("minionpro-regular", '', 8);
         $pdf->writeHTML($html22, true, false, true, false, '');
         $pdf->SetFont("minionc", '', 8);
         $pdf->writeHTML($html23, true, false, true, false, '');
         $pdf->SetFont("minionpro-regular", '', 8);
         $pdf->writeHTML($html24, true, false, true, false, '');
         $pdf->SetFont("minionc", '', 8);
         $pdf->writeHTML($html25, true, false, true, false, '');
         $pdf->SetFont("minionpro-regular", '', 8);
         $pdf->writeHTML($html26, true, false, true, false, '');
         $pdf->SetFont("minionc", '', 8);
         $pdf->writeHTML($html27, true, false, true, false, '');
         $pdf->SetFont("minionpro-regular", '', 8);
         $pdf->writeHTML($html28, true, false, true, false, '');
  
  
  
        //Close and output PDF document
        $pdf->Output('sa_contract.pdf', 'I');
      }

   
 
}