<?php
 
namespace App\Controller;
 
use App\Entity\User;
use App\Entity\Course;
use App\Form\CourseType;
use App\Form\UserPasswordEditType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\AdminDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class CourseController
 *
 * @Route("/course")
 */
class CourseController extends FOSRestController
{
    
 
    /**
     * @Rest\Get("/", name="course_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all courses."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all course courses."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Course")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $courses = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $courses = $em->getRepository("App:Course")->findAll();
 
            if (is_null($courses)) {
                $courses = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Admins - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $courses : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array("course_list"))));
    }

 

    /**
     * @Rest\Post("/new", name="course_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="User was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="User was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The course name",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="state",
     *     in="body",
     *     type="string",
     *     description="The state",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="user_id",
     *     in="body",
     *     type="integer",
     *     description="The Admin id of the new Principle",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="string",
     *     description="The course Language",
     *     schema={}
     * )
     *    
     * @SWG\Parameter(
     *     name="roles",
     *     in="body",
     *     type="array",
     *     description="The roles assigned to this course",
     *     schema={}
     * ) 
     * 
     * @SWG\Parameter(
     *     name="picture",
     *     in="body",
     *     type="array",
     *     description="The picture assigned to this course",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="code",
     *     in="body",
     *     type="array",
     *     description="The code assigned to this course",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="requirement",
     *     in="path",
     *     type="string",
     *     description="The set of requirements"
     * )
     *      
     *
     * @SWG\Tag(name="Course")
     */ 
    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $roles = explode(',', $request->request->get('roles'));
 
        $message = "";

        $course = new Course();
        //Create a form
        $form=$this->createForm(CourseType::class, $course);
        $form->submit($request->request->all());
        $admin = $em->getRepository("App:User")->find($request->request->get('user_id'));
       
        try {
            $code = 200;
            $error = false;
            $course->setRoles($roles);
            $course->setAdmin($admin);
            $em->persist($course);
            $em->flush();
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the course - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $course : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/clone", name="course_clone")
     *
     * @SWG\Response(
     *     response=201,
     *     description="User was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="User was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The course name",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="state",
     *     in="body",
     *     type="string",
     *     description="The state",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="user_id",
     *     in="body",
     *     type="integer",
     *     description="The Admin id of the new Principle",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="string",
     *     description="The course Language",
     *     schema={}
     * )
     *    
     * @SWG\Parameter(
     *     name="roles",
     *     in="body",
     *     type="array",
     *     description="The roles assigned to this course",
     *     schema={}
     * ) 
     * 
     * @SWG\Parameter(
     *     name="picture",
     *     in="body",
     *     type="array",
     *     description="The picture assigned to this course",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="code",
     *     in="body",
     *     type="array",
     *     description="The code assigned to this course",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="requirement",
     *     in="path",
     *     type="string",
     *     description="The set of requirements"
     * )
     * 
    * @SWG\Parameter(
     *     name="clone_id",
     *     in="path",
     *     type="string",
     *     description="The id of the original course"
     * )
     *      
     *
     * @SWG\Tag(name="Course")
     */ 
    public function cloneAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $roles = explode(',', $request->request->get('roles'));
        $clone_id = $request->request->get('clone_id');
 
        $message = "";

        $course = new Course();
        //Create a form
        $form=$this->createForm(CourseType::class, $course);
        $form->submit($request->request->all());
        $admin = $em->getRepository("App:User")->find($request->request->get('user_id'));
       
        try {
            $code = 200;
            $error = false;
            $course->setRoles($roles);
            $course->setAdmin($admin);
            $em->persist($course);
            $em->flush();

            $units = $em->getRepository("App:Unit")->findBy(array('course' => $clone_id));
            foreach ($units as $unit) {
                $principles = $em->getRepository("App:Principle")->findBy(array('unit' => $unit->getId()));
                $new_unit = clone $unit;
                $new_unit->setCourse($course);
                $em->persist($new_unit);
                $em->flush();

                foreach ($principles as $principle) {
                    $new_principle = clone $principle;
                    $new_principle->setUnit($new_unit);
                    $em->persist($new_principle);
                    $em->flush();
                }
            }
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the course - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $course : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }


    /**
     * @Rest\Get("/show/{id}.{_format}", name="course_show_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets course info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The course with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Course ID"
     * )
     * 
     *
     * @SWG\Tag(name="Course")
     */
    public function showAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $course = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $course_id = $id;
            $course = $em->getRepository("App:Course")->find($course_id);
 
            if (is_null($course)) {
                $code = 500;
                $error = true;
                $message = "The Course does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Course- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $course : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()->setGroups(array('show_course'))));
    }

    

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="course_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The course was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the course."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The course ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The course name",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="state",
     *     in="body",
     *     type="string",
     *     description="The state",
     *     schema={}
     * )
     *    
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="string",
     *     description="The course Language",
     *     schema={}
     * )
     * 
     *  @SWG\Parameter(
     *     name="picture",
     *     in="body",
     *     type="array",
     *     description="The picture assigned to this course",
     *     schema={}
     * )  
     * 
     *  @SWG\Parameter(
     *     name="code",
     *     in="body",
     *     type="array",
     *     description="The code assigned to this course",
     *     schema={}
     * )
     * 
     *  @SWG\Parameter(
     *     name="requirement",
     *     in="path",
     *     type="string",
     *     description="The set of requirements"
     * )
     *
     * @SWG\Tag(name="Course")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $roles = explode(',', $request->request->get('roles'));
        $course = [];
        $message = "";
        

        try {
            $code = 200;
            $error = false;
            $course = $em->getRepository("App:Course")->find($id);
 
            if (!is_null($course)) {
                $form = $this->createForm(CourseType::class, $course);
                $form->submit($request->request->all()); 
                $course->setRoles($roles);            
 
                $em->persist($course);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Admin - Error: You must to provide fields course or the course id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the course - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $course : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Post("/available/list", name="available_course_list", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The course was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the course."
     * )
     *
     * @SWG\Parameter(
     *     name="user_id",
     *     in="path",
     *     type="string",
     *     description="The user ID"
     * )
     *     
     *
     * @SWG\Tag(name="Course")
     */
    public function availableCourseAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $user_id = $request->request->get('user_id');
        $courses = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $user = $em->getRepository("App:User")->find($user_id);
            $language = $user->getLanguage();

            if (!is_null($user)) {
                $roles = $user->getRoles();
                if($user->getStudentgroup()){

                    $group_id = $user->getStudentgroup()->getGroup()->getId();
                    if($group_id === 7911){
                        $courses = $em->getRepository("App:Course")->getAvailableCourses("ROLE_FUNNEL", $language);
                    }
                    else{
                        $courses = $em->getRepository("App:Course")->getAvailableCourses($roles[0], $language);
                    }
                }
                else{
                    $courses = $em->getRepository("App:Course")->getAvailableCourses($roles[0], $language);
                }
                
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Admin - Error: You must to provide fields course or the course id does not exist";
            }
            
           
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the course - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $courses : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array("show_course"))));
    }

     

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="course_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Admin was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the course"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The course ID"
     * )
     *
     * @SWG\Tag(name="Course")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $course = $em->getRepository("App:Course")->find($id);
 
            if (!is_null($course)) {
                $em->remove($course);
                $em->flush();
 
                $message = "The course was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent course - Error: The course id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current course - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    

}