<?php

 
namespace App\Controller;
 
use App\Entity\Grant;
use App\Form\GrantType;
use App\Entity\GrantUpdate;
use App\Form\GrantUpdateType;
use App\Entity\GrantAmbassador;
use App\Entity\GrantGroup;
use App\Form\GrantAmbassadorType;
use App\Form\GrantAmbassadorUpdateType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\UserDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class GrantController
 *
 * @Route("/grant")
 */
class GrantController extends FOSRestController
{
    
    /**
     * @Rest\Post("/", name="grants_index")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all grants."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all grants."
     * )
     *
     * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="path",
     *     type="string",
     *     description="The ID of Ambassador"
     * )
     * 
     * @SWG\Parameter(
     *     name="role",
     *     in="path",
     *     type="string",
     *     description="The role of user"
     * )
     *
     *
     * @SWG\Tag(name="Grant")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grants = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
            $current_date_3 = new \DateTime();
 
            $role = $request->request->get('role');
            $id = $request->request->get('id_ambassador');
            if($role == 'ROLE_ADMIN' or $role == 'ROLE_LANGUAGE_ADMIN'){
                $outdate_grants = $em->getRepository("App:Grant")->grantByDate("state.available", $current_date_3->format('Y-m-d'));
                foreach ($outdate_grants as $gr) {
                    $gr->setState("state.not_available");
                    $em->persist($gr);
                    $em->flush();
                }
                $grants = $em->getRepository("App:Grant")->findBy(array(), array("state" => "ASC", "id" => "DESC"));

            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Grant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grants : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

     /**
     * @Rest\Get("/deadline", name="grants_deadline")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all grants."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all grants."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Grant")
     */
    public function deadlineAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $deadline = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
            $deadline = date("Y-m-t");
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get deadline Grant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $deadline : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Post("/ambassadorlist", name="grants_ambassador_list")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all grants."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all grants."
     * )
     *
     * @SWG\Parameter(
     *     name="state",
     *     in="path",
     *     type="string",
     *     description="The state of grants"
     * )
     *     
     *
     *
     * @SWG\Tag(name="Grant")
     */
    public function listAmbassadorAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grantsambassador = [];
        $applications = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $state = $request->request->get('state');
            $grantsambassador = $em->getRepository("App:GrantAmbassador")->findBy(array("state" => $state));

            foreach ($grantsambassador as $ga) {
                if($ga->getGrant()->getType() === "state.incentive"){
                    $attemps = count($em->getRepository("App:GrantAmbassador")->findBy(array("mentoredambassador" => $ga->getMentoredambassador() , "ambassador" => $ga->getAmbassador()->getId())));
                    $ga->setAttemps($attemps."th");
                } 
                if($ga->getGrant()->getType() === "state.growth"){    
                    $attemps = count($em->getRepository("App:GrantAmbassador")->ambassadorGrantByTypeState( $ga->getAmbassador()->getId(), "state.growth", "state.reject" ));
                    $ga->setAttemps(($attemps + 1)."th");
                }           
            }
           
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Grant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grantsambassador : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()->setGroups(array('grant_ambassador_list'))));
    }

     /**
     * @Rest\Post("/active", name="grant_active", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all active Grants."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all active grants."
     * )
     *    
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description="The language of user"
     * )
     * 
     * @SWG\Parameter(
     *     name="id_user",
     *     in="path",
     *     type="string",
     *     description="The id of user"
     * )
     *
     * @SWG\Tag(name="Grant")
     */
    public function activeAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grants_available = [];
        $grants_ambassador = [];
        $deadline_month = date("m-Y");
        $datem = "";
        
        $message = "";
 
        try {
            $code = 200;
            $error = false;

            $language = $request->request->get('language');
            $id_user = $request->request->get('id_user');
            $current_date = new \DateTime();
            $current_date_2 = new \DateTime();
            $current_date_3 = new \DateTime();
            $current_date_4 = new \DateTime();
            $current_date_5 = new \DateTime();

            $student = $em->getRepository("App:User")->find($id_user);
            $grants = $em->getRepository("App:Grant")->findBy(array("language" => $language, "state" => "state.available" ), array("state" => "ASC", "createdAt" => "DESC"));

            $incentiveRequirement = $em->getRepository("App:GrantRequirement")->findOneBy(array("type" => "state.incentive", "country" => $student->getCountry()));
            $growthRequirement = $em->getRepository("App:GrantRequirement")->findOneBy(array("type" => "state.growth", "country" => $student->getCountry()));

            if(is_null($incentiveRequirement)){
                $incentiveRequirement = $em->getRepository("App:GrantRequirement")->findOneBy(array("type" => "state.incentive", "customized" => "false"));
            }
            if(is_null($growthRequirement)){
                $growthRequirement = $em->getRepository("App:GrantRequirement")->findOneBy(array("type" => "state.growth", "customized" => "false"));
            }


            $init_date = $current_date->modify( '-6 month' )->format('Y-m-d');
            $four_month_init_date = $current_date_2->modify( '-'.$growthRequirement->getReceiptTime().' month' )->format('Y-m-d');
            $six_month_init_date = $current_date_4->modify( '-'.$incentiveRequirement->getActiveTime().' month' )->format('Y-m-d');
            $twelve_month_init_date = $current_date_5->modify( '-'.$growthRequirement->getActiveTime().' month' )->format('Y-m-d');

            $outdate_grants = $em->getRepository("App:Grant")->grantByDate("state.available", $current_date_3->format('Y-m-d'));
            foreach ($outdate_grants as $gr) {
                $gr->setState("state.not_available");
                $em->persist($gr);
                $em->flush();
            }
            
           
            

            foreach ($grants as $grant) {        
                $grant_requirements =  "false";

               
                if($grant->getType() === "state.matching"){

                    $four_month_matching_grants = $em->getRepository("App:GrantAmbassador")->ambassadorGrantByTypeDate($id_user, 'state.matching', $four_month_init_date);
                    $alumni_ambassador_list = $em->getRepository("App:StudentGroup")->nsaByAmbassador($id_user);
                    if(empty($four_month_matching_grants) && count($alumni_ambassador_list) >= 1 ){
                        $grant_requirements =  "true";
                    }
                 
                    

                }
                else if($grant->getType() === "state.incentive"){

                    $programSa = $em->getRepository("App:ProgramSa")->findOneBy(array('student' => $id_user));
                    if(is_null($programSa)){
                        $date_requirement =  true;
                    }
                    else{
                        $date_programsa = $em->getRepository("App:User")->ambassadorByDate($programSa->getId(), $six_month_init_date);
                        if(empty($date_programsa)){
                            $date_requirement =  false;
                        }
                        else{
                            $date_requirement = true;
                        }
                    }
                    $total_graduates = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassador($id_user, 'state.approved');
                    //$six_month_growth_grants = $em->getRepository("App:GrantAmbassador")->ambassadorGrantByTypeDate($id_user, 'state.growth', $init_date);
                    //$groups =  $em->getRepository("App:Groupe")->findBy(array("embassador" => $id_user));


                    $alumni_ambassador_list = $em->getRepository("App:StudentGroup")->nsaByAmbassador($id_user);

                    if(count($total_graduates) >= $incentiveRequirement->getMbsGraduates() && $date_requirement){
                        foreach ($alumni_ambassador_list as $st) {
                            $ambassador = $st->getStudent();
                            $graduates = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassador($ambassador->getId(), 'state.approved');                        
                            if(count($graduates) >= $incentiveRequirement->getNsaGraduates() ){
                                $gb = $em->getRepository("App:GrantAmbassador")->findOneBy(array("mentoredambassador" => $ambassador->getId(), "state" => "state.approved"));
                                if(is_null($gb)){
                                    $grant_requirements =  "true";
                                }
                            }
                        }
                    }

                }
                else if($grant->getType() === "state.growth"){

                    $programSa = $em->getRepository("App:ProgramSa")->findOneBy(array('student' => $id_user));
                    if(is_null($programSa)){
                        $date_requirement =  true;
                    }
                    else{
                        $date_programsa = $em->getRepository("App:User")->ambassadorByDate($programSa->getId(), $twelve_month_init_date);
                        if(empty($date_programsa)){
                            $date_requirement =  false;
                        }
                        else{
                            $date_requirement = true;
                        }
                    }
                    $all_time_growth_grants = $em->getRepository("App:GrantAmbassador")->ambassadorGrantByType($id_user, 'state.growth');
                    if(empty($all_time_growth_grants)){
                        $all_time_growth_grants = 0; 
                    }
                    else{
                        $all_time_growth_grants = count($all_time_growth_grants);
                    }
                    $growth_minimum_graduates = $growthRequirement->getMbsGraduates();
                    
                    if($student->getLanguage() == "en"){                
                        $total_graduates = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassadorFromDate($id_user, 'state.approved', '2024-01-01');
                    }
                    else{
                        $total_graduates = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassador($id_user, 'state.approved');
                    }

                    $growth_missing_graduates = ( ($all_time_growth_grants + 1) * $growth_minimum_graduates ) - count($total_graduates);
                    
                    
                    $six_month_growth_grants = $em->getRepository("App:GrantAmbassador")->ambassadorGrantByTypeDate($id_user, 'state.growth', $four_month_init_date);

                    if(empty($six_month_growth_grants) && $growth_missing_graduates <= 0 && $date_requirement){
                        $grant_requirements =  "true";
                    }

                    if($id_user == 73 || $id_user == 65987 || $id_user == 182 || $id_user == 74840 || $id_user == 71 || $id_user == 50 || $id_user == 49533 || $id_user == 67672 || $id_user == 83206 || $id_user == 16757 || $id_user == 62 || $id_user == 4816 || $id_user == 48 || $id_user == 257 || $id_user == 27850 || $id_user == 168 || $id_user == 167 || $id_user == 169 || $id_user == 60){
                        $grant_requirements =  "true";
                    }


                }else if($grant->getType() === "state.cooperative"){
                    $grant_requirements =  "true";
                }

                if($grant->getType() === "state.incentive"){
                    $grantAmbassador = $em->getRepository("App:GrantAmbassador")->findOneBy(array("ambassador" => $id_user, "state" => "state.development", "grant" => $grant->getId()));
                }
                else{
                    $grantAmbassador = $em->getRepository("App:GrantAmbassador")->findOneBy(array("grant" => $grant->getId(), "ambassador" => $id_user));
                }
                                
               
                $grt = [
                    'id'                    => $grant->getId(),
                    'title'                 => $grant->getTitle(),
                    'type'                  => $grant->getType(),
                    'administrator'         => $grant->getAdministrator(),
                    'deadline_date'         => $grant->getDeadlineDate(),
                    'requirements'          => $grant_requirements, 
                    'state_application'     => $grantAmbassador ? $grantAmbassador->getState() :  "state.not_started",
                    'id_grant_ambassador'   => $grantAmbassador ? strval($grantAmbassador->getId()) : "-1",
                ];

                $grants_available[] = $grt;               
            }

            $ambassador_grant_list = $em->getRepository("App:GrantAmbassador")->findBy(array("ambassador" => $id_user), array("createdAt" => "DESC"));
            foreach ($ambassador_grant_list as $agl) {
                if($agl->getState() != "state.development"){
                    $grants_ambassador[] = $agl;
                }
            }


            $grants = [                 
                'grants_available'   => $grants_available,
                'grants_ambassador'  => $grants_ambassador,
                'incentive_requirements' => $incentiveRequirement,
                'growth_requirements' => $growthRequirement
            ];
 
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Admins - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grants : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

     /**
     * @Rest\Post("/requirement", name="grant_requirement", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all active Grants."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all active grants."
     * )
     *    
     * @SWG\Parameter(
     *     name="id_grant",
     *     in="path",
     *     type="string",
     *     description="The id grant"
     * )
     * 
     * @SWG\Parameter(
     *     name="id_user",
     *     in="path",
     *     type="string",
     *     description="The id of user"
     * )
     *
     * @SWG\Tag(name="Grant")
     */
    public function requirementAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();        
        
        $message = "";
 
        try {
            $code = 200;
            $error = false;

            $id_grant = $request->request->get('id_grant');
            $id_user = $request->request->get('id_user');

            $student = $em->getRepository("App:User")->find($id_user);

            $ambassador_active_time = $em->getRepository("App:ProgramSa")->monthsFromApproval($id_user);
            $last_growth_approved_grant = $em->getRepository("App:GrantAmbassador")->monthsAmbassadorGrant($id_user, "state.growth");
            

            $incentiveRequirement = $em->getRepository("App:GrantRequirement")->findOneBy(array("type" => "state.incentive", "country" => $student->getCountry()));
            if(is_null($incentiveRequirement)){
                $incentiveRequirement = $em->getRepository("App:GrantRequirement")->findOneBy(array("type" => "state.incentive", "customized" => "false"));
            }
            $incentive_active_time = $incentiveRequirement->getActiveTime();
            $incentive_nsa_graduates = $incentiveRequirement->getNsaGraduates();
            

            $ambassador_grant = $em->getRepository("App:GrantAmbassador")->findOneBy(array("ambassador" => $id_user, "state" => "state.revision", "grant" => $id_grant));
            if(is_null($ambassador_grant)){
                $application_under_revision = "true";
            }
            else{
                $application_under_revision = "false";
            }

            if($student->getLanguage() == "en"){                
                $total_graduates = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassadorFromDate($id_user, 'state.approved', '2024-01-01');
            }
            else{
                $total_graduates = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassador($id_user, 'state.approved');
            }
            
            
            $groups =  $em->getRepository("App:Groupe")->findBy(array("embassador" => $id_user));

            $growthRequirement = $em->getRepository("App:GrantRequirement")->findOneBy(array("type" => "state.growth", "country" => $student->getCountry()));           
            if(is_null($growthRequirement)){
                $growthRequirement = $em->getRepository("App:GrantRequirement")->findOneBy(array("type" => "state.growth", "customized" => "false"));
            }
            $growth_minimum_graduates = $growthRequirement->getMbsGraduates();
            $growth_receipt_time = $growthRequirement->getReceiptTime();
            $growth_active_time = $growthRequirement->getActiveTime();             

            $all_time_growth_grants = $em->getRepository("App:GrantAmbassador")->ambassadorGrantByType($id_user, 'state.growth');
            if(empty($all_time_growth_grants)){
                $all_time_growth_grants = 0; 
            }
            else{
                $all_time_growth_grants = count($all_time_growth_grants);
            }

            $growth_missing_graduates = ( ($all_time_growth_grants + 1) * $growth_minimum_graduates ) - count($total_graduates);

            if($growth_missing_graduates > $growth_minimum_graduates){
                $growth_missing_graduates = $growth_minimum_graduates;
            }

           

            $alumni_ambassador_list = $em->getRepository("App:StudentGroup")->nsaByAmbassador($id_user);
            $alumni_with_20_graduates =  "false";
            foreach ($alumni_ambassador_list as $st) {
                $ambassador = $st->getStudent();
                $graduates = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassador($ambassador->getId(), 'state.approved');                        
                if(count($graduates) >= $incentive_nsa_graduates ){
                    $gb = $em->getRepository("App:GrantAmbassador")->findOneBy(array("mentoredambassador" => $ambassador->getId(), "state" => "state.approved"));
                    if(is_null($gb)){
                        $alumni_with_20_graduates =  "true";
                    }
                }
            }
            

            $requirements = [
                "application_under_revision" => $application_under_revision,
                "graduates_individual"       => strval(count($total_graduates)),
                "total_groups"               => strval(count($groups)),
                "all_time_growth_grants"     => $all_time_growth_grants,
                "ambassador_active_time"     => $ambassador_active_time,
                "growth_minimum_graduates"   => $growth_minimum_graduates,
                "growth_missing_graduates"   => $growth_missing_graduates,
                "growth_receipt_time"        => $growth_receipt_time,
                "last_growth_approved_grant" => $last_growth_approved_grant,
                "incentive_active_time"      => $incentive_active_time,
                "growth_active_time"         => $growth_active_time,
                "alumni_with_20_graduates"   => $alumni_with_20_graduates, 
                "incentive_nsa_graduates"    => $incentive_nsa_graduates,
                "sa_alumni"                  => strval(count($alumni_ambassador_list))
            ];
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Admins - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $requirements : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Post("/mentoredambassador/list", name="grant_mentored_ambassador_list")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Grant was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Grant was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="body",
     *     type="string",
     *     description="Id Ambassador",
     *     schema={}
     * )
     * 
     *    
     * @SWG\Tag(name="Grant")
     */ 

    public function mentoredAmbassadorListAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";
        $ambassador_list = [];
        $id_ambassador = $request->request->get('id_ambassador');
        $id_grant = $request->request->get('id_grant');
        $grant=new Grant();
        //Create a form
        $form=$this->createForm(GrantType::class, $grant);
        $form->submit($request->request->all());
        
        
        try {
            $code = 200;
            $error = false;

            $ambassador = $em->getRepository("App:User")->find($id_ambassador);
 
            if (is_null($ambassador)) {
                $code = 500;
                $error = true;
                $message = "The Ambassador does not exist";
            }
            else{
                $st_ambassador_list = $em->getRepository("App:StudentGroup")->nsaByAmbassador($id_ambassador);

                foreach ($st_ambassador_list as $st) {
                    $application = "false";
                    $ambassador = $st->getStudent();
                    $graduates = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassador($ambassador->getId(), 'state.approved');
                    $ambassador_app = $em->getRepository('App:GrantAmbassador')->findOneBy(array("mentoredambassador" => $ambassador->getId(), "grant" => $id_grant));
                    if(!is_null($ambassador_app)){
                        $application = $ambassador_app->getState();
                    } 
                    
                    $ambassador_list [] = [
                        "id" => $ambassador->getId(), 
                        "name" => $ambassador->getFirstName()." ".$ambassador->getLastName(),
                        "group" => $st->getGroup()->getName(),
                        "graduates" => count($graduates),
                        "application" => $application
                    ];
                }
            }

            
  
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Grant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $ambassador_list : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Post("/mentoredambassador", name="grant_mentored_ambassador")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Grant was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Grant was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="body",
     *     type="string",
     *     description="Id Ambassador",
     *     schema={}
     * )
     * 
     *    
     * @SWG\Tag(name="Grant")
     */ 

    public function mentoredAmbassadorAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";
        $ambassador_list = [];
        $id_ambassador = $request->request->get('id_ambassador');
        
        
        try {
            $code = 200;
            $error = false;

            $ambassador = $em->getRepository("App:User")->find($id_ambassador);
 
            if (is_null($ambassador)) {
                $code = 500;
                $error = true;
                $message = "The Ambassador does not exist";
            }
            else{
                $st_ambassador_list = $em->getRepository("App:StudentGroup")->nsaByAmbassador($id_ambassador);

                foreach ($st_ambassador_list as $st) {
                    $ambassador = $st->getStudent();
                    $graduates = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassador($ambassador->getId(), 'state.approved');
                    
                    $ambassador_list [] = [
                        "id" => $ambassador->getId(), 
                        "name" => $ambassador->getFirstName()." ".$ambassador->getLastName(),
                        "group" => $st->getGroup()->getName(),
                        "graduates" => count($graduates)
                    ];
                }
            }

            
  
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Grant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $ambassador_list : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Get("/approved/list", name="grant_approved_list")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Grant was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Grant was not successfully registered"
     * )    
     * 
     *    
     * @SWG\Tag(name="Grant")
     */ 

    public function approvedListAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        
        try {
            $code = 200;
            $error = false;

            $grants_ambassador = $em->getRepository("App:GrantAmbassador")->findBy(array("state" => "state.approved"), array("grant" => "DESC"));
           
           
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Grant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grants_ambassador : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()->setGroups(array('grant_ambassador_list'))));
    }

    /**
     * @Rest\Get("/rejected/list", name="grant_rejected_list")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Grant was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Grant was not successfully registered"
     * )    
     * 
     *    
     * @SWG\Tag(name="Grant")
     */ 

    public function rejectedListAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        
        try {
            $code = 200;
            $error = false;

            $grants_ambassador = $em->getRepository("App:GrantAmbassador")->findBy(array("state" => "state.reject"), array("grant" => "DESC"));
           
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Grant - Error: {$ex->getMessage()}";
        }
  
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grants_ambassador : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()->setGroups(array('grant_ambassador_list'))));
    }



     /**
     * @Rest\Post("/new", name="grant_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Grant was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Grant was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="id_administrator",
     *     in="body",
     *     type="string",
     *     description="Id Administrator",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="title",
     *     in="body",
     *     type="string",
     *     description="The title of Grant",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description of Grant",
     *     schema={}
     * )
     * 
     * * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="string",
     *     description="The language of Grant",
     *     schema={}
     * )
     * 
     * * @SWG\Parameter(
     *     name="state",
     *     in="body",
     *     type="string",
     *     description="The state of Grant",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="deadline_date",
     *     in="body",
     *     type="date",
     *     description="The deadline date",
     *     schema={}
     * )
     *       
     *    
     * @SWG\Tag(name="Grant")
     */ 

    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";
        $id_administrator = $request->request->get('id_administrator');
        $grant=new Grant();
        //Create a form
        $form=$this->createForm(GrantType::class, $grant);
        $form->submit($request->request->all());
        
        
        try {
            $code = 200;
            $error = false;

            $administrator = $em->getRepository("App:User")->find($id_administrator);
 
            if (is_null($administrator)) {
                $code = 500;
                $error = true;
                $message = "The Administrator does not exist";
            }
            else{
                $grant->setAdministrator($administrator);


                $requestDeadLineDate = strtotime($request->request->get('deadline_date'));
                $formatDeadLineDate = date('Y-m-d', $requestDeadLineDate);
                $grant->setDeadLineDate(new \DateTime($formatDeadLineDate, (new \DateTimeZone('America/New_York'))));

                $em->persist($grant);
                $em->flush();

            }

            
  
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Grant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grant : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

     /**
     * @Rest\Post("/newgrantgroups", name="grant_new_groups")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Grant was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Grant was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="id_grant_ambassador",
     *     in="body",
     *     type="string",
     *     description="Id Grant Ambassador",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="groups",
     *     in="body",
     *     type="string",
     *     description="The array Id Groups",
     *     schema={}
     * )
     * 
     
     *       
     *    
     * @SWG\Tag(name="Grant")
     */ 

    public function newGrantGroupsAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";
        $id_grant_ambassador = $request->request->get('id_grant_ambassador');
        $groups = explode(',', $request->request->get('groups'));

        
        try {
            $code = 200;
            $error = false;

            $grant_ambassador = $em->getRepository("App:GrantAmbassador")->find($id_grant_ambassador);
 
            if (is_null($grant_ambassador)) {
                $code = 500;
                $error = true;
                $message = "The Grant Ambassador does not exist";
            }

            $em->getRepository("App:GrantGroup")->deleteGrantGroups($id_grant_ambassador);
            
            foreach ($groups as $group) {
                $grant=new GrantGroup();
                $id_group =  explode("-", $group);

                $grp = $em->getRepository("App:Groupe")->find($id_group[1]);

                $grant->setGroup($grp);
                $grant->setGrantAmbassador($grant_ambassador);
                $em->persist($grant);
                $em->flush();

            }
            
  
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Grant Group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grant_ambassador : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Post("/newupdate", name="grant_new_update")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Grant update was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Grant update was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="id_grant",
     *     in="body",
     *     type="string",
     *     description="Id Grant",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="id_user",
     *     in="body",
     *     type="string",
     *     description="Id User",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description of Grant",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="file",
     *     in="body",
     *     type="string",
     *     description="The file",
     *     schema={}
     * )
     *   
     *    
     * @SWG\Tag(name="Grant")
     */ 

    public function newUpdateAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";
        $id_grant_ambassador = $request->request->get('id_grant_ambassador');
        $id_user = $request->request->get('id_user');
        $grantupdate=new GrantUpdate();
        //Create a form
        $form=$this->createForm(GrantUpdateType::class, $grantupdate);
        $form->submit($request->request->all());
        
        
        try {
            $code = 200;
            $error = false;

            $grantambassador = $em->getRepository("App:GrantAmbassador")->find($id_grant_ambassador);
            $user = $em->getRepository("App:User")->find($id_user);
 
            if (is_null($grantambassador)) {
                $code = 500;
                $error = true;
                $message = "The Grant ambassador does not exist";
            }

            if (is_null($user)) {
                $code = 500;
                $error = true;
                $message = "The User does not exist";
            }

            $grantupdate->setGrantAmbassador($grantambassador);     
            $grantupdate->setUser($user);                 

            $em->persist($grantupdate);
            $em->flush();
  
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Grant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grantupdate : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

     /**
     * @Rest\Post("/newgroup", name="grant_new_group")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Grant update was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Grant update was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="id_grant_ambassador",
     *     in="body",
     *     type="string",
     *     description="Id Grant Ambassador",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="id_group",
     *     in="body",
     *     type="string",
     *     description="Id Group",
     *     schema={}
     * )
     *      
     *   
     *    
     * @SWG\Tag(name="Grant")
     */ 

    public function newGroupAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";
        $id_grant_ambassador = $request->request->get('id_grant_ambassador');
        $id_group = $request->request->get('id_group');

        $grantgroup=new GrantGroup();
                
        
        try {
            $code = 200;
            $error = false;

            $grantambassador = $em->getRepository("App:GrantAmbassador")->find($id_grant_ambassador);
            $group = $em->getRepository("App:Groupe")->find($id_group);
 
            if (is_null($grantambassador)) {
                $code = 500;
                $error = true;
                $message = "The Grant ambassador does not exist";
            }

            if (is_null($group)) {
                $code = 500;
                $error = true;
                $message = "The Group does not exist";
            }

            $grantgroup->setGrantAmbassador($grantambassador);     
            $grantgroup->setGroup($group);                 

            $em->persist($grantgroup);
            $em->flush();
  
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Grant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grantgroup : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Post("/newambassador", name="grant_new_ambassador")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Grant ambassador was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Grant ambassador was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="id_grant",
     *     in="body",
     *     type="integer",
     *     description="Id Grant",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="body",
     *     type="integer",
     *     description="Id Ambassador",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="code",
     *     in="body",
     *     type="string",
     *     description="The code of Ambassador",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="state",
     *     in="body",
     *     type="string",
     *     description="The state of Grant Aplication",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="amount",
     *     in="body",
     *     type="integer",
     *     description="The amount of money assigned",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="number",
     *     in="body",
     *     type="integer",
     *     description="The number of participants ",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="question1",
     *     in="body",
     *     type="string",
     *     description="The question 1 ",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="question2",
     *     in="body",
     *     type="string",
     *     description="The question 2 ",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="question3",
     *     in="body",
     *     type="string",
     *     description="The question 3 ",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="question4",
     *     in="body",
     *     type="string",
     *     description="The question 4 ",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="question5",
     *     in="body",
     *     type="string",
     *     description="The question 5 ",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="question6",
     *     in="body",
     *     type="string",
     *     description="The question 6 ",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="question7",
     *     in="body",
     *     type="string",
     *     description="The question 7 ",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="question8",
     *     in="body",
     *     type="string",
     *     description="The question 8 ",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="question9",
     *     in="body",
     *     type="string",
     *     description="The question 9 ",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="question10",
     *     in="body",
     *     type="string",
     *     description="The question 10 ",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="file",
     *     in="body",
     *     type="string",
     *     description="The file",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="file2",
     *     in="body",
     *     type="string",
     *     description="The file 2",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="file3",
     *     in="body",
     *     type="string",
     *     description="The file 3",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="file4",
     *     in="body",
     *     type="string",
     *     description="The file 4",
     *     schema={}
     * )
     *   
     *    
     * @SWG\Tag(name="Grant")
     */ 

    public function newAmbassadorAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";
        $id_grant = $request->request->get('id_grant');
        $id_ambassador = $request->request->get('id_ambassador');
        $id_mentored_ambassador = $request->request->get('mentoredambassador');
        $id = $request->request->get('id');

        $grant = $em->getRepository("App:Grant")->find($id_grant);
        $ambassador = $em->getRepository("App:User")->find($id_ambassador);

        if($grant->getType() == "state.incentive" || $grant->getType() == "state.matching"){
            if(is_null($id_mentored_ambassador)){
                $mentored_sa = null;
            }
            else{
                $mentored_sa = $em->getRepository("App:User")->find($id_mentored_ambassador);
            }
            
            if(is_null($mentored_sa)){
                $grantambassador = $em->getRepository("App:GrantAmbassador")->findOneBy(array("ambassador" => $id_ambassador, "grant" => $id_grant, "state" => "state.development" ) );
            }
            else{
                $grantambassador = $em->getRepository("App:GrantAmbassador")->findOneBy(array("ambassador" => $id_ambassador, "grant" => $id_grant, "mentoredambassador" => $id_mentored_ambassador));
                if(is_null($grantambassador)){
                    $grantambassador = $em->getRepository("App:GrantAmbassador")->findOneBy(array("ambassador" => $id_ambassador, "grant" => $id_grant, "state" => "state.development" ) );
                }
            }
        }
        else{
            $grantambassador = $em->getRepository("App:GrantAmbassador")->findOneBy(array("ambassador" => $id_ambassador, "grant" => $id_grant));
        }

        
        if (is_null($grantambassador) ) {
            $grantambassador=new GrantAmbassador();
        }
            
        //Create a form
        $form=$this->createForm(GrantAmbassadorType::class, $grantambassador);
        $form->submit($request->request->all());
        
        
        try {
            $code = 200;
            $error = false;
            

            if (is_null($grant) ) {
                $code = 500;
                $error = true;
                $message = "The Grant does not exist";
            }

            if (is_null($ambassador) ) {
                $code = 500;
                $error = true;
                $message = "The Ambassador does not exist";
            }

            $grantambassador->setGrant($grant); 
            $grantambassador->setName($grant->getTitle());
            $grantambassador->setAmbassador($ambassador); 
            if($grantambassador->getState() != "state.revision"){
                $grantambassador->setState("state.development");
            }            
            $grantambassador->setAmount(0);  
            $grantambassador->setCorrection(" ");             

            if($grant->getState() == "state.available"){
                $em->persist($grantambassador);
                $em->flush();
            }
            
  
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Grant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grantambassador : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Get("/show/{id}.{_format}", name="grant_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets grant info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The grant with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Grant ID"
     * )
     *
     * @SWG\Tag(name="Grant")
     */
    public function showAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grant = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $grant_id = $id;
            $grant = $em->getRepository("App:Grant")->find($grant_id);
 
            if (is_null($grant)) {
                $code = 500;
                $error = true;
                $message = "The Grant does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Grant- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grant : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()->setGroups(array('grant_ambassador_list'))));
    }

    /**
     * @Rest\Get("/showambassador/{id}.{_format}", name="grant_show_ambassador", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets grant ambassador info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The grant ambassador with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Grant Ambassador ID"
     * )
     *
     * @SWG\Tag(name="Grant")
     */
    public function showAmbassadorAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grant = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $grant_id = $id;
            $grant = $em->getRepository("App:GrantAmbassador")->find($grant_id);

            $last_graduated = "Never";
            $graduate = $em->getRepository('App:StudentGroup')->lastMbsGraduatedByEmbassador($grant->getAmbassador()->getId(), 'state.approved');
            if($graduate > 0){
                $last_graduated = $em->getRepository('App:StudentGroup')->lastMbsGraduatedByEmbassadorDate($grant->getAmbassador()->getId(), 'state.approved');
                if(!is_null($last_graduated )){
                    $grant->setLastgraduated($last_graduated->format('Y-m-d'));
                }
            }
            else{
                $grant->setLastgraduated($last_graduated);
            }

            if($grant->getGrant()->getType() === "state.incentive"){
                $attemps = count($em->getRepository("App:GrantAmbassador")->findBy(array("mentoredambassador" => $grant->getMentoredambassador() , "ambassador" => $grant->getAmbassador()->getId())));
                $grant->setAttemps($attemps."th");

                if($grant->getMentoredAmbassador()){
                    $studentsMbs = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassador($grant->getMentoredAmbassador()->getId(), 'state.approved');
                    $grant->setNumber(count($studentsMbs));
                }
                
            } 
            if($grant->getGrant()->getType() === "state.growth"){    
                $attemps = count($em->getRepository("App:GrantAmbassador")->ambassadorGrantByTypeState( $grant ->getAmbassador()->getId(), "state.growth", "state.reject" ));
                $grant->setAttemps(($attemps + 1)."th");
            }
 
            if (is_null($grant)) {
                $code = 500;
                $error = true;
                $message = "The Grant Ambassador does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Grant Ambassador- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grant : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()->setGroups(array('grant_ambassador_list'))));
    }

    /**
     * @Rest\Get("/showgroup/{id}.{_format}", name="grant_show_group", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets grant ambassador info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The grant ambassador with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Grant Ambassador ID"
     * )
     *
     * @SWG\Tag(name="Grant")
     */
    public function showGroupAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $groups = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $grant_ambassador_id = $id;
            $grantgroups = $em->getRepository("App:GrantGroup")->findBy(array("grantambassador" => $grant_ambassador_id));
            foreach ($grantgroups as $ga) {
                $groups[]= $ga->getGroup();
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Grant Ambassador- Error: {$ex->getMessage()}";
        }

        $list = [
            'groups' => $groups,
            'grantgroups' => $grantgroups
        ];
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $list : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Get("/showuser/{id}.{_format}", name="grant_show_user", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets user grant info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The grant user with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The user ID"
     * )
     *
     * @SWG\Tag(name="Grant")
     */
    public function showUserAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grantgroup = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $user_id = $id;
            $grantgroup = $em->getRepository("App:GrantGroup")->userGrant($user_id);
           
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Grant Ambassador- Error: {$ex->getMessage()}";
        }

        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grantgroup : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Get("/showlistambassador/{id}.{_format}", name="grant_show_list_ambassador", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets user grant info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The grant user with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The user ID"
     * )
     *
     * @SWG\Tag(name="Grant")
     */
    public function showListAmbassadorAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grantgroup = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $user_id = $id;
            $grantgroup = $em->getRepository("App:GrantAmbassador")->ambassadorGrant($user_id);
           
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Grant Ambassador- Error: {$ex->getMessage()}";
        }

        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grantgroup : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Post("/ambassadorapplication/{id}.{_format}", name="grant_ambassador_application", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets grant ambassador info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The grant ambassador with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Grant Ambassador ID"
     * )
     *
     * @SWG\Tag(name="Grant")
     */
    public function ambassadorApplicationAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grantsambassador = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $grant_id = $id;
            $grantsambassador = $em->getRepository("App:GrantAmbassador")->findBy(array("grant" => $id));
           
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Grant Ambassador- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grantsambassador : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Get("/showupdate/{id}.{_format}", name="grant_show_updates", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets grant info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The grant with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Grant ID"
     * )
     *
     * @SWG\Tag(name="Grant")
     */
    public function showUpdateAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grantupdates = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $grant_ambassador_id = $id;
            $grant_ambassador = $em->getRepository("App:GrantAmbassador")->find($grant_ambassador_id);
            $grantupdates = $em->getRepository("App:GrantUpdate")->findBy(array("grantambassador" => $grant_ambassador_id));
 
            if (is_null($grant_ambassador)) {
                $code = 500;
                $error = true;
                $message = "The Grant does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Grant- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grantupdates : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }
    

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="grant_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The grant was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the grant."
     * )
     *
     * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="body",
     *     type="string",
     *     description="Id Ambassador",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description of Grant",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="date",
     *     in="body",
     *     type="date",
     *     description="The date",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="participants_number",
     *     in="body",
     *     type="string",
     *     description="Number of Participants",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="amount",
     *     in="body",
     *     type="string",
     *     description="Amount of Money",
     *     schema={}
     * )
     *
     * @SWG\Tag(name="Grant")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grant = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $grant = $em->getRepository("App:Grant")->find($id);
 
            if (!is_null($grant)) {
                $form = $this->createForm(GrantType::class, $grant);
                $form->submit($request->request->all());

                $requestDeadLineDate = strtotime($request->request->get('deadline_date'));
                $formatDeadLineDate = date('Y-m-d', $requestDeadLineDate);
                $grant->setDeadLineDate(new \DateTime($formatDeadLineDate, (new \DateTimeZone('America/New_York'))));

 
                $em->persist($grant);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a grant - Error: You must to provide fields user or the grant id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the grant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grant : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Put("/editupdate/{id}.{_format}", name="grant_edit_update", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The grant was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the grant."
     * )
     *
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description of Grant",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="file",
     *     in="body",
     *     type="string",
     *     description="The file",
     *     schema={}
     * )
     *
     * @SWG\Tag(name="Grant")
     */
    public function editUpdateAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grantupdate = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $grantupdate = $em->getRepository("App:GrantUpdate")->find($id);
 
            if (!is_null($grantupdate)) {
                $form = $this->createForm(GrantUpdateType::class, $grantupdate);
                $form->submit($request->request->all());
              
                $em->persist($grantupdate);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a grant update - Error: You must to provide fields user or the grant id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the grant update - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grantupdate : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Put("/editambassador/{id}.{_format}", name="grant_edit_ambassador", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The grant was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the grant."
     * )
     *
      * @SWG\Parameter(
     *     name="id_grant",
     *     in="body",
     *     type="integer",
     *     description="Id Grant",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="body",
     *     type="integer",
     *     description="Id Ambassador",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="code",
     *     in="body",
     *     type="string",
     *     description="The code of Ambassador",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="state",
     *     in="body",
     *     type="string",
     *     description="The state of Grant Aplication",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="amount",
     *     in="body",
     *     type="integer",
     *     description="The amount of money assigned",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="number",
     *     in="body",
     *     type="integer",
     *     description="The number of participants ",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="question1",
     *     in="body",
     *     type="string",
     *     description="The question 1 ",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="question2",
     *     in="body",
     *     type="string",
     *     description="The question 2 ",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="question3",
     *     in="body",
     *     type="string",
     *     description="The question 3 ",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="question4",
     *     in="body",
     *     type="string",
     *     description="The question 4 ",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="question5",
     *     in="body",
     *     type="string",
     *     description="The question 5 ",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="question6",
     *     in="body",
     *     type="string",
     *     description="The question 6 ",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="question7",
     *     in="body",
     *     type="string",
     *     description="The question 7 ",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="file",
     *     in="body",
     *     type="string",
     *     description="The file",
     *     schema={}
     * )
     *
     * @SWG\Tag(name="Grant")
     */
    public function editAmbassadorAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grantambassador = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $grantambassador = $em->getRepository("App:GrantAmbassador")->find($id);
            $grant = $em->getRepository("App:Grant")->find($grantambassador->getGrant()->getId());
 
            if (!is_null($grantambassador) && $grant->getState() == "state.available") {
                $form = $this->createForm(GrantAmbassadorType::class, $grantambassador);
                $form->submit($request->request->all());
              
                $em->persist($grantambassador);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a grant update - Error: You must to provide fields user or the grant id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the grant update - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grantambassador : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Put("/revisionambassador/{id}.{_format}", name="grant_revision_ambassador", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The grant was sent to revision successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to sent to revision grant."
     * )
     *
     *
     * @SWG\Tag(name="Grant")
     */
    public function revisionAmbassadorAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grant = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $grant_ambassador = $em->getRepository("App:GrantAmbassador")->find($id);
 
            if (!is_null($grant_ambassador)) {               
                $grant_ambassador->setState("state.revision");              

                $em->persist($grant_ambassador);
                $em->flush();

                $this->sendMessageList($grant_ambassador->getAmbassador(), $grant_ambassador->getGrant());
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a grant - Error: You must to provide fields user or the grant id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the grant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grant_ambassador : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Put("/correctionambassador/{id}.{_format}", name="grant_correction_ambassador", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The grant was sent to correction successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to sent to correction grant."
     * )
     *
     *
     * @SWG\Tag(name="Grant")
     */
    public function correctionAmbassadorAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grant = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $grant_ambassador = $em->getRepository("App:GrantAmbassador")->find($id);
 
            if (!is_null($grant_ambassador)) {               
                $grant_ambassador->setState("state.correction");      

                $grant_ambassador->setCorrection($request->request->get('correction'));
                $em->persist($grant_ambassador);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to edit correction a grant - Error: You must to provide fields user or the grant ambassador id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the grant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grant_ambassador : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Put("/approveambassador/{id}.{_format}", name="grant_approve_ambassador", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The grant was sent to approve successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to sent to approve grant."
     * )
     *
     *
     * @SWG\Tag(name="Grant")
     */
    public function approveAmbassadorAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grant = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $grant_ambassador = $em->getRepository("App:GrantAmbassador")->find($id);
 
            if (!is_null($grant_ambassador)) {

                $grant_ambassador->setState("state.approved");  
                $grant_ambassador->setCorrection($request->request->get('correction'));       
                $grant_ambassador->setAmount($request->request->get('amount'));     

                $em->persist($grant_ambassador);
                $em->flush();

                $this->sendMessageApproved($grant_ambassador->getAmbassador(), $grant_ambassador->getGrant());
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a grant - Error: You must to provide fields user or the grant id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the grant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grant_ambassador : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Put("/rejectambassador/{id}.{_format}", name="grant_reject_ambassador", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The grant was sent to approve successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to sent to approve grant."
     * )
     *
     *
     * @SWG\Tag(name="Grant")
     */
    public function rejectAmbassadorAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grant = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $grant_ambassador = $em->getRepository("App:GrantAmbassador")->find($id);
 
            if (!is_null($grant_ambassador)) {

                $grant_ambassador->setState("state.reject");  
                $grant_ambassador->setCorrection($request->request->get('correction'));            

                $em->persist($grant_ambassador);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a grant - Error: You must to provide fields user or the grant id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the grant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grant_ambassador : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="grant_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="grant was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the grant"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Grant ID"
     * )
     *
     * @SWG\Tag(name="Grant")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $grant = $em->getRepository("App:Grant")->find($id);
 
            if (!is_null($grant)) {
                $em->remove($grant);
                $em->flush();
 
                $message = "The grant was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent grant - Error: The grant id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current grant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Delete("/deleteupdate/{id}.{_format}", name="grant_delete_update", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="grant update was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the grant update"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Grant Update ID"
     * )
     *
     * @SWG\Tag(name="Grant")
     */
    public function deleteUpdateAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $grantupdate = $em->getRepository("App:GrantUpdate")->find($id);
 
            if (!is_null($$grantupdate)) {
                $em->remove($$grantupdate);
                $em->flush();
 
                $message = "The grant update was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent grant - Error: The grant update id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current grant update - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks() ));
    }

    /**
     * @Rest\Get("/graduates", name="grant_graduates")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all Grant Graduates"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all grant Graduates."
     * )
     *    
     * 
     * @SWG\Tag(name="Grant")
     */
    public function grantGraduates(Request $request) {
        $serializer = $this->get('jms_serializer');     
        $em = $this->getDoctrine()->getManager();
        $graduates = [];
        
        try {
          $code = 200;
          $error = false;
  
          $graduates = $em->getRepository('App:GrantGroup')->grantGraduates();
          
  
      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }
  
      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $graduates : $message,
      ];
  
      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array("student_group"))));
  
    }

    public function sendMessageList($ambassador, $grant){

        $em = $this->getDoctrine()->getManager();

        $admins = $em->getRepository("App:User")->getAdminsMessage($ambassador->getLanguage(), "grant");
        $languageadmins = $em->getRepository("App:User")->getAdminsLanguageMessage($ambassador->getLanguage(), "grant");

        foreach ($admins as $admin) {
            $message = $this->getParameter("message.new_application_".$admin->getLanguage())." ".$ambassador->getFirstName()." ".$ambassador->getLastName()." / ".$grant->getTitle()." ".$this->getParameter("message.pending_review_".$admin->getLanguage());
            $this->sendEmail($admin, "subject.new_application", $message );
        }

        foreach ($languageadmins as $admin) {
            $message = $this->getParameter("message.new_application_".$admin->getLanguage())." ".$ambassador->getFirstName()." ".$ambassador->getLastName()." / ".$grant->getTitle()." ".$this->getParameter("message.pending_review_".$admin->getLanguage());
            $this->sendEmail($admin, "subject.new_application", $message );
        }


    }

    public function sendMessageApproved($ambassador, $grant){

        $em = $this->getDoctrine()->getManager();

        $message = $this->getParameter("subject.grant_approved_".$ambassador->getLanguage())." ".$ambassador->getFirstName()." ".$ambassador->getLastName()." / ".$grant->getTitle()." ".$this->getParameter("message.grant_update_".$ambassador->getLanguage());
        $this->sendEmail($ambassador, "subject.grant_approved", $message );


    }

    
    public function sendEmail($user, $subject, $message){
        if (filter_var($user->getUsername(), FILTER_VALIDATE_EMAIL)) {

            $subject = $this->getParameter($subject."_".$user->getLanguage());
            $subjectEmail = $subject;
            $bodyEmail = $message;

            $message = (new \Swift_Message($subjectEmail))
            ->setFrom('MyPlatform@interweavesolutions.co')
            ->setTo($user->getUsername())
            ->setBody($bodyEmail);

            $this->get('mailer')->send($message);
        }

    }

 
}