<?php
 
namespace App\Controller;
 
use App\Entity\GrantMember;
use App\Form\GrantMemberType;
use App\Form\GrantMemberEditType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\UserDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class GrantMemberController
 *
 * @Route("/grantmember")
 */
class GrantMemberController extends FOSRestController
{
    
    /**
     * @Rest\Post("/", name="grant_members_index")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all grant_members."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all grant_members."
     * )
     *
     * @SWG\Parameter(
     *     name="grant_ambassador_id",
     *     in="path",
     *     type="string",
     *     description="The Id of Grant Ambassador"
     * )
     *     
     *
     *
     * @SWG\Tag(name="GrantMember")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grant_members = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
            
            $id     = $request->request->get('grant_ambassador_id');
    
            
            $grant_members = $em->getRepository("App:GrantMember")->findBy(array("grantambassador" => $id));
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all GrantMember - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grant_members : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('student_list'))));
    }

    /**
     * @Rest\Post("/pagination", name="grant_members_pagination")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all grant_members."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all grant_members."
     * )
     *
     * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="path",
     *     type="string",
     *     description="The ID of Ambassador"
     * )
     * 
     * @SWG\Parameter(
     *     name="role",
     *     in="path",
     *     type="string",
     *     description="The role of user"
     * )
     *
     * @SWG\Parameter(
     *     name="keyword",
     *     in="path",
     *     type="string",
     *     description="The search keyword"
     * )
     * 
     * @SWG\Parameter(
     *     name="page",
     *     in="path",
     *     type="string",
     *     description="The search Page"
     * )
     * 
     * @SWG\Parameter(
     *     name="page_size",
     *     in="path",
     *     type="string",
     *     description="The number of records for page"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_column",
     *     in="path",
     *     type="string",
     *     description="Search order Column"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_direction",
     *     in="path",
     *     type="string",
     *     description="Search order Direction"
     * )
     *
     * @SWG\Tag(name="GrantMember")
     */
    public function paginationAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grant_members = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
            
            $id     = $request->request->get('id_ambassador');
            $key    = $request->request->get('key');
            $role   = $request->request->get('role');
            $page   = $request->request->get('page');
            $page_size = $request->request->get('page_size');
            $order_column = $request->request->get('order_column');
            $order_direction = $request->request->get('order_direction');

            if($role == 'ROLE_ADMIN' or $role == 'ROLE_LANGUAGE_ADMIN'){
                $grant_members = $em->getRepository("App:GrantMembere")->getGrantMembersPagination($key, $page, $page_size, $order_column, $order_direction);        
            }
            else if($role == 'ROLE_EMBASSADOR' or $role == 'ROLE_STUDENT_EMBASSADOR' or $role == 'ROLE_FACILITATOR'){ 
                $grant_members = $em->getRepository("App:GrantMembere")->getGrantMembersByUserPagination($key, $page, $page_size, $order_column, $order_direction, $id);
            }

 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all GrantMember - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grant_members : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('grant_member_list'))));
    }


     /**
     * @Rest\Post("/new", name="GrantMember_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="GrantMember was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="GrantMember was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="user_id",
     *     in="body",
     *     type="string",
     *     description="Id User",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="grant_ambassador_id",
     *     in="body",
     *     type="string",
     *     description="The name of GrantMember",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="is_ambassador",
     *     in="body",
     *     type="string",
     *     description="if the members is ambassador",
     *     schema={}
     * )
     *     
     * 
     *    
     * @SWG\Tag(name="GrantMember")
     */ 

    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";
        $id     = $request->request->get('user_id');
        $grant_ambassador_id   = $request->request->get('grant_ambassador_id');
        $is_ambassador   = $request->request->get('is_ambassador');


        $grant_member=new GrantMember();
                
        
        try {
            $code = 200;
            $error = false;

            $grant_ambassador = $em->getRepository("App:GrantAmbassador")->find($grant_ambassador_id);
            $user = $em->getRepository("App:User")->find($id);
 
            if (is_null($user) || is_null($grant_ambassador)) {
                $code = 500;
                $error = true;
                $message = "The User or grant does not exist";
            }
            else{
                $grant_member->setMember($user);
                $grant_member->setGrantAmbassador($grant_ambassador);     
                $grant_member->setIsambassador($is_ambassador);           

                $em->persist($grant_member);
                $em->flush();
            }

            
  
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the GrantMember - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grant_member : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('student_list'))));

    }

    /**
     * @Rest\Get("/show/{id}.{_format}", name="grant_member_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets grant_member info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The grant_member with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The GrantMember ID"
     * )
     *
     * @SWG\Tag(name="GrantMember")
     */
    public function showAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grant_member = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $grant_member_id = $id;
            $grant_member = $em->getRepository("App:GrantMembere")->find($grant_member_id);
 
            if (is_null($grant_member)) {
                $code = 500;
                $error = true;
                $message = "The GrantMember does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current GrantMember- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grant_member : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="grant_member_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The grant_member was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the grant_member."
     * )
     *
       * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The name of GrantMember",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="startDate",
     *     in="body",
     *     type="string",
     *     description="The start date",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="finalDate",
     *     in="body",
     *     type="string",
     *     description="The final date",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="graduationDate",
     *     in="body",
     *     type="string",
     *     description="The graduation date",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="modality",
     *     in="body",
     *     type="string",
     *     description="modality",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="program",
     *     in="body",
     *     type="string",
     *     description="type of program",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="interweaveLocal",
     *     in="body",
     *     type="string",
     *     description="Local Organization",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="authorizationCode",
     *     in="body",
     *     type="string",
     *     description="authorization code",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="name_image",
     *     in="body",
     *     type="string",
     *     description="the name of file",
     *     schema={}
     * )
     *
     * @SWG\Tag(name="GrantMember")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grant_member = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $grant_member = $em->getRepository("App:GrantMembere")->find($id);
 
            if (!is_null($grant_member)) {
                $form = $this->createForm(GrantMemberType::class, $grant_member);
                $form->submit($request->request->all());

                $requestFinalDate = strtotime($request->request->get('finalDate'));
                $formatFinalDate = date('Y-m-d', $requestFinalDate);
                $grant_member->setFinalDate(new \DateTime($formatFinalDate, (new \DateTimeZone('America/New_York'))));

                $requestStartDate = strtotime($request->request->get('startDate'));
                $formatStartDate = date('Y-m-d', $requestStartDate);
                $grant_member->setStartDate(new \DateTime($formatStartDate, (new \DateTimeZone('America/New_York'))));

                $requestGraduationDate = strtotime($request->request->get('graduationDate'));
                $formatGraduationDate = date('Y-m-d', $requestGraduationDate);
                $grant_member->setGraduationDate(new \DateTime($formatGraduationDate, (new \DateTimeZone('America/New_York'))));

                $grant_member->setNumberStudents(0);
 
                $em->persist($grant_member);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a grant_member - Error: You must to provide fields user or the grant_member id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the grant_member - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grant_member : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Delete("/delete/{id}/{grant}.{_format}", name="grant_member_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="grant_member was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the grant_member"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The GrantMember ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="grant",
     *     in="path",
     *     type="string",
     *     description="The grant Ambassador ID"
     * )
     *
     * @SWG\Tag(name="GrantMember")
     */
    public function deleteAction(Request $request, $id, $grant) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $students = 0;
        $grant_member = [];
 
        try {
            $code = 200;
            $error = false;
            $grant_ambassador = $em->getRepository("App:GrantAmbassador")->find($grant);
            $user = $em->getRepository("App:User")->find($id);
 
            if (!is_null($user) && !is_null($grant_ambassador)) {
                $grant_member = $em->getRepository("App:GrantMember")->findOneBy(array("member" => $id, "grantambassador" => $grant));
                $em->remove($grant_member);
                $em->flush();
                
 
                $message = "The grant_member was removed successfully!";
 
            } else {
                $code = 400;
                $error = true;
                $message = "An error has occurred trying to remove the currrent grant_member - Error: The grant_member id does not exist or this grant_member have Certified Students";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current grant_member - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'message' => $message,
            'error' => $user,
            'data' => $grant_member,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

 
}