<?php
 
namespace App\Controller;
 
use App\Entity\User;
use App\Entity\GrantRequirement;
use App\Form\GrantRequirementType;
use App\Form\UserPasswordEditType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\AdminDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class GrantRequirementController
 *
 * @Route("/grantrequirement")
 */
class GrantRequirementController extends FOSRestController
{
    
 
    /**
     * @Rest\Get("/", name="grant_requirement_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all grant_requirements."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all grant_requirement grant_requirements."
     * )
     *    
     *
     *
     * @SWG\Tag(name="GrantRequirement")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grant_requirements = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $grant_requirements = $em->getRepository("App:GrantRequirement")->findAll();
 
            if (is_null($grant_requirements)) {
                $grant_requirements = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Admins - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grant_requirements : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

 

    /**
     * @Rest\Post("/new", name="grant_requirement_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="User was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="User was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="activeTime",
     *     in="body",
     *     type="integer",
     *     description="The activeTime",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="receiptTime",
     *     in="body",
     *     type="integer",
     *     description="The receiptTime",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="mbsGraduates",
     *     in="body",
     *     type="integer",
     *     description="The mbsGraduates",
     *     schema={}
     * )
     *      
     * @SWG\Parameter(
     *     name="saGraduates",
     *     in="body",
     *     type="integer",
     *     description="The saGraduates",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="nsaGraduates",
     *     in="body",
     *     type="integer",
     *     description="The nsaGraduates",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="country",
     *     in="body",
     *     type="string",
     *     description="The country",
     *     schema={}
     * ) 
     * 
      * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="string",
     *     description="The language",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="type",
     *     in="body",
     *     type="string",
     *     description="The type",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="customized",
     *     in="body",
     *     type="string",
     *     description="The customized",
     *     schema={}
     * ) 
     *     
     *
     * @SWG\Tag(name="GrantRequirement")
     */ 
    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";
        $country     = $request->request->get('country');
        $type        = $request->request->get('type');
        $customized  = $request->request->get('customized');

        $grant_requirement = $em->getRepository("App:GrantRequirement")->findOneBy(array("customized" => $customized, "type" => $type, "country" => $country));

        if(is_null($grant_requirement)){
            $grant_requirement = new GrantRequirement();     
        }
        
        $form=$this->createForm(GrantRequirementType::class, $grant_requirement);
        $form->submit($request->request->all());
          
                      
        try {
           
            $code = 200;
            $error = false;           
            $em->persist($grant_requirement);
            $em->flush();            
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the grant_requirement - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grant_requirement : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

   


    /**
     * @Rest\Get("/show/{id}.{_format}", name="grant_requirement_show_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets grant_requirement info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The grant_requirement with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The GrantRequirement ID"
     * )
     * 
     *
     * @SWG\Tag(name="GrantRequirement")
     */
    public function showAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grant_requirement = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $grant_requirement_id = $id;
            $grant_requirement = $em->getRepository("App:GrantRequirement")->find($grant_requirement_id);
 
            if (is_null($grant_requirement)) {
                $code = 500;
                $error = true;
                $message = "The GrantRequirement does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current GrantRequirement- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grant_requirement : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="grant_requirement_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The grant_requirement was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the grant_requirement."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The grant_requirement ID"
     * )
     * 
    * @SWG\Parameter(
     *     name="activeTime",
     *     in="body",
     *     type="integer",
     *     description="The activeTime",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="receiptTime",
     *     in="body",
     *     type="integer",
     *     description="The receiptTime",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="mbsGraduates",
     *     in="body",
     *     type="integer",
     *     description="The mbsGraduates",
     *     schema={}
     * )
     *      
     * @SWG\Parameter(
     *     name="saGraduates",
     *     in="body",
     *     type="integer",
     *     description="The saGraduates",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="nsaGraduates",
     *     in="body",
     *     type="integer",
     *     description="The nsaGraduates",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="country",
     *     in="body",
     *     type="string",
     *     description="The country",
     *     schema={}
     * ) 
     * 
      * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="string",
     *     description="The language",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="type",
     *     in="body",
     *     type="string",
     *     description="The type",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="customized",
     *     in="body",
     *     type="string",
     *     description="The customized",
     *     schema={}
     * ) 
     *
     * @SWG\Tag(name="GrantRequirement")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $grant_requirement = [];
        $message = "";
        

        try {
            $code = 200;
            $error = false;
            $grant_requirement = $em->getRepository("App:GrantRequirement")->find($id);
 
            if (!is_null($grant_requirement)) {
                //Create a form
                $form=$this->createForm(GrantRequirementType::class, $grant_requirement);
                $form->submit($request->request->all());
 
                $em->persist($grant_requirement);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Admin - Error: You must to provide fields grant_requirement or the grant_requirement id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the grant_requirement - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $grant_requirement : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="grant_requirement_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Admin was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the grant_requirement"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The grant_requirement ID"
     * )
     *
     * @SWG\Tag(name="GrantRequirement")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $grant_requirement = $em->getRepository("App:GrantRequirement")->find($id);
 
            if (!is_null($grant_requirement)) {
                $em->remove($grant_requirement);
                $em->flush();
 
                $message = "The grant_requirement was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent grant_requirement - Error: The grant_requirement id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current grant_requirement - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    

}