<?php
 
namespace App\Controller;
 
use App\Entity\Groupe;
use App\Entity\Tracking;
use App\Form\GroupType;
use App\Form\GroupEditType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\UserDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class GroupController
 *
 * @Route("/group")
 */
class GroupController extends FOSRestController
{
    
    /**
     * @Rest\Post("/", name="groups_index")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all groups."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all groups."
     * )
     *
     * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="path",
     *     type="string",
     *     description="The ID of Ambassador"
     * )
     * 
     * @SWG\Parameter(
     *     name="role",
     *     in="path",
     *     type="string",
     *     description="The role of user"
     * )
     *
     *
     * @SWG\Tag(name="Group")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $groups = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
            
            $id     = $request->request->get('id_ambassador');
            $role   = $request->request->get('role');
         

            if($role == 'ROLE_ADMIN' or $role == 'ROLE_LANGUAGE_ADMIN'){
                $groups = $em->getRepository("App:Groupe")->findBy(array(), array('startDate' => 'DESC'));
                $this->forward('App\Controller\InitializationController::groupCreateAction', []);
            }
            else if($role == 'ROLE_EMBASSADOR' or $role == 'ROLE_STUDENT_EMBASSADOR'){ 
                $groups = $em->getRepository("App:Groupe")->findBy(array('embassador' => $id), array('startDate' => 'DESC'));
            }
            else{
                $groups = $em->getRepository("App:Groupe")->findBy(array(), array('startDate' => 'DESC'));
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $groups : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('group_list'))));
    }

    /**
     * @Rest\Post("/pagination", name="groups_pagination")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all groups."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all groups."
     * )
     *
     * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="path",
     *     type="string",
     *     description="The ID of Ambassador"
     * )
     * 
     * @SWG\Parameter(
     *     name="role",
     *     in="path",
     *     type="string",
     *     description="The role of user"
     * )
     *
     * @SWG\Parameter(
     *     name="keyword",
     *     in="path",
     *     type="string",
     *     description="The search keyword"
     * )
     * 
     * @SWG\Parameter(
     *     name="page",
     *     in="path",
     *     type="string",
     *     description="The search Page"
     * )
     * 
     * @SWG\Parameter(
     *     name="page_size",
     *     in="path",
     *     type="string",
     *     description="The number of records for page"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_column",
     *     in="path",
     *     type="string",
     *     description="Search order Column"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_direction",
     *     in="path",
     *     type="string",
     *     description="Search order Direction"
     * )
     *
     * @SWG\Tag(name="Group")
     */
    public function paginationAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $groups = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
            
            $id     = $request->request->get('id_ambassador');
            $key    = $request->request->get('key');
            $role   = $request->request->get('role');
            $page   = $request->request->get('page');
            $page_size = $request->request->get('page_size');
            $order_column = $request->request->get('order_column');
            $order_direction = $request->request->get('order_direction');

            if($role == 'ROLE_ADMIN' or $role == 'ROLE_LANGUAGE_ADMIN'){
                $groups = $em->getRepository("App:Groupe")->getGroupsPagination($key, $page, $page_size, $order_column, $order_direction);        
            }
            else if($role == 'ROLE_EMBASSADOR' or $role == 'ROLE_STUDENT_EMBASSADOR' or $role == 'ROLE_FACILITATOR'){ 
                $groups = $em->getRepository("App:Groupe")->getGroupsByUserPagination($key, $page, $page_size, $order_column, $order_direction, $id);
            }

 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $groups : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('group_list'))));
    }


     /**
     * @Rest\Post("/new", name="Group_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Group was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Group was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="body",
     *     type="string",
     *     description="Id Ambassador",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The name of Group",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="startDate",
     *     in="body",
     *     type="string",
     *     description="The start date",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="finalDate",
     *     in="body",
     *     type="string",
     *     description="The final date",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="graduationDate",
     *     in="body",
     *     type="string",
     *     description="The graduation date",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="modality",
     *     in="body",
     *     type="string",
     *     description="modality",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="program",
     *     in="body",
     *     type="string",
     *     description="type of program",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="interweaveLocal",
     *     in="body",
     *     type="string",
     *     description="Local Organization",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="authorizationCode",
     *     in="body",
     *     type="string",
     *     description="authorization code",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="name_image",
     *     in="body",
     *     type="string",
     *     description="the name of file",
     *     schema={}
     * )
     * 
     *    
     * @SWG\Tag(name="Group")
     */ 

    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";
        $id_ambassador = $request->request->get('id_ambassador');
        $group=new Groupe();
        //Create a form
        $form=$this->createForm(GroupType::class, $group);
        $form->submit($request->request->all());
        
        
        try {
            $code = 200;
            $error = false;

            $ambassador = $em->getRepository("App:User")->find($id_ambassador);
 
            if (is_null($ambassador)) {
                $code = 500;
                $error = true;
                $message = "The Ambassador does not exist";
            }
            else{
                $group->setEmbassador($ambassador);

                $requestFinalDate = strtotime($request->request->get('finalDate'));
                $formatFinalDate = date('Y-m-d', $requestFinalDate);
                $group->setFinalDate(new \DateTime($formatFinalDate, (new \DateTimeZone('America/New_York'))));

                $requestStartDate = strtotime($request->request->get('startDate'));
                $formatStartDate = date('Y-m-d', $requestStartDate);
                $group->setStartDate(new \DateTime($formatStartDate, (new \DateTimeZone('America/New_York'))));

                $requestGraduationDate = strtotime($request->request->get('graduationDate'));
                $formatGraduationDate = date('Y-m-d', $requestGraduationDate);
                $group->setGraduationDate(new \DateTime($formatGraduationDate, (new \DateTimeZone('America/New_York'))));

                $group->setNumberStudents(0);

                //$this->sendMessageList($ambassador, $group);

                $em->persist($group);
                $em->flush();
            }

            
  
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $group : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('group_list'))));

    }

    /**
     * @Rest\Get("/show/{id}.{_format}", name="group_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets group info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The group with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Group ID"
     * )
     *
     * @SWG\Tag(name="Group")
     */
    public function showAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $group = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $group_id = $id;
            $group = $em->getRepository("App:Groupe")->find($group_id);
 
            if (is_null($group)) {
                $code = 500;
                $error = true;
                $message = "The Group does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Group- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $group : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="group_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The group was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the group."
     * )
     *
       * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The name of Group",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="startDate",
     *     in="body",
     *     type="string",
     *     description="The start date",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="finalDate",
     *     in="body",
     *     type="string",
     *     description="The final date",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="graduationDate",
     *     in="body",
     *     type="string",
     *     description="The graduation date",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="modality",
     *     in="body",
     *     type="string",
     *     description="modality",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="program",
     *     in="body",
     *     type="string",
     *     description="type of program",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="interweaveLocal",
     *     in="body",
     *     type="string",
     *     description="Local Organization",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="authorizationCode",
     *     in="body",
     *     type="string",
     *     description="authorization code",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="name_image",
     *     in="body",
     *     type="string",
     *     description="the name of file",
     *     schema={}
     * )
     *
     * @SWG\Tag(name="Group")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $group = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $group = $em->getRepository("App:Groupe")->find($id);
 
            if (!is_null($group)) {
                $form = $this->createForm(GroupType::class, $group);
                $form->submit($request->request->all());

                $requestFinalDate = strtotime($request->request->get('finalDate'));
                $formatFinalDate = date('Y-m-d', $requestFinalDate);
                $group->setFinalDate(new \DateTime($formatFinalDate, (new \DateTimeZone('America/New_York'))));

                $requestStartDate = strtotime($request->request->get('startDate'));
                $formatStartDate = date('Y-m-d', $requestStartDate);
                $group->setStartDate(new \DateTime($formatStartDate, (new \DateTimeZone('America/New_York'))));

                $requestGraduationDate = strtotime($request->request->get('graduationDate'));
                $formatGraduationDate = date('Y-m-d', $requestGraduationDate);
                $group->setGraduationDate(new \DateTime($formatGraduationDate, (new \DateTimeZone('America/New_York'))));

                $group->setNumberStudents(0);
 
                $em->persist($group);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a group - Error: You must to provide fields user or the group id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $group : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="group_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="group was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the group"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Group ID"
     * )
     *
     * @SWG\Tag(name="Group")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $students = 0;
 
        try {
            $code = 200;
            $error = false;
            $group = $em->getRepository("App:Groupe")->find($id);
            $certificates = $em->getRepository("App:StudentGroup")->studentsMbsStateByGroup($group->getId(), "state.approved"); 
            $students = $em->getRepository("App:StudentGroup")->studentsMbsByGroup($group->getId());
            
 
            if (!is_null($group) && count($certificates) == 0 ) {

                foreach ($students as $st) {
                    $tracking =  new Tracking();
                    $student = $st->getStudent();
                    $log = str_replace ("-0001-", "2018-", $serializer->serialize($student, "json", SerializationContext::create()->enableMaxDepthChecks() ) );
                    $tracking->setUser($this->getUser());
                    $tracking->setEntityId($student->getId());
                    $tracking->setEntity("label_user");
                    $tracking->setAction("label_delete");
                    $tracking->setName($student->getFirstName()." ".$student->getLastName());
                    $tracking->setLog($log);
                    $em->persist($tracking);
                    $em->flush();
                }

                $tracking =  new Tracking();
                $tracking->setUser($this->getUser());
                $tracking->setEntityId($group->getId());
                $tracking->setEntity("label_group");
                $tracking->setAction("label_delete");
                $tracking->setName($group->getName());
                $tracking->setLog($serializer->serialize($group, "json", SerializationContext::create()->enableMaxDepthChecks() ));
                $em->persist($tracking);
                $em->flush();


                $students = $em->getRepository("App:User")->deleteStudentByGroup($group->getId());
                $em->remove($group);
                $em->flush();
                
 
                $message = "The group was removed successfully!";
 
            } else {
                $code = 400;
                $error = true;
                $message = "An error has occurred trying to remove the currrent group - Error: The group id does not exist or this group have Certified Students";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => count($certificates),
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/program", name="group_program")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all groups."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all groups."
     * )
     *
     * @SWG\Parameter(
     *     name="program",
     *     in="path",
     *     type="string",
     *     description="The program group"
     * )  
     *
     * @SWG\Tag(name="Group")
     */
    public function programAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $groups = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $program = $request->request->get('program');
            $groups = $em->getRepository("App:Groupe")->findBy(array('program' => $program));
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $groups : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('group_list'))));
    }

    public function sendMessageList($ambassador, $group){

        $em = $this->getDoctrine()->getManager();

        $admins = $em->getRepository("App:User")->getAdminsMessage($ambassador->getLanguage(), "group");
        $languageadmins = $em->getRepository("App:User")->getAdminsLanguageMessage($ambassador->getLanguage(), "group");

        foreach ($admins as $admin) {
            $message = $ambassador->getFirstName()." ".$ambassador->getLastName()." ".$this->getParameter("message.new_group_".$ambassador->getLanguage())." ".$group->getName();
            $this->sendEmail($admin, "subject.new_group", $message );
        }

        foreach ($languageadmins as $admin) {
            $message = $ambassador->getFirstName()." ".$ambassador->getLastName()." ".$this->getParameter("message.new_group_".$ambassador->getLanguage())." ".$group->getName();
            $this->sendEmail($admin, "subject.new_group", $message );
        }
        return $admins;

    }
    
    public function sendEmail($user, $subject, $message){
        if (filter_var($user->getUsername(), FILTER_VALIDATE_EMAIL)) {

        $subject = $this->getParameter($subject."_".$user->getLanguage());
        $subjectEmail = $subject;
        $bodyEmail = $message;

        $message = (new \Swift_Message($subjectEmail))
         ->setFrom('MyPlatform@interweavesolutions.co')
         ->setTo($user->getUsername())
         ->setBody($bodyEmail);

         $this->get('mailer')->send($message);
        }

    }

   
 
}