<?php
/**
 * UserController.php
 *
 * API Controller
 *
 * @category   Controller
 * @package    MyKanban
 * @author     Francisco Ugalde
 * @copyright  2018 www.franciscougalde.com
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 */
 
namespace App\Controller;
 
use App\Entity\User;
use App\Entity\Task;
use App\Entity\InitializationGroup;
use App\Entity\InitializationAmbassadorGroup;
use App\Form\UserType;
use App\Form\InitializationType;
use App\Form\UserEditType;
use Doctrine\Common\Collections\ArrayCollection;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\UserDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class InitializationController
 *
 * @Route("/initialization")
 */
class InitializationController extends FOSRestController
{
    
 
    /**
     * @Rest\GET("/student/create", name="initialization_student_create", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all students."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all students."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Initialization")
     */
    public function studentCreateAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $users = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $current_date = new \DateTime();
            $init_date = $current_date->modify( '-1 month' )->format('Y-m-d');
            $users = $em->getRepository("App:User")->participantsByDate($init_date);
 
            if (is_null($users)) {
                $users = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Users - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $users : $message,
        ];

        
        $result = $serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('participant_list')));
        $file = fopen($this->container->getparameter('kernel.project_dir')."/web/query/students.json", "w");
        fwrite($file, $result);              
        fclose($file);
 
        return new Response($code);
    }

    /**
     * @Rest\GET("/student", name="initialization_student", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all students."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all students."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Initialization")
     */
    public function studentAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $users = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $file = fopen($this->container->getparameter('kernel.project_dir')."/web/query/students.json", "r");
            $response = fread($file, filesize($this->container->getparameter('kernel.project_dir')."/web/query/students.json"));
            fclose($file);
 
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Users - Error: {$ex->getMessage()}";
        } 
 
        return new Response($response);
    }

    /**
     * @Rest\GET("/group/create", name="initialization_group_create", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all groups."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all groups."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Initialization")
     */
    public function groupCreateAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $groups = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $groups = $em->getRepository("App:Groupe")->findBy(array(), array('startDate' => 'DESC'));
           
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Groups - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $groups : $message,
        ];

        
        $result = $serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('group_list')));
        $file = fopen($this->container->getparameter('kernel.project_dir')."/web/query/groups.json", "w");
        fwrite($file, $result);              
        fclose($file);
 
        return new Response($error);
    }

    /**
     * @Rest\GET("/group", name="initialization_group", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all group."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all group."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Initialization")
     */
    public function groupAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $users = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $file = fopen($this->container->getparameter('kernel.project_dir')."/web/query/groups.json", "r");
            $response = fread($file, filesize($this->container->getparameter('kernel.project_dir')."/web/query/groups.json"));
            fclose($file);
 
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all groups - Error: {$ex->getMessage()}";
        } 
 
        return new Response($response);
    }

    /**
     * @Rest\GET("/ambassador/create", name="initialization_ambassador_create", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all Ambassadors."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all Ambassadors."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Initialization")
     */
    public function ambassadorCreateAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $ambassadors = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $ambassadors = $em->getRepository("App:User")->getAmbassadors();
           
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Groups - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $ambassadors : $message,
        ];

        
        //$result = $serializer->serialize($response, "json", SerializationContext::create()->setGroups(array("ambassador_list")));
        //$file = fopen($this->container->getparameter('kernel.project_dir')."/web/query/ambassadors.json", "w");
        //fwrite($file, $result);              
        //fclose($file);
 
        return new Response($error);
    }

    /**
     * @Rest\GET("/ambassador", name="initialization_ambassador", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all ambassadors."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassadors."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Initialization")
     */
    public function ambassadorAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $users = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $file = fopen($this->container->getparameter('kernel.project_dir')."/web/query/ambassadors.json", "r");
            $response = fread($file, filesize($this->container->getparameter('kernel.project_dir')."/web/query/ambassadors.json"));
            fclose($file);
 
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all ambassadors - Error: {$ex->getMessage()}";
        } 
 
        return new Response($response);
    }

    /**
     * @Rest\GET("/evaluations/create", name="initialization_ambassador_create", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all Evaluations."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all Evaluations."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Initialization")
     */
    public function evaluationCreateAction($evaluations, $country) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Groups - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $evaluations : $message,
        ];

        
        $result = $serializer->serialize($response, "json");
        $file = fopen($this->container->getparameter('kernel.project_dir')."/web/query/evaluations/".$country.".json", "w");
        fwrite($file, $result);              
        fclose($file);
 
        return new Response($error);
    }

    /**
     * @Rest\GET("/evaluations/{id}.{_format}", name="initialization_evaluation", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all evaluations."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassadors."
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The country ID"
     * )
     *    
     *
     *
     * @SWG\Tag(name="Initialization")
     */
    public function evaluationAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $users = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $file = fopen($this->container->getparameter('kernel.project_dir')."/web/query/evaluations/".$id.".json", "r");
            $response = fread($file, filesize($this->container->getparameter('kernel.project_dir')."/web/query/evaluations/".$id.".json"));
            fclose($file);
 
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all evaluations - Error: {$ex->getMessage()}";
        } 
 
        return new Response($response);
    }

     
}