<?php

 
namespace App\Controller;
 
use App\Entity\Introduction;
use App\Form\IntroductionType;
use App\Form\IntroductionEditType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\UserDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class IntroductionController
 *
 * @Route("/introduction")
 */
class IntroductionController extends FOSRestController
{
    
    /**
     * @Rest\Get("/", name="introduction_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all Introductions."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all Introductions."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="Introduction ID"
     * )
     *
     *
     * @SWG\Tag(name="Introduction")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $introductions = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $introductions = $em->getRepository("App:Introduction")->findAll();
 
            if (is_null($introductions)) {
                $Introductions = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Introduction - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $introductions : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Post("/new", name="introduction_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Introduction was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Introduction was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="group_id",
     *     in="body",
     *     type="string",
     *     description="The ID Group",
     *     schema={}
     * )
     *       
     * 
     * @SWG\Parameter(
     *     name="content",
     *     in="body",
     *     type="string",
     *     description="The content",
     *     schema={}
     * )     
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="string",
     *     description="language introduction",
     *     schema={}
     * )
     * 
     *  @SWG\Parameter(
     *     name="type",
     *     in="body",
     *     type="integer",
     *     description="The type of the introduction",
     *     schema={}
     * )
     * 
     *    
     * 
     * @SWG\Tag(name="Introduction")
     */ 

    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $message = "";

        
        $type = $request->request->get("type");

        

        if($type === "group"){
            $group_id= $request->request->get("group_id");
            $introduction = $em->getRepository("App:Introduction")->findOneBy(array("group" => $group_id));
            if (is_null($introduction)) {
                $introduction=new Introduction();
                
                $group = $em->getRepository("App:Groupe")->find($group_id);
                $introduction->setGroup($group);
            } 
        }
        else{
            $introduction=new Introduction();
        }

        
        //Create a form
        $form=$this->createForm(IntroductionType::class, $introduction);
        $form->submit($request->request->all());
        


        try {
            $code = 200;
            $error = false;

            $em->persist($introduction);
            $em->flush();
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Introduction - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $introduction : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/show/{id}.{_format}", name="Introduction_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Introduction info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Introduction with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Introduction ID"
     * )
     *
     * @SWG\Tag(name="Introduction")
     */
    public function showAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $introduction = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $introduction_id = $id;
            $introduction = $em->getRepository("App:Introduction")->find($introduction_id);
 
            if (is_null($introduction)) {
                $code = 500;
                $error = true;
                $message = "The Introduction does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Introduction- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $introduction : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    } 

    /**
     * @Rest\Get("/show/group/{id}.{_format}", name="Introduction_group_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Introduction info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Introduction with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Introduction ID"
     * )
     *
     * @SWG\Tag(name="Introduction")
     */
    public function showGroupAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $introduction = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $introduction = $em->getRepository("App:Introduction")->findOneBy(array("group" => $id));
 
            if (is_null($introduction)) {
                $code = 500;
                $error = true;
                $message = "The Introduction does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Introduction- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $introduction : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="Introduction_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The Introduction was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the Introduction."
     * )
     *
     * @SWG\Parameter(
     *     name="group_id",
     *     in="body",
     *     type="string",
     *     description="The ID Group",
     *     schema={}
     * )
     *       
     * 
     * @SWG\Parameter(
     *     name="content",
     *     in="body",
     *     type="string",
     *     description="The content",
     *     schema={}
     * )     
     * 
     *  @SWG\Parameter(
     *     name="type",
     *     in="body",
     *     type="integer",
     *     description="The type of the introduction",
     *     schema={}
     * )
     *    
     * 
     *
     * @SWG\Tag(name="Introduction")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $introduction = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $introduction = $em->getRepository("App:Introduction")->find($id);
 
            if (!is_null($introduction)) {
                $form = $this->createForm(IntroductionEditType::class, $introduction);
                $form->submit($request->request->all());
                //$curse->setName($name);
 
                $em->persist($introduction);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Introduction - Error: You must to provide fields user or the Introduction id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the Introduction - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $introduction : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }


     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="Introduction_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Introduction was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the Introduction"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Introduction ID"
     * )
     *
     * @SWG\Tag(name="Introduction")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $introduction = $em->getRepository("App:Introduction")->find($id);
 
            if (!is_null($introduction)) {
                $em->remove($introduction);
                $em->flush();
 
                $message = "The Introduction was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent Introduction - Error: The Introduction id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current Introduction - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }
 
}