<?php
 
namespace App\Controller;
 
use App\Entity\User;
use App\Entity\Payment;
use App\Form\PaymentType;
use App\Form\UserPasswordEditType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\AdminDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class PaymentController
 *
 * @Route("/payment")
 */
class PaymentController extends FOSRestController
{
    
 
    /**
     * @Rest\Get("/", name="payment_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all payments."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all payment payments."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Payment")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $payments = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $payments = $em->getRepository("App:Payment")->findAll();
 
            if (is_null($payments)) {
                $payments = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Admins - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $payments : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

 

    /**
     * @Rest\Post("/new", name="payment_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="User was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="User was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="price",
     *     in="body",
     *     type="integer",
     *     description="The price",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="student_id",
     *     in="body",
     *     type="integer",
     *     description="The Student id of the new Payment",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="course_id",
     *     in="body",
     *     type="integer",
     *     description="The Course id of the new Payment",
     *     schema={}
     * )
     *      
     *      
     *
     * @SWG\Tag(name="Payment")
     */ 
    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";

        $payment = new Payment();
        
        $student = $em->getRepository("App:User")->find($request->request->get('student_id'));
        $course = $em->getRepository("App:Course")->find($request->request->get('course_id'));
        $price = $request->request->get('price');
       
        try {
 
            if (is_null($student) || is_null($course)) {
                $code = 500;
                $error = true;
                $message = "The student or course does not exist";
            }
            else{
                $code = 200;
                $error = false;
                $payment->setStudent($student);
                $payment->setCourse($course);
                $payment->setPrice($price);
                $em->persist($payment);
                $em->flush();
            }
            
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the payment - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $payment : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

   


    /**
     * @Rest\Get("/show/{id}.{_format}", name="payment_show_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets payment info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The payment with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Payment ID"
     * )
     * 
     *
     * @SWG\Tag(name="Payment")
     */
    public function showAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $payment = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $payment_id = $id;
            $payment = $em->getRepository("App:Payment")->find($payment_id);
 
            if (is_null($payment)) {
                $code = 500;
                $error = true;
                $message = "The Payment does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Payment- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $payment : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="payment_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The payment was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the payment."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The payment ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="price",
     *     in="body",
     *     type="integer",
     *     description="The price",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="student_id",
     *     in="body",
     *     type="integer",
     *     description="The Student id of the new Payment",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="course_id",
     *     in="body",
     *     type="integer",
     *     description="The Course id of the new Payment",
     *     schema={}
     * )
     *
     * @SWG\Tag(name="Payment")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $payment = [];
        $message = "";
        

        try {
            $code = 200;
            $error = false;
            $payment = $em->getRepository("App:Payment")->find($id);
 
            if (!is_null($payment)) {
 
                $em->persist($payment);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Admin - Error: You must to provide fields payment or the payment id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the payment - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $payment : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Get("/student/{student_id}/{course_id}.{_format}", name="available_payment_student", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The payment was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the payment."
     * )
     *
     * @SWG\Parameter(
     *     name="student_id",
     *     in="path",
     *     type="string",
     *     description="The user ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="course_id",
     *     in="path",
     *     type="string",
     *     description="The user ID"
     * )
     *     
     *
     * @SWG\Tag(name="Payment")
     */
    public function studentPaymentAction(Request $request, $student_id, $course_id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $payments = [];
        $state = "state.free";
        $message = "";

        try {
            $code = 200;
            $error = false;
            $student = $em->getRepository("App:User")->find($student_id);
            

            if (!is_null($student)) {
                if (!is_null($student->getStudentgroup())) {
                    if($student->getStudentgroup()->getGroup()->getType() == "paid"){
                        $payment = $em->getRepository("App:Payment")->findOneBy(array('student' => $student_id, 'course' => $course_id));
                        if(is_null($payment)){
                            $state = "state.non_payment";
                        }
                        else{
                            $state = "state.paid";
                        }
                    }
                }
                
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Admin - Error: You must to provide fields payment or the payment id does not exist";
            }
            
           
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the payment - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $state : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

   

     

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="payment_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Admin was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the payment"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The payment ID"
     * )
     *
     * @SWG\Tag(name="Payment")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $payment = $em->getRepository("App:Payment")->find($id);
 
            if (!is_null($payment)) {
                $em->remove($payment);
                $em->flush();
 
                $message = "The payment was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent payment - Error: The payment id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current payment - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    

}