<?php

 
namespace App\Controller;
 
use App\Entity\Principle;
use App\Form\PrincipleType;
use App\Form\PrincipleEditType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\UserDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class PrincipleController
 *
 * @Route("/principle")
 */
class PrincipleController extends FOSRestController
{
    
    /**
     * @Rest\Get("/", name="principle_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all Principles."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all Principles."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="Principle ID"
     * )
     *
     *
     * @SWG\Tag(name="Principle")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $principles = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $principles = $em->getRepository("App:Principle")->findAll();
 
            if (is_null($principles)) {
                $Principles = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Principle - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $principles : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Post("/new", name="principle_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Principle was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Principle was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The name",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="state",
     *     in="body",
     *     type="string",
     *     description="The state",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="unit_id",
     *     in="body",
     *     type="string",
     *     description="The Unit id of the new Principle",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="content",
     *     in="body",
     *     type="string",
     *     description="The content",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="position",
     *     in="body",
     *     type="integer",
     *     description="The order of the principle",
     *     schema={}
     * )
     * 
     *  @SWG\Parameter(
     *     name="type",
     *     in="body",
     *     type="integer",
     *     description="The type of the principle",
     *     schema={}
     * )
     * 
     * 
     * @SWG\Parameter(
     *     name="finalAnwserType",
     *     in="body",
     *     type="integer",
     *     description="The type of Final Answer",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="finalAnswer",
     *     in="body",
     *     type="integer",
     *     description="Final Answer content",
     *     schema={}
     * )
     * 
     * @SWG\Tag(name="Principle")
     */ 

    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";
        $principle=new Principle();
        //Create a form
        $form=$this->createForm(PrincipleType::class, $principle);
        $form->submit($request->request->all());
        $unitId= $request->request->get("unit_id");
        $unit = $em->getRepository("App:Unit")->find($unitId);
        $principle->setUnit($unit);

        $consecutive = $em->getRepository("App:Principle")->principleConsecutive($unit->getCourse()->getId());
        $principle->setPosition($consecutive + 1);

        try {
            $code = 200;
            $error = false;

            $em->persist($principle);
            $em->flush();
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Principle - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $principle : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Get("/show/{id}.{_format}", name="Principle_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Principle info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Principle with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Principle ID"
     * )
     *
     * @SWG\Tag(name="Principle")
     */
    public function showAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $principle = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $principle_id = $id;
            $principle = $em->getRepository("App:Principle")->find($principle_id);
 
            if (is_null($principle)) {
                $code = 500;
                $error = true;
                $message = "The Principle does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Principle- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $principle : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    } 

    

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="Principle_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The Principle was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the Principle."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Principle ID"
     * )
     * 
    * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The name",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="state",
     *     in="body",
     *     type="string",
     *     description="The state",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="unit_id",
     *     in="body",
     *     type="string",
     *     description="The Unit id of the new Principle",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="content",
     *     in="body",
     *     type="string",
     *     description="The content",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="position",
     *     in="body",
     *     type="integer",
     *     description="The order of the principle",
     *     schema={}
     * )
     * 
     *  @SWG\Parameter(
     *     name="type",
     *     in="body",
     *     type="integer",
     *     description="The type of the principle",
     *     schema={}
     * )
     * 
     * 
     * @SWG\Parameter(
     *     name="finalAnwserType",
     *     in="body",
     *     type="integer",
     *     description="The type of Final Answer",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="finalAnswer",
     *     in="body",
     *     type="integer",
     *     description="Final Answer content",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="stopState",
     *     in="body",
     *     type="integer",
     *     description="The Stop State",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="stopContent",
     *     in="body",
     *     type="integer",
     *     description="The content for the Stop",
     *     schema={}
     * )
     *
     * @SWG\Tag(name="Principle")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $principle = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $principle = $em->getRepository("App:Principle")->find($id);
 
            if (!is_null($principle)) {
                $form = $this->createForm(PrincipleEditType::class, $principle);
                $form->submit($request->request->all());
                //$curse->setName($name);
 
                $em->persist($principle);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Principle - Error: You must to provide fields user or the Principle id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the Principle - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $principle : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

     /**
     * @Rest\Put("/editstate/{id}.{_format}", name="principle_state_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The Principle was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the Principle."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Principle ID"
     * )
     *    
     * 
     * @SWG\Parameter(
     *     name="state",
     *     in="body",
     *     type="string",
     *     description="The state",
     *     schema={}
     * )
     *
     *
     * @SWG\Tag(name="Principle")
     */
    public function editStateAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $principle = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $principle = $em->getRepository("App:Principle")->find($id);
            $state = $request->request->get('state');
 
            if (!is_null($principle)) {
                
                $principle->setState($state);
 
                $em->persist($principle);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Principle - Error: You must to provide fields user or the Principle id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the Principle - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $principle : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Put("/editstop/{id}.{_format}", name="principle_stop_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The Principle was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the Principle."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Principle ID"
     * )
     *    
     * 
     * @SWG\Parameter(
     *     name="stopState",
     *     in="body",
     *     type="string",
     *     description="The Stop state",
     *     schema={}
     * )
     *
     *
     * @SWG\Tag(name="Principle")
     */
    public function editStopAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $principle = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $principle = $em->getRepository("App:Principle")->find($id);
            $stop_state = $request->request->get('stopState');
 
            if (!is_null($principle)) {
                
                $principle->setStopState($stop_state);
 
                $em->persist($principle);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Principle - Error: You must to provide fields user or the Principle id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the Principle - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $principle : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Put("/orderupdate", name="principle_order_update")
     *
     * @SWG\Response(
     *     response=201,
     *     description="User was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="User was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="principle_array",
     *     in="body",
     *     type="string",
     *     description="The array of Principles",
     *     schema={}
     * )
     * 
     *      
     *
     * @SWG\Tag(name="Principle")
     */ 
    public function orderUpdateAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();

        $principle_array = explode(',', $request->request->get('principle_array'));
 
        $message = "";
       
        try {
            $code = 200;
            $error = false;
            $unit_position = 1;
            $principle_position = 1;
            $unit = null;

            foreach ($principle_array as $value) {
                $string_id = explode("-", $value);
                if($string_id[2] == 0){
                    $unit_id = $string_id[1];
                    $unit = $em->getRepository("App:Unit")->find($unit_id);
                    $unit->setPosition($unit_position);
                    $em->persist($unit);
                    $em->flush();
                    $unit_position = $unit_position + 1;
                }
                else{
                    $principle_id = $string_id[2];
                    $principle = $em->getRepository("App:Principle")->find($principle_id);
                    if(!is_null($unit)){
                        $principle->setUnit($unit);
                    }
                    $principle->setPosition($principle_position);
                    $em->persist($principle);
                    $em->flush();
                    $principle_position = $principle_position + 1;
                    
                }
            } 

            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the course - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $principle_array : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Put("/orderunitupdate", name="unit_order_update")
     *
     * @SWG\Response(
     *     response=201,
     *     description="User was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="User was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="principle_array",
     *     in="body",
     *     type="string",
     *     description="The array of Principles",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="course_id",
     *     in="body",
     *     type="string",
     *     description="The ID of Course",
     *     schema={}
     * )
     * 
     *      
     *
     * @SWG\Tag(name="Principle")
     */ 
    public function orderUnitUpdateAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();

        $principle_array = explode(',', $request->request->get('principle_array'));
 
        $message = "";
       
        try {
            $code = 200;
            $error = false;
            $unit_position = 1;
            $principle_position = 1;
            $unit = null;

            foreach ($principle_array as $value) {
                $string_id = explode("-", $value);
                if($string_id[2] == 0){
                    $unit_id = $string_id[1];
                    $unit = $em->getRepository("App:Unit")->find($unit_id);
                    $unit->setPosition($unit_position);
                    $em->persist($unit);
                    $em->flush();
                    $unit_position = $unit_position + 1;
                }
            } 

                       
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the course - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $principle_array : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="Principle_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Principle was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the Principle"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Principle ID"
     * )
     *
     * @SWG\Tag(name="Principle")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $principle = $em->getRepository("App:Principle")->find($id);
 
            if (!is_null($principle)) {
                $em->remove($principle);
                $em->flush();
 
                $message = "The Principle was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent Principle - Error: The Principle id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current Principle - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }
 
}