<?php
/**
 * ProgrammbsController.php
 *
 */
 
namespace App\Controller;
 
use App\Entity\ProgramMbs;
use App\Entity\Task;
use App\Entity\Certificate;
use App\Form\ProgramMbsUpdateRevisionType;
use App\Form\ProgramMbsType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Nelmio\ProgrammbsDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class ProgrammbsController
 *
 * @Route("/programmbs")
 */
class ProgrammbsController extends FOSRestController
{
    
 
    /**
     * @Rest\Get("/", name="programmbss_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all programmbss."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all programmbs programmbss."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="Programmbs ID"
     * )
     *
     *
     * @SWG\Tag(name="Programmbs")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programmbss = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            //$programmbsId = $this->getProgrammbs()->getId();
            $programmbss = $em->getRepository("App:ProgramMbs")->findBy(array(), array(), 20);
 
            if (is_null($programmbss)) {
                $programmbss = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Programmbss - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programmbss : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/pagination", name="programmbs_pagination")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all students."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all students."
     * )
     *
     *
     * @SWG\Parameter(
     *     name="keyword",
     *     in="path",
     *     type="string",
     *     description="The search keyword"
     * )
     * 
     * @SWG\Parameter(
     *     name="page",
     *     in="path",
     *     type="string",
     *     description="The search Page"
     * )
     * 
     * @SWG\Parameter(
     *     name="page_size",
     *     in="path",
     *     type="string",
     *     description="The number of records for page"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_column",
     *     in="path",
     *     type="string",
     *     description="Search order Column"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_direction",
     *     in="path",
     *     type="string",
     *     description="Search order Direction"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description=" Array Language Project"
     * )
     * 
     * @SWG\Parameter(
     *     name="state",
     *     in="path",
     *     type="string",
     *     description="State Project"
     * )
     * 
     * @SWG\Parameter(
     *     name="role",
     *     in="path",
     *     type="string",
     *     description="User Role"
     * )
     *    
     *
     * @SWG\Tag(name="Programmbs")
     */
    public function paginationAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $groups = [];
        $message = "";
        $students = [];
 
        try {
            $code = 200;
            $error = false;
            
            $keyword    = $request->request->get('keyword');
            $page   = $request->request->get('page');
            $page_size = $request->request->get('page_size');
            $order_column = $request->request->get('order_column');
            $order_direction = $request->request->get('order_direction');
            $language = $request->request->get("language");
            $state = $request->request->get("state");
            $role = $request->request->get("role");

            $language = explode(",", preg_replace('([^A-Za-z0-9,])', '', $language));

            if($role == "ROLE_ADMIN" ){
                if($state === "state.approved"){
                    $studentsMbs = $em->getRepository('App:ProgramMbs')->mbsApprovedPagination($keyword, $page, $page_size, $order_column, $order_direction);    
                }
                else{
                    $studentsMbs = $em->getRepository('App:ProgramMbs')->mbsByStatePagination($keyword, $page, $page_size, $order_column, $order_direction, $state);    
                }
            }
            if($role == "ROLE_LANGUAGE_ADMIN"  || $role == "ROLE_PROJECT_QUALIFIER"){
                if($state === "state.approved"){
                    $studentsMbs = $em->getRepository('App:ProgramMbs')->mbsApprovedLanguagePagination($keyword, $page, $page_size, $order_column, $order_direction, $language); 
                }
                else{
                    $studentsMbs = $em->getRepository('App:ProgramMbs')->mbsByStateLanguagePagination($keyword, $page, $page_size, $order_column, $order_direction, $state, $language);
                }
                    
            }

            foreach ($studentsMbs['list'] as $student) {
                $st = $student[0];
                $course = $em->getRepository('App:Course')->getCourseByRequirementsLanguage($st->getStudent(), 'requirement.mbs', $st->getStudent()->getLanguage());
                $admin = $st->getAdmin();
                $students[] = [
                    'participant_id'            => $student['participant_id'],
                    'participant_name'          => $student['participant_name'],
                    'country'                   => $student['country'],
                    'programmbs_id'             => $student['id'],
                    'updated_at'                => $student['updated_at'],
                    'approval_date'             => $student['approval_date'],
                    'group_program'             => $student['group_program'],
                    'group_name'                => $student['group_name'],
                    'ambassador_name'           => $student['ambassador_name'],
                    'programmbs_modality'       => $student['programmbs_modality'],
                    'admin_name'                => $admin ?  $admin->getFirstName(). " " .$admin->getLastName() : "",
                    'mbs_course'                => $course ? $course->getId() : "",
                    'geolocation'               => $st->getGeolocation()
                ];
            }

            $data_array = [
                'list'              => $students,
                'items_total'       => $studentsMbs['items_total'],
                'pages_total'       => $studentsMbs['pages_total']
            ];
           
           
         
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data_array : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('participant_list'))));
    }

    /**
     * @Rest\Get("/lastgraduated/{id}.{_format}", name="programmbs_last_graduated", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all ambassadors."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador ambassadors."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="Ambassador ID"
     * )
     *
     *
     * @SWG\Tag(name="Programmbs")
     */
    public function lastGraduatedAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $list = [];
        $message = "";
        
 
        try {
            $code = 200;
            $error = false;
 
            $total_graduates = $em->getRepository('App:StudentGroup')->lastMbsGraduatedByEmbassador($id, 'state.approved');
            if($total_graduates > 0){
                $current_date = new \DateTime();
                $last_graduated_date = $em->getRepository('App:StudentGroup')->lastMbsGraduatedByEmbassadorDate($id, 'state.approved');

                $init_date  = new \DateTime( $last_graduated_date->format('Y-m-d') );
                $final_date = new \DateTime( $current_date->format('Y-m-d') );

                $interval = date_diff($init_date, $final_date);
                    
                $data = [
                    'last_graduated_date' => $last_graduated_date,
                    'days_interval'       => $interval->format('%a')
                ];
            }
            else{
                $data = [
                    'last_graduated_date' => "never",
                    'days_interval'       => "0"
                ];
            }
            

        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Ambassadors - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/new", name="programmbs_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Programmbs was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Programmbs was not successfully registered"
     * )
     *     
     *
     * @SWG\Tag(name="Programmbs")
     */ 
    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programmbs = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $programmbs = $em->getRepository('App:ProgramMbs')->findOneBy(array('student' => $request->request->get('id_student')));
 
            if (!is_null($programmbs)) {
                $progressOrigin = $this->mbsProgress($programmbs);
                $form = $this->createForm(ProgramMbsType::class, $programmbs);
                $form->submit($request->request->all());
                
                $process1 = explode(',', $request->request->get('process1'));
                $programmbs->setProcess1($process1);

                $paperwork3 = explode(',', $request->request->get('paperwork3'));
                $programmbs->setPaperwork3($paperwork3);
                $checklist = explode(',', $request->request->get('checklist'));
                $programmbs->setChecklist($checklist);
                $programmbs->setPaperwork4(json_decode($programmbs->getPaperwork4()));
                $programmbs->setPaperwork5(json_decode($programmbs->getPaperwork5()));
                $programmbs->setPaperwork6(json_decode($programmbs->getPaperwork6()));
                $programmbs->setPaperwork7(json_decode($programmbs->getPaperwork7()));
                $programmbs->setPaperwork8(json_decode($programmbs->getPaperwork8()));
                $programmbs->setPaperwork10(json_decode($programmbs->getPaperwork10()));
                $programmbs->setPaperwork11(json_decode($programmbs->getPaperwork11()));

                $programmbs->setState("state.development");
                
                if($this->mbsProgress($programmbs) >= $progressOrigin || $programmbs->getVersion() == 5 ){
                    //if($this->mbsProgress($programmbs) == 800){
                        //$programmbs->setState("state.revision");
                        //$message_list = $this->sendMessageList($programmbs->getStudent());
                    //}
                    $em->persist($programmbs);
                    $em->flush();
                }
                else{
                    $code = 500;
                    $error = true;
                    $message = "An error has occurred trying to edit the programmbs";
                }
                              
 
            } else {
                $student = $em->getRepository('App:User')->find($request->request->get('id_student'));
                $programmbs=new Programmbs();
                $form = $this->createForm(ProgramMbsType::class, $programmbs);
                $form->submit($request->request->all());
                
                $process1 = explode(',', $request->request->get('process1'));
                $programmbs->setProcess1($process1);
                
                $programmbs->setStudent($student);
                $paperwork3 = explode(',', $request->request->get('paperwork3'));
                $programmbs->setPaperwork3($paperwork3);
                $checklist = explode(',', $request->request->get('checklist'));
                $programmbs->setChecklist($checklist);
                $programmbs->setPaperwork4(json_decode($programmbs->getPaperwork4()));
                $programmbs->setPaperwork5(json_decode($programmbs->getPaperwork5()));
                $programmbs->setPaperwork6(json_decode($programmbs->getPaperwork6()));
                $programmbs->setPaperwork7(json_decode($programmbs->getPaperwork7()));
                $programmbs->setPaperwork8(json_decode($programmbs->getPaperwork8()));
                $programmbs->setPaperwork10(json_decode($programmbs->getPaperwork10()));
                $programmbs->setPaperwork11(json_decode($programmbs->getPaperwork11()));

                

                $programmbs->setState("state.development");
                
 
                $em->persist($programmbs);
                $em->flush();
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programmbs : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/newfile", name="programmbs_new_file")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Programmbs was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Programmbs was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="id_student",
     *     in="body",
     *     type="string",
     *     description="The id student",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="file_name",
     *     in="body",
     *     type="string",
     *     description="The name of file",
     *     schema={}
     * )
     *     
     *
     * @SWG\Tag(name="Programmbs")
     */ 
    public function newFileAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";        
        $id = $request->request->get('id_student');
        $filename = $request->request->get('file_name');
 
        try {
            $code = 200;
            $error = false;
           
            $student = $em->getRepository("App:User")->find($id);
            $programmbs = $em->getRepository("App:Programmbs")->findOneBy(array('student' => $id));

            if(is_null($programmbs)){
                $programmbs=new Programmbs();
            }            
 
            if (is_null($student)) {
                $code = 500;
                $error = true;
                $message = "The Student does not exist";
            }
            else{
                $programmbs->setFilestudent($filename);
                $programmbs->setStudent($student);
                $programmbs->setModality("option.modality1");
                $programmbs->setUploadDateStudent(new \DateTime('now', (new \DateTimeZone('America/New_York') ) ) ); 

                $programmbs->setState("state.revision");
                
                $programmbs->setProcess1([""]);
                $programmbs->setPaperwork3([""]);
                $programmbs->setPaperwork4([""]);
                $programmbs->setPaperwork5([""]);
                $programmbs->setPaperwork6([""]);
                $programmbs->setPaperwork7([""]);
                $programmbs->setPaperwork8([""]);
                $programmbs->setPaperwork10([""]);
                $programmbs->setPaperwork11([""]);
                $em->persist($programmbs);
                $em->flush();

                $message_list = $this->sendMessageList($programmbs->getStudent());

            }            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $message_list : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Get("/show/{id}.{_format}", name="course_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets course info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The course with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Programmbs ID"
     * )
     *
     * @SWG\Tag(name="Programmbs")
     */
    public function showAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programmbs = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $programmbs_id = $id;
            $programmbs = $em->getRepository("App:ProgramMbs")->find($programmbs_id);
 
            if (is_null($programmbs)) {
                $code = 500;
                $error = true;
                $message = "The Programmbs does not exist";
            }
            else{
                $cvDir = $this->container->getparameter('kernel.project_dir').'/web/file/'.$programmbs->getHistory2();
                if(!file_exists($cvDir) || $programmbs->getHistory2() == ""){
                    //$programmbs->setHistory2("undefined");
                }
                //$em->getRepository("App:ProgramMbs")->stringReplace($programmbs_id);
                //$programmbs = $em->getRepository("App:ProgramMbs")->find($programmbs_id);
            }

            //foreach ($programmbs[0]["paperwork11"]["p11_array"] as $key => &$value) {
                //if ($value === null) {
                    //$value = ""; // Reemplazar el valor nulo con una cadena vacía
                //}
            //}
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Programmbs- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programmbs : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Get("/show/participant/{id}.{_format}", name="programmbs_show_participant", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets course info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The course with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Student ID"
     * )
     *
     * @SWG\Tag(name="Programmbs")
     */
    public function showParticipantAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programmbs = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $programmbs = $em->getRepository("App:ProgramMbs")->findOneBy(array("student" => $id));
 
            if (is_null($programmbs)) {
                $code = 500;
                $error = true;
                $message = "The Programmbs does not exist";
            }
            else{
                $cvDir = $this->container->getparameter('kernel.project_dir').'/web/file/'.$programmbs->getHistory2();
                if(!file_exists($cvDir) || $programmbs->getHistory2() == ""){
                    //$programmbs->setHistory2("undefined");
                }
            }
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Programmbs- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programmbs : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Get("/show/progress/{id}.{_format}", name="mbs_requirements_show_progress", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets course info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The course with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Student ID"
     * )
     *
     * @SWG\Tag(name="Programmbs")
     */
    public function showProgressAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programmbs = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $programmbs = $em->getRepository("App:ProgramMbs")->findOneBy(array('student' => $id));
 
            if (is_null($programmbs)) {
                $code = 200;
                $error = true;
                $requirements = [
                    'business' => 0,
                    'business_budget' => 0,
                    'income_expense' => 0,
                    'income_statement' => 0,
                    'quality_life' => 0,
                    'success_story' => 0,
                    'service' => 0,
                    'checklist' => 0, 
                    'post_evaluation' => 0,
                    'money_management' => 0
                ];

                $corrections = [
                   
                ];
        
                $progress =[
                   'requirements' => $requirements,
                   'corrections'  => $corrections,
                   'total_progress' => 0,
                   'state'        => "state.not_started"
                ];
            } 
            else{
                $evaluation = $em->getRepository("App:Evaluation")->findOneBy( array('student' => $programmbs->getStudent()->getId() ) );
                $progress = $this->requirementMbsProgress($programmbs, $evaluation);
            }
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Programmbs- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $progress : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/progress/group/{id}.{_format}", name="mbs_requirements_progress_group", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets course info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The course with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Group ID"
     * )
     *
     * @SWG\Tag(name="Programmbs")
     */
    public function progressGroupAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programmbs = [];
        $students_progress = [];
        $students_old_progress = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;

            $students = $em->getRepository("App:User")->getParticipantByGroup($id);

            foreach ($students as $student) {
                $programmbs = $em->getRepository("App:ProgramMbs")->findOneBy(array('student' => $student->getId()));
 
                if (is_null($programmbs)) {
                    $code = 200;
                    $error = true;
                    $requirements = [
                        'business' => 0,
                        'business_budget' => 0,
                        'income_expense' => 0,
                        'income_statement' => 0,
                        'quality_life' => 0,
                        'success_story' => 0,
                        'service' => 0,
                        'checklist' => 0, 
                        'post_evaluation' => 0,
                        'money_management' => 0
                    ];

                    $corrections = [
                    
                    ];
            
                    $progress =[
                        'name' => $student->getFirstName()." ".$student->getLastName(),
                        'requirements' => $requirements,
                        'corrections'  => $corrections,
                        'total_progress' => 0,
                        'state'        => "state.not_started",
                        'version'      => "0"
                    ];
                    $students_progress[] = $progress;
                } 
                else if($programmbs->getModality() === "option.modality1" && $programmbs->getState() === "state.approved"){
                    $requirements = [
                        'business' => 100,
                        'business_budget' => 100,
                        'income_expense' => 100,
                        'income_statement' => 100,
                        'quality_life' => 100,
                        'success_story' => 100,
                        'service' => 100,
                        'checklist' => 100, 
                        'post_evaluation' => 100,
                        'money_management' => 100
                    ];

                    $corrections = [
                    
                    ];
            
                    $progress =[
                        'name' => $student->getFirstName()." ".$student->getLastName(),
                        'requirements' => $requirements,
                        'corrections'  => $corrections,
                        'total_progress' => 100,
                        'state'        => "state.approved",
                        'version'      => "0"
                    ];
                    $students_progress[] = $progress;

                }
                else if($programmbs->getVersion() === "5" ){
                    $evaluation = $em->getRepository("App:Evaluation")->findOneBy( array('student' => $programmbs->getStudent()->getId() ) );
                    $progress = $this->requirementMbsProgress($programmbs, $evaluation);
                    $students_progress[] = $progress;
                }

                $old_programmbs = $em->getRepository("App:ProgramMbs")->findOneBy(array('student' => $student->getId() , 'version' => '4'));
                if( !is_null($old_programmbs) ) {
                    $progress = $this->mbsOldRequirementsProgress($old_programmbs);
                    $students_old_progress[] = $progress;
                }

                
            }

            $progress_list=[
                'student_progress' => $students_progress,
                'student_old_progress' => $students_old_progress
            ];            
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Programmbs- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $progress_list : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    

    /**
     * @Rest\Delete("/delete/{id}.{_format}", name="programmbs_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Programmbs was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the programmbs"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The programmbs ID"
     * )
     *
     * @SWG\Tag(name="Programmbs")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $programmbs = $em->getRepository("App:ProgramMbs")->find($id);
 
            if (!is_null($programmbs)) {
                $em->remove($programmbs);
                $em->flush();
 
                $message = "The programmbs was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent programmbs - Error: The programmbs id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Get("/search/{key}.{_format}", name="programmbs_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets programmbs info based on passed key parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The programmbs with the passed key parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="key",
     *     in="path",
     *     type="string",
     *     description="The programmbs key"
     * )
     *
     *
     * @SWG\Tag(name="Programmbs")
     */
    public function searchAction(Request $request, $key ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programmbs = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            
            $programmbs = $em->getRepository("App:ProgramMbs")->programmbsSearch($key);
 
            if (is_null($programmbs)) {
                $code = 500;
                $error = true;
                $message = "The programmbs does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programmbs : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/active_programmbs", name="active_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Programmbs was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Programmbs was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="state",
     *     in="body",
     *     type="string",
     *     description="The state",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="query",
     *     type="string",
     *     description="The language",
     * )
     * @SWG\Tag(name="Programmbs")
     */ 

    public function activeprogrammbsAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
 
            $programmbs = $this->getProgrammbs();
            $em = $this->getDoctrine()->getManager();
            $programmbs = $em->getRepository("App:ProgramMbs")->find($programmbs->getId());
            
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programmbs : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/edit/{id}", name="edit_programmbs")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Revision was successfully update"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Revision was not successfully update"
     * )
     *
     * @SWG\Parameter(
     *     name="planrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="productrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="pricerevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="promotionrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="paperworkrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="processrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * @SWG\Tag(name="Programmbs")
     */

    public function editAction(Request $request, $id)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programmbs = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $programmbs = $em->getRepository('App:ProgramMbs')->find($id);
 
            if (!is_null($programmbs)) {
                $progressOrigin = $this->mbsProgress($programmbs);
                $form = $this->createForm(ProgramMbsType::class, $programmbs);
                $form->submit($request->request->all());
                
                $process1 = explode(',', $request->request->get('process1'));
                $programmbs->setProcess1($process1);
                
                $paperwork3 = explode(',', $request->request->get('paperwork3'));
                $programmbs->setPaperwork3($paperwork3);
                $checklist = explode(',', $request->request->get('checklist'));
                $programmbs->setChecklist($checklist);
                $programmbs->setPaperwork4(json_decode($programmbs->getPaperwork4()));
                $programmbs->setPaperwork5(json_decode($programmbs->getPaperwork5()));
                $programmbs->setPaperwork6(json_decode($programmbs->getPaperwork6()));
                $programmbs->setPaperwork7(json_decode($programmbs->getPaperwork7()));
                $programmbs->setPaperwork8(json_decode($programmbs->getPaperwork8()));
                $programmbs->setPaperwork10(json_decode($programmbs->getPaperwork10()));
                $programmbs->setPaperwork11(json_decode($programmbs->getPaperwork11()));
                
 
                if($this->mbsProgress($programmbs) >= $progressOrigin || $programmbs->getVersion() == 5){
                    //if($this->mbsProgress($programmbs) == 800){
                        //
                        //$message_list = $this->sendMessageList($programmbs->getStudent());
                    //}
                    $em->persist($programmbs);
                    $em->flush();
                }
                else{
                    $code = 500;
                    $error = true;
                    $message = "An error has occurred trying to edit the programmbs";
                }
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Programmbs - Error: You must to provide fields programmbs or the programmbs id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $this->mbsProgress($programmbs),
            'error' => $error,
            'data' => $code == 200 ? $programmbs : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/update_revision/{id}", name="update_revision_programmbs")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Revision was successfully update"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Revision was not successfully update"
     * )
     *
     * @SWG\Parameter(
     *     name="revisionplan",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="revisionproduct",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionprice",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionpromotion",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionpaperwork",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionprocess",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionbusinessbudget",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionbusiness",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionchecklist",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionincomeexpenselog",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionincomestatement",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionmoneymanagement",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionqualitylife",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionsucessstory",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * ) 
     * 
     * @SWG\Parameter(
     *     name="revisionservice",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Tag(name="Programmbs")
     * 
     * 
     */

    public function updateRevisionAction(Request $request, $id)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programmbs = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $programmbs = $em->getRepository('App:ProgramMbs')->find($id);
 
            if (!is_null($programmbs)) {
                $form = $this->createForm(ProgramMbsUpdateRevisionType::class, $programmbs);
                $form->submit($request->request->all());
 
                $em->persist($programmbs);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Programmbs - Error: You must to provide fields programmbs or the programmbs id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programmbs : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/approved", name="approved_programmbs")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Project mbs approval was successful"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Project mbs was not successfully approved"
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="body",
     *     type="string",
     *     description="The id programmbs",
     *     schema={}
     * )
     * 
     *  * @SWG\Parameter(
     *     name="admin",
     *     in="body",
     *     type="string",
     *     description="The id admin",
     *     schema={}
     * )
     * @SWG\Tag(name="Programmbs")
     */

    public function approvedAction(Request $request)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programMb = [];
        $message = ""; 

        try {
            $code = 200;
            $error = false;
            $id = $request->request->get('id');
            $admin = $request->request->get('admin');
            $geolocation = $request->request->get('geolocation');

            $programMb = $em->getRepository('App:ProgramMbs')->find($id);
            $student = $programMb->getStudent();
            $admin = $em->getRepository('App:User')->find($admin);
 
            if (!is_null($programMb) && !is_null($admin)) {
                $em = $this->getDoctrine()->getManager();
                
                $programMb->setState('state.approved');
                $programMb->setAdmin($admin);
                $programMb->setGeolocation($geolocation);

                $programMb->setApprovalDate(new \DateTime('now', (new \DateTimeZone('America/New_York'))));
                if(!$programMb->getCode()){
                    if($programMb->getStudent()->getStudentGroup()->getGroup()->getProgram() == "option.program4"){
                        $programMb->setCode($programMb->getStudent()->getCountry()."-".$this->getNumberCodeJr($programMb, $request));
                    } 
                    else{
                        $programMb->setCode($programMb->getStudent()->getCountry()."-".$this->getNumberCode($programMb, $request));
                    }                   
                }

                $em->persist($programMb);
                $em->flush();
                
                $student->setRoles(["ROLE_STUDENT_EMBASSADOR"]);
                $em->persist($student);
                $em->flush();
                
                $message_list =  $this->sendMessageApproved($programMb->getStudent());
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Programmbs - Error: You must to provide fields programmbs or the programmbs id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $message_list : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/revision", name="revision_programmbs")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Project mbs approval was successful"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Project mbs was not successfully revision"
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="body",
     *     type="string",
     *     description="The id programmbs",
     *     schema={}
     * )
     * @SWG\Tag(name="Programmbs")
     */

    public function revisionAction(Request $request)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programMb = [];
        $message = ""; 

        try {
            $code = 200;
            $error = false;
            $id = $request->request->get('id');
            $programMb = $em->getRepository('App:ProgramMbs')->find($id);
 
            if (!is_null($programMb)) {
                $em = $this->getDoctrine()->getManager();

                
                $programMb->setState('state.revision');
                $em->persist($programMb);
                $em->flush();
                
                //$message_list = $this->sendMessageList($programmbs->getStudent());
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Programmbs - Error: You must to provide fields programmbs or the programmbs id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programMb : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/sendrevision", name="sendrevision_programmbs")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Project mbs sendrevision was successful"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Project mbs was not successfully sendrevision"
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="body",
     *     type="string",
     *     description="The id programmbs",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="planrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="productrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="pricerevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="promotionrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="paperworkrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="processrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * @SWG\Tag(name="Programmbs")
     */

    public function sendRevisionAction(Request $request)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programMb = [];
        $message = ""; 

        try {
            $code = 200;
            $error = false;
            $id = $request->request->get('id');
            $programMb = $em->getRepository('App:ProgramMbs')->find($id);
 
            if (!is_null($programMb)) {
                $em = $this->getDoctrine()->getManager();

                $form = $this->createForm(ProgramMbsUpdateRevisionType::class, $programMb);
                $form->submit($request->request->all());

                $programMb->setState('state.correction');
                $email = $this->sendCorrectionsMessage($programMb->getStudent());
            
                $em->persist($programMb);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to send revision Programmbs - Error: You must to provide fields programmbs or the programmbs id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying send revision of programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $email : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    public function getNumberCode(ProgramMbs $programMbs){

        $em = $this->getDoctrine()->getManager();
        $number = $em->getRepository('App:Certificate')->findOneBy(array('country' => $programMbs->getStudent()->getCountry(), 'program' => 'MBS'));
        if($number){
          $number->setNumber($number->getNumber() + 1);
          $em->persist($number);
          $em->flush();
        }
        else{
          $number = new Certificate();
          $number->setCountry($programMbs->getStudent()->getCountry());
          $number->setProgram("MBS");
          $number->setNumber(1);
          $number->setInitial(0);
          $number->setLanguage("en");
          $em->persist($number);
          $em->flush();
        }
  
        return $number->getNumber();
    }

    public function getNumberCodeJr(ProgramMbs $programMbs){

        $em = $this->getDoctrine()->getManager();
        $number = $em->getRepository('App:Certificate')->findOneBy(array('country' => $programMbs->getStudent()->getCountry(), 'program' => 'JR'));
        if($number){
          $number->setNumber($number->getNumber() + 1);
          $em->persist($number);
          $em->flush();
        }
        else{
          $number = new Certificate();
          $number->setCountry($programMbs->getStudent()->getCountry());
          $number->setProgram("JR");
          $number->setNumber(1);
          $number->setInitial(0);
          $number->setLanguage("en");
          $em->persist($number);
          $em->flush();
        }
  
        return $number->getNumber();
    }

    

    public function mbsProgress($programMbs){

        $plan = 0;
        $product = 0;
        $process = 0;
        $promotion = 0;
        $paperwork = 0;
        $price = 0;
        $service = 0;
        $quality_life = 0;

        $paperwork4 = json_decode(json_encode($programMbs->getPaperwork4()), true);
        $paperwork5 = json_decode(json_encode($programMbs->getPaperwork5()), true);
        $paperwork6 = json_decode(json_encode($programMbs->getPaperwork6()), true);
        $paperwork7 = json_decode(json_encode($programMbs->getPaperwork7()), true);
        $paperwork8 = json_decode(json_encode($programMbs->getPaperwork8()), true);
        $paperwork10 = json_decode(json_encode($programMbs->getPaperwork10()), true);

        if( $programMbs->getPlan1() )              { $plan = $plan + 50; }
        if( $programMbs->getPlan2() )              { $plan = $plan + 50; }
        if( $programMbs->getProduct1() )           { $product = $product + 14; }
        if( $programMbs->getProduct2() )           { $product = $product + 14; }
        if( $programMbs->getProduct3() )           { $product = $product + 14; }
        if( $programMbs->getProduct4() )           { $product = $product + 14; }
        if( $programMbs->getProduct5() )           { $product = $product + 14; }
        if( $programMbs->getProduct6() )           { $product = $product + 14; }
        if( $programMbs->getProduct7() )           { $product = $product + 16; }
        if( $programMbs->getProcess1()[0] != "" )  { $process = $process + 25; }
        if( $programMbs->getProcess2() )           { $process = $process + 25; }
        if( $programMbs->getProcess3() )           { $process = $process + 25; }
        if( $programMbs->getProcess4() )           { $process = $process + 25; }
        if( $programMbs->getPrice1() )             { $price = $price + 25; }
        if( $programMbs->getPrice2() )             { $price = $price + 25; }
        if( $programMbs->getPrice3() )             { $price = $price + 25; }
        if( $programMbs->getPrice4() )             { $price = $price + 25; }
        if( $programMbs->getPaperwork1() )         { $paperwork = $paperwork + 10; }
        if( $programMbs->getPaperwork3()[0] != "" )      { $paperwork = $paperwork + 10; }
        //if( $paperwork4['p4_balance']  != "" )      { $paperwork = $paperwork + 10; }
        //if( $paperwork5['p5_income']   != "" )       { $paperwork = $paperwork + 10; }
        //if( $paperwork6['p6_balance']  != "" )      { $paperwork = $paperwork + 10; }
        //if( $paperwork7['p7_income'][0]   != "" )       { $paperwork = $paperwork + 10; }
        //if( $paperwork8['p8_balance'][0]  != "" )      { $paperwork = $paperwork + 10; }
        //if( $paperwork10['p10_month']  != "" )      { $paperwork = $paperwork + 10; }
        //if( $paperwork10['p10_total_income_actual']  != "" )      { $paperwork = $paperwork + 10; }
        //if( $paperwork10['p10_total_expenses_plan']  != "" )      { $paperwork = $paperwork + 10; }
        if( $programMbs->getService1() )             { $service = $service + 20; }
        if( $programMbs->getService2() )             { $service = $service + 20; }
        if( $programMbs->getService3() )             { $service = $service + 20; }
        if( $programMbs->getService4() )             { $service = $service + 20; }
        if( $programMbs->getService5() )             { $service = $service + 20; }
        if( $programMbs->getPromotion1() )           { $promotion = $promotion + 25; }
        if( $programMbs->getPromotion2() )           { $promotion = $promotion + 25; }
        if( $programMbs->getPromotion3() )           { $promotion = $promotion + 25; }
        if( $programMbs->getPromotion4() )           { $promotion = $promotion + 25; }
        if( $programMbs->getQualityP1() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP2() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP3() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP4() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP5() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP6() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP7() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP8() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG1() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG2() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG3() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG4() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG5() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG6() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG7() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG8() )            { $quality_life = $quality_life + 10; }

        return $plan + $product + $process +  $promotion +  $paperwork +  $price +  $service + $quality_life ;

    }

    public function mbsOldRequirementsProgress($programMbs){

        $plan = 0;
        $product = 0;
        $process = 0;
        $promotion = 0;
        $paperwork = 0;
        $price = 0;
        $service = 0;
        $quality_life = 0;

        $paperwork4 = json_decode(json_encode($programMbs->getPaperwork4()), true);
        $paperwork5 = json_decode(json_encode($programMbs->getPaperwork5()), true);
        $paperwork6 = json_decode(json_encode($programMbs->getPaperwork6()), true);
        $paperwork7 = json_decode(json_encode($programMbs->getPaperwork7()), true);
        $paperwork8 = json_decode(json_encode($programMbs->getPaperwork8()), true);
        $paperwork10 = json_decode(json_encode($programMbs->getPaperwork10()), true);

        if( $programMbs->getPlan1() )              { $plan = $plan + 50; }
        if( $programMbs->getPlan2() )              { $plan = $plan + 50; }
        if( $programMbs->getProduct1() )           { $product = $product + 14; }
        if( $programMbs->getProduct2() )           { $product = $product + 14; }
        if( $programMbs->getProduct3() )           { $product = $product + 14; }
        if( $programMbs->getProduct4() )           { $product = $product + 14; }
        if( $programMbs->getProduct5() )           { $product = $product + 14; }
        if( $programMbs->getProduct6() )           { $product = $product + 14; }
        if( $programMbs->getProduct7() )           { $product = $product + 16; }
        if( $programMbs->getProcess1()[0] != "" )  { $process = $process + 25; }
        if( $programMbs->getProcess2() )           { $process = $process + 25; }
        if( $programMbs->getProcess3() )           { $process = $process + 25; }
        if( $programMbs->getProcess4() )           { $process = $process + 25; }
        if( $programMbs->getPrice1() )             { $price = $price + 25; }
        if( $programMbs->getPrice2() )             { $price = $price + 25; }
        if( $programMbs->getPrice3() )             { $price = $price + 25; }
        if( $programMbs->getPrice4() )             { $price = $price + 25; }
        if( $programMbs->getPaperwork1() )         { $paperwork = $paperwork + 10; }
        if( $programMbs->getPaperwork3()[0] != "" )      { $paperwork = $paperwork + 90; }
        //if( $paperwork4['p4_balance']  != "" )      { $paperwork = $paperwork + 10; }
        //if( $paperwork5['p5_income']   != "" )       { $paperwork = $paperwork + 10; }
        //if( $paperwork6['p6_balance']  != "" )      { $paperwork = $paperwork + 10; }
        //if( $paperwork7['p7_income'][0]   != "" )       { $paperwork = $paperwork + 10; }
        //if( $paperwork8['p8_balance'][0]  != "" )      { $paperwork = $paperwork + 10; }
        //if( $paperwork10['p10_month']  != "" )      { $paperwork = $paperwork + 10; }
        //if( $paperwork10['p10_total_income_actual']  != "" )      { $paperwork = $paperwork + 10; }
        //if( $paperwork10['p10_total_expenses_plan']  != "" )      { $paperwork = $paperwork + 10; }
        if( $programMbs->getService1() )             { $service = $service + 20; }
        if( $programMbs->getService2() )             { $service = $service + 20; }
        if( $programMbs->getService3() )             { $service = $service + 20; }
        if( $programMbs->getService4() )             { $service = $service + 20; }
        if( $programMbs->getService5() )             { $service = $service + 20; }
        if( $programMbs->getPromotion1() )           { $promotion = $promotion + 25; }
        if( $programMbs->getPromotion2() )           { $promotion = $promotion + 25; }
        if( $programMbs->getPromotion3() )           { $promotion = $promotion + 25; }
        if( $programMbs->getPromotion4() )           { $promotion = $promotion + 25; }
        if( $programMbs->getQualityP1() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP2() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP3() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP4() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP5() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP6() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP7() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP8() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG1() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG2() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG3() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG4() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG5() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG6() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG7() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG8() )            { $quality_life = $quality_life + 10; }

        $total =  $plan + $product + $process +  $promotion +  $paperwork +  $price +  $service + $quality_life ;

        $requirements = [
            'plan' => $plan,
            'product' => $product,
            'process' => $process,
            'promotion' => $promotion,
            'paperwork' => $paperwork,
            'price' => $price,
            'service' => $service,
            'quality_life' => $quality_life,
        ];

        $corrections = [
            'plan' => "",
            'product' => "",
            'process' => "",
            'promotion' => "",
            'paperwork' => "",
            'price' => "",
            'service' => "",
            'quality_life' => "",
        ];

        $totals =[
           'name' => $programMbs->getStudent()->getFirstName()." ".$programMbs->getStudent()->getLastName(),
           'requirements' => $requirements,
           'corrections'  => $corrections,
           'total_progress' => $total / 8,
           'state' => $programMbs->getState(),
           'version' => $programMbs->getVersion()
        ];      
        
        return $totals;

    }

    public function requirementMbsProgress($programMbs, $evaluation){

        $business = 0;
        $business_budget = 0; 
        $income_expense = 0;
        $income_statement = 0;
        $quality_life = 0;
        $success_story = 100;
        $service = 0;
        $checklist = 0;
        $post_evaluation = 0;
        $money_management = 0;

        $paperwork4 = json_decode(json_encode($programMbs->getPaperwork4()), true);
        $paperwork5 = json_decode(json_encode($programMbs->getPaperwork5()), true);
        $paperwork6 = json_decode(json_encode($programMbs->getPaperwork6()), true);
        $paperwork7 = json_decode(json_encode($programMbs->getPaperwork7()), true);
        $paperwork8 = json_decode(json_encode($programMbs->getPaperwork8()), true);
        $paperwork10 = json_decode(json_encode($programMbs->getPaperwork10()), true);

        if( $programMbs->getPlan1() )              { $business = $business + 6; }
        if( $programMbs->getPlan2() )              { $business = $business + 6; }
        if( $programMbs->getPlan3() )              { $business = $business + 6; }
        
        if( $programMbs->getProduct1() )           { $business = $business + 6; }
        if( $programMbs->getProduct2() )           { $business = $business + 6; }
        if( $programMbs->getProduct3() )           { $business = $business + 6; }
        if( $programMbs->getProduct4() )           { $business = $business + 6; }

        if( $programMbs->getPrice1() )             { $business = $business + 6; }
        if( $programMbs->getPrice2() )             { $business = $business + 6; }
        if( $programMbs->getPrice3() )             { $business = $business + 6; }
        if( $programMbs->getPrice4() )             { $business = $business + 6; }

        if( $programMbs->getProcess1()[0] != "" )  { $business = $business + 6; }
        if( $programMbs->getProcess2() )           { $business = $business + 6; }

        if( $programMbs->getPromotion1() )             { $business = $business + 3; }
        if( $programMbs->getPromotion2() )             { $business = $business + 3; }
        if( $programMbs->getPromotion3() )             { $business = $business + 3; }
        if( $programMbs->getPromotion5() )             { $business = $business + 3; }
        if( $programMbs->getPromotion8() )             { $business = $business + 3; }
        if( $programMbs->getPromotion9() )             { $business = $business + 3; }
        if( $programMbs->getPromotion10() )             { $business = $business + 4; }

        if( $programMbs->getChecklist()[0] != "" ){ 
            $num = count($programMbs->getChecklist());
            if($num >= 8){
                $checklist = 100;
            }
            else{
                $checklist = $num * 12;
            }             
        }

        $num = 0;
        foreach ($paperwork7['p7_income'] as $value) {
            if($value != ""){
                $num++;
            }
        }
        if( $paperwork7['p7_income'][0] != "" || $num > 1){ 
            
            if($num >= 4){
                $business_budget = $business_budget + 15;
            }
            else{
                $business_budget = $business_budget + ($num * 4);
            }             
        }

        $num = 0;
        foreach ($paperwork8['p8_expenses'] as $value) {
            if($value != ""){
                $num++;
            }
        }
        if( $paperwork8['p8_expenses'][0] != "" || $num > 1){ 
            
            if($num >= 4){
                $business_budget = $business_budget + 15;
            }
            else{
                $business_budget = $business_budget + ($num * 4);
            }             
        }

        $num = 0;
        foreach ($paperwork8['p8_earnings_loses'] as $value) {
            if($value != ""){
                $num++;
            }
        }
        if( $paperwork8['p8_earnings_loses'][0] != "" || $num > 1){ 
            
            if($num >= 4){
                $business_budget = $business_budget + 15;
            }
            else{
                $business_budget = $business_budget + ($num * 4);
            }             
        }

        $num = 0;
        foreach ($paperwork8['p8_opening_balance'] as $value) {
            if($value != ""){
                $num++;
            }
        }
        if( $paperwork8['p8_opening_balance'][0] != "" || $num > 1){ 
            
            if($num >= 4){
                $business_budget = $business_budget + 15;
            }
            else{
                $business_budget = $business_budget + ($num * 4);
            }             
        }

        $num = 0;
        foreach ($paperwork8['p8_profit_loss_balance'] as $value) {
            if($value != ""){
                $num++;
            }
        }
        if( $paperwork8['p8_profit_loss_balance'][0] != "" || $num > 1){ 
            
            if($num >= 4){
                $business_budget = $business_budget + 15;
            }
            else{
                $business_budget = $business_budget + ($num * 4);
            }             
        }

        $num = 0;
        foreach ($paperwork8['p8_ending_balance'] as $value) {
            if($value != ""){
                $num++;
            }
        }
        if( $paperwork8['p8_ending_balance'][0] != "" || $num > 1){ 
            
            if($num >= 4){
                $business_budget = $business_budget + 25;
            }
            else{
                $business_budget = $business_budget + ($num * 4);
            }             
        }

        if( $paperwork4['p4_balance']  != "" )              { $income_expense = $income_expense + 50; }
        if( $paperwork4['p4_initial_capital']  != "" )      { $income_expense = $income_expense + 50; }
        
        if( $paperwork5['p5_income']    != "" )              { $income_statement = $income_statement + 33; }
        if( $paperwork6['p6_expenses']  != "" )              { $income_statement = $income_statement + 33; }
        if( $paperwork6['p6_earnings_loses']  != "" )        { $income_statement = $income_statement + 34; }

        if( $paperwork10['p10_total_expenses_plan']  != "" )        { $money_management = $money_management + 20; }
        if( $paperwork10['p10_total_expenses_actual']  != "" )      { $money_management = $money_management + 20; }
        if( $paperwork10['p10_total_income_plan']  != "" )          { $money_management = $money_management + 20; }
        if( $paperwork10['p10_total_income_actual']  != "" )        { $money_management = $money_management + 20; }
        if( $programMbs->getPaperwork17() )                         { $money_management = $money_management + 10; }
        if( $programMbs->getPaperwork18() )                         { $money_management = $money_management + 10; }

        if( ! is_null( $evaluation->getPostquestion1() ) && $evaluation->getPostquestion1() != "undefined")      { $post_evaluation = $post_evaluation + 10; }
        if( ! is_null( $evaluation->getPostquestion2() ) && $evaluation->getPostQuestion2() != "undefined")      { $post_evaluation = $post_evaluation + 10; }
        if( ! is_null( $evaluation->getPostquestion3() ) && $evaluation->getPostQuestion3() != "undefined")      { $post_evaluation = $post_evaluation + 10; }
        if( ! is_null( $evaluation->getPostquestion4() ) && $evaluation->getPostQuestion4() != "undefined")      { $post_evaluation = $post_evaluation + 10; }
        if( ! is_null( $evaluation->getPostquestion5() ) && $evaluation->getPostQuestion5() != "undefined")      { $post_evaluation = $post_evaluation + 10; }
        if( ! is_null( $evaluation->getPostquestion6() ) && $evaluation->getPostQuestion6() != "undefined")      { $post_evaluation = $post_evaluation + 10; }
        if( ! is_null( $evaluation->getPostquestion7() ) && $evaluation->getPostQuestion7() != "undefined")      { $post_evaluation = $post_evaluation + 10; }
        if( ! is_null( $evaluation->getPostquestion8() ) && $evaluation->getPostQuestion8() != "undefined")      { $post_evaluation = $post_evaluation + 10; }
        if( ! is_null( $evaluation->getPostquestion9() ) && $evaluation->getPostQuestion9() != "undefined")      { $post_evaluation = $post_evaluation + 20; }



        if( $programMbs->getQualityP1() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP2() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP3() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP4() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP5() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP6() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP7() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP8() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG1() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG2() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG3() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG4() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG5() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG6() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG7() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG8() )            { $quality_life = $quality_life + 10; }

        if( $programMbs->getService1() )             { $service = $service + 20; }
        if( $programMbs->getService2() )             { $service = $service + 20; }
        if( $programMbs->getService4() )             { $service = $service + 20; }
        if( $programMbs->getService5() )             { $service = $service + 20; }
        if( $programMbs->getService6() )             { $service = $service + 20; }

        $total =  $business + $business_budget + $income_expense + $income_statement + $quality_life + $success_story + $service + $checklist + $post_evaluation + $money_management;
        
        $requirements = [
            'business' => $business,
            'business_budget' => $business_budget,
            'income_expense' => $income_expense,
            'income_statement' => $income_statement,
            'quality_life' => $quality_life,
            'success_story' => $success_story,
            'service' => $service,
            'checklist' => $checklist,
            'post_evaluation' => $post_evaluation,
            'money_management' => $money_management
        ];

        $corrections = [
            'business' => $programMbs->getRevisionbusiness(),
            'business_budget' => $programMbs->getRevisionbusinessbudget(),
            'income_expense' => $programMbs->getRevisionincomeexpenselog(),
            'income_statement' => $programMbs->getRevisionincomestatement(),
            'quality_life' => $programMbs->getRevisionqualitylife(),
            'success_story' => $programMbs->getRevisionsuccessstory(),
            'service' => $programMbs->getRevisionservice(),
            'checklist' => $programMbs->getRevisionchecklist(),
            'money_management' => $programMbs->getRevisionmoneymanagement()
        ];

        $totals =[
           'name' => $programMbs->getStudent()->getFirstName()." ".$programMbs->getStudent()->getLastName(),
           'requirements' => $requirements,
           'corrections'  => $corrections,
           'total_progress' => $total / 10,
           'state' => $programMbs->getState(),
           'version' => $programMbs->getVersion()
        ];      
        
        return $totals;

    }




   

     /**
     * @Rest\Put("/approvedlist", name="approved_programmbs_list")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Project mbs approval was successful"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Project mbs was not successfully approved"
     * )
     * 
     * @SWG\Parameter(
     *     name="list",
     *     in="body",
     *     type="string",
     *     description="The array id programmbs",
     *     schema={}
     * )
     * @SWG\Tag(name="Programmbs")
     */

    public function approvedListAction(Request $request)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programMb = [];
        $message = ""; 

        try {
            $code = 200;
            $error = false;
            $list = explode(',', $request->request->get('list')); 

            foreach ($list as $key) {

                $programMb = $em->getRepository('App:ProgramMbs')->findOneBy(array('student' => $key));
                $student = $em->getRepository('App:User')->find($key);

                $admin = $request->request->get('admin');
                $admin = $em->getRepository('App:User')->find($admin);

                if (!is_null($student) && !is_null($admin)) {

                    if (!is_null($programMb) ) {
                        $em = $this->getDoctrine()->getManager();

                        if($programMb->getState() != "state.approved"){

                            $programMb->setState('state.approved');
                            $programMb->setAdmin($admin);
                            $programMb->setApprovalDate(new \DateTime('now', (new \DateTimeZone('America/New_York'))));
                            if(!$programMb->getCode()){
                                if($programMb->getStudent()->getStudentGroup()->getGroup()->getProgram() == "option.program4"){
                                    $programMb->setCode($programMb->getStudent()->getCountry()."-".$this->getNumberCodeJr($programMb, $request));
                                } 
                                else{
                                    $programMb->setCode($programMb->getStudent()->getCountry()."-".$this->getNumberCode($programMb, $request));
                                }                   
                            }
            
                            $em->persist($programMb);
                            $em->flush();

                            $student->setRoles(["ROLE_STUDENT_EMBASSADOR"]);
                            $em->persist($student);
                            $em->flush();

                        }
                        
        
                    } else {
                        
                        $programmbs=new Programmbs();
                        $programmbs->setStudent($student);
                        $programmbs->setAdmin($admin);
                        $programmbs->setModality("option.modality1");
                        $programmbs->setApprovalDate(new \DateTime('now', (new \DateTimeZone('America/New_York')))); 

                        if(!$programmbs->getCode()){
                            if($programmbs->getStudent()->getStudentGroup()->getGroup()->getProgram() == "option.program4"){
                                $programmbs->setCode($programmbs->getStudent()->getCountry()."-".$this->getNumberCodeJr($programmbs, $request));
                            } 
                            else{
                                $programmbs->setCode($programmbs->getStudent()->getCountry()."-".$this->getNumberCode($programmbs, $request));
                            }                   
                        }
        
                        $programmbs->setState("state.approved");
                        
                        $programmbs->setPromotion7("state.not_joined_facebook");
                        $programmbs->setProductWeb("option.clothing");

                        $programmbs->setProcess1([" "]);
                        $programmbs->setPaperwork2("option1");
                        $programmbs->setPaperwork3(["option1"]);
                        $programmbs->setPaperwork4( json_encode ( ["p4_initial_capital"=>"","p4_expenses"=>"","p4_income"=>"","p4_balance"=>"","p4_array"=>["","","","","","","","","",""] ] ) );
                        $programmbs->setPaperwork5( json_encode ( ["p5_income"=>"","p5_array"=>["","","",""] ]) );
                        $programmbs->setPaperwork6( json_encode ( ["p6_expenses"=>"","p6_earnings_loses"=>"","p6_balance"=>"","p6_array"=>["","","",""]]) );
                        $programmbs->setPaperwork7( json_encode ( ["p7_initial_capital"=>["","","","","","","","",""],"p7_title"=>["","","","","","","","",""],"p7_income"=>["","","","","","","","",""],"p7_array"=>["","","","","","","","","",""]]));
                        $programmbs->setPaperwork8( json_encode (["p8_balance"=>["","","","","","","","",""],"p8_expenses"=>["","","","","","","","",""],"p8_earnings_loses"=>["","","","","","","","",""],"p8_array"=>["","","","","","","","","",""]]));
                        $programmbs->setQualityQ1("274,119");
                        $programmbs->setQualityQ2("303,132");
                        $programmbs->setQualityQ3("314,159");
                        $programmbs->setQualityQ4("303,188");
                        $programmbs->setQualityQ5("274,199");
                        $programmbs->setQualityQ6("248,187");
                        $programmbs->setQualityQ7("234,159");
                        $programmbs->setQualityQ8("247,132");
                       
                        $em->persist($programmbs);
                        $em->flush();

                        $student->setRoles(["ROLE_STUDENT_EMBASSADOR"]);
                        $em->persist($student);
                        $em->flush();
                    }

                }
            }
            
 
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $list : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\GET("/approvedproject", name="approved_project", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets approved projects."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all approved Projects."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Programmbs")
     */
    public function approvedProjectAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $projects = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;

            $current_date = new \DateTime();
            $current_date_2 = new \DateTime();
            $init_date = $current_date->modify( '-7 day' )->format('Y-m-d');
            $finish_date = $current_date_2->format('Y-m-d');
 
            $projects = $em->getRepository("App:ProgramMbs")->graduatesbyDateDesc($init_date, $finish_date);
 
            if (is_null($projects)) {
                $projects = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Users - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $projects : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('project_list'))));
        
    }

    public function sendMessageList($student){

        $em = $this->getDoctrine()->getManager();

        $admins = $em->getRepository("App:User")->getAdminsMessage($student->getLanguage(), "participant");
        $languageadmins = $em->getRepository("App:User")->getAdminsLanguageMessage($student->getLanguage(), "participant");
        $ambassador = $student->getStudentGroup()->getGroup()->getEmbassador();
        $message_list = [];

        foreach ($admins as $admin) {
            $message = $this->getParameter("message.new_mbs_project_".$admin->getLanguage())." ".$student->getFirstName()." ".$student->getLastName()." / ".$student->getStudentGroup()->getGroup()->getName()." ".$this->getParameter("message.pending_review_".$admin->getLanguage());
            $this->sendEmail($admin, "subject.new_mbs_project", $message );
            $message_list[] = [
                "email"       => $admin->getUsername(),
                "subject"     => $this->getParameter("subject.new_mbs_project_".$admin->getLanguage()),
                "body_email"  => $message
            ];
        }

        foreach ($languageadmins as $admin) {
            $message = $this->getParameter("message.new_mbs_project_".$admin->getLanguage())." ".$student->getFirstName()." ".$student->getLastName()." / ".$student->getStudentGroup()->getGroup()->getName()." ".$this->getParameter("message.pending_review_".$admin->getLanguage());
            $this->sendEmail($admin, "subject.new_mbs_project", $message );
            $message_list[] = [
                "email"       => $admin->getUsername(),
                "subject"     => $this->getParameter("subject.new_mbs_project_".$admin->getLanguage()),
                "body_email"  => $message
            ];
        }

        $message = $this->getParameter("message.new_mbs_project_".$ambassador->getLanguage())." ".$student->getFirstName()." ".$student->getLastName()." / ".$student->getStudentGroup()->getGroup()->getName()." ".$this->getParameter("message.pending_review_".$ambassador->getLanguage());
        $this->sendEmail($admin, "subject.new_mbs_project", $message );

        $message_list[] = [
            "email"       => $admin->getUsername(),
            "subject"     => $this->getParameter("subject.new_mbs_project_".$admin->getLanguage()),
            "body_email"  => $message
        ];


        return $message_list;

    }

    public function sendMessageApproved($student){

        $em = $this->getDoctrine()->getManager();
        $message_list = [];

        $admins = $em->getRepository("App:User")->getAdminsMessage($student->getLanguage(), "participant");
        $languageadmins = $em->getRepository("App:User")->getAdminsLanguageMessage($student->getLanguage(), "participant");
        $ambassador = $student->getStudentGroup()->getGroup()->getEmbassador();

        foreach ($admins as $admin) {
            $message = $this->getParameter("message.mbs_approved_".$admin->getLanguage())." ".$student->getFirstName()." ".$student->getLastName()." / ".$student->getStudentGroup()->getGroup()->getName()." / ".$student->getProgrammbs()->getCode();
            $this->sendEmail($admin, "subject.mbs_approved", $message );
            $message_list[] = [
                "email"       => $admin->getUsername(),
                "subject"     => $this->getParameter("message.mbs_approved_".$admin->getLanguage()),
                "body_email"  => $message
            ];
        }
 
        foreach ($languageadmins as $admin) {
            $message = $this->getParameter("message.mbs_approved_".$admin->getLanguage())." ".$student->getFirstName()." ".$student->getLastName()." / ".$student->getStudentGroup()->getGroup()->getName()." / ".$student->getProgrammbs()->getCode();
            $this->sendEmail($admin, "subject.mbs_approved", $message );
            $message_list[] = [
                "email"       => $admin->getUsername(),
                "subject"     => $this->getParameter("message.mbs_approved_".$admin->getLanguage()),
                "body_email"  => $message
            ];
        }

        $message = $this->getParameter("message.mbs_approved_".$ambassador->getLanguage())." ".$student->getFirstName()." ".$student->getLastName()." / ".$student->getStudentGroup()->getGroup()->getName()." / ".$student->getProgrammbs()->getCode();
        $this->sendEmail($admin, "subject.mbs_approved", $message );
        $message_list[] = [
            "email"       => $admin->getUsername(),
            "subject"     => $this->getParameter("message.mbs_approved_".$admin->getLanguage()),
            "body_email"  => $message
        ];


        return $message_list;

    }

    public function sendCorrectionsMessage($student){

        $em = $this->getDoctrine()->getManager();
        $message_list = [];

        $ambassador = $student->getStudentGroup()->getGroup()->getEmbassador();

        $corrections = $this->getParameter("message.plan_".$student->getLanguage()).": ".$student->getProgramMbs()->getRevisionPlan()."<br/>"        
        .$this->getParameter("message.product_".$student->getLanguage()).": ".$student->getProgramMbs()->getRevisionProduct()."<br/>"
        .$this->getParameter("message.process_".$student->getLanguage()).": ".$student->getProgramMbs()->getRevisionProcess()."<br/>"
        .$this->getParameter("message.price_".$student->getLanguage()).": ".$student->getProgramMbs()->getRevisionPrice()."<br/>"
        .$this->getParameter("message.promotion_".$student->getLanguage()).": ".$student->getProgramMbs()->getRevisionPromotion()."<br/>"
        .$this->getParameter("message.paperwork_".$student->getLanguage()).": ".$student->getProgramMbs()->getRevisionPaperwork()."<br/>";

        
        $message = $this->getParameter("message.new_mbs_project_".$student->getLanguage())." ".$student->getFirstName()." ".$student->getLastName()." / ".$student->getStudentGroup()->getGroup()->getName()." ".$this->getParameter("message.pending_corrections_".$student->getLanguage()).
                   ": ".$corrections;
        $this->sendEmail($ambassador, "subject.mbs_correction", $message );
        $message_list[] = [
            "email"       => $ambassador->getUsername(),
            "subject"     => $this->getParameter("subject.mbs_correction_".$ambassador->getLanguage()),
            "body_email"  => $message
        ];
        
        $this->sendEmail($student, "subject.mbs_correction", $message );
        $message_list[] = [
            "email"       => $student->getUsername(),
            "subject"     => $this->getParameter("subject.mbs_correction_".$student->getLanguage()),
            "body_email"  => $message
        ];


        return $message_list;

    }
    
    public function sendEmail($user, $subject, $message){

        if (filter_var($user->getUsername(), FILTER_VALIDATE_EMAIL)) {
            $subject = $this->getParameter($subject."_".$user->getLanguage());
            $subjectEmail = $subject;
            $bodyEmail = $message;

            $message = (new \Swift_Message($subjectEmail))
            ->setFrom('MyPlatform@interweavesolutions.co')
            ->setTo($user->getUsername())
            ->setBody($bodyEmail);

            $this->get('mailer')->send($message);
        }

    }

   
 
}