<?php
/**
 * ProgramsaController.php
 *
 */
 
namespace App\Controller;
 
use App\Entity\ProgramSa;
use App\Entity\Task;
use App\Entity\PilotGroup;
use App\Entity\Certificate;
use App\Form\ProgramSaUpdateRevisionType;
use App\Form\ProgramSaType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Nelmio\ProgramsaDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class ProgramsaController
 *
 * @Route("/programsa")
 */
class ProgramsaController extends FOSRestController
{
    
 
    /**
     * @Rest\Get("/", name="programsa_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all programsa."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all programsa programsa."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="Programsa ID"
     * )
     *
     *
     * @SWG\Tag(name="Programsa")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programsa = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            //$programsaId = $this->getProgramSa()->getId();
            $programsa = $em->getRepository("App:ProgramSa")->findBy(array(), array(), 20);
 
            if (is_null($programsa)) {
                $programsa = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Programsas - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programsa : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/new", name="programsa_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Programsa was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Programsa was not successfully registered"
     * )
     *     
     *
     * @SWG\Tag(name="Programsa")
     */ 
    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programsa = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $programsa = $em->getRepository('App:ProgramSa')->findOneBy(array('student' => $request->request->get('id_student')));
 
            if (!is_null($programsa)) {
                $form = $this->createForm(ProgramSaType::class, $programsa);
                $form->submit($request->request->all());
                
                $generateGroups3 = explode(',', $request->request->get('generateGroups3'));
                $programsa->setGenerateGroups3($generateGroups3);  

                if($programsa->getState() != "state.revision"){
                    $programsa->setState("state.development");
                }               
                
 
                $em->persist($programsa);
                $em->flush();
 
            } else {
                $student = $em->getRepository('App:User')->find($request->request->get('id_student'));
                $programsa=new Programsa();
                $form = $this->createForm(ProgramSaType::class, $programsa);
                $form->submit($request->request->all());
                
                $programsa->setProcess1([""]);

                $programsa->setStudent($student);

                $programsa->setPaperwork3([""]);
              
                $generateGroups3 = explode(',', $request->request->get('generateGroups3'));
                $programsa->setGenerateGroups3($generateGroups3);  
              
                $programsa->setState("state.development");
                
 
                $em->persist($programsa);
                $em->flush();
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the programsa - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programsa : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/show/{id}.{_format}", name="programsa_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets programsa info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The programsa with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Programsa ID"
     * )
     *
     * @SWG\Tag(name="Programsa")
     */
    public function showAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programsa = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $programsa_id = $id;
            $programsa = $em->getRepository("App:ProgramSa")->find($programsa_id);
 
            if (is_null($programsa)) {
                $code = 500;
                $error = true;
                $message = "The Programsa does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Programsa- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programsa : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/show/requirement/{id}.{_format}", name="programsa_requirement_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets programsa info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The programsa with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Student ID"
     * )
     *
     * @SWG\Tag(name="Programsa")
     */
    public function showRequirementAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programsa = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $student_id = $id;
            $programsa = $em->getRepository("App:ProgramSa")->findOneBy(array('student' => $student_id ));
 
            if (is_null($programsa)) {
                $code = 500;
                $error = true;
                $message = "The Programsa does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Programsa- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programsa : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="programsa_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The programsa was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the programsa."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The programsa ID"
     * )
     *
     *
     *
     * @SWG\Tag(name="Programsa")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programsa = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $programsa = $em->getRepository('App:ProgramSa')->find($id);
 
            if (!is_null($programsa)) {
                $form = $this->createForm(ProgramSaType::class, $programsa);
                $form->submit($request->request->all());
                
             
                $generateGroups3 = explode(',', $request->request->get('generateGroups3'));
                $programsa->setGenerateGroups3($generateGroups3);  
               
                $em->persist($programsa);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Programsa - Error: You must to provide fields programsa or the programsa id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the programsa - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programsa : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Put("/revision", name="revision_programsa")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Project mbs approval was successful"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Project mbs was not successfully revision"
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="body",
     *     type="string",
     *     description="The id programsa",
     *     schema={}
     * )
     * @SWG\Tag(name="Programsa")
     */

    public function revisionAction(Request $request)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programSa = [];
        $message = ""; 

        try {
            $code = 200;
            $error = false;
            $id = $request->request->get('id');
            $programSa = $em->getRepository('App:ProgramSa')->find($id);
 
            if (!is_null($programSa)) {
                $em = $this->getDoctrine()->getManager();

                
                $programSa->setState('state.revision');
                $em->persist($programSa);
                $em->flush();
                
                //$this->sendEmail("subject.approved_project", $programSa->getStudent());
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Programsa - Error: You must to provide fields programsa or the programsa id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the programsa - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programSa : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="programsa_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Programsa was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the programsa"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The programsa ID"
     * )
     *
     * @SWG\Tag(name="Programsa")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $programsa = $em->getRepository("App:ProgramSa")->find($id);
 
            if (!is_null($programsa)) {
                $em->remove($programsa);
                $em->flush();
 
                $message = "The programsa was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent programsa - Error: The programsa id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current programsa - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/newfile", name="programsa_new_file")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Programsa was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Programsa was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="id_student",
     *     in="body",
     *     type="string",
     *     description="The id student",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="file_name",
     *     in="body",
     *     type="string",
     *     description="The name of file",
     *     schema={}
     * )
     *     
     *
     * @SWG\Tag(name="Programsa")
     */ 
    public function newFileAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";        
        $id = $request->request->get('id_student');
        $filename = $request->request->get('file_name');
 
        try {
            $code = 200;
            $error = false;
           
            $student = $em->getRepository("App:User")->find($id);
            $programsa = $em->getRepository("App:Programsa")->findOneBy(array('student' => $id));

            if(is_null($programsa)){
                $programsa=new Programsa();
            }            
 
            if (is_null($student)) {
                $code = 500;
                $error = true;
                $message = "The Student does not exist";
            }
            else{
                $programsa->setFilestudent($filename);
                $programsa->setStudent($student);
                $programsa->setModality("option.modality1");
                $programsa->setUploadDateStudent(new \DateTime('now', (new \DateTimeZone('America/New_York') ) ) ); 

                $programsa->setState("state.revision");
                
                $programsa->setProcess1([""]);
                $programsa->setPaperwork3([""]);
                $programsa->setPaperwork4([""]);
                $programsa->setPaperwork5([""]);
                $programsa->setPaperwork6([""]);
                $programsa->setPaperwork7([""]);
                $programsa->setPaperwork8([""]);
                $em->persist($programsa);
                $em->flush();

                //$this->sendMessageList($programsa->getStudent());

            }            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the programsa - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programsa : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }


    

    /**
     * @Rest\Put("/update_revision/{id}", name="update_revision_programsa")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Revision was successfully update"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Revision was not successfully update"
     * )
     *
     * @SWG\Parameter(
     *     name="misionrevision",
     *     in="body",
     *     type="string",
     *     description="The mision description",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="generategroupstrevision",
     *     in="body",
     *     type="string",
     *     description="The generategroups description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="rulerevision",
     *     in="body",
     *     type="string",
     *     description="The rule description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="graduaterevision",
     *     in="body",
     *     type="string",
     *     description="The graduate description",
     *     schema={}
     * )
     *      
     * @SWG\Tag(name="Programsa")
     */

    public function updateRevisionAction(Request $request, $id)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programsa = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $programsa = $em->getRepository('App:ProgramSa')->find($id);
 
            if (!is_null($programsa)) {
                $form = $this->createForm(ProgramSaUpdateRevisionType::class, $programsa);
                $form->submit($request->request->all());
 
                $em->persist($programsa);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Programsa - Error: You must to provide fields programsa or the programsa id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the programsa - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programsa : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }


    /**
     * @Rest\Put("/approved", name="approved_programsa")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Project mbs approval was successful"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Project mbs was not successfully approved"
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="body",
     *     type="string",
     *     description="The id programsa",
     *     schema={}
     * )
     * @SWG\Tag(name="Programsa")
     */

    public function approvedAction(Request $request)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programSa = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $id = $request->request->get('id');
            $programSa = $em->getRepository('App:ProgramSa')->find($id);
            $user = $em->getRepository('App:User')->find($programSa->getStudent()->getId());

            $admin_id = $request->request->get('admin');
            $admin = $em->getRepository('App:User')->find($admin_id);
 
            if (!is_null($programSa) && !is_null($admin)) {
                $em = $this->getDoctrine()->getManager();

               
                $programSa->setState('state.approved');
                $programSa->setAdmin($admin);
                $user->setRoles(["ROLE_EMBASSADOR"]);
                $programSa->setApprovalDate(new \DateTime('now', (new \DateTimeZone('America/New_York'))));
                if(!$programSa->getCode()){
                    $programSa->setCode($programSa->getStudent()->getCountry()."-".$this->getNumberCode($programSa, $request));
                    $user->setCode($programSa->getCode());
                }

                $em->persist($programSa);
                $em->flush();

                $em->persist($user);
                $em->flush();
                
                //$this->sendEmail("subject.approved_project", $programSa->getStudent());
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Programsa - Error: You must to provide fields programsa or the programsa id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the programsa - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programSa : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Put("/approvedlist", name="approved_programsa_list")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Project mbs approval was successful"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Project mbs was not successfully approved"
     * )
     * 
     * @SWG\Parameter(
     *     name="list",
     *     in="body",
     *     type="string",
     *     description="The array id programsa",
     *     schema={}
     * )
     * @SWG\Tag(name="Programsa")
     */

    public function approvedListAction(Request $request)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programSa = [];
        $message = ""; 

        try {
            $code = 200;
            $error = false;
            $list = explode(',', $request->request->get('list'));
            $admin_id = $request->request->get('admin');
            $admin = $em->getRepository('App:User')->find($admin_id);

            foreach ($list as $key) {

                $programSa = $em->getRepository('App:ProgramSa')->findOneBy(array('student' => $key));
                $student = $em->getRepository('App:User')->find($key);

                if (!is_null($student) && !is_null($admin)) {

                    if (!is_null($programSa) ) {
                        $em = $this->getDoctrine()->getManager();
 
                        $programSa->setState('state.approved');
                        $programSa->setAdmin($admin);

                        $student->setRoles(["ROLE_EMBASSADOR"]);
                        $programSa->setApprovalDate(new \DateTime('now', (new \DateTimeZone('America/New_York'))));
                        if(!$programSa->getCode()){
                            $programSa->setCode($programSa->getStudent()->getCountry()."-".$this->getNumberCode($programSa, $request));
                            $student->setCode($programSa->getCode());
                        }

                        $em->persist($programSa);
                        $em->flush();

                        $em->persist($student);
                        $em->flush();

                    } else {
                        
                        $programSa=new Programsa();
                        $programSa->setStudent($student);
                        $em = $this->getDoctrine()->getManager();
 
                        $programSa->setState('state.approved');
                        $programSa->setAdmin($admin);
                        $programSa->setGraduate5([]);
                        $programSa->setGenerateGroups3([""]);
                        $programSa->setProcess1([""]);
                        $programSa->setPaperwork3([""]);
                        
                        $student->setRoles(["ROLE_EMBASSADOR"]);
                        $programSa->setApprovalDate(new \DateTime('now', (new \DateTimeZone('America/New_York'))));
                        if(!$programSa->getCode()){
                            $programSa->setCode($programSa->getStudent()->getCountry()."-".$this->getNumberCode($programSa, $request));
                            $student->setCode($programSa->getCode());
                        }

                        $em->persist($programSa);
                        $em->flush();

                        $em->persist($student);
                        $em->flush();
        

                        //$this->sendMessageApproved($programmbs->getStudent());
                    }

                }
            }
            
 
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $list : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/sendrevision", name="sendrevision_programsa")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Project mbs sendrevision was successful"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Project mbs was not successfully sendrevision"
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="body",
     *     type="string",
     *     description="The id programsa",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionmision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="revisiongenerategroups",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionrule",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisiongraduate",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionsupport",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     *      
     * @SWG\Tag(name="Programsa")
     */

    public function sendRevisionAction(Request $request)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programSa = [];
        $message = ""; 

        try {
            $code = 200;
            $error = false;
            $id = $request->request->get('id');
            $programSa = $em->getRepository('App:ProgramSa')->find($id);
 
            if (!is_null($programSa)) {
                $em = $this->getDoctrine()->getManager();

                $form = $this->createForm(ProgramSaUpdateRevisionType::class, $programSa);
                $form->submit($request->request->all());

                $programSa->setState('state.correction');
                //$this->sendEmail("subject.pending_correction", $programSa->getStudent());
            
                $em->persist($programSa);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to send revision Programsa - Error: You must to provide fields programsa or the programsa id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying send revision of programsa - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programSa : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\GET("/approvedproject", name="approved_sa_project", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets approved projects."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all approved Projects."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Programsa")
     */
    public function approvedProjectAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $projects = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;

            $current_date = new \DateTime();
            $current_date_2 = new \DateTime();
            $init_date = $current_date->modify( '-1 month' )->format('Y-m-d');
            $finish_date = $current_date_2->format('Y-m-d');
 
            $projects = $em->getRepository("App:ProgramSa")->graduatesbyDateDesc($init_date, $finish_date);
 
            if (is_null($projects)) {
                $projects = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Users - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $projects : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('project_list'))));
        
    }

     /**
     * @Rest\Post("/newpilotgroups", name="pilot_new_groups")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Pilot was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Pilot was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="id_pilot_ambassador",
     *     in="body",
     *     type="string",
     *     description="Id Pilot Ambassador",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="groups",
     *     in="body",
     *     type="string",
     *     description="The array Id Groups",
     *     schema={}
     * )
     * 
     
     *       
     *    
     * @SWG\Tag(name="Programsa")
     */ 

    public function newPilotGroupsAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";
        $id_pilot_ambassador = $request->request->get('id_pilot_ambassador');
        $groups = explode(',', $request->request->get('groups'));

        
        try {
            $code = 200;
            $error = false;

            $ambassador = $em->getRepository("App:User")->find($id_pilot_ambassador);
 
            if (is_null($ambassador)) {
                $code = 500;
                $error = true;
                $message = "The Ambassador does not exist";
            }
            else{
                $em->getRepository("App:PilotGroup")->deletePilotGroups($id_pilot_ambassador);
            
                foreach ($groups as $group) {
                    $pilot=new PilotGroup();
                    $id_group =  explode("-", $group);

                    $grp = $em->getRepository("App:Groupe")->find($id_group[1]);

                    $pilot->setGroup($grp);
                    $pilot->setAmbassador($ambassador);
                    $em->persist($pilot);
                    $em->flush();

                }

            }

            
            
  
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Pilot Group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $pilot : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/showgroup/{id}.{_format}", name="pilot_show_group", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets pilot Groups ambassador info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The pilot Group ambassador with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Pilot Ambassador ID"
     * )
     *
     * @SWG\Tag(name="Programsa")
     */
    public function showGroupAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $groups = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $pilot_ambassador_id = $id;
            $pilotgroups = $em->getRepository("App:PilotGroup")->findBy(array("ambassador" => $pilot_ambassador_id));
            foreach ($pilotgroups as $ga) {
                $groups[]= $ga->getGroup();
            }
            $graduates = $em->getRepository('App:StudentGroup')->studentsMbsStateByAmbassador($id, "state.approved");
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Pilot Ambassador- Error: {$ex->getMessage()}";
        }

        $list = [
            'groups' => $groups,
            'pilotgroups' => $pilotgroups,
            'graduates' => $graduates
        ];
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $list : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('group_list'))));
    }

    /**
     * @Rest\Get("/showpilotgroup/{id}.{_format}", name="pilot_show_pilot_group", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets pilot Groups ambassador info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The pilot Group ambassador with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Programsa ID"
     * )
     *
     * @SWG\Tag(name="Programsa")
     */
    public function showPilotGroupAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $groups = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $programsa = $em->getRepository("App:ProgramSa")->find($id);
            $ambassador_id = $programsa->getStudent()->getId();
            $pilotgroups = $em->getRepository("App:PilotGroup")->findBy(array("ambassador" => $ambassador_id));
            foreach ($pilotgroups as $ga) {
                $groups[]= $ga->getGroup();
            }
            $graduates = $em->getRepository('App:StudentGroup')->studentsMbsStateByAmbassador($ambassador_id, "state.approved");
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Pilot Ambassador- Error: {$ex->getMessage()}";
        }

        $list = [
            'groups' => $groups,
            'pilotgroups' => $pilotgroups,
            'graduates' => $graduates
        ];
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $list : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('group_list'))));
    }

    /**
     * @Rest\Get("/show/progress/{id}.{_format}", name="sa_requirements_show_progress", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets course info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The course with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Student ID"
     * )
     *
     * @SWG\Tag(name="Programsa")
     */
    public function showProgressAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programsa = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $programsa = $em->getRepository("App:ProgramSa")->findOneBy(array('student' => $id));
            
 
            if (is_null($programsa)) {
                $code = 200;
                $error = true;
                $requirements = [
                    'mision' => 0,
                    'generate' => 0,
                    'graduate' => 0,
                    'facilitate' => 0,
                    'support' => 0,
                    'pilot' => 0,
                ];

                $corrections = [
                   
                ];
        
                $progress =[
                   'requirements' => $requirements,
                   'corrections'  => $corrections,
                   'total_progress' => 0,
                   'state'        => "state.not_started"
                ];
            }
            else{
                $progress = $this->requirementSaProgress($programsa);
            }
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Programmbs- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $progress : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Post("/pagination", name="programsa_pagination")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all students."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all students."
     * )
     *
     *
     * @SWG\Parameter(
     *     name="keyword",
     *     in="path",
     *     type="string",
     *     description="The search keyword"
     * )
     * 
     * @SWG\Parameter(
     *     name="page",
     *     in="path",
     *     type="string",
     *     description="The search Page"
     * )
     * 
     * @SWG\Parameter(
     *     name="page_size",
     *     in="path",
     *     type="string",
     *     description="The number of records for page"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_column",
     *     in="path",
     *     type="string",
     *     description="Search order Column"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_direction",
     *     in="path",
     *     type="string",
     *     description="Search order Direction"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description=" Array Language Project"
     * )
     * 
     * @SWG\Parameter(
     *     name="state",
     *     in="path",
     *     type="string",
     *     description="State Project"
     * )
     * 
     * @SWG\Parameter(
     *     name="role",
     *     in="path",
     *     type="string",
     *     description="User Role"
     * )
     *    
     *
     * @SWG\Tag(name="Programsa")
     */
    public function paginationAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $groups = [];
        $message = "";
        $students = [];
 
        try {
            $code = 200;
            $error = false;
            
            $keyword    = $request->request->get('keyword');
            $page   = $request->request->get('page');
            $page_size = $request->request->get('page_size');
            $order_column = $request->request->get('order_column');
            $order_direction = $request->request->get('order_direction');
            $language = $request->request->get("language");
            $state = $request->request->get("state");
            $role = $request->request->get("role");

            $language = explode(",", preg_replace('([^A-Za-z0-9,])', '', $language));

            if($role == "ROLE_ADMIN" ){
                if($state === "state.approved"){
                    $studentsSa = $em->getRepository('App:ProgramSa')->saApprovedPagination($keyword, $page, $page_size, $order_column, $order_direction);
                }
                else{
                    $studentsSa = $em->getRepository('App:ProgramSa')->saByStatePagination($keyword, $page, $page_size, $order_column, $order_direction, $state);
                }
                    
            }
            if($role == "ROLE_LANGUAGE_ADMIN"  || $role == "ROLE_PROJECT_QUALIFIER"){
                if($state === "state.approved"){
                    $studentsSa = $em->getRepository('App:ProgramSa')->saApprovedLanguagePagination($keyword, $page, $page_size, $order_column, $order_direction, $language);
                }
                else{
                    $studentsSa = $em->getRepository('App:ProgramSa')->saByStateLanguagePagination($keyword, $page, $page_size, $order_column, $order_direction, $state, $language);
                }
                    
            }

            foreach ($studentsSa['list'] as $student) {
                $st = $student[0]; 
                $course = $em->getRepository('App:Course')->getCourseByRequirements($st->getStudent(), 'requirement.sa');
                $admin = $st->getAdmin();
                $students[] = [
                    'participant_id'            => $student['participant_id'],
                    'participant_name'          => $student['participant_name'],
                    'country'                   => $student['country'],
                    'programsa_id'              => $student['id'],
                    'updated_at'                => $student['updated_at'],
                    'approval_date'             => $student['approval_date'],
                    'group_program'             => $student['group_program'],
                    'group_name'                => $student['group_name'],
                    'ambassador_name'           => $student['ambassador_name'],
                    'programsa_modality'        => $student['programsa_modality'],
                    'admin_name'                => $admin ?  $admin->getFirstName(). " " .$admin->getLastName() : "",
                    'sa_course'                 => $course ? $course->getId() : "",
                ];
            }

            $data_array = [
                'list'              => $students,
                'items_total'       => $studentsSa['items_total'],
                'pages_total'       => $studentsSa['pages_total']
            ];
           
           
         
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data_array : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('participant_list'))));
    }

    public function requirementSaProgress($programSa){

        $em = $this->getDoctrine()->getManager();

        $mision = 0;
        $generate = 0;
        $graduate = 0;
        $facilitate = 0;
        $graduate = 0;
        $support = 0;  
        $pilot = 0;     

        $groups = $em->getRepository('App:PilotGroup')->findBy(array('ambassador' => $programSa->getStudent()->getId() ));
        $graduates = 0;

        foreach ($groups as $group) {
            $graduates = $graduates + count($em->getRepository('App:StudentGroup')->studentsMbsStateByGroup($group->getGroup()->getId(), "state.approved"));
        }
        

        if(!$programSa->getModality()){
            if( $programSa->getMision1() )              { $mision = $mision + 25; }
            if( $programSa->getMision2() )              { $mision = $mision + 25; }
            if( $programSa->getMision3() )              { $mision = $mision + 25; }
            if( $programSa->getMision4() )              { $mision = $mision + 25; }
            if( $programSa->getgenerateGroups1() )           { $generate = $generate + 20; }
            if( $programSa->getgenerateGroups2() )           { $generate = $generate + 20; }
            if( $programSa->getgenerateGroups3() )           { $generate = $generate + 20; }
            if( $programSa->getgenerateGroups4() )           { $generate = $generate + 20; }
            if( $programSa->getgenerateGroups5() )           { $generate = $generate + 20; }
            if( $programSa->getRule1() )           { $facilitate = $facilitate + 10; }
            if( $programSa->getRule2() )           { $facilitate = $facilitate + 10; }
            if( $programSa->getRule3() )           { $facilitate = $facilitate + 10; }
            if( $programSa->getRule4() )           { $facilitate = $facilitate + 10; }
            if( $programSa->getRule5() )           { $facilitate = $facilitate + 10; }
            if( $programSa->getRule6() )           { $facilitate = $facilitate + 10; }
            if( $programSa->getRule7() )           { $facilitate = $facilitate + 10; }
            if( $programSa->getRule8() )           { $facilitate = $facilitate + 10; }
            if( $programSa->getRule9() )           { $facilitate = $facilitate + 10; }
            if( $programSa->getRule10() )          { $facilitate = $facilitate + 10; }                             
            if( $programSa->getGraduate1() )       { $graduate = $graduate + 25; }
            if( $programSa->getGraduate2() )       { $graduate = $graduate + 25; }
            if( $programSa->getGraduate3() )       { $graduate = $graduate + 25; }
            if( $programSa->getGraduate4() )       { $graduate = $graduate + 25; }                              
            if( $programSa->getSupport1() )        { $support = $support + 25; }
            if( $programSa->getSupport2() )        { $support = $support + 25; }
            if( $programSa->getSupport3() )        { $support = $support + 25; }
            if( $programSa->getSupport4() )        { $support = $support + 25; }
            if( $graduates != 0 )                  { $pilot = 100; }


            
            $total = $mision + $generate + $facilitate + $graduate + $support + $pilot;
            

            $requirements     = array(
                'mision'        => $mision,
                'generate'      => $generate,
                'facilitate'    => $facilitate,   
                'graduate'      => $graduate,                         
                'support'       => $support,
                'pilot'         => $pilot,
            );

           
        }
        else{

            $requirements     = array(
                'mision'        => 100,
                'generate'      => 100,
                'facilitate'    => 100,   
                'graduate'      => 100,                         
                'support'       => 100,
                'pilot'         => 100,
            );

            $total = 600;

        } 
        
        $corrections = [

            'mision'        => $programSa->getRevisionmision(),
            'generate'      => $programSa->getRevisiongenerategroups(),
            'facilitate'    => $programSa->getRevisionrule(),   
            'graduate'      => $programSa->getRevisiongraduate(),                          
            'support'       => $programSa->getRevisionsupport(),

        ];

        $totals =[
            'requirements' => $requirements,
            'corrections'  => $corrections,
            'total_progress' => $total / 6,
            'state' => $programSa->getState()
        ];      
        
        return $totals;

       

    }

    public function getNumberCode(ProgramSa $programSa){

        $em = $this->getDoctrine()->getManager();
        $number = $em->getRepository('App:Certificate')->findOneBy(array('country' => $programSa->getStudent()->getCountry(), 'program' => 'SA'));
        if($number){
          $number->setNumber($number->getNumber() + 1);
          $em->persist($number);
          $em->flush();
        }
        else{
          $number = new Certificate();
          $number->setCountry($programSa->getStudent()->getCountry());
          $number->setProgram("SA");
          $number->setNumber(1);
          $number->setInitial(0);
          $number->setLanguage("en");
          $em->persist($number);
          $em->flush();
        }
  
        return $number->getNumber();
    }

    public function sendEmail($subject, $student){

        $em = $this->getDoctrine()->getManager();
        $admins = $em->getRepository('App:User')->userByRole("ROLE_ADMIN");
  
        if( $subject == "subject.pending_revision"){
  
           foreach ($admins as $admin ) {
               if($admin->getLanguage() == "en"){
                     $subjectEmail = $this->get('translator')->trans($subject, [] , null, "en");
                     $bodyEmail = $this->get('translator')->trans('message.pending_revision', [] , null, "en")." ".$student->getFirstName()." ".$student->getLastName();
  
                     $message = (new \Swift_Message($subjectEmail))
                      ->setFrom('myplatform@interweavesolutions.com')
                      ->setTo($admin->getUsername())
                      ->setBody($bodyEmail);
  
                      //$mailer->send($message);
                      $this->get('mailer')->send($message);
                }
                elseif($admin->getLanguage() == $student->getLanguage()){
                    $subjectEmail = $this->get('translator')->trans($subject, [] , null, $student->getLanguage());
                    $bodyEmail = $this->get('translator')->trans('message.pending_revision', [] , null, $student->getLanguage())." ".$student->getFirstName()." ".$student->getLastName();
  
                    $message = (new \Swift_Message($subjectEmail))
                     ->setFrom('myplatform@interweavesolutions.com')
                     ->setTo($admin->getUsername())
                     ->setBody($bodyEmail);
  
                     //$mailer->send($message);
                     $this->get('mailer')->send($message);
                }
           }
        }
  
        if($subject == "subject.approved_project") {
          $em = $this->getDoctrine()->getManager();
          $studentGroup = $student->getStudentgroup();
  
          // Send Notification to Ambbasador
          $subjectEmail = $this->get('translator')->trans($subject, [] , null, $studentGroup->getGroup()->getEmbassador()->getLanguage());
          $bodyEmail = $this->get('translator')->trans('message.approved_project', [] , null, $studentGroup->getGroup()->getEmbassador()->getLanguage())." ".$student->getFirstName()." ".$student->getLastName()." ".$student->getProgramSa()->getCode();
  
          $message = (new \Swift_Message($subjectEmail))
           ->setFrom('myplatform@interweavesolutions.com')
           ->setTo($studentGroup->getGroup()->getEmbassador()->getUsername())
           ->setBody($bodyEmail);
  
           //$mailer->send($message);
           $this->get('mailer')->send($message);
  
           // Sent Notification to Student
           $subjectEmail = $this->get('translator')->trans($subject, [] , null, $student->getLanguage());
           $bodyEmail = $this->get('translator')->trans('message.approved_project', [] , null, $student->getLanguage())." ".$student->getFirstName()." ".$student->getLastName()." ".$student->getProgramSa()->getCode();
  
           $message = (new \Swift_Message($subjectEmail))
            ->setFrom('myplatform@interweavesolutions.com')
            ->setTo($student->getUsername())
            ->setBody($bodyEmail);
  
            //$mailer->send($message);
            $this->get('mailer')->send($message);
  
            // Sent Notification to $admin
            foreach($admins as $admin){
              if($admin->getLanguage() == "en"){
                    $subjectEmail = $this->get('translator')->trans($subject, [] , null, "en");
                    $bodyEmail = $this->get('translator')->trans('message.approved_project_admin', [] , null, "en")." ".$student->getFirstName()." ".$student->getLastName()." whith the follow code ".$student->getProgramSa()->getCode();
  
                    $message = (new \Swift_Message($subjectEmail))
                     ->setFrom('myplatform@interweavesolutions.com')
                     ->setTo($admin->getUsername())
                     ->setBody($bodyEmail);
  
                     //$mailer->send($message);
                     $this->get('mailer')->send($message);
               }
            }
          }
  
          if($subject == "subject.pending_correction") {
            $em = $this->getDoctrine()->getManager();
            $studentGroup = $student->getStudentgroup();
  
            // Send Notification to Ambbasador
            $subjectEmail = $this->get('translator')->trans($subject, [] , null, $studentGroup->getGroup()->getEmbassador()->getLanguage());
            $bodyEmail = $this->get('translator')->trans('message.pending_correction', [] , null, $studentGroup->getGroup()->getEmbassador()->getLanguage())." ".$student->getFirstName()." ".$student->getLastName();
  
            $message = (new \Swift_Message($subjectEmail))
             ->setFrom('myplatform@interweavesolutions.com')
             ->setTo($studentGroup->getGroup()->getEmbassador()->getUsername())
             ->setBody($bodyEmail);
  
             //$mailer->send($message);
             $this->get('mailer')->send($message);
  
             // Sent Notification to Student
             $subjectEmail = $this->get('translator')->trans($subject, [] , null, $student->getLanguage());
             $bodyEmail = $this->get('translator')->trans('message.pending_correction', [] , null, $student->getLanguage())." ".$student->getFirstName()." ".$student->getLastName();
  
             $message = (new \Swift_Message($subjectEmail))
              ->setFrom('myplatform@interweavesolutions.com')
              ->setTo($student->getUsername())
              ->setBody($bodyEmail);
  
              //$mailer->send($message);
              $this->get('mailer')->send($message);
  
  
            }
      }

   
 
}