<?php

 
namespace App\Controller;
 
use App\Entity\Progress;
use App\Form\ProgressType;
use App\Form\ProgressEditType;


use Doctrine\Common\Collections\ArrayCollection;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\UserDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class ProgressController
 *
 * @Route("/progress")
 */
class ProgressController extends FOSRestController
{
    
    /**
     * @Rest\Get("/{id}.{_format}", name="progress_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all progresss."
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="body",
     *     type="integer",
     *     description="The Course Id",
     *     schema={}
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all progresss."
     * )
     *
     * @SWG\Tag(name="Progress")
     */
    public function indexAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $progress_list = [];
        $message = "";
        $program = "";
        $button = "";
 
        try {
            $code = 200;
            $error = false;
 
            $students = $em->getRepository("App:Progress")->studentProgressList($id);
            $course = $em->getRepository("App:Course")->find($id);
            if($course->getRequirements() == "requirement.mbs"){
                $program = "App:Programmbs";
                $button = "button_mbs";
            }
            else if($course->getRequirements() == "requirement.sa"){
                $program = "App:Programsa";
                $button = "button_sa";
            }
            else if($course->getRequirements() == "requirement.wellness"){
                $program = "App:Wellness";
                $button = "button_wellness";
            }
            else if($course->getRequirements() == "requirement.without"){
                $button = "button_without";
            }

            foreach ($students as $st) { 
                $group = "";
                $ambassador = "";
                $requirements = "false";
                $version = "";
                $mbs_id = "";
                $modality = "";
                $st_principles = $em->getRepository("App:Progress")->studentPrinciples($id, $st->getId());
                $total_principles = $em->getRepository("App:Principle")->principlesTotal($id);
                $init_principle = $em->getRepository("App:Progress")->findOneBy(array('course' => $id, 'student' => $st->getId() ));
                $progress =  round(($st_principles * 100) / $total_principles) ;
                if($progress > 100){
                    $progress = 100;
                }
                if($st->getStudentGroup()){
                    $group = $st->getStudentGroup()->getGroup()->getName();
                    $ambassador = $st->getStudentGroup()->getGroup()->getEmbassador()->getFirstName()." ".$st->getStudentGroup()->getGroup()->getEmbassador()->getLastName();
                }
                if($course->getRequirements() == "requirement.without"){
                    $requirements =  "false";
                }
                else if($em->getRepository($program)->findOneBy(array('student' => $st->getId()))){
                    $requirements = "true";
                }
                
                if($st->getProgrammbs()){
                    $version =  $st->getProgrammbs()->getVersion();
                    $mbs_id = $st->getProgrammbs()->getId();
                    $modality = $st->getProgrammbs()->getModality();
                }
                $progress_list[] = [
                    'id'           => $st->getId(),
                    'first_name'   => $st->getFirstName(),
                    'last_name'    => $st->getLastName(),
                    'country'      => $st->getCountry(),
                    'whatsapp'     => $st->getWhatsapp(),
                    'progress'     => $progress,
                    'enrolled'     => $init_principle->getCreatedAt(),
                    'ambassador'   => $ambassador,
                    'group'        => $group,
                    'requirements' => $requirements,
                    'button'       => $button,
                    'mbs_version'  => $version,
                    'mbs_id'       => $mbs_id,
                    'modality'     => $modality
                ];
            }
 
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Progress - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $progress_list : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()->setGroups(array('future_ambassador'))));
    }

    /**
     * @Rest\Post("/studentlist/pagination", name="progress_studentlist_pagination")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all groups."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all groups."
     * )
     *
     * @SWG\Parameter(
     *     name="course_id",
     *     in="path",
     *     type="string",
     *     description="The ID of Course"
     * )
     * 
     *
     * @SWG\Parameter(
     *     name="keyword",
     *     in="path",
     *     type="string",
     *     description="The search keyword"
     * )
     * 
     * @SWG\Parameter(
     *     name="page",
     *     in="path",
     *     type="string",
     *     description="The search Page"
     * )
     * 
     * @SWG\Parameter(
     *     name="page_size",
     *     in="path",
     *     type="string",
     *     description="The number of records for page"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_column",
     *     in="path",
     *     type="string",
     *     description="Search order Column"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_direction",
     *     in="path",
     *     type="string",
     *     description="Search order Direction"
     * )
     *
     * @SWG\Tag(name="Progress")
     */
    public function studentListPaginationAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $students = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
            
            $id         = $request->request->get('course_id');
            $keyword    = $request->request->get('keyword');
            $role       = $request->request->get('role');
            $page       = $request->request->get('page');
            $page_size = $request->request->get('page_size');
            $order_column = $request->request->get('order_column');
            $order_direction = $request->request->get('order_direction');

            

            $course = $em->getRepository("App:Course")->find($id);
            if($course->getRequirements() == "requirement.mbs"){
                $program = "App:Programmbs";
                $button = "button_mbs";
            }
            else if($course->getRequirements() == "requirement.sa"){
                $program = "App:Programsa";
                $button = "button_sa";
            }
            else if($course->getRequirements() == "requirement.wellness"){
                $program = "App:Wellness";
                $button = "button_wellness";
            }
            else if($course->getRequirements() == "requirement.without"){
                $program = "without_requirements";
                $button = "button_without";
            }

            $students = $em->getRepository('App:Progress')->studentProgressListPagination($keyword, $page, $page_size, $order_column, $order_direction, $id, $program);

             

            foreach ($students['list'] as $student) { 
                $st = $student[0];
                $st_principles = $student['progress'];
                $init_principle_date = $student['enrolled'];
                $participant_name = $student['participant_name'];
                $group = "";
                $ambassador = "";
                $requirements = "false";
                $version = "";
                $mbs_id = "";
                $modality = "";
                $status = $student['status'];
                $progress =  $em->getRepository("App:Course")->getCoursePercentajeProgressByCourse($st->getId(), $id);

                if($program == "without_requirements"){
                    $project = false;
                }
                else{
                    $project = $em->getRepository($program)->findOneBy(array('student' => $st->getId()));
                }
                
                
                if($progress > 100){
                    $progress = 100;
                }
                if($st->getStudentGroup()){
                    $group = $st->getStudentGroup()->getGroup()->getName();
                    $ambassador = $st->getStudentGroup()->getGroup()->getEmbassador()->getFirstName()." ".$st->getStudentGroup()->getGroup()->getEmbassador()->getLastName();
                }
                if($course->getRequirements() == "requirement.without"){
                    $requirements =  "false";                    
                }
                else if($project){
                    $requirements = "true";
                    //$status = $project->getState();
                }
                
                if($st->getProgrammbs()){
                    $version =  $st->getProgrammbs()->getVersion();
                    $mbs_id = $st->getProgrammbs()->getId();
                    $modality = $st->getProgrammbs()->getModality();
                }
                $progress_list[] = [
                    'id'                => $st->getId(),
                    'participant_name'  => $participant_name,
                    'firts_name'        => $st->getFirstName(),
                    'last_name'         => $st->getLastName(),
                    'country'           => $st->getCountry(),
                    'whatsapp'          => $st->getWhatsapp(),
                    'progress'          => $progress,
                    'enrolled'          => $init_principle_date,
                    'ambassador'        => $ambassador,
                    'group'             => $group,
                    'requirements'      => $requirements,
                    'button'            => $button,
                    'status'            => $status == "0" ? "state.without_starting" : $status,
                    'mbs_version'       => $version,
                    'mbs_id'            => $mbs_id,
                    'modality'          => $modality
                ];
            }

            $data = [
                'list'              => $progress_list,
                'items_total'       => $students['items_total'],
                'pages_total'       => $students['pages_total']
            ];
           
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()->setGroups(array('future_ambassador'))));
    }

     /**
     * @Rest\Post("/new", name="progress_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Progress was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Progress was not successfully registered"
     * )
     *
     * 
     *
     * @SWG\Parameter(
     *     name="course_id",
     *     in="body",
     *     type="integer",
     *     description="The Course id of the new progress",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="student_id",
     *     in="body",
     *     type="string",
     *     description="The student ID",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="principle_id",
     *     in="body",
     *     type="string",
     *     description="The Principle ID",
     *     schema={}
     * )
     * 
     *  @SWG\Parameter(
     *     name="answer",
     *     in="body",
     *     type="string",
     *     description="The Principle Answer",
     *     schema={}
     * )
     *     
     * 
     * @SWG\Tag(name="Progress")
     */ 

    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $message = "";       
        
        $course_id= $request->request->get("course_id");
        $principle_id= $request->request->get("principle_id");
        $student_id= $request->request->get("student_id");
        $answer= $request->request->get("answer");

        
       

        try {
            $code = 200;
            $error = false;

            $progress = $em->getRepository("App:Progress")->findOneBy( array("course" => $course_id, "principle" => $principle_id, "student" => $student_id));

            if(is_null($progress)){
                $progress=new Progress();
                $course = $em->getRepository("App:Course")->find($course_id);
                $principle = $em->getRepository("App:Principle")->find($principle_id);
                $student = $em->getRepository("App:User")->find($student_id);
    
                $progress->setCourse($course);
                $progress->setPrinciple($principle);
                $progress->setStudent($student);
                $progress->setAnswer($answer);
    
                $em->persist($progress);
                $em->flush();
            }
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Progress - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $progress : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }


    /**
     * @Rest\Put("/edit/{id}.{_format}", name="Progress_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The Progress was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the Progress."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Progress ID"
     * )
     * 
     *  @SWG\Parameter(
     *     name="answer",
     *     in="body",
     *     type="string",
     *     description="The Principle Answer",
     *     schema={}
     * )
     *
     * @SWG\Tag(name="Progress")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $progress = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $progress = $em->getRepository("App:Progress")->find($id);
            $answer= $request->request->get("answer");
 
            if (!is_null($progress)) {
               
                $progress->setAnswer($answer);
                $progress->setState("state.revision");
 
                $em->persist($progress);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Progress - Error: You must to provide fields user or the Progress id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the Progress - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $progress : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Put("/edit/state/{id}.{_format}", name="Progress_edit_state", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The Progress State was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the Progress State."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Progress ID"
     * )
     * 
     *  @SWG\Parameter(
     *     name="state",
     *     in="body",
     *     type="string",
     *     description="The Answer State",
     *     schema={}
     * )
     *
     * @SWG\Tag(name="Progress")
     */
    public function editStateAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $progress = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $progress = $em->getRepository("App:Progress")->find($id);
            $state= $request->request->get("state");
 
            if (!is_null($progress)) {
               
                $progress->setState($state);
 
                $em->persist($progress);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Progress - Error: You must to provide fields user or the Progress id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the Progress - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $progress : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Put("/edit/comment/{id}.{_format}", name="Progress_edit_comment", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The Progress Comment was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the Progress Comment."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Progress ID"
     * )
     * 
     *  @SWG\Parameter(
     *     name="comment",
     *     in="body",
     *     type="string",
     *     description="The Answer Comment",
     *     schema={}
     * )
     *
     * @SWG\Tag(name="Progress")
     */
    public function editCommentAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $progress = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $progress = $em->getRepository("App:Progress")->find($id);
            $comment= $request->request->get("comment");
 
            if (!is_null($progress)) {
               
                $progress->setComment($comment);
                $progress->setState("state.correction");
 
                $em->persist($progress);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Progress - Error: You must to provide fields user or the Progress id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the Progress - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $progress : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }



    /**
     * @Rest\Get("/show/{id}.{_format}", name="progress_show_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Progress info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Progress with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Progress ID"
     * )
     *
     * @SWG\Tag(name="Progress")
     */
    public function showAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $progress = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $progress_id = $id;
            $progress = $em->getRepository("App:Progress")->find($progress_id);
 
            if (is_null($progress)) {
                $code = 500;
                $error = true;
                $message = "The Progress does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Progress- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $progress : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Get("/show/answer/{principle}/{student}.{_format}", name="progress_show_answer", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Progress info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Progress with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="principle",
     *     in="path",
     *     type="string",
     *     description="The Principle ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="student",
     *     in="path",
     *     type="string",
     *     description="The student ID"
     * )
     *
     * @SWG\Tag(name="Progress")
     */
    public function showAnswerAction(Request $request, $principle, $student) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $progress = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $progress = $em->getRepository("App:Progress")->findOneBy(array('principle' => $principle, 'student' => $student));
 
            if (is_null($progress)) {
                $code = 500;
                $error = true;
                $message = "The Progress does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Progress- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $progress : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Get("/show/answer/list/{course}/{student}.{_format}", name="progress_show_list_answer", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Progress info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Progress with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="course",
     *     in="path",
     *     type="string",
     *     description="The Course ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="student",
     *     in="path",
     *     type="string",
     *     description="The student ID"
     * )
     *
     * @SWG\Tag(name="Progress")
     */
    public function showAnswerListAction(Request $request, $course, $student) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $progress = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $progress = $em->getRepository("App:Progress")->findBy(array('course' => $course, 'student' => $student));
           

            if (is_null($progress)) {
                $code = 500;
                $error = true;
                $message = "The Progress does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Progress- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $progress : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Post("/show/list/state.{_format}", name="progress_show_list_state", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Progress info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Progress with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="course_id",
     *     in="path",
     *     type="string",
     *     description="The Course ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="student_id",
     *     in="path",
     *     type="string",
     *     description="The student ID"
     * )
     * 
     * 
    * @SWG\Parameter(
     *     name="state",
     *     in="path",
     *     type="string",
     *     description="The answer State"
     * )
     *
     * @SWG\Tag(name="Progress")
     */
    public function showAnswerStateAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $progress = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
            
            $course_id = $request->request->get("course_id");
            $student_id = $request->request->get("student_id");
            $state = $request->request->get("state");

            $progress = $em->getRepository("App:Progress")->findBy(array('course' => $course_id, 'student' => $student_id, "state" => $state));
           

            if (is_null($progress)) {
                $code = 500;
                $error = true;
                $message = "The Progress does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Progress- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $progress : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Post("/show/nextpending.{_format}", name="progress_next_pending", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Progress info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Progress with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="course_id",
     *     in="path",
     *     type="string",
     *     description="The Course ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="student_id",
     *     in="path",
     *     type="string",
     *     description="The student ID"
     * )
     * 
     *
     * @SWG\Tag(name="Progress")
     */
    public function showNextPendingAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $progress = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
            
            $course_id = $request->request->get("course_id");
            $student_id = $request->request->get("student_id");
            $state = $request->request->get("state");

            $progress = $em->getRepository("App:Progress")->findOneBy(array('course' => $course_id, 'student' => $student_id, "state" => "state.correction"));
           

            if (is_null($progress)) {
                $code = 500;
                $error = true;
                $message = "The Progress does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Progress- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $progress : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Post("/show/pendingcorrection", name="progress_pending_correction")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Progress info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Progress with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * 
     * @SWG\Parameter(
     *     name="student_id",
     *     in="path",
     *     type="string",
     *     description="The student ID"
     * )
     * 
     *
     * @SWG\Tag(name="Progress")
     */
    public function showPendingCorrectionAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $progress = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
            
            $student_id = $request->request->get("student_id");
            $state = $request->request->get("state");

            $progress = $em->getRepository("App:Progress")->answerPendingCorrections($student_id);
           

            if (is_null($progress)) {
                $code = 500;
                $error = true;
                $message = "The Progress does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Progress- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $progress : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()->setGroups(array('correction_list'))));
    }

    /**
     * @Rest\Get("/show/list/{id}.{_format}", name="progress_show_list_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all Progresss of Course Id Parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The list Progresss the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Course ID"
     * )
     *
     * @SWG\Tag(name="Progress")
     */
    public function showListAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $progress = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
            $learner_view = "false";
 
            $course_id = $id;

            $progresss = $em->getRepository("App:Progress")->findBy(array("course" => $course_id));

            foreach ($progresss as $progress) {
                $principles = $em->getRepository("App:Principle")->findBy(array("progress" => $progress->getId()), array("position" => "ASC"));
                $progress->setPrinciples(new ArrayCollection( $principles));
                if(!empty($principles) && $learner_view == "false"){
                    $learner_view = $principles[0]->getId();
                }
            }
 
            if (is_null($course)) {
                $code = 500;
                $error = true;
                $message = "The Course does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Progress- Error: {$ex->getMessage()}";
        }

        $data = [
            "progresss"  => $progresss,
            "course" => $course,
            "learner_view" => $learner_view
        ];
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Delete("/reset/{id}/{course_id}.{_format}", name="Progress_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Progress was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the Progress"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Progress ID"
     * )
     *
     * @SWG\Tag(name="Progress")
     */
    public function resetAction(Request $request, $id, $course_id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $progress = $em->getRepository("App:Progress")->findBy(array('course' => $course_id, 'student' => $id));
 
            if (!is_null($progress)) {
 
                $message = $em->getRepository("App:Progress")->deleteProgressByStudent($course_id, $id);
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent Progress - Error: The Progress id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current Progress - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Delete("/delete/student/{id}.{_format}", name="delete_progress", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Progress was successfully deleted"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to delete the progress"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The student ID"
     * )
     *
     * @SWG\Tag(name="Progress")
     */
    public function deleteStudentAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $course = $em->getRepository('App:Course')->getCourseByRequirements($id, 'requirement.sa');
 
            if (!is_null($course)) {

                $result = $em->getRepository('App:Progress')->deleteProgressByCourse($course->getId(), $id);
                $result = $em->getRepository('App:Stop')->deleteStopByCourse($course->getId(), $id);
 
                $message = "The progress was deleted successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent course - Error: The course id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current course - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }
 
}