<?php
 
namespace App\Controller;
 
use App\Entity\User;
use App\Entity\ResourceCategory;
use App\Form\ResourceCategoryType;
use App\Form\UserPasswordEditType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\AdminDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class ResourcecategoryController
 *
 * @Route("/resourcecategory")
 */
class ResourceCategoryController extends FOSRestController
{
    
 
    /**
     * @Rest\Get("/", name="resourcecategory_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all resourcecategorys."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all resourcecategory resourcecategorys."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Resourcecategory")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $resourcecategorys = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $resourcecategorys = $em->getRepository("App:ResourceCategory")->findAll(array(), array("language" => 'DESC', 'position' => "ASC"));
 
            if (is_null($resourcecategorys)) {
                $resourcecategorys = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Admins - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $resourcecategorys : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/showlist/{category}.{_format}", name="resourcecategory_show_list_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets resourcecategory info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The resourcecategory with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="category",
     *     in="path",
     *     type="string",
     *     description="The Resourcecategory category"
     * )
     * 
     *
     * @SWG\Tag(name="Resourcecategory")
     */
    public function showListAction(Request $request, $category ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $resourcecategory = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $resourcecategory = $em->getRepository("App:ResourceCategory")->findBy(array('category' => $category), array("position" => "ASC"));
 
            if (is_null($resourcecategory)) {
                $code = 500;
                $error = true;
                $message = "The Resourcecategory does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Resourcecategory- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $resourcecategory : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

 

    /**
     * @Rest\Post("/new", name="resourcecategory_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="User was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="User was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The resourcecategory name",
     *     schema={}
     * )
     *    
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     *     
     *    
     * @SWG\Parameter(
     *     name="category",
     *     in="body",
     *     type="array",
     *     description="The category assigned to this resourcecategory",
     *     schema={}
     * ) 
     * 
     * @SWG\Parameter(
     *     name="picture",
     *     in="body",
     *     type="array",
     *     description="The picture assigned to this resourcecategory",
     *     schema={}
     * )  
     * 
     * 
     * @SWG\Parameter(
     *     name="position",
     *     in="body",
     *     type="integer",
     *     description="The resource position",
     *     schema={}
     * )
     * 
     *
     * @SWG\Tag(name="Resourcecategory")
     */ 
    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";

        $resourcecategory = new Resourcecategory();
        //Create a form
        $form=$this->createForm(ResourceCategoryType::class, $resourcecategory);
        $form->submit($request->request->all());
       
        try {
            $code = 200;
            $error = false;
            $em->persist($resourcecategory);
            $em->flush();
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the resourcecategory - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $resourcecategory : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }


    /**
     * @Rest\Get("/show/{id}.{_format}", name="resourcecategory_show_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets resourcecategory info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The resourcecategory with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Resourcecategory ID"
     * )
     * 
     *
     * @SWG\Tag(name="Resourcecategory")
     */
    public function showAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $resourcecategory = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $resourcecategory_id = $id;
            $resourcecategory = $em->getRepository("App:ResourceCategory")->find($resourcecategory_id);
 
            if (is_null($resourcecategory)) {
                $code = 500;
                $error = true;
                $message = "The Resourcecategory does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Resourcecategory- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $resourcecategory : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="resourcecategory_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The resourcecategory was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the resourcecategory."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The resourcecategory ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The resourcecategory name",
     *     schema={}
     * )
     *    
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     *     
     *    
     * @SWG\Parameter(
     *     name="category",
     *     in="body",
     *     type="array",
     *     description="The language assigned to this category",
     *     schema={}
     * ) 
     * 
     * @SWG\Parameter(
     *     name="picture",
     *     in="body",
     *     type="array",
     *     description="The picture assigned to this resourcecategory",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="position",
     *     in="body",
     *     type="integer",
     *     description="The resource position",
     *     schema={}
     * )
     *
     * @SWG\Tag(name="Resourcecategory")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $message = "";
        

        try {
            $code = 200;
            $error = false;
            $resourcecategory = $em->getRepository("App:ResourceCategory")->find($id);
 
            if (!is_null($resourcecategory)) {
                $form = $this->createForm(ResourceCategoryType::class, $resourcecategory);
                $form->submit($request->request->all()); 
 
                $em->persist($resourcecategory);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Admin - Error: You must to provide fields resourcecategory or the resourcecategory id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the resourcecategory - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $resourcecategory : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/edit/position/{id}.{_format}", name="resourcecategory_edit_position", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The resourcecategory was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the resourcecategory."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The resourcecategory ID"
     * )
     *     
     * @SWG\Parameter(
     *     name="position",
     *     in="body",
     *     type="integer",
     *     description="The resource position",
     *     schema={}
     * )
     *
     * @SWG\Tag(name="Resourcecategory")
     */
    public function editPositionAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $position = $request->request->get('position');
        $message = "";
        

        try {
            $code = 200;
            $error = false;
            $resourcecategory = $em->getRepository("App:ResourceCategory")->find($id);
 
            if (!is_null($resourcecategory)) {
                $resourcecategory->setPosition($position);
 
                $em->persist($resourcecategory);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Admin - Error: You must to provide fields resourcecategory or the resourcecategory id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the resourcecategory - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $resourcecategory : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

   

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="resourcecategory_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="resource category was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the resourcecategory"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The resourcecategory ID"
     * )
     *
     * @SWG\Tag(name="Resourcecategory")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $resourcecategory = $em->getRepository("App:ResourceCategory")->find($id);
 
            if (!is_null($resourcecategory)) {
                $em->remove($resourcecategory);
                $em->flush();
 
                $message = "The resourcecategory was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent resourcecategory - Error: The resourcecategory id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current resourcecategory - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

}