<?php
 
namespace App\Controller;
 
use App\Entity\User;
use App\Entity\Resource;
use App\Form\ResourceType;
use App\Form\UserPasswordEditType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\AdminDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class ResourceController
 *
 * @Route("/resource")
 */
class ResourceController extends FOSRestController
{
    
 
    /**
     * @Rest\Get("/", name="resource_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all resources."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all resource resources."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Resource")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $resources = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $resources = $em->getRepository("App:Resource")->findAll();
 
            if (is_null($resources)) {
                $resources = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Admins - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $resources : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/showlist/{category}.{_format}", name="resource_show_list_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets resource info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The resource with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="resourcecategory",
     *     in="path",
     *     type="string",
     *     description="The Resource category"
     * )
     * 
     *
     * @SWG\Tag(name="Resource")
     */
    public function showListAction(Request $request, $category ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $resource = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $resource = $em->getRepository("App:Resource")->findBy(array('resourcecategory' => $category), array("position" => "ASC"));
 
            if (is_null($resource)) {
                $code = 500;
                $error = true;
                $message = "The Resource does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Resource- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $resource : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

 

    /**
     * @Rest\Post("/new", name="resource_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="User was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="User was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The resource name",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="position",
     *     in="body",
     *     type="integer",
     *     description="The resource position",
     *     schema={}
     * )
     *    
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     *     
     *    
     * @SWG\Parameter(
     *     name="resourcecategory",
     *     in="body",
     *     type="array",
     *     description="The language assigned to this resource",
     *     schema={}
     * ) 
     * 
     * @SWG\Parameter(
     *     name="picture",
     *     in="body",
     *     type="array",
     *     description="The picture assigned to this resource",
     *     schema={}
     * )  
     * 
     *  @SWG\Parameter(
     *     name="pptfile",
     *     in="body",
     *     type="array",
     *     description="The ppt assigned to this file",
     *     schema={}
     * )  
     * 
     *  *  @SWG\Parameter(
     *     name="pngfile",
     *     in="body",
     *     type="array",
     *     description="The png assigned to this file",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="pdffile",
     *     in="body",
     *     type="array",
     *     description="The pdf assigned to this file",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="videofile",
     *     in="body",
     *     type="array",
     *     description="The video assigned to this file",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="zipfile",
     *     in="body",
     *     type="array",
     *     description="The zip assigned to this file",
     *     schema={}
     * )  
     * 
     * 
     * @SWG\Parameter(
     *     name="epsfile",
     *     in="body",
     *     type="array",
     *     description="The eps assigned to this file",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="aifile",
     *     in="body",
     *     type="array",
     *     description="The ai assigned to this file",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="docxfile",
     *     in="body",
     *     type="array",
     *     description="The docx assigned to this file",
     *     schema={}
     * )  
     * 
     * 
     *  @SWG\Parameter(
     *     name="video",
     *     in="body",
     *     type="array",
     *     description="The video assigned to this file",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="version",
     *     in="body",
     *     type="array",
     *     description="The version assigned to this file",
     *     schema={}
     * )
     * 
     * 
     *      
     *
     * @SWG\Tag(name="Resource")
     */ 
    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
       
 
        $message = "";

        $resource = new Resource();
        //Create a form
        $form=$this->createForm(ResourceType::class, $resource);
        $form->submit($request->request->all());
        
       
        try {
            $code = 200;
            $error = false;
            $em->persist($resource);
            $em->flush();
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the resource - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $resource : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/show/filter", name="resource_filter")
     *
     * @SWG\Response(
     *     response=201,
     *     description="User was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="User was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="string",
     *     description="The category language",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="category",
     *     in="body",
     *     type="integer",
     *     description="The resource category",
     *     schema={}
     * )
     *    
     * 
     * @SWG\Parameter(
     *     name="subcategory",
     *     in="body",
     *     type="string",
     *     description="The resource subcategory",
     *     schema={}
     * )
     *     
     *    
     *      
     *
     * @SWG\Tag(name="Resource")
     */ 
    public function showFilterAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
       
 
        $message = "";

        $language = $request->request->get('language');
        $category = $request->request->get('category');
        $subcategory = $request->request->get('subcategory');
        
       
        try {
            $code = 200;
            $error = false;
            $resources = $em->getRepository("App:Resource")->resourceByCategoryLanguage($language, $category, $subcategory);
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the resource - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $resources : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }


    /**
     * @Rest\Get("/show/{id}.{_format}", name="resource_show_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets resource info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The resource with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Resource ID"
     * )
     * 
     *
     * @SWG\Tag(name="Resource")
     */
    public function showAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $resource = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $resource_id = $id;
            $resource = $em->getRepository("App:Resource")->find($resource_id);
 
            if (is_null($resource)) {
                $code = 500;
                $error = true;
                $message = "The Resource does not exist";
            }
            else{
                $resource_obj = [
                    "id"                => $resource->getId(),
                    "name"              => $resource->getName(),
                    "picture"           => $resource->getPicture(),
                    "description"       => $resource->getDescription(),
                    "version"           => $resource->getVersion(),
                    "pdffile"           => $resource->getPdffile(),
                    "pngfile"           => $resource->getPngfile(),
                    "pptfile"           => $resource->getPptfile(),
                    "videofile"         => $resource->getVideofile(),
                    "zipfile"           => $resource->getZipfile(),
                    "epsfile"           => $resource->getEpsfile(),
                    "aifile"            => $resource->getAifile(),
                    "docxfile"          => $resource->getDocxfile(),
                    "video"             => $resource->getVideo(),
                    "url"               => $resource->getUrl(),
                    "category"          => $resource->getResourcecategory()->getCategory()->getId(),
                    "resourcecategory"  => $resource->getResourcecategory(),
                    "subcategory"       => $resource->getResourcecategory()->getId(),
                ];

            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Resource- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $resource_obj : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="resource_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The resource was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the resource."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The resource ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The resource name",
     *     schema={}
     * )
     *    
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     *     
     *    
     * @SWG\Parameter(
     *     name="resourceCategory",
     *     in="body",
     *     type="array",
     *     description="The language assigned to this resource",
     *     schema={}
     * ) 
     * 
     * @SWG\Parameter(
     *     name="picture",
     *     in="body",
     *     type="array",
     *     description="The picture assigned to this resource",
     *     schema={}
     * )  
     * 
     *  @SWG\Parameter(
     *     name="pptfile",
     *     in="body",
     *     type="array",
     *     description="The ppt assigned to this file",
     *     schema={}
     * )  
     * 
     *  *  @SWG\Parameter(
     *     name="pngfile",
     *     in="body",
     *     type="array",
     *     description="The png assigned to this file",
     *     schema={}
     * )  
     * 
     *  *  @SWG\Parameter(
     *     name="pdffile",
     *     in="body",
     *     type="array",
     *     description="The pdf assigned to this file",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="position",
     *     in="body",
     *     type="integer",
     *     description="The resource position",
     *     schema={}
     * )
     * 
     *  @SWG\Parameter(
     *     name="video",
     *     in="body",
     *     type="array",
     *     description="The video assigned to this file",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="version",
     *     in="body",
     *     type="array",
     *     description="The version assigned to this file",
     *     schema={}
     * )
     *
     * @SWG\Tag(name="Resource")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $message = "";
        

        try {
            $code = 200;
            $error = false;
            $resource = $em->getRepository("App:Resource")->find($id);
 
            if (!is_null($resource)) {
                $form = $this->createForm(ResourceType::class, $resource);
                $form->submit($request->request->all()); 
 
                $em->persist($resource);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Admin - Error: You must to provide fields resource or the resource id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the resource - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $resource : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/edit/position/{id}.{_format}", name="resource_edit_position", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The resource was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the resource."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The resource ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="position",
     *     in="body",
     *     type="integer",
     *     description="The resource position",
     *     schema={}
     * )
     *    
     * 
     *
     * @SWG\Tag(name="Resource")
     */
    public function editPositionAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $message = "";
        $position = $request->request->get('position');
        

        try {
            $code = 200;
            $error = false;
            $resource = $em->getRepository("App:Resource")->find($id);
 
            if (!is_null($resource)) {
                $resource->setPosition($position); 
 
                $em->persist($resource);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Admin - Error: You must to provide fields resource or the resource id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the resource - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $resource : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

   

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="resource_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="resource category was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the resource"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The resource ID"
     * )
     *
     * @SWG\Tag(name="Resource")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $resource = $em->getRepository("App:Resource")->find($id);
 
            if (!is_null($resource)) {
                $em->remove($resource);
                $em->flush();
 
                $message = "The resource was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent resource - Error: The resource id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current resource - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

}