<?php
 
namespace App\Controller;
 
use App\Entity\User;
use App\Entity\Section;
use App\Form\SectionType;
use App\Form\UserPasswordEditType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\AdminDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class SectionController
 *
 * @Route("/section")
 */
class SectionController extends FOSRestController
{
    
 
    /**
     * @Rest\Get("/", name="section_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all categories."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all section categories."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Section")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $categories = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $categories = $em->getRepository("App:Section")->findAll(array(), array("language" => 'DESC'));
 
            if (is_null($categories)) {
                $categories = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Admins - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $categories : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/showlist/{language}.{_format}", name="section_show_list_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets section info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The section with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="lang",
     *     in="path",
     *     type="string",
     *     description="The Section language"
     * )
     * 
     *
     * @SWG\Tag(name="Section")
     */
    public function showListAction(Request $request, $language ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $section = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $section = $em->getRepository("App:Section")->findBy(array('language' => $language));
 
            if (is_null($section)) {
                $code = 500;
                $error = true;
                $message = "The Section does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Section- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $section : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/show/available", name="section_show_available_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets section info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The section with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="string",
     *     description="The Section language"
     * )
     * 
     * @SWG\Parameter(
     *     name="role",
     *     in="body",
     *     type="string",
     *     description="The User Role"
     * )
     * 
     *
     * @SWG\Tag(name="Section")
     */
    public function showAvailableAction(Request $request ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $sections = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
            $role = $request->request->get('role');
            $language = $request->request->get('language');
 
            $sections = $em->getRepository("App:Section")->getAvailableResources($role, $language);
 
            if (is_null($sections)) {
                $code = 500;
                $error = true;
                $message = "The Section does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Section- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $sections : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

 

    /**
     * @Rest\Post("/new", name="section_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="User was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="User was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The section name",
     *     schema={}
     * )
     *    
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     *     
     * 
     * @SWG\Parameter(
     *     name="picture",
     *     in="body",
     *     type="array",
     *     description="The picture assigned to this section",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="array",
     *     description="The language assigned to this section",
     *     schema={}
     * )
     * 
     *       
     *
     * @SWG\Tag(name="Section")
     */ 
    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";

        $section = new Section();
        //Create a form
        $form=$this->createForm(SectionType::class, $section);
        $form->submit($request->request->all());
       
        try {
            $code = 200;
            $error = false;
            $em->persist($section);
            $em->flush();
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the section - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $section : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }


    /**
     * @Rest\Get("/show/{id}.{_format}", name="section_show_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets section info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The section with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Section ID"
     * )
     * 
     *
     * @SWG\Tag(name="Section")
     */
    public function showAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $section = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $section_id = $id;
            $section = $em->getRepository("App:Section")->find($section_id);
 
            if (is_null($section)) {
                $code = 500;
                $error = true;
                $message = "The Section does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Section- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $section : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="section_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The section was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the section."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The section ID"
     * )
     * 
      * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The section name",
     *     schema={}
     * )
     *    
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     *     
     * 
     * @SWG\Parameter(
     *     name="picture",
     *     in="body",
     *     type="array",
     *     description="The picture assigned to this section",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="array",
     *     description="The language assigned to this section",
     *     schema={}
     * )
     * 
     *
     * 
     * @SWG\Tag(name="Section")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $message = "";
        

        try {
            $code = 200;
            $error = false;
            $section = $em->getRepository("App:Section")->find($id);
 
            if (!is_null($section)) {
                $form = $this->createForm(SectionType::class, $section);
                $form->submit($request->request->all()); 
                
                $em->persist($section);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Admin - Error: You must to provide fields section or the section id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the section - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $section : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

   

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="section_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="resource section was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the section"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The section ID"
     * )
     *
     * @SWG\Tag(name="Section")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $section = $em->getRepository("App:Section")->find($id);
 
            if (!is_null($section)) {
                $em->remove($section);
                $em->flush();
 
                $message = "The section was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent section - Error: The section id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current section - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

}