<?php

 
namespace App\Controller;
 
use App\Entity\Stop;
use App\Form\StopType;
use App\Form\StopEditType;


use Doctrine\Common\Collections\ArrayCollection;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\UserDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class StopController
 *
 * @Route("/stop")
 */
class StopController extends FOSRestController
{
    
    /**
     * @Rest\Get("/{id}/{student}.{_format}", name="stop_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all stops."
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="body",
     *     type="integer",
     *     description="The Course Id",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="student",
     *     in="body",
     *     type="integer",
     *     description="The Student Id",
     *     schema={}
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all stops."
     * )
     *
     * @SWG\Tag(name="Stop")
     */
    public function indexAction(Request $request, $id, $student) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $stops = [];
        $message = "";       
 
        try {
            $code = 200;
            $error = false;
 
            //$stops = $em->getRepository("App:Stop")->findAll();
            $stops = $em->getRepository("App:Stop")->findBy(array("course" => $id, "student" => $student));
           
 
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Stop - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $stops : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

     /**
     * @Rest\Post("/new", name="stop_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Stop was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Stop was not successfully registered"
     * )
     *
     * 
     *
     * @SWG\Parameter(
     *     name="course_id",
     *     in="body",
     *     type="integer",
     *     description="The Course id of the new stop",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="student_id",
     *     in="body",
     *     type="string",
     *     description="The student ID",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="principle_id",
     *     in="body",
     *     type="string",
     *     description="The Principle ID",
     *     schema={}
     * )
     * 
     *  @SWG\Parameter(
     *     name="state",
     *     in="body",
     *     type="string",
     *     description="The Stop State",
     *     schema={}
     * )
     *     
     * 
     * @SWG\Tag(name="Stop")
     */ 

    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $message = "";       
        
        
        $principle_id= $request->request->get("principle_id");
        $student_id= $request->request->get("student_id");
        $state= $request->request->get("state");
        $principle= $em->getRepository("App:Principle")->find($principle_id);
        $course_id = $principle->getUnit()->getCourse()->getId();

        
       

        try {
            $code = 200;
            $error = false;

            $stop = $em->getRepository("App:Stop")->findOneBy( array("principle" => $principle_id, "student" => $student_id));

            if(is_null($stop)){
                $stop=new Stop();
                $course = $em->getRepository("App:Course")->find($course_id);
                $principle = $em->getRepository("App:Principle")->find($principle_id);
                $student = $em->getRepository("App:User")->find($student_id);
    
                $stop->setCourse($course);
                $stop->setPrinciple($principle);
                $stop->setStudent($student);
                $stop->setState($state);
    
                $em->persist($stop);
                $em->flush();
            }
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Stop - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $stop : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }


    /**
     * @Rest\Put("/edit/{id}.{_format}", name="Stop_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The Stop was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the Stop."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Stop ID"
     * )
     * 
     *  @SWG\Parameter(
     *     name="state",
     *     in="body",
     *     type="string",
     *     description="The Stop State",
     *     schema={}
     * )
     *
     * @SWG\Tag(name="Stop")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $stop = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $stop = $em->getRepository("App:Stop")->find($id);
            $state= $request->request->get("state");
 
            if (!is_null($stop)) {
               
                $stop->setState($state);
 
                $em->persist($stop);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Stop - Error: You must to provide fields user or the Stop id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the Stop - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $stop : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }


    /**
     * @Rest\Get("/show/{id}.{_format}", name="stop_show_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Stop info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Stop with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Stop ID"
     * )
     *
     * @SWG\Tag(name="Stop")
     */
    public function showAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $stop = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $stop_id = $id;
            $stop = $em->getRepository("App:Stop")->find($stop_id);
 
            if (is_null($stop)) {
                $code = 500;
                $error = true;
                $message = "The Stop does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Stop- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $stop : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    

    /**
     * @Rest\Get("/show/stop/{principle}/{student}.{_format}", name="stop_show_stop", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Stop info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Stop with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="principle",
     *     in="path",
     *     type="string",
     *     description="The Principle ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="student",
     *     in="path",
     *     type="string",
     *     description="The student ID"
     * )
     *
     * @SWG\Tag(name="Stop")
     */
    public function showStopAction(Request $request, $principle, $student) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $stop = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $stop = $em->getRepository("App:Stop")->findOneBy(array('principle' => $principle, 'student' => $student));
 
            if (is_null($stop)) {
                $code = 500;
                $error = true;
                $message = "The Stop does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Stop- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $stop : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Get("/show/stop/{course}/{student}.{_format}", name="course_state_show_stop", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Stop info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Stop with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="course",
     *     in="path",
     *     type="string",
     *     description="The Course ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="student",
     *     in="path",
     *     type="string",
     *     description="The student ID"
     * )     
     *
     * @SWG\Tag(name="Stop")
     */
    public function showStopCourseStateAction(Request $request, $course, $student) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $stop = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $stop = $em->getRepository("App:Stop")->stopByState("state.active");
 
            if (is_null($stop)) {
                $code = 500;
                $error = true;
                $message = "The Stop does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Stop- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $stop : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/show/state/list/{course}/{state}.{_format}", name="stop_show_list_state", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Stop info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Stop with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="course",
     *     in="path",
     *     type="string",
     *     description="The Course ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="state",
     *     in="path",
     *     type="string",
     *     description="The State of Stop ID"
     * )
     *
     * @SWG\Tag(name="Stop")
     */
    public function showStateListAction(Request $request, $course, $state) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $stop = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $stop = $em->getRepository("App:Stop")->findBy(array('course' => $course, 'state' => $state));
           

            if (is_null($stop)) {
                $code = 500;
                $error = true;
                $message = "The Stop does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Stop- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $stop : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Post("/show/state/all", name="stop_show_all_state", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Stop info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Stop with the passed ID parameter was not found or doesn't exist."
     * )
     *    
     * 
     * @SWG\Parameter(
     *     name="state",
     *     in="path",
     *     type="string",
     *     description="The State of Stop ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="user_id",
     *     in="path",
     *     type="string",
     *     description="The Admin Id"
     * )
     *
     * @SWG\Tag(name="Stop")
     */
    public function showStateAllAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $stop = [];
        $stop_list = [];
        $message = "";

        $language = $request->request->get("language");
        $state = $request->request->get("state");
        $role = $request->request->get("role");
        $language = explode(",", preg_replace('([^A-Za-z0-9,])', '', $language));
        
        try {
            $code = 200;
            $error = false;
            
            if($role === "ROLE_ADMIN"){
                $stop = $em->getRepository("App:Stop")->stopByState($state);
            }
            else{
                $stop = $em->getRepository("App:Stop")->stopByLanguageState($state, $language);
            }
            
            foreach ($stop as $st) {
                $answers = $em->getRepository("App:Progress")->findOneBy(array('course' => $st->getCourse()->getId(), 'student' => $st->getStudent()->getId(), 'state' => 'state.correction'));
                if (is_null($answers)) {
                    $stop_list[] = $st;
                }
            }

            if (is_null($stop)) {
                $code = 500;
                $error = true;
                $message = "The Stop does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Stop- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $stop_list : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Get("/show/list/{id}.{_format}", name="stop_show_list_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all Stops of Course Id Parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The list Stops the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Course ID"
     * )
     *
     * @SWG\Tag(name="Stop")
     */
    public function showListAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $stop = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
            $learner_view = "false";
 
            $course_id = $id;

            $stops = $em->getRepository("App:Stop")->findBy(array("course" => $course_id));

            foreach ($stops as $stop) {
                $principles = $em->getRepository("App:Principle")->findBy(array("stop" => $stop->getId()), array("position" => "ASC"));
                $stop->setPrinciples(new ArrayCollection( $principles));
                if(!empty($principles) && $learner_view == "false"){
                    $learner_view = $principles[0]->getId();
                }
            }
 
            if (is_null($course)) {
                $code = 500;
                $error = true;
                $message = "The Course does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Stop- Error: {$ex->getMessage()}";
        }

        $data = [
            "stops"  => $stops,
            "course" => $course,
            "learner_view" => $learner_view
        ];
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Delete("/reset/{id}/{course_id}.{_format}", name="Stop_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Stop was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the Stop"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Student ID"
     * )
     *
     * @SWG\Tag(name="Stop")
     */
    public function resetAction(Request $request, $id, $course_id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $message = "";
 
        try {
            $code = 200;
            $error = false;
            $stop = $em->getRepository("App:Stop")->findOneBy(array('course' => $course_id, 'student' => $id, 'state' => "state.active"));
            $progress = $em->getRepository("App:Progress")->deleteAnswerCommentsByStudent($course_id, $id);

            if (!is_null($stop)) {
 
                $stop->setState("state.inactive");
 
                $em->persist($stop);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent Stop - Error: The Stop id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current Stop - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }
 
}