<?php

namespace App\Controller;
 
use App\Entity\User;
use App\Entity\Task;
use App\Entity\Tracking;
use App\Entity\StudentGroup;
use App\Entity\StudentAmbassadorGroup;
use App\Form\UserType;
use App\Form\StudentType;
use App\Form\UserEditType;
use App\Form\UserNotificationsType;
use Doctrine\Common\Collections\ArrayCollection;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\UserDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class StudentController
 *
 * @Route("/student")
 */
class StudentController extends FOSRestController
{
    
 
    /**
     * @Rest\GET("/", name="students_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all students."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all students."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Student")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $users = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            //$users = $em->getRepository("App:User")->findAll();
            //$this->forward('App\Controller\InitializationController::studentCreateAction', []);
            $current_date = new \DateTime();
            $init_date = $current_date->modify( '-1 month' )->format('Y-m-d');
            $users = $em->getRepository("App:User")->participantsByDate($init_date);
 
            if (is_null($users)) {
                $users = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Users - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $users : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()->setGroups(array('participant_list'))));
    }

    /**
     * @Rest\Post("/pagination", name="student_pagination")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all students."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all students."
     * )
     *
     *
     * @SWG\Parameter(
     *     name="keyword",
     *     in="path",
     *     type="string",
     *     description="The search keyword"
     * )
     * 
     * @SWG\Parameter(
     *     name="page",
     *     in="path",
     *     type="string",
     *     description="The search Page"
     * )
     * 
     * @SWG\Parameter(
     *     name="page_size",
     *     in="path",
     *     type="string",
     *     description="The number of records for page"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_column",
     *     in="path",
     *     type="string",
     *     description="Search order Column"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_direction",
     *     in="path",
     *     type="string",
     *     description="Search order Direction"
     * )
     *    
     *
     * @SWG\Tag(name="Student")
     */
    public function paginationAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $groups = [];
        $message = "";
        $studentList = [];
 
        try {
            $code = 200;
            $error = false;
            
            $keyword    = $request->request->get('keyword');
            $page   = $request->request->get('page');
            $page_size = $request->request->get('page_size');
            $order_column = $request->request->get('order_column');
            $order_direction = $request->request->get('order_direction');

            $result = $em->getRepository("App:User")->getParticipantListPagination($keyword, $page, $page_size, $order_column, $order_direction);    
            
            foreach ($result['list'] as $student) {
                $st = $student[0];
                $whatsapp = "";
                $mbs_progress = "";
                $wellness_progress = "";
                $sa_progress = "";
                if($st->getAreacode() == "USA +1"){
                    $whatsapp = $st->getWhatsapp();
                }
                else{
                    $whatsapp = substr($st->getAreacode(), 3).$st->getWhatsapp();
                }

                if($st->getProgrammbs()  && $st->getEvaluation()){
                    if($st->getProgrammbs()->getVersion() === "5"){
                        $mbs_progress = $this->requirementMbsProgress( $st->getProgrammbs(), $st->getEvaluation() );
                    }
                    else if($st->getProgrammbs()->getModality() === "option.modality1" || $st->getProgrammbs()->getState() === "state.approved"){
                        $mbs_progress = 100;
                    }
                    else{
                        $mbs_progress = ($this->mbsProgress($st->getProgrammbs()) / 8);
                    }
                    
                }
                if($st->getWellness()){
                    $wellness_progress = ($this->wellProgress($st->getWellness()) / 4);
                }
                if($st->getProgramsa()){
                    if($st->getProgramsa()->getState() === "state.approved" ){
                        $sa_progress = 100 ;
                    }
                    else{
                        $sa_progress = ($this->saProgress($st->getProgramsa()) / 6);
                    }
                    
                }

                
                $studentList[] = [
                    'id'                        => $st->getId(),
                    'participant_name'          => $st->getFirstName(). " " .$st->getLastName(),
                    'country'                   => $st->getCountry(),
                    'role'                      => $st->getRoles(),
                    'created_at'                => $st->getCreatedAt(),
                    'programmbs'                => $st->getProgrammbs(),
                    'programsa'                 => $st->getProgramsa(),
                    'programwell'               => $st->getWellness(),
                    'group_program'             => $st->getStudentGroup() ? $st->getStudentGroup()->getGroup()->getProgram() : "",
                    'group_1'                   => $st->getStudentGroup() ? $st->getStudentGroup()->getGroup()->getName() : "",
                    'group_2'                   => $st->getStudentAmbassadorGroup() ? $st->getStudentAmbassadorGroup()->getGroup()->getName() : "",
                    'whatsapp'                  => $whatsapp,
                    'mbs_requirements_progress' => round($mbs_progress),
                    'well_requirements_progress'=> round($wellness_progress),
                    'sa_requirements_progress'  => round($sa_progress),
                    'mbs_course'                => $this->courseProgress($st, 'requirement.mbs'),
                    'sa_course'                 => $this->courseProgress($st, 'requirement.sa'),
                    'well_course'               => $this->courseProgress($st, 'requirement.wellness')
                ];
            }

            $data = [
                'list'              => $studentList,
                'items_total'       => $result['items_total'],
                'pages_total'       => $result['pages_total' ]
            ];
            
           
         
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('participant_list'))));
    }

    /**
     * @Rest\Post("/potentialsa/pagination", name="student_potential_sa_pagination")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all students."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all students."
     * )
     *
     *
     * @SWG\Parameter(
     *     name="keyword",
     *     in="path",
     *     type="string",
     *     description="The search keyword"
     * )
     * 
     * @SWG\Parameter(
     *     name="page",
     *     in="path",
     *     type="string",
     *     description="The search Page"
     * )
     * 
     * @SWG\Parameter(
     *     name="page_size",
     *     in="path",
     *     type="string",
     *     description="The number of records for page"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_column",
     *     in="path",
     *     type="string",
     *     description="Search order Column"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_direction",
     *     in="path",
     *     type="string",
     *     description="Search order Direction"
     * )
     *    
     *
     * @SWG\Tag(name="Student")
     */
    public function potentialSaPaginationAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $groups = [];
        $message = "";
        $studentList = [];
 
        try {
            $code = 200;
            $error = false;
            
            $keyword    = $request->request->get('keyword');
            $page   = $request->request->get('page');
            $page_size = $request->request->get('page_size');
            $order_column = $request->request->get('order_column');
            $order_direction = $request->request->get('order_direction');

            $result = $em->getRepository("App:User")->getPotentialSaListPagination($keyword, $page, $page_size, $order_column, $order_direction);    
            
            foreach ($result['list'] as $student) {
                $st = $student[0];               
                $studentList[] = [
                    'id'                        => $st->getId(),
                    'participant_name'          => $student['participant_name'],
                    'created_at'                => $st->getCreatedAt(),
                    'programmbs_state'          => $student['programmbs_state'] ? $student['programmbs_state'] : "state.not_started",                   
                    'group_name'                => $student['group_name'],
                    'ambassador_name'           => $student['ambassador_name'],
                ];
            }

            $data = [
                'list'              => $studentList,
                'items_total'       => $result['items_total'],
                'pages_total'       => $result['pages_total' ]
            ];
            
           
         
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('participant_list'))));
    }

    /**
     * @Rest\Post("/grantmember/pagination", name="grant_member_pagination")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all students."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all students."
     * )
     *
     *
     * @SWG\Parameter(
     *     name="keyword",
     *     in="path",
     *     type="string",
     *     description="The search keyword"
     * )
     * 
     * @SWG\Parameter(
     *     name="page",
     *     in="path",
     *     type="string",
     *     description="The search Page"
     * )
     * 
     * @SWG\Parameter(
     *     name="page_size",
     *     in="path",
     *     type="string",
     *     description="The number of records for page"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_column",
     *     in="path",
     *     type="string",
     *     description="Search order Column"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_direction",
     *     in="path",
     *     type="string",
     *     description="Search order Direction"
     * )
     *    
     *
     * @SWG\Tag(name="Student")
     */
    public function grantMemberPaginationAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $groups = [];
        $message = "";
        $studentList = [];
 
        try {
            $code = 200;
            $error = false;
            
            $keyword    = $request->request->get('keyword');
            $page   = $request->request->get('page');
            $page_size = $request->request->get('page_size');
            $order_column = $request->request->get('order_column');
            $order_direction = $request->request->get('order_direction');

            $result = $em->getRepository("App:User")->getGrantMemberListPagination($keyword, $page, $page_size, $order_column, $order_direction);    
            
            foreach ($result['list'] as $student) {
                $st = $student[0];               
                $studentList[] = [
                    'id'                        => $st->getId(),
                    'participant_name'          => $student['participant_name'],
                    'created_at'                => $st->getCreatedAt(),
                    'group_name'                => $student['group_name'],
                    'ambassador_name'           => $student['ambassador_name'],
                ];
            }

            $data = [
                'list'              => $studentList,
                'items_total'       => $result['items_total'],
                'pages_total'       => $result['pages_total' ]
            ];
            
           
         
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('participant_list'))));
    }

     /**
     * @Rest\Get("/list", name="students_list", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all students."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all students."
     * )
     *
     *
     *
     * @SWG\Tag(name="Student")
     */
    public function listAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $users = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            //$userId = $this->getUser()->getId();
            $users = $em->getRepository("App:User")->findAll();
 
            if (is_null($users)) {
                $users = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Users - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $users : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('student_list'))));
    }

    /**
     * @Rest\Get("/list/group/{id}.{_format}", name="group_student_list", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets students of group info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The students with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Group ID"
     * )
     *
     *
     * @SWG\Tag(name="Student")
     */
    public function listGroupAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $studentList = [];
        $list = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $group_id = $id;
            $studentMbsList = $em->getRepository("App:StudentGroup")->findBy(array('group' => $group_id));
            $studentAmbassadorList = $em->getRepository("App:StudentAmbassadorGroup")->findBy(array('group' => $group_id));

            $list = new ArrayCollection(
                array_merge($studentMbsList, $studentAmbassadorList )
            );

            foreach ($list as $st) {
                $whatsapp = "";
                $mbs_progress = "";
                $wellness_progress = "";
                $sa_progress = "";
                if($st->getStudent()->getAreacode() == "USA +1"){
                    $whatsapp = $st->getStudent()->getWhatsapp();
                }
                else{
                    $whatsapp = substr($st->getStudent()->getAreacode(), 3).$st->getStudent()->getWhatsapp();
                }

                if($st->getStudent()->getProgrammbs()  && $st->getStudent()->getEvaluation()){
                    if($st->getStudent()->getProgrammbs()->getVersion() === "5"){
                        $mbs_progress = $this->requirementMbsProgress( $st->getStudent()->getProgrammbs(), $st->getStudent()->getEvaluation() );
                    }
                    else if($st->getStudent()->getProgrammbs()->getModality() === "option.modality1" || $st->getStudent()->getProgrammbs()->getState() === "state.approved"){
                        $mbs_progress = 100;
                    }
                    else{
                        $mbs_progress = ($this->mbsProgress($st->getStudent()->getProgrammbs()) / 8);
                    }
                    
                }
                if($st->getStudent()->getWellness()){
                    $wellness_progress = ($this->wellProgress($st->getStudent()->getWellness()) / 4);
                }
                if($st->getStudent()->getProgramsa()){
                    if($st->getStudent()->getProgramsa()->getState() === "state.approved" ){
                        $sa_progress = 100 ;
                    }
                    else{
                        $sa_progress = ($this->saProgress($st->getStudent()->getProgramsa()) / 6);
                    }
                    
                }

                
                $studentList[] = [
                    'id'                        => $st->getStudent()->getId(),
                    'first_name'                => $st->getStudent()->getFirstName(),
                    'last_name'                 => $st->getStudent()->getLastName(),
                    'country'                   => $st->getStudent()->getCountry(),
                    'created_date'              => $st->getStudent()->getCreatedAt(),
                    'programmbs'                => $st->getStudent()->getProgrammbs(),
                    'programsa'                 => $st->getStudent()->getProgramsa(),
                    'programwell'               => $st->getStudent()->getWellness(),
                    'group_program'             => $st->getGroup()->getProgram(),
                    'whatsapp'                  => $whatsapp,
                    'mbs_requirements_progress' => round($mbs_progress),
                    'well_requirements_progress'=> round($wellness_progress),
                    'sa_requirements_progress'  => round($sa_progress),
                    'mbs_course'                => $this->courseProgress($st->getStudent(), 'requirement.mbs'),
                    'sa_course'                 => $this->courseProgress($st->getStudent(), 'requirement.sa'),
                    'well_course'               => $this->courseProgress($st->getStudent(), 'requirement.wellness')
                ];
            }
            
 
            if (is_null($studentList)) {
                $code = 500;
                $error = true;
                $message = "The group not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the list students - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $studentList : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('student_group'))));
    }

    /**
     * @Rest\Post("/list/group/pagination", name="list_group_pagination")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all students."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all students."
     * )
     *
     *
     * @SWG\Parameter(
     *     name="keyword",
     *     in="path",
     *     type="string",
     *     description="The search keyword"
     * )
     * 
     * @SWG\Parameter(
     *     name="page",
     *     in="path",
     *     type="string",
     *     description="The search Page"
     * )
     * 
     * @SWG\Parameter(
     *     name="page_size",
     *     in="path",
     *     type="string",
     *     description="The number of records for page"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_column",
     *     in="path",
     *     type="string",
     *     description="Search order Column"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_direction",
     *     in="path",
     *     type="string",
     *     description="Search order Direction"
     * )
     * 
     * @SWG\Parameter(
     *     name="group_id",
     *     in="path",
     *     type="string",
     *     description="Group Id"
     * )
     *
     * @SWG\Tag(name="Student")
     */
    public function listGroupPaginationAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $groups = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
            
            $key    = $request->request->get('key');
            $page   = $request->request->get('page');
            $page_size = $request->request->get('page_size');
            $order_column = $request->request->get('order_column');
            $order_direction = $request->request->get('order_direction');
            $group = $em->getRepository("App:Groupe")->find($request->request->get('group_id'));

            $result = $em->getRepository("App:User")->getParticipantByGroupPagination($key, $page, $page_size, $order_column, $order_direction, $group->getId());    
            
            foreach ($result['list'] as $student) {
                $st = $student[0];
                $whatsapp = "";
                $mbs_progress = "";
                $wellness_progress = "";
                $sa_progress = "";
                if($st->getAreacode() == "USA +1"){
                    $whatsapp = $st->getWhatsapp();
                }
                else{
                    $whatsapp = substr($st->getAreacode(), 3).$st->getWhatsapp();
                }

                if($st->getProgrammbs()  && $st->getEvaluation()){
                    if($st->getProgrammbs()->getVersion() === "5"){
                        $mbs_progress = $this->requirementMbsProgress( $st->getProgrammbs(), $st->getEvaluation() );
                    }
                    else if($st->getProgrammbs()->getModality() === "option.modality1" || $st->getProgrammbs()->getState() === "state.approved"){
                        $mbs_progress = 100;
                    }
                    else{
                        $mbs_progress = ($this->mbsProgress($st->getProgrammbs()) / 8);
                    }
                    
                }
                if($st->getWellness()){
                    $wellness_progress = ($this->wellProgress($st->getWellness()) / 4);
                }
                if($st->getProgramsa()){
                    if($st->getProgramsa()->getState() === "state.approved" ){
                        $sa_progress = 100 ;
                    }
                    else{
                        $sa_progress = ($this->saProgress($st->getProgramsa()) / 6);
                    }
                    
                }

                
                $studentList[] = [
                    'id'                        => $st->getId(),
                    'student_name'              => $st->getFirstName(). " " .$st->getLastName(),
                    'country'                   => $st->getCountry(),
                    'role'                      => $st->getRoles(),
                    'created_at'                => $st->getCreatedAt(),
                    'programmbs'                => $st->getProgrammbs(),
                    'programsa'                 => $st->getProgramsa(),
                    'programwell'               => $st->getWellness(),
                    'group_program'             => $group->getProgram(),
                    'whatsapp'                  => $whatsapp,
                    'mbs_requirements_progress' => round($mbs_progress),
                    'well_requirements_progress'=> round($wellness_progress),
                    'sa_requirements_progress'  => round($sa_progress),
                    'mbs_course'                => $this->courseProgress($st, 'requirement.mbs'),
                    'sa_course'                 => $this->courseProgress($st, 'requirement.sa'),
                    'well_course'               => $this->courseProgress($st, 'requirement.wellness')
                ];
            }

            $data = [
                'list'              => $studentList,
                'items_total'       => $result['items_total'],
                'pages_total'       => $result['pages_total' ]
            ];
            
           
         
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('ambassador_list'))));
    }

    /**
     * @Rest\Get("/mbs", name="students_mbs", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all students."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all students."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="User ID"
     * )
     *
     *
     * @SWG\Tag(name="Student")
     */
    public function mbsAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $users = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            //$userId = $this->getUser()->getId();
            //$users = $em->getRepository("App:User")->getMbsStudents();
            $list = $em->getRepository("App:ProgramMbs")->graduates();
 
            foreach ($list as $pm) {
                $student = $pm->getStudent();
                $users[] = [
                    "name" => $student->getFirstName()." ".$student->getLastName(),
                    "email" => $student->getUsername(),
                    "language" => $student->getLanguage(),
                    "country" => $student->getCountry(),
                    "approval_date" => $pm->getApprovalDate()
                ];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Users - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $users : $message,
        ];
 
        return new Response($serializer->serialize($users, "json", SerializationContext::create()->setGroups(array('student_list'))));
    }

    /**
     * @Rest\Post("/new", name="student_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="User was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="User was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="first_name",
     *     in="body",
     *     type="string",
     *     description="The first Name",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="last_name",
     *     in="body",
     *     type="string",
     *     description="The last name",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="username",
     *     in="body",
     *     type="string",
     *     description="The username",
     *     schema={}
     * )
     *
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="query",
     *     type="string",
     *     description="The language"
     * )
     * 
     *  * * @SWG\Parameter(
     *     name="country",
     *     in="query",
     *     type="string",
     *     description="The country code"
     * )
     * 
     * @SWG\Parameter(
     *     name="whatsapp",
     *     in="query",
     *     type="integer",
     *     description="The whatsapp"
     * )
     * 
     * @SWG\Parameter(
     *     name="city",
     *     in="query",
     *     type="string",
     *     description="The city of student"
     * )
     * 
     * @SWG\Parameter(
     *     name="modality",
     *     in="query",
     *     type="string",
     *     description="The method of participation"
     * )
     *
     * @SWG\Tag(name="Student")
     */ 
    public function newAction(Request $request, UserPasswordEncoderInterface $encoder) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";

        $user=new User();
        //Create a form
        $form=$this->createForm(StudentType::class, $user);
        $form->submit($request->request->all());

        $group = $em->getRepository('App:Groupe')->find($request->request->get('group'));
        $student = $em->getRepository('App:User')->findOneBy(array('username' => $user->getUsername()));
        $password = $request->request->get('password');
 
        try {
            $code = 200;
            $error = false;

            if (is_null($group)) {
                $code = 700;
                $error = true;
                $message = "The group does not exist";
            }
            else if(! is_null($student)){
                $code = 600;
                $error = true;
                $message = $student;
            }
            else{

                if ($group->getProgram() == 'option.program2'){
                    $user->setRoles(['ROLE_STUDENT_EMBASSADOR']);
                }
                else if ($group->getProgram() == 'option.program5'){
                    $user->setRoles(['ROLE_FACILITATOR']);
                }
                else{ 
                    $user->setRoles(['ROLE_STUDENT']);
                }

                if(! $password){
                    $password = "123"; 
                    $user->setPlainPassword($password);
                }
                
                $user->setVerifiedphone("false");
                $user->setVerifiedemail("false");
                $user->setVerifiedwhatsapp("false");
                $user->setPassword($encoder->encodePassword($user, $password));
                $em->persist($user);
                $em->flush();
    
    
                
                $sg = new StudentGroup();
                $sg->setStudent($user);
                $sg->setGroup($group);
                $em->persist($sg);
                $em->flush();
    
                //$this->sendEmailStudent("subject.new_student_created", $sg->getId());    
               
            }

            
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the user - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $user : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('student_list'))));
    }

    /**
     * @Rest\Get("/show/{id}.{_format}", name="student_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets user info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The user with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The user ID"
     * )
     *
     *
     * @SWG\Tag(name="Student")
     */
    public function showAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $user = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $student_id = $id;
            $user = $em->getRepository("App:User")->find($student_id);
 
            if (is_null($user)) {
                $code = 500;
                $error = true;
                $message = "The user does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current User - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $user : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/progress/{id}.{_format}", name="student_progress", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets users progress by group."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The group with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The group ID"
     * )
     *
     *
     * @SWG\Tag(name="Student")
     */
    public function progressAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $user = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $group_id = $id;

            $studentgroups = $em->getRepository('App:StudentGroup')->findBy(array('group' => $group_id ) );
            $studentambassadorgroups = $em->getRepository('App:StudentAmbassadorGroup')->findBy(array('group' => $group_id ) );

            $liststudentgroups = new ArrayCollection(
                array_merge($studentgroups, $studentambassadorgroups)
            );
 
            if (is_null($liststudentgroups)) {
                $code = 500;
                $error = true;
                $message = "The group does not exist";
            }
            else{
                $progressMbs = array();
                $progressSa  = array();

                foreach ($liststudentgroups as $st) {
                $programMbs = $em->getRepository('App:ProgramMbs')->findOneBy(array( 'student' => $st->getStudent()->getId() ));
                $plan = 0;
                $product = 0;
                $process = 0;
                $promotion = 0;
                $paperwork = 0;
                $price = 0;
                $service = 0;
                $quality = 0;


                        if($programMbs){
                            if(!$programMbs->getModality()){

                                $paperwork4 = json_decode(json_encode($programMbs->getPaperwork4()), true);
                                $paperwork5 = json_decode(json_encode($programMbs->getPaperwork5()), true);
                                $paperwork6 = json_decode(json_encode($programMbs->getPaperwork6()), true);
                                $paperwork7 = json_decode(json_encode($programMbs->getPaperwork7()), true);
                                $paperwork8 = json_decode(json_encode($programMbs->getPaperwork8()), true);
                                $paperwork10 = json_decode(json_encode($programMbs->getPaperwork10()), true);

                                if( $programMbs->getPlan1() )              { $plan = $plan + 50; }
                                if( $programMbs->getPlan2() )              { $plan = $plan + 50; }
                                if( $programMbs->getProduct1() )           { $product = $product + 14; }
                                if( $programMbs->getProduct2() )           { $product = $product + 14; }
                                if( $programMbs->getProduct3() )           { $product = $product + 14; }
                                if( $programMbs->getProduct4() )           { $product = $product + 14; }
                                if( $programMbs->getProduct5() )           { $product = $product + 14; }
                                if( $programMbs->getProduct6() )           { $product = $product + 14; }
                                if( $programMbs->getProduct7() )           { $product = $product + 16; }
                                if( $programMbs->getProcess1()[0] != "" )           { $process = $process + 25; }
                                if( $programMbs->getProcess2() )           { $process = $process + 25; }
                                if( $programMbs->getProcess3() )           { $process = $process + 25; }
                                if( $programMbs->getProcess4() )           { $process = $process + 25; }
                                if( $programMbs->getPrice1() )             { $price = $price + 25; }
                                if( $programMbs->getPrice2() )             { $price = $price + 25; }
                                if( $programMbs->getPrice3() )             { $price = $price + 25; }
                                if( $programMbs->getPrice4() )             { $price = $price + 25; }
                                if( $programMbs->getPaperwork1() )         { $paperwork = $paperwork + 10; }
                                if( $programMbs->getPaperwork3()[0] != "" )      { $paperwork = $paperwork + 10; }
                                if( $paperwork4['p4_balance']  != "" )      { $paperwork = $paperwork + 10; }
                                if( $paperwork5['p5_income']   != "" )       { $paperwork = $paperwork + 10; }
                                if( $paperwork6['p6_balance']  != "" )      { $paperwork = $paperwork + 10; }
                                if( $paperwork7['p7_income'][0]   != "" )       { $paperwork = $paperwork + 10; }
                                if( $paperwork8['p8_balance'][0]  != "" )      { $paperwork = $paperwork + 10; }
                                if( $paperwork10['p10_month']  != "" )      { $paperwork = $paperwork + 10; }
                                if( $paperwork10['p10_total_income_actual']  != "" )      { $paperwork = $paperwork + 10; }
                                if( $paperwork10['p10_total_expenses_plan']  != "" )      { $paperwork = $paperwork + 10; }
                                if( $programMbs->getService1() )             { $service = $service + 20; }
                                if( $programMbs->getService2() )             { $service = $service + 20; }
                                if( $programMbs->getService3() )             { $service = $service + 20; }
                                if( $programMbs->getService4() )             { $service = $service + 20; }
                                if( $programMbs->getService5() )             { $service = $service + 20; }
                                if( $programMbs->getPromotion1() )           { $promotion = $promotion + 25; }
                                if( $programMbs->getPromotion2() )           { $promotion = $promotion + 25; }
                                if( $programMbs->getPromotion3() )           { $promotion = $promotion + 25; }
                                if( $programMbs->getPromotion4() )           { $promotion = $promotion + 25; }
                                if( $programMbs->getQualityP1() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityP2() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityP3() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityP4() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityP5() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityP6() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityP7() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityP8() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityG1() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityG2() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityG3() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityG4() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityG5() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityG6() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityG7() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityG8() )            { $quality = $quality + 10; }

                                $progressMbs[] = array(
                                'name'        => $st->getStudent()->getFirstName()." ".$st->getStudent()->getLastName(),
                                'plan'        => $plan."%",
                                'product'     => $product."%",
                                'process'     => $process."%",
                                'price'       => $price."%",
                                'promotion'   => $promotion."%",
                                'paperwork'   => $paperwork."%",
                                'quality'     => $quality."%",
                                'service'     => $service."%"
                                );
                            }
                            else{
                                if($programMbs->getState() == "state.approved"){
                                    $progressMbs[]      = array(
                                        'id'          => $programMbs->getId(),
                                        'name'        => $st->getStudent()->getFirstName()." ".$st->getStudent()->getLastName(),
                                        'state'       => "edit",
                                        'complete'    =>  true,
                                        'submitted'   => "state.approved",
                                        'plan'        => "100%",
                                        'product'     => "100%",
                                        'process'     => "100%",
                                        'price'       => "100%",
                                        'promotion'   => "100%",
                                        'paperwork'   => "100%",
                                        'quality'     => "100%",
                                        'service'     => "100%",
                                    );
                                }
                                else{
                                    $progressMbs[]      = array(
                                        'id'          => $programMbs->getId(),
                                        'name'        => $st->getStudent()->getFirstName()." ".$st->getStudent()->getLastName(),
                                        'state'       => "new",
                                        'complete'    => "false",
                                        'submitted'   => "state.not_started",
                                        'plan'        => "0%",
                                        'product'     => "0%",
                                        'process'     => "0%",
                                        'price'       => "0%",
                                        'promotion'   => "0%",
                                        'paperwork'   => "0%",
                                        'quality'     => "0%",
                                        'service'     => "0%",
                                    );
                                }
                            }                              
                        }
                        else{
                            $progressMbs[] = array(
                                'name'        => $st->getStudent()->getFirstName()." ".$st->getStudent()->getLastName(),
                                'plan'        => "0%",
                                'product'     => "0%",
                                'process'     => "0%",
                                'price'       => "0%",
                                'promotion'   => "0%",
                                'paperwork'   => "0%",
                                'quality'     => "0%",
                                'service'     => "0%"
                            );
                        }




                        $programSa = $em->getRepository('App:ProgramSa')->findOneBy(array( 'student' => $st->getStudent()->getId() ));
                        $mision = 0;
                        $generate = 0;
                        $graduate = 0;
                        $facilitate = 0;
                        $graduate = 0;
                        $support = 0;                       


                        if($programSa){

                            if(!$programSa->getModality()){
                                if( $programSa->getMision1() )              { $mision = $mision + 25; }
                                if( $programSa->getMision2() )              { $mision = $mision + 25; }
                                if( $programSa->getMision3() )              { $mision = $mision + 25; }
                                if( $programSa->getMision4() )              { $mision = $mision + 25; }
                                if( $programSa->getgenerateGroups1() )           { $generate = $generate + 20; }
                                if( $programSa->getgenerateGroups2() )           { $generate = $generate + 20; }
                                if( $programSa->getgenerateGroups3() )           { $generate = $generate + 20; }
                                if( $programSa->getgenerateGroups4() )           { $generate = $generate + 20; }
                                if( $programSa->getgenerateGroups5() )           { $generate = $generate + 20; }
                                if( $programSa->getRule1() )           { $facilitate = $facilitate + 10; }
                                if( $programSa->getRule2() )           { $facilitate = $facilitate + 10; }
                                if( $programSa->getRule3() )           { $facilitate = $facilitate + 10; }
                                if( $programSa->getRule4() )           { $facilitate = $facilitate + 10; }
                                if( $programSa->getRule5() )           { $facilitate = $facilitate + 10; }
                                if( $programSa->getRule6() )           { $facilitate = $facilitate + 10; }
                                if( $programSa->getRule7() )           { $facilitate = $facilitate + 10; }
                                if( $programSa->getRule8() )           { $facilitate = $facilitate + 10; }
                                if( $programSa->getRule9() )           { $facilitate = $facilitate + 10; }
                                if( $programSa->getRule10() )           { $facilitate = $facilitate + 10; }                             
                                if( $programSa->getGraduate1() )             { $graduate = $graduate + 25; }
                                if( $programSa->getGraduate2() )             { $graduate = $graduate + 25; }
                                if( $programSa->getGraduate3() )             { $graduate = $graduate + 25; }
                                if( $programSa->getGraduate4() )             { $graduate = $graduate + 25; }                              
                                if( $programSa->getSupport1() )             { $support = $support + 25; }
                                if( $programSa->getSupport2() )             { $support = $support + 25; }
                                if( $programSa->getSupport3() )             { $support = $support + 25; }
                                if( $programSa->getSupport4() )             { $support = $support + 25; }
                               

                                $progressSa[] = array(
                                'name'          => $st->getStudent()->getFirstName()." ".$st->getStudent()->getLastName(),
                                'mision'        => $mision."%",
                                'generate'      => $generate."%",
                                'facilitate'    => $facilitate."%",   
                                'graduate'      => $graduate."%",                         
                                'support'       => $support."%"
                                );
                            }                       

                        }
                }
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current group - Error: {$ex->getMessage()}";
        }

        $data = [
            "progressMbs" => $progressMbs,
            "progressSa"  => $progressSa
        ];
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/dashboard/{id}.{_format}", name="student_dashboard", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets users dashboard by group."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The student with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The student ID"
     * )
     *
     *
     * @SWG\Tag(name="Student")
     */
    public function dashboardAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $user = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $student_id = $id;
            $student = $em->getRepository('App:User')->find($student_id);

 
            if (is_null($student)) {
                $code = 500;
                $error = true;
                $message = "The group does not exist";
            }
            else{
                $progressMbs = array();
                $progressSa  = array();

                $programMbs = $em->getRepository('App:ProgramMbs')->findOneBy(array( 'student' => $student->getId() ));

                $plan = 0;
                $product = 0;
                $process = 0;
                $promotion = 0;
                $paperwork = 0;
                $price = 0;
                $service = 0;
                $quality = 0;
                
              
                        if($programMbs){
                            if(!$programMbs->getModality()){

                                $paperwork4 = json_decode(json_encode($programMbs->getPaperwork4()), true);
                                $paperwork5 = json_decode(json_encode($programMbs->getPaperwork5()), true);
                                $paperwork6 = json_decode(json_encode($programMbs->getPaperwork6()), true);
                                $paperwork7 = json_decode(json_encode($programMbs->getPaperwork7()), true);
                                $paperwork8 = json_decode(json_encode($programMbs->getPaperwork8()), true);
                                $paperwork10 = json_decode(json_encode($programMbs->getPaperwork10()), true);

                                if( $programMbs->getPlan1() )              { $plan = $plan + 50; }
                                if( $programMbs->getPlan2() )              { $plan = $plan + 50; }
                                if( $programMbs->getProduct1() )           { $product = $product + 14; }
                                if( $programMbs->getProduct2() )           { $product = $product + 14; }
                                if( $programMbs->getProduct3() )           { $product = $product + 14; }
                                if( $programMbs->getProduct4() )           { $product = $product + 14; }
                                if( $programMbs->getProduct5() )           { $product = $product + 14; }
                                if( $programMbs->getProduct6() )           { $product = $product + 14; }
                                if( $programMbs->getProduct7() )           { $product = $product + 16; }
                                if( $programMbs->getProcess1()[0] != "" )           { $process = $process + 25; }
                                if( $programMbs->getProcess2() )           { $process = $process + 25; }
                                if( $programMbs->getProcess3() )           { $process = $process + 25; }
                                if( $programMbs->getProcess4() )           { $process = $process + 25; }
                                if( $programMbs->getPrice1() )             { $price = $price + 25; }
                                if( $programMbs->getPrice2() )             { $price = $price + 25; }
                                if( $programMbs->getPrice3() )             { $price = $price + 25; }
                                if( $programMbs->getPrice4() )             { $price = $price + 25; }
                                if( $programMbs->getPaperwork1() )         { $paperwork = $paperwork + 10; }
                                if( $programMbs->getPaperwork3()[0] != "" )      { $paperwork = $paperwork + 10; }
                                if( $paperwork4['p4_balance']  != "" )      { $paperwork = $paperwork + 10; }
                                if( $paperwork5['p5_income']   != "" )       { $paperwork = $paperwork + 10; }
                                if( $paperwork6['p6_balance']  != "" )      { $paperwork = $paperwork + 10; }
                                if( $paperwork7['p7_income'][0]   != "" )       { $paperwork = $paperwork + 10; }
                                if( $paperwork8['p8_balance'][0]  != "" )      { $paperwork = $paperwork + 10; }
                                if( $paperwork10['p10_month']  != "" )      { $paperwork = $paperwork + 10; }
                                if( $paperwork10['p10_total_income_actual']  != "" )      { $paperwork = $paperwork + 10; }
                                if( $paperwork10['p10_total_expenses_plan']  != "" )      { $paperwork = $paperwork + 10; }
                                if( $programMbs->getService1() )             { $service = $service + 20; }
                                if( $programMbs->getService2() )             { $service = $service + 20; }
                                if( $programMbs->getService3() )             { $service = $service + 20; }
                                if( $programMbs->getService4() )             { $service = $service + 20; }
                                if( $programMbs->getService5() )             { $service = $service + 20; }
                                if( $programMbs->getPromotion1() )           { $promotion = $promotion + 25; }
                                if( $programMbs->getPromotion2() )           { $promotion = $promotion + 25; }
                                if( $programMbs->getPromotion3() )           { $promotion = $promotion + 25; }
                                if( $programMbs->getPromotion4() )           { $promotion = $promotion + 25; }
                                if( $programMbs->getQualityP1() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityP2() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityP3() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityP4() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityP5() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityP6() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityP7() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityP8() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityG1() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityG2() )            { $quality = $quality + 6; } 
                                if( $programMbs->getQualityG3() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityG4() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityG5() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityG6() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityG7() )            { $quality = $quality + 6; }
                                if( $programMbs->getQualityG8() )            { $quality = $quality + 10; }

                                $total = $plan + $product + $process + $price + $promotion + $paperwork + $quality + $service;
                                if($total == 800){
                                    $complete = true;
                                }
                                else{
                                    $complete = false;
                                }

                                $progressMbs  = array(
                                'id'          => $programMbs->getId(),
                                'state'       => "edit",
                                'submitted'   => $programMbs->getState(),
                                'complete'    => $complete,
                                'plan'        => $plan."%",
                                'product'     => $product."%",
                                'process'     => $process."%",
                                'price'       => $price."%",
                                'promotion'   => $promotion."%",
                                'paperwork'   => $paperwork."%",
                                'quality'     => $quality."%",
                                'service'     => $service."%"
                                );
                            }
                            else{
                                if($programMbs->getState() == "state.approved"){
                                    $progressMbs      = array(
                                        'id'          => $programMbs->getId(),
                                        'state'       => "edit",
                                        'complete'    =>  true,
                                        'submitted'   => "state.approved",
                                        'plan'        => "100%",
                                        'product'     => "100%",
                                        'process'     => "100%",
                                        'price'       => "100%",
                                        'promotion'   => "100%",
                                        'paperwork'   => "100%",
                                        'quality'     => "100%",
                                        'service'     => "100%",
                                    );
                                }
                                else{
                                    $progressMbs      = array(
                                        'id'          => $programMbs->getId(),
                                        'state'       => "new",
                                        'complete'    => "false",
                                        'submitted'   => "state.not_started",
                                        'plan'        => "0%",
                                        'product'     => "0%",
                                        'process'     => "0%",
                                        'price'       => "0%",
                                        'promotion'   => "0%",
                                        'paperwork'   => "0%",
                                        'quality'     => "0%",
                                        'service'     => "0%",
                                    );
                                }
                            }
                                                        
                        }
                        else{
                            $progressMbs      = array(
                                'state'       => "new",
                                'complete'    => "false",
                                'submitted'   => "state.not_started",
                                'plan'        => "0%",
                                'product'     => "0%",
                                'process'     => "0%",
                                'price'       => "0%",
                                'promotion'   => "0%",
                                'paperwork'   => "0%",
                                'quality'     => "0%",
                                'service'     => "0%",
                            );
                        }




                        $programSa = $em->getRepository('App:ProgramSa')->findOneBy(array( 'student' => $student->getId() ));
                        $mision = 0;
                        $generate = 0;
                        $graduate = 0;
                        $facilitate = 0;
                        $graduate = 0;
                        $support = 0;  
                        $pilot = 0;     
                        $student_ambassador = false;
                        $complete = false;
                        
                        $studentGroup = $em->getRepository('App:StudentGroup')->findOneBy(array( 'student' => $student->getId() ));
                        $studentAmbassadorGroup = $em->getRepository('App:StudentAmbassadorGroup')->findOneBy(array( 'student' => $student->getId() ));

                        if($studentGroup){
                            if($studentGroup->getGroup()->getProgram() == "option.program3" || $studentGroup->getGroup()->getProgram() == "option.program2"){
                                $student_ambassador = true;
                            }
                        }
                        if($studentAmbassadorGroup){
                            if($studentAmbassadorGroup->getGroup()->getProgram() == "option.program3" || $studentAmbassadorGroup->getGroup()->getProgram() == "option.program2"){
                                $student_ambassador = true;
                            }
                        }

                        $groups = $em->getRepository('App:PilotGroup')->findBy(array('ambassador' => $student->getId() ));
                        $graduates = 0;

                        foreach ($groups as $group) {
                            $graduates = $graduates + count($em->getRepository('App:StudentGroup')->studentsMbsStateByGroup($group->getGroup()->getId(), "state.approved"));
                        }



                        if($programSa){

                            if(!$programSa->getModality()){
                                if( $programSa->getMision1() )              { $mision = $mision + 25; }
                                if( $programSa->getMision2() )              { $mision = $mision + 25; }
                                if( $programSa->getMision3() )              { $mision = $mision + 25; }
                                if( $programSa->getMision4() )              { $mision = $mision + 25; }
                                if( $programSa->getgenerateGroups1() )           { $generate = $generate + 20; }
                                if( $programSa->getgenerateGroups2() )           { $generate = $generate + 20; }
                                if( $programSa->getgenerateGroups3() )           { $generate = $generate + 20; }
                                if( $programSa->getgenerateGroups4() )           { $generate = $generate + 20; }
                                if( $programSa->getgenerateGroups5() )           { $generate = $generate + 20; }
                                if( $programSa->getRule1() )           { $facilitate = $facilitate + 10; }
                                if( $programSa->getRule2() )           { $facilitate = $facilitate + 10; }
                                if( $programSa->getRule3() )           { $facilitate = $facilitate + 10; }
                                if( $programSa->getRule4() )           { $facilitate = $facilitate + 10; }
                                if( $programSa->getRule5() )           { $facilitate = $facilitate + 10; }
                                if( $programSa->getRule6() )           { $facilitate = $facilitate + 10; }
                                if( $programSa->getRule7() )           { $facilitate = $facilitate + 10; }
                                if( $programSa->getRule8() )           { $facilitate = $facilitate + 10; }
                                if( $programSa->getRule9() )           { $facilitate = $facilitate + 10; }
                                if( $programSa->getRule10() )           { $facilitate = $facilitate + 10; }                             
                                if( $programSa->getGraduate1() )             { $graduate = $graduate + 25; }
                                if( $programSa->getGraduate2() )             { $graduate = $graduate + 25; }
                                if( $programSa->getGraduate3() )             { $graduate = $graduate + 25; }
                                if( $programSa->getGraduate4() )             { $graduate = $graduate + 25; }                              
                                if( $programSa->getSupport1() )             { $support = $support + 25; }
                                if( $programSa->getSupport2() )             { $support = $support + 25; }
                                if( $programSa->getSupport3() )             { $support = $support + 25; }
                                if( $programSa->getSupport4() )             { $support = $support + 25; }
                                if( $graduates != 0 )            { $pilot = 100; }


                               
                                $total = $mision + $generate + $facilitate + $graduate + $support + $pilot;
                                if($total == 600){
                                    $complete = true;
                                }
                                else{
                                    $complete =  false;
                                }

                                $progressSa     = array(
                                'id'            => $programSa->getId(),
                                'submitted'     => $programSa->getState(),
                                'state'         => "edit",
                                'complete'      => $complete,
                                'mision'        => $mision."%",
                                'generate'      => $generate."%",
                                'facilitate'    => $facilitate."%",   
                                'graduate'      => $graduate."%",                         
                                'support'       => $support."%",
                                'pilot'         => $pilot."%",
                                'student_ambassador' => $student_ambassador
                                );
                            }                       

                        }
                        else{
                            $progressSa         = array(
                                'submitted'     => "state.not_started",
                                'state'         => "new",
                                'complete'      => $complete,
                                'mision'        => $mision."%",
                                'generate'      => $generate."%",
                                'facilitate'    => $facilitate."%",   
                                'graduate'      => $graduate."%",                         
                                'support'       => $support."%",
                                'pilot'         => $pilot."%",
                                'student_ambassador' => $student_ambassador
                                );
                        }
            } 
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current group - Error: {$ex->getMessage()}";
        }

        $data = [
            "progressMbs" => $progressMbs,
            "progressSa"  => $progressSa
        ];
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="student_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The user was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the user."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The user ID"
     * )
     *
     *
     *
     * @SWG\Tag(name="Student")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $user = [];
        $message = "";

        
 
        try {
            $code = 200;
            $error = false;
            $user = $em->getRepository("App:User")->find($id);
 
            if (!is_null($user)) {
                $form = $this->createForm(UserEditType::class, $user);
                $form->submit($request->request->all());
                //$user->setName($name);
 
                $em->persist($user);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a User - Error: You must to provide fields user or the user id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the user - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $user : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/notifications/{id}.{_format}", name="student_notifications", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The user was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the user."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The user ID"
     * )
     *   
     * @SWG\Parameter(
     *     name="verifiedemail",
     *     in="path",
     *     type="string",
     *     description="State of email verification"
     * )
     * 
     * @SWG\Parameter(
     *     name="verifiedwhatsapp",
     *     in="path",
     *     type="string",
     *     description="State of whatsapp verification"
     * )
     * 
     * @SWG\Parameter(
     *     name="verifiedphone",
     *     in="path",
     *     type="string",
     *     description="State of phone verification"
     * )
     * 
     *
     *
     *
     * @SWG\Tag(name="Student")
     */
    public function notificationsAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $user = [];
        $message = "";
       
 
        try {
            $code = 200;
            $error = false;
            $user = $em->getRepository("App:User")->find($id);
 
            if (!is_null($user)) {
                $form = $this->createForm(UserNotificationsType::class, $user);
                $form->submit($request->request->all());
                //$user->setName($name);
 
                $em->persist($user);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a User - Error: You must to provide fields user or the user id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the user - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $user : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="student_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="User was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the user"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The user ID"
     * )
     *
     * @SWG\Tag(name="Student")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $user = $em->getRepository("App:User")->find($id);
            $tracking =  new Tracking();
 
            if (!is_null($user)) {

                $log = str_replace ("-0001-", "2018-", $serializer->serialize($user, "json", SerializationContext::create()->enableMaxDepthChecks() ) );
                $tracking->setUser($this->getUser());
                $tracking->setEntityId($user->getId());
                $tracking->setEntity("label_user");
                $tracking->setAction("label_delete");
                $tracking->setName($user->getFirstName()." ".$user->getLastName());
                $tracking->setLog($log);
                $em->persist($tracking);
                $em->flush();

                $em->remove($user);
                $em->flush();
 
                $message = "The user was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent user - Error: The user id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current user - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Get("/search/{key}.{_format}", name="student_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets user info based on passed key parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The user with the passed key parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="key",
     *     in="path",
     *     type="string",
     *     description="The user key"
     * )
     *
     *
     * @SWG\Tag(name="Student")
     */
    public function searchAction(Request $request, $key ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $user = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            
            $user = $em->getRepository("App:User")->userSearch($key);
            //$user = $em->getRepository("App:User")->getStudentsByName($key, 1 , 10);
 
            if (is_null($user)) {
                $code = 500;
                $error = true;
                $message = "The user does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current User - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $user : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()->setGroups(array("participant_list"))));
    }

    /**
     * @Rest\Get("/search/enrolled/{course}/{key}.{_format}", name="student_enrolled_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets user info based on passed key parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The user with the passed key parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="key",
     *     in="path",
     *     type="string",
     *     description="The user key"
     * )
     * 
     * @SWG\Parameter(
     *     name="course",
     *     in="path",
     *     type="string",
     *     description="The course id"
     * )
     *
     *
     * @SWG\Tag(name="Student")
     */
    public function searchEnrolledAction(Request $request, $course, $key ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $users = [];
        $message = "";
        $progress = 0;
        
        try {
            $code = 200;
            $error = false;
 
            
            $students = $em->getRepository("App:User")->userSearch($key);
            foreach ($students as $st) {
                $group = "";
                $ambassador = "";
                $requirements = "false";
                $date_created_at = "never";
                $st_principles = $em->getRepository("App:Progress")->studentPrinciples($course, $st->getId());
                if($st_principles > 0){
                    $total_principles = $em->getRepository("App:Principle")->principlesTotal($course);
                    $init_principle = $em->getRepository("App:Progress")->findOneBy(array('course' => $course, 'student' => $st->getId() ));
                    $progress =  round(($st_principles * 100) / $total_principles) ;
                    $date_created_at = $init_principle->getCreatedAt();
                }
               
                if($st->getStudentGroup()){
                    $group = $st->getStudentGroup()->getGroup()->getName();
                    $ambassador = $st->getStudentGroup()->getGroup()->getEmbassador()->getFirstName()." ".$st->getStudentGroup()->getGroup()->getEmbassador()->getLastName();
                }
               
                $users[] = [
                    'id'           => $st->getId(),
                    'first_name'   => $st->getFirstName(),
                    'last_name'    => $st->getLastName(),
                    'progress'     => $progress,
                    'enrolled'     => $date_created_at,
                    'ambassador'   => $ambassador,
                    'group'        => $group,
                ];
            }
 
            if (is_null($users)) {
                $code = 500;
                $error = true;
                $message = "The user does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current User - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $users : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()->setGroups(array("participant_list"))));
    }

    /**
     * @Rest\Post("/mbs", name="student_studentmbs")
     *
    * @SWG\Response(
     *     response=200,
     *     description="Gets all students."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all students."
     * )
     * 
     *  * * @SWG\Parameter(
     *     name="state",
     *     in="query",
     *     type="string",
     *     description="The state project"
     * )
     * 
     *  * * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="query",
     *     type="integer",
     *     description="The id ambassador"
     * )
     * 
     *  * * @SWG\Parameter(
     *     name="language",
     *     in="query",
     *     type="string",
     *     description="The language"
     * )
     * 
     *  * * @SWG\Parameter(
     *     name="role",
     *     in="query",
     *     type="string",
     *     description="The role user"
     * )
     *
     * @SWG\Tag(name="Student")
     */ 
    public function studentMbsAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";

        $user=new User();
        //Create a form
        $form=$this->createForm(UserType::class, $user);
        $form->submit($request->request->all());
 
        try {
            $code = 200;
            $error = false;

            $language = $request->request->get("language");
            $id_ambassador = $request->request->get("id_ambassador");
            $state = $request->request->get("state");
            $role = $request->request->get("role");
            $studentsMbs = [];
            $students = [];

            $language = explode(",", preg_replace('([^A-Za-z0-9,])', '', $language));

            if($role == "ROLE_EMBASSADOR" || $role == "ROLE_STUDENT_EMBASSADOR"){ 
                $studentsMbs1 = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassador($id_ambassador, "state.correction");
                $studentsMbs2 = $em->getRepository('App:StudentAmbassadorGroup')->studentsMbsStateByEmbassador($id_ambassador, "state.correction");

                $studentsMbs = new ArrayCollection(
                    array_merge($studentsMbs1, $studentsMbs2)
                );

            
            }
            if($role == "ROLE_ADMIN" ){
                $studentsMbs = $em->getRepository('App:StudentGroup')->studentMbsByState($state);
            }
            if($role == "ROLE_LANGUAGE_ADMIN"  || $role == "ROLE_PROJECT_QUALIFIER"){
                $studentsMbs = $em->getRepository('App:StudentGroup')->studentsMbsStateByLanguage($language, $state);
            }

            foreach ($studentsMbs as $st) {
                $students[] = [
                    'id'                        => $st->getStudent()->getId(),
                    'first_name'                => $st->getStudent()->getFirstName(),
                    'last_name'                 => $st->getStudent()->getLastName(),
                    'country'                   => $st->getStudent()->getCountry(),
                    'created_date'              => $st->getStudent()->getCreatedAt(),
                    'programmbs_id'             => $st->getStudent()->getProgrammbs()->getId(),
                    'programmbs_updated_at'     => $st->getStudent()->getProgrammbs()->getUpdatedAt(),
                    'programmbs_modality'       => $st->getStudent()->getProgrammbs()->getModality(),
                    'programmbs_version'        => $st->getStudent()->getProgrammbs()->getVersion(),
                    'group_program'             => $st->getGroup()->getProgram(),
                    'group_name'                => $st->getGroup()->getName(),
                    'ambassador_name'           => $st->getGroup()->getEmbassador()->getFirstName(). " " .$st->getGroup()->getEmbassador()->getLastName(),
                    'mbs_course'                => $this->courseProgress($st->getStudent(), 'requirement.mbs'),
                    'sa_course'                 => $this->courseProgress($st->getStudent(), 'requirement.sa'),
                    'well_course'               => $this->courseProgress($st->getStudent(), 'requirement.wellness')
                ];
            }
 
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get student list - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $students : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('future_ambassador'))));
    }

    /**
     * @Rest\Post("/ambassador", name="student_studentambassador")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all students."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all students."
     * )
     * 
     * @SWG\Parameter(
     *     name="state",
     *     in="query",
     *     type="string",
     *     description="The state project"
     * )
     * 
     * @SWG\Parameter(
     *     name="ambassador",
     *     in="query",
     *     type="integer",
     *     description="The id ambassador"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="query",
     *     type="string",
     *     description="The language"
     * )
     * 
     * @SWG\Parameter(
     *     name="role",
     *     in="query",
     *     type="string",
     *     description="The role user"
     * )
     *
     * @SWG\Tag(name="Student")
     */ 
    public function studentAmbassadorAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";

 
        try {
            $code = 200;
            $error = false;

            $language = $request->request->get("language");
            $id_ambassador = $request->request->get("ambassador");
            $state = $request->request->get("state");
            $role = $request->request->get("role");
            $studentsAmbassador = [];

            $language = explode(",", preg_replace('([^A-Za-z0-9,])', '', $language)); 

            if($role == "ROLE_EMBASSADOR" ){ 
                $studentsAmbassador1 = $em->getRepository('App:StudentGroup')->studentsAmbassadorStateByEmbassador($id_ambassador, "state.correction");
                $studentsAmbassador2 = $em->getRepository('App:StudentAmbassadorGroup')->studentsAmbassadorStateByEmbassador($id_ambassador, "state.correction");

                $studentsAmbassador = new ArrayCollection(
                    array_merge($studentsAmbassador1, $studentsAmbassador2)
                );

            
            }
            if($role == "ROLE_ADMIN" ){
                $studentsGroup = $em->getRepository('App:StudentGroup')->studentAmbassadorByState($state);
                $studentsAmbassadorGroup = $em->getRepository('App:StudentAmbassadorGroup')->studentAmbassadorByState($state);

                foreach ($studentsGroup as $key => $st) {
                    $student = $em->getRepository('App:StudentAmbassadorGroup')->findOneBy(array('student' => $st->getStudent()->getId()));
                    if($student){
                        unset($studentsGroup[$key]);
                    }
                }

                $studentsAmbassador = new ArrayCollection(
                    array_merge($studentsGroup, $studentsAmbassadorGroup )
                );

            }
            if($role == "ROLE_LANGUAGE_ADMIN" ){
                $studentsGroup = $em->getRepository('App:StudentGroup')->studentsAmbassadorStateByLanguage($language, $state);
                $studentsAmbassadorGroup = $em->getRepository('App:StudentAmbassadorGroup')->studentsAmbassadorStateByLanguage($language, $state);

                $studentsAmbassador = new ArrayCollection(
                    array_merge($studentsGroup, $studentsAmbassadorGroup )
                );
            }
 
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get student list - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $studentsAmbassador : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('future_ambassador'))));
    }

    /**
     * @Rest\Post("/wellness", name="student_wellness")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all students."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all students."
     * )
     * 
     * @SWG\Parameter(
     *     name="state",
     *     in="query",
     *     type="string",
     *     description="The state project"
     * )
     * 
     * @SWG\Parameter(
     *     name="ambassador",
     *     in="query",
     *     type="integer",
     *     description="The id ambassador"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="query",
     *     type="string",
     *     description="The language"
     * )
     * 
     * @SWG\Parameter(
     *     name="role",
     *     in="query",
     *     type="string",
     *     description="The role user"
     * )
     *
     * @SWG\Tag(name="Student")
     */ 
    public function studentWellnessAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";

 
        try {
            $code = 200;
            $error = false;

            $language = $request->request->get("language");
            $id_ambassador = $request->request->get("ambassador");
            $state = $request->request->get("state");
            $role = $request->request->get("role");
            $students = [];

            $language = explode(",", preg_replace('([^A-Za-z0-9,])', '', $language)); 

            if($role == "ROLE_ADMIN" ){
                $student_ambassador = $em->getRepository('App:Wellness')->wellnessByState($state);
            }
            if($role == "ROLE_LANGUAGE_ADMIN" ){
                $student_ambassador = $em->getRepository('App:Wellness')->wellnessByStateLanguage($state, $language);
            }

            foreach ($student_ambassador as $student) {
                $st = $student[0];
                $course = $em->getRepository('App:Course')->getCourseByRequirements($student['participant_id'], 'requirement.wellness');
                $admin = $st->getAdmin();
                $students[] = [
                    'participant_id'            => $student['participant_id'],
                    'participant_name'          => $student['participant_name'],
                    'country'                   => $student['country'],
                    'wellness_id'               => $student['id'],
                    'updated_at'                => $student['updated_at'],
                    'approval_date'             => $student['approval_date'],
                    'group_program'             => $student['group_program'],
                    'group_name'                => $student['group_name'],
                    'ambassador_name'           => $student['ambassador_name'],
                    'wellness_course'           => $course ? $course->getId() : "",
                ];
            }
 
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get student list - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $students : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('future_ambassador'))));
    }

    /**
     * @Rest\Post("/wellnessparticipant", name="student_wellness_participant")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all students."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all students."
     * )
     * 
     * @SWG\Parameter(
     *     name="state",
     *     in="query",
     *     type="string",
     *     description="The state project"
     * )
     * 
     * @SWG\Parameter(
     *     name="ambassador",
     *     in="query",
     *     type="integer",
     *     description="The id ambassador"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="query",
     *     type="string",
     *     description="The language"
     * )
     * 
     * @SWG\Parameter(
     *     name="role",
     *     in="query",
     *     type="string",
     *     description="The role user"
     * )
     *
     * @SWG\Tag(name="Student")
     */ 
    public function studentWellnessParticipantAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";

 
        try {
            $code = 200;
            $error = false;

            $language = $request->request->get("language");
            $id_ambassador = $request->request->get("ambassador");
            $state = $request->request->get("state");
            $role = $request->request->get("role");
            $students = [];

            $language = explode(",", preg_replace('([^A-Za-z0-9,])', '', $language)); 

            if($role == "ROLE_ADMIN" ){
                $student_ambassador = $em->getRepository('App:WellnessParticipant')->wellnessParticipantByState($state);
            }
            if($role == "ROLE_LANGUAGE_ADMIN" ){
                $student_ambassador = $em->getRepository('App:WellnessParticipant')->wellnessParticipantByStateLanguage($state, $language);
            }
            if($role == "ROLE_EMBASSADOR" || $role == "ROLE_STUDENT_EMBASSADOR"){ 
                $student_ambassador = $em->getRepository('App:WellnessParticipant')->wellnessParticipantByStateEmbassador($state, $id_ambassador);            
            }

            foreach ($student_ambassador as $student) {
                $st = $student[0];
                $admin = $st->getAdmin();
                $students[] = [
                    'participant_id'            => $student['participant_id'],
                    'participant_name'          => $student['participant_name'],
                    'country'                   => $student['country'],
                    'wellness_participant_id'   => $student['id'],
                    'updated_at'                => $student['updated_at'],
                    'approval_date'             => $student['approval_date'],
                    'group_program'             => $student['group_program'],
                    'group_name'                => $student['group_name'],
                    'ambassador_name'           => $student['ambassador_name'],
                ];
            }
 
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get student list - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $students : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('future_ambassador'))));
    }

    /**
     * @Rest\Post("/confirmgroup", name="student_confirmgroup")
     *
     * @SWG\Response(
     *     response=200,
     *     description="The new group was successful assigned."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to assign the new group."
     * )
     *
     * @SWG\Parameter(
     *     name="student",
     *     in="path",
     *     type="string",
     *     description="The student ID"
     * )
     *
     * @SWG\Parameter(
     *     name="group",
     *     in="path",
     *     type="string",
     *     description="The Group ID"
     * )
     *
     * @SWG\Tag(name="Student")
     */
    public function confirmGroupAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $studentAmbassadorGroup = new StudentAmbassadorGroup();
        $message = "";

        
 
        try {
            $code = 200;
            $error = false;
            $student = $em->getRepository("App:User")->find($request->request->get('student'));
            $oldGroup = $student->getStudentGroup()->getGroup()->getId();
            $newGroup = $request->request->get('group');
            $group = $em->getRepository("App:Groupe")->find($newGroup);
 
            if (!is_null($student) and !is_null($group) ) {
                
                if($oldGroup != $newGroup){
                    $studentAmbassadorGroup->setStudent($student);
                    $studentAmbassadorGroup->setGroup($group);
                    $em->persist($studentAmbassadorGroup);
                    $em->flush();
                }
                

                $student->setRoles(['ROLE_STUDENT_EMBASSADOR']);
                $em->persist($student);
                $em->flush();
 
                
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to assign the new group - Error: You must to provide fields student or the group does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to assign new group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $studentAmbassadorGroup : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/deletefutureambassador", name="student_deletefutureambassador")
     *
     * @SWG\Response(
     *     response=200,
     *     description="The student was successful delete of future ambassador list."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to delete future ambassador."
     * )
     *
     * @SWG\Parameter(
     *     name="student",
     *     in="path",
     *     type="string",
     *     description="The student ID"
     * )
     *    
     *
     * @SWG\Tag(name="Student")
     */
    public function deleteFutureAmbassadorGroupAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $message = "";

        try {
            $code = 200;
            $error = false;
            $evaluation = $em->getRepository("App:Evaluation")->findOneBy(array('student' => $request->request->get('student')));
 
            if (!is_null($evaluation)) {
                $evaluation->setPostquestion10("option2");
 
                $em->persist($evaluation);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to assign the new group - Error: You must to provide fields student or the group does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to assign new group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $evaluation : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/ambassador/all", name="student_ambassador")
     *
     * @SWG\Response(
     *     response=200,
     *     description="The list student belong to ambassador."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get list student."
     * )
     *
     * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="path",
     *     type="string",
     *     description="The ambassador ID"
     * )
     *    
     *
     * @SWG\Tag(name="Student")
     */
    public function ambassadorAllAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $message = "";
        $students = [];

        try {
            $code = 200;
            $error = false;
            $studentsGroup = $em->getRepository("App:User")->studentGroupByAmbassador($request->request->get('id_ambassador'));
            $studentsAmbassadorGroup = $em->getRepository("App:User")->studentAmbassadorGroupByAmbassador($request->request->get('id_ambassador'));  

            $students = new ArrayCollection(
                array_merge($studentsGroup, $studentsAmbassadorGroup)
            );
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to assign new group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $students : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('student_list'))));
    }

    /**
     * @Rest\Post("/futureambassador", name="student_futureambassador")
     *
    * @SWG\Response(
     *     response=200,
     *     description="Gets all students."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all students."
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description="The language Grader"
     * )
     * 
     * @SWG\Parameter(
     *     name="roles",
     *     in="path",
     *     type="string",
     *     description="The role user"
     * )
     *
     * @SWG\Tag(name="Student")
     */ 
    public function futureAmbassadorAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";

        $user=new User();
        //Create a form
        $form=$this->createForm(UserType::class, $user);
        $form->submit($request->request->all());
 
        try {
            $code = 200;
            $error = false;

            $role = $request->request->get("role");
            $lang = $request->request->get("language");

            $lang = explode(",", preg_replace('([^A-Za-z0-9,])', '', $lang));

            $futureAmbassadors = [];
            if($role == "ROLE_LANGUAGE_ADMIN"){
                $futureAmbassadors  = $em->getRepository('App:User')->futureEmbassadorsByLanguage($lang);
            }
            else{
                $futureAmbassadors  = $em->getRepository('App:User')->futureEmbassadors();
            }
            
 
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get student list - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $futureAmbassadors : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('future_ambassador'))));
    }

    /**
     * @Rest\Post("/groupswitch", name="group_switch")
     *
     * @SWG\Response(
     *     response=200,
     *     description="The new group was successful assigned."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to assign the new group."
     * )
     *
     * @SWG\Parameter(
     *     name="student",
     *     in="path",
     *     type="string",
     *     description="The student ID"
     * )
     *
     * @SWG\Parameter(
     *     name="group",
     *     in="path",
     *     type="string",
     *     description="The Group ID"
     * )
     *
     * @SWG\Tag(name="Student")
     */
    public function groupSwitchAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $message = "";

        try {
            $code = 200;
            $error = false;
            $studentGroup = $em->getRepository("App:StudentGroup")->findOneBy(array('student' => $request->request->get('student')));
            $group = $em->getRepository("App:Groupe")->find($request->request->get('group'));
            $student = $em->getRepository("App:User")->find($request->request->get('student'));
 
            if (!is_null($studentGroup) and !is_null($group)) {
                $studentGroup->setGroup($group);
 
                $em->persist($studentGroup);
                $em->flush();
 
            }
            else if(!is_null($student) and !is_null($group) and is_null($studentGroup)){

                $studentGroup = new StudentGroup();
                $studentGroup->setStudent($student);
                $studentGroup->setGroup($group);

                $em->persist($studentGroup);
                $em->flush();

            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to assign the new group - Error: You must to provide fields student or the group does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to assign new group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $studentGroup : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/groupswitch/list", name="group_switch_list")
     *
     * @SWG\Response(
     *     response=200,
     *     description="The new group was successful assigned."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to assign the new group."
     * )
     *
     * @SWG\Parameter(
     *     name="list",
     *     in="path",
     *     type="string",
     *     description="The array of student ID"
     * )
     *
     * @SWG\Parameter(
     *     name="group",
     *     in="path",
     *     type="string",
     *     description="The Group ID"
     * )
     *
     * @SWG\Tag(name="Student")
     */
    public function groupSwitchListAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $message = "";

        try {
            $code = 200;
            $error = false;
            
            $list = intval($request->request->get('list'));
            $group = $em->getRepository("App:Groupe")->find($request->request->get('group'));
            $source_group = $request->request->get('source_group');

            $studentsgroups = $em->getRepository("App:StudentGroup")->findBy(array('group' => $source_group));

            $listof = [];

            $indice = 1;

            foreach ($studentsgroups as $sg) {
                if(!$sg->getStudent()->getProgrammbs()){
                    $listof[] = $sg->getStudent();

                    if (!is_null($sg) and !is_null($group)) {
                        $sg->setGroup($group);
         
                        $em->persist($sg);
                        $em->flush();
         
                    } 
                    if($indice == $list){
                        break;
                    }
                    $indice++;
                }
              
            }

           

 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to assign new group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $listof : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()->setGroups(array('participant_list'))));
    }

    /**
     * @Rest\Post("/groupswitch/graduates/list", name="group_graduates_switch_list")
     *
     * @SWG\Response(
     *     response=200,
     *     description="The new group was successful assigned."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to assign the new group."
     * )
     *
     * @SWG\Parameter(
     *     name="list",
     *     in="path",
     *     type="string",
     *     description="The array of student ID"
     * )
     *
     * @SWG\Parameter(
     *     name="group",
     *     in="path",
     *     type="string",
     *     description="The Group ID"
     * )
     *
     * @SWG\Tag(name="Student")
     */
    public function groupSwitchGraduatesListAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $message = "";

        try {
            $code = 200;
            $error = false;
            
            $list = intval($request->request->get('list'));
            $group = $em->getRepository("App:Groupe")->find($request->request->get('group'));
            $source_group = $request->request->get('source_group');

            $studentsgroups = $em->getRepository("App:StudentGroup")->findBy(array('group' => $source_group));

            $listof = [];

            $indice = 1;

            foreach ($studentsgroups as $sg) {
                if($sg->getStudent()->getProgrammbs()){

                    if($sg->getStudent()->getProgrammbs()->getState() == "state.approved"){

                        if(!$sg->getStudent()->getProgramsa()){

                            $listof[] = $sg->getStudent();
                            if (!is_null($sg) and !is_null($group)) {
                                $sg->setGroup($group);
                                $em->persist($sg);
                                $em->flush();
                 
                            } 
                            if($indice == $list){
                                break;
                            }
                            $indice++;

                        }

                    }


                }
              
            }

           

 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to assign new group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $listof : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()->setGroups(array('participant_list'))));
    }

    /**
     * @Rest\Post("/successstorylist", name="success_story_list")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all available success stories."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all success stories."
     * )
     *
     * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="path",
     *     type="string",
     *     description="The ID of Ambassador"
     * )
     * 
     * @SWG\Parameter(
     *     name="role",
     *     in="path",
     *     type="string",
     *     description="The role of user"
     * )
     *
     *
     * @SWG\Tag(name="Student")
     */
    public function SuccessStorylistAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $students = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $role = $request->request->get('role');
            $id = $request->request->get('id_ambassador');

            if($role == 'ROLE_ADMIN' or $role == 'ROLE_LANGUAGE_ADMIN'){
                $students = $em->getRepository('App:StudentGroup')->listSuccessStory();
            }
            else if($role == 'ROLE_EMBASSADOR' or $role == 'ROLE_STUDENT_EMBASSADOR'){
                $students = $em->getRepository('App:StudentGroup')->successStoryByEmbassador($id);
            }
          
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all SuccessStory - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $students : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array("student_group"))));
    }

    /**
     * @Rest\Post("/successstorylist/pagination", name="student_successstorylist_pagination")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all groups."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all groups."
     * )
     *
     * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="path",
     *     type="string",
     *     description="The ID of Ambassador"
     * )
     * 
     * @SWG\Parameter(
     *     name="role",
     *     in="path",
     *     type="string",
     *     description="The role of user"
     * )
     *
     * @SWG\Parameter(
     *     name="keyword",
     *     in="path",
     *     type="string",
     *     description="The search keyword"
     * )
     * 
     * @SWG\Parameter(
     *     name="page",
     *     in="path",
     *     type="string",
     *     description="The search Page"
     * )
     * 
     * @SWG\Parameter(
     *     name="page_size",
     *     in="path",
     *     type="string",
     *     description="The number of records for page"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_column",
     *     in="path",
     *     type="string",
     *     description="Search order Column"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_direction",
     *     in="path",
     *     type="string",
     *     description="Search order Direction"
     * )
     *
     * @SWG\Tag(name="Student")
     */
    public function successStoryPaginationAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $students = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
            
            $id         = $request->request->get('id_ambassador');
            $keyword    = $request->request->get('keyword');
            $role       = $request->request->get('role');
            $page       = $request->request->get('page');
            $page_size = $request->request->get('page_size');
            $order_column = $request->request->get('order_column');
            $order_direction = $request->request->get('order_direction');

            if($role == 'ROLE_ADMIN' or $role == 'ROLE_LANGUAGE_ADMIN'){
                $students = $em->getRepository('App:StudentGroup')->listSuccessStoryPagination($keyword, $page, $page_size, $order_column, $order_direction);
            }
            else if($role == 'ROLE_EMBASSADOR' or $role == 'ROLE_STUDENT_EMBASSADOR'){
                $students = $em->getRepository('App:StudentGroup')->successStoryByEmbassador($id);
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $students : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('group_list'))));
    }

    /**
     * @Rest\Post("/videopromotion", name="video_promotion_statement")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all available video promotion."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all videos promotion."
     * )
     *
     *
     * @SWG\Tag(name="Student")
     */
    public function videoPromotionAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $students = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;

            $students = $em->getRepository('App:StudentGroup')->videoPromotionStatement();
          
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all SuccessStory - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $students : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array("student_group"))));
    }

    public function requirementMbsProgress($programMbs, $evaluation){

        $business = 0;
        $business_budget = 0;
        $income_expense = 0;
        $income_statement = 0;
        $quality_life = 0;
        $success_story = 100;
        $service = 0;
        $checklist = 0;
        $post_evaluation = 0;
        $money_management = 0;

        $paperwork4 = json_decode(json_encode($programMbs->getPaperwork4()), true);
        $paperwork5 = json_decode(json_encode($programMbs->getPaperwork5()), true);
        $paperwork6 = json_decode(json_encode($programMbs->getPaperwork6()), true);
        $paperwork7 = json_decode(json_encode($programMbs->getPaperwork7()), true);
        $paperwork8 = json_decode(json_encode($programMbs->getPaperwork8()), true);
        $paperwork10 = json_decode(json_encode($programMbs->getPaperwork10()), true);

        if( $programMbs->getPlan1() )              { $business = $business + 6; }
        if( $programMbs->getPlan2() )              { $business = $business + 6; }
        if( $programMbs->getPlan3() )              { $business = $business + 6; }
        
        if( $programMbs->getProduct1() )           { $business = $business + 6; }
        if( $programMbs->getProduct2() )           { $business = $business + 6; }
        if( $programMbs->getProduct3() )           { $business = $business + 6; }
        if( $programMbs->getProduct4() )           { $business = $business + 6; }

        if( $programMbs->getPrice1() )             { $business = $business + 6; }
        if( $programMbs->getPrice2() )             { $business = $business + 6; }
        if( $programMbs->getPrice3() )             { $business = $business + 6; }
        if( $programMbs->getPrice4() )             { $business = $business + 6; }

        if( $programMbs->getProcess1()[0] != "" )  { $business = $business + 6; }
        if( $programMbs->getProcess2() )           { $business = $business + 6; }

        if( $programMbs->getPromotion1() )             { $business = $business + 3; }
        if( $programMbs->getPromotion2() )             { $business = $business + 3; }
        if( $programMbs->getPromotion3() )             { $business = $business + 3; }
        if( $programMbs->getPromotion5() )             { $business = $business + 3; }
        if( $programMbs->getPromotion8() )             { $business = $business + 3; }
        if( $programMbs->getPromotion9() )             { $business = $business + 3; }
        if( $programMbs->getPromotion10() )             { $business = $business + 4; }

        if( $programMbs->getChecklist()[0] != "" ){ 
            $num = count($programMbs->getChecklist());
            if($num >= 8){
                $checklist = 100;
            }
            else{
                $checklist = $num * 12;
            }             
        }

        $num = 0;
        foreach ($paperwork7['p7_income'] as $value) {
            if($value != ""){
                $num++;
            }
        }
        if( $paperwork7['p7_income'][0] != "" || $num > 1){ 
            
            if($num >= 4){
                $business_budget = $business_budget + 15;
            }
            else{
                $business_budget = $business_budget + ($num * 4);
            }             
        }

        $num = 0;
        foreach ($paperwork8['p8_expenses'] as $value) {
            if($value != ""){
                $num++;
            }
        }
        if( $paperwork8['p8_expenses'][0] != "" || $num > 1){ 
            
            if($num >= 4){
                $business_budget = $business_budget + 15;
            }
            else{
                $business_budget = $business_budget + ($num * 4);
            }             
        }

        $num = 0;
        foreach ($paperwork8['p8_earnings_loses'] as $value) {
            if($value != ""){
                $num++;
            }
        }
        if( $paperwork8['p8_earnings_loses'][0] != "" || $num > 1){ 
            
            if($num >= 4){
                $business_budget = $business_budget + 15;
            }
            else{
                $business_budget = $business_budget + ($num * 4);
            }             
        }

        $num = 0;
        foreach ($paperwork8['p8_opening_balance'] as $value) {
            if($value != ""){
                $num++;
            }
        }
        if( $paperwork8['p8_opening_balance'][0] != "" || $num > 1){ 
            
            if($num >= 4){
                $business_budget = $business_budget + 15;
            }
            else{
                $business_budget = $business_budget + ($num * 4);
            }             
        }

        $num = 0;
        foreach ($paperwork8['p8_profit_loss_balance'] as $value) {
            if($value != ""){
                $num++;
            }
        }
        if( $paperwork8['p8_profit_loss_balance'][0] != "" || $num > 1){ 
            
            if($num >= 4){
                $business_budget = $business_budget + 15;
            }
            else{
                $business_budget = $business_budget + ($num * 4);
            }             
        }

        $num = 0;
        foreach ($paperwork8['p8_ending_balance'] as $value) {
            if($value != ""){
                $num++;
            }
        }
        if( $paperwork8['p8_ending_balance'][0] != "" || $num > 1){ 
            
            if($num >= 4){
                $business_budget = $business_budget + 25;
            }
            else{
                $business_budget = $business_budget + ($num * 4);
            }             
        }


        if( $paperwork4['p4_balance']  != "" )              { $income_expense = $income_expense + 50; }
        if( $paperwork4['p4_initial_capital']  != "" )      { $income_expense = $income_expense + 50; }
        
        if( $paperwork5['p5_income']    != "" )              { $income_statement = $income_statement + 33; }
        if( $paperwork6['p6_expenses']  != "" )              { $income_statement = $income_statement + 33; }
        if( $paperwork6['p6_earnings_loses']  != "" )        { $income_statement = $income_statement + 34; }

        if( $paperwork10['p10_total_expenses_plan']  != "" )        { $money_management = $money_management + 20; }
        if( $paperwork10['p10_total_expenses_actual']  != "" )      { $money_management = $money_management + 20; }
        if( $paperwork10['p10_total_income_plan']  != "" )          { $money_management = $money_management + 20; }
        if( $paperwork10['p10_total_income_actual']  != "" )        { $money_management = $money_management + 20; }
        if( $programMbs->getPaperwork17() )                         { $money_management = $money_management + 10; }
        if( $programMbs->getPaperwork18() )                         { $money_management = $money_management + 10; }

        if( ! is_null( $evaluation->getPostquestion1() ) && $evaluation->getPostquestion1() != "undefined")      { $post_evaluation = $post_evaluation + 10; }
        if( ! is_null( $evaluation->getPostquestion2() ) && $evaluation->getPostQuestion2() != "undefined")      { $post_evaluation = $post_evaluation + 10; }
        if( ! is_null( $evaluation->getPostquestion3() ) && $evaluation->getPostQuestion3() != "undefined")      { $post_evaluation = $post_evaluation + 10; }
        if( ! is_null( $evaluation->getPostquestion4() ) && $evaluation->getPostQuestion4() != "undefined")      { $post_evaluation = $post_evaluation + 10; }
        if( ! is_null( $evaluation->getPostquestion5() ) && $evaluation->getPostQuestion5() != "undefined")      { $post_evaluation = $post_evaluation + 10; }
        if( ! is_null( $evaluation->getPostquestion6() ) && $evaluation->getPostQuestion6() != "undefined")      { $post_evaluation = $post_evaluation + 10; }
        if( ! is_null( $evaluation->getPostquestion7() ) && $evaluation->getPostQuestion7() != "undefined")      { $post_evaluation = $post_evaluation + 10; }
        if( ! is_null( $evaluation->getPostquestion8() ) && $evaluation->getPostQuestion8() != "undefined")      { $post_evaluation = $post_evaluation + 10; }
        if( ! is_null( $evaluation->getPostquestion9() ) && $evaluation->getPostQuestion9() != "undefined")      { $post_evaluation = $post_evaluation + 20; }



        if( $programMbs->getQualityP1() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP2() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP3() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP4() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP5() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP6() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP7() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP8() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG1() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG2() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG3() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG4() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG5() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG6() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG7() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG8() )            { $quality_life = $quality_life + 10; }

        if( $programMbs->getService1() )             { $service = $service + 20; }
        if( $programMbs->getService2() )             { $service = $service + 20; }
        if( $programMbs->getService4() )             { $service = $service + 20; }
        if( $programMbs->getService5() )             { $service = $service + 20; }
        if( $programMbs->getService6() )             { $service = $service + 20; }

        $total =  $business + $business_budget + $income_expense + $income_statement + $quality_life + $success_story + $service + $checklist + $post_evaluation + $money_management;
        
        return $total / 10;

    }

    public function mbsProgress($programMbs){

        $plan = 0;
        $product = 0;
        $process = 0;
        $promotion = 0;
        $paperwork = 0;
        $price = 0;
        $service = 0;
        $quality_life = 0;

        $paperwork4 = json_decode(json_encode($programMbs->getPaperwork4()), true);
        $paperwork5 = json_decode(json_encode($programMbs->getPaperwork5()), true);
        $paperwork6 = json_decode(json_encode($programMbs->getPaperwork6()), true);
        $paperwork7 = json_decode(json_encode($programMbs->getPaperwork7()), true);
        $paperwork8 = json_decode(json_encode($programMbs->getPaperwork8()), true);
        $paperwork10 = json_decode(json_encode($programMbs->getPaperwork10()), true);

        if( $programMbs->getPlan1() )              { $plan = $plan + 50; }
        if( $programMbs->getPlan2() )              { $plan = $plan + 50; }
        if( $programMbs->getProduct1() )           { $product = $product + 14; }
        if( $programMbs->getProduct2() )           { $product = $product + 14; }
        if( $programMbs->getProduct3() )           { $product = $product + 14; }
        if( $programMbs->getProduct4() )           { $product = $product + 14; }
        if( $programMbs->getProduct5() )           { $product = $product + 14; }
        if( $programMbs->getProduct6() )           { $product = $product + 14; }
        if( $programMbs->getProduct7() )           { $product = $product + 16; }
        if( $programMbs->getProcess1()[0] != "" )  { $process = $process + 25; }
        if( $programMbs->getProcess2() )           { $process = $process + 25; }
        if( $programMbs->getProcess3() )           { $process = $process + 25; }
        if( $programMbs->getProcess4() )           { $process = $process + 25; }
        if( $programMbs->getPrice1() )             { $price = $price + 25; }
        if( $programMbs->getPrice2() )             { $price = $price + 25; }
        if( $programMbs->getPrice3() )             { $price = $price + 25; }
        if( $programMbs->getPrice4() )             { $price = $price + 25; }
        if( $programMbs->getPaperwork1() )         { $paperwork = $paperwork + 10; }
        if( $programMbs->getPaperwork3()[0] != "" )      { $paperwork = $paperwork + 10; }
        if( isset($paperwork4['p4_balance']) )      { $paperwork4['p4_balance']  != "" ? ($paperwork = $paperwork + 10) : ""; }
        if( isset($paperwork5['p5_income'])  )      { $paperwork5['p5_income']   != "" ? ($paperwork = $paperwork + 10) : ""; }
        if( isset($paperwork6['p6_balance']) )      { $paperwork6['p6_balance']  != "" ? ($paperwork = $paperwork + 10) : ""; }
        if( isset($paperwork7['p7_income'])  )   { $paperwork7['p7_income'][0]   != "" ? ($paperwork = $paperwork + 10) : ""; }
        if( isset($paperwork8['p8_balance']) )   { $paperwork8['p8_balance'][0]  != "" ? ($paperwork = $paperwork + 10) : ""; }
        if( isset($paperwork10['p10_month']) )      { $paperwork10['p10_month']  != "" ? ($paperwork = $paperwork + 10) : ""; }
        if( isset($paperwork10['p10_total_income_actual']) )      { $paperwork10['p10_total_income_actual']  != "" ? ($paperwork = $paperwork + 10) : ""; }
        if( isset($paperwork10['p10_total_expenses_plan']) )      { $paperwork10['p10_total_expenses_plan']  != "" ? ($paperwork = $paperwork + 10) : ""; }
        if( $programMbs->getService1() )             { $service = $service + 20; }
        if( $programMbs->getService2() )             { $service = $service + 20; }
        if( $programMbs->getService3() )             { $service = $service + 20; }
        if( $programMbs->getService4() )             { $service = $service + 20; }
        if( $programMbs->getService5() )             { $service = $service + 20; }
        if( $programMbs->getPromotion1() )           { $promotion = $promotion + 25; }
        if( $programMbs->getPromotion2() )           { $promotion = $promotion + 25; }
        if( $programMbs->getPromotion3() )           { $promotion = $promotion + 25; }
        if( $programMbs->getPromotion4() )           { $promotion = $promotion + 25; }
        if( $programMbs->getQualityP1() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP2() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP3() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP4() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP5() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP6() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP7() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityP8() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG1() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG2() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG3() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG4() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG5() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG6() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG7() )            { $quality_life = $quality_life + 6; }
        if( $programMbs->getQualityG8() )            { $quality_life = $quality_life + 10; }

        return $plan + $product + $process +  $promotion +  $paperwork +  $price +  $service + $quality_life ;

    }

    public function saProgress($programSa){
        $mision = 0;
        $generate = 0;
        $graduate = 0;
        $facilitate = 0;
        $graduate = 0;
        $support = 0;                       


        if($programSa){
            $em = $this->getDoctrine()->getManager();
            $groups = $em->getRepository('App:PilotGroup')->findBy(array('ambassador' => $programSa->getStudent()->getId() ));
            $graduates = 0;

            foreach ($groups as $group) {
                $graduates = $graduates + count($em->getRepository('App:StudentGroup')->studentsMbsStateByGroup($group->getGroup()->getId(), "state.approved"));
            }

            if(!$programSa->getModality()){
                if( $programSa->getMision1() )              { $mision = $mision + 25; }
                if( $programSa->getMision2() )              { $mision = $mision + 25; }
                if( $programSa->getMision3() )              { $mision = $mision + 25; }
                if( $programSa->getMision4() )              { $mision = $mision + 25; }
                if( $programSa->getgenerateGroups1() )           { $generate = $generate + 20; }
                if( $programSa->getgenerateGroups2() )           { $generate = $generate + 20; }
                if( $programSa->getgenerateGroups3() )           { $generate = $generate + 20; }
                if( $programSa->getgenerateGroups4() )           { $generate = $generate + 20; }
                if( $programSa->getgenerateGroups5() )           { $generate = $generate + 20; }
                if( $programSa->getRule1() )           { $facilitate = $facilitate + 10; }
                if( $programSa->getRule2() )           { $facilitate = $facilitate + 10; }
                if( $programSa->getRule3() )           { $facilitate = $facilitate + 10; }
                if( $programSa->getRule4() )           { $facilitate = $facilitate + 10; }
                if( $programSa->getRule5() )           { $facilitate = $facilitate + 10; }
                if( $programSa->getRule6() )           { $facilitate = $facilitate + 10; }
                if( $programSa->getRule7() )           { $facilitate = $facilitate + 10; }
                if( $programSa->getRule8() )           { $facilitate = $facilitate + 10; }
                if( $programSa->getRule9() )           { $facilitate = $facilitate + 10; }
                if( $programSa->getRule10() )          { $facilitate = $facilitate + 10; }                             
                if( $programSa->getGraduate1() )       { $graduate = $graduate + 25; }
                if( $programSa->getGraduate2() )       { $graduate = $graduate + 25; }
                if( $programSa->getGraduate3() )       { $graduate = $graduate + 25; }
                if( $programSa->getGraduate4() )       { $graduate = $graduate + 25; }                              
                if( $programSa->getSupport1() )        { $support = $support + 25; }
                if( $programSa->getSupport2() )        { $support = $support + 25; }
                if( $programSa->getSupport3() )        { $support = $support + 25; }
                if( $programSa->getSupport4() )        { $support = $support + 25; }
                if( $graduates != 0 )                  { $pilot = 100; }
    
                $total = $mision + $generate + $facilitate + $graduate + $support + $pilot;
                
            }
            else{
    
                $total = 600;
    
            }                       

        }

        return $total;
    }

    public function wellProgress($wellness){

        $ambassador_skills = 0;
        $pilot_group = 0;
        $plans_future = 0;
        $conclusions = 0;


        if( $wellness->getWellness1() )              { $ambassador_skills = $ambassador_skills + 50; }
        if( $wellness->getWellness2() )              { $ambassador_skills = $ambassador_skills + 50; }
        if( $wellness->getWellness3() )              { $pilot_group = 100; }
        if( $wellness->getWellness4() )              { $plans_future = $plans_future + 33; }
        if( $wellness->getWellness5() )              { $plans_future = $plans_future + 33; }
        if( $wellness->getWellness6() )              { $plans_future = $plans_future + 34; }
        if( $wellness->getWellness7() )              { $conclusions = 100; }

        return  $ambassador_skills + $pilot_group + $plans_future + $conclusions;

    }

    public function courseProgress($student, $requirements){
        $em = $this->getDoctrine()->getManager();
        $progress = 0;
        $course_id = "";
        $course = $em->getRepository("App:Course")->findOneBy(array("language" => $student->getLanguage() , "requirements" => $requirements, "state" => 'state.published') );
        if(! is_null($course)){
            $st_principles = $em->getRepository("App:Progress")->studentPrinciples($course->getId(), $student->getId());
            $total_principles = $em->getRepository("App:Principle")->principlesTotal($course->getId());
            if($total_principles < 1){
                $progress =  0;
            }else{
                $progress =  round(($st_principles * 100) / $total_principles) ;
            }
            if($progress > 100){
                $progress = 100;
            }
            
            $course_id = $course->getId();
        }

        return  [
            'course_id'   => $course_id,
            'progress'    => $progress
        ];

    }

    

    
}