<?php

 
namespace App\Controller;
 
use App\Entity\Tracking;
use App\Entity\User;
use App\Form\TrackingType;
use App\Form\TrackingEditType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\UserDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class TrackingController
 *
 * @Route("/tracking")
 */
class TrackingController extends FOSRestController
{
    
    /**
     * @Rest\Get("/", name="tracking_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all Trackings."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all Trackings."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="Tracking ID"
     * )
     *
     *
     * @SWG\Tag(name="Tracking")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $trackings = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $trackings = $em->getRepository("App:Tracking")->findBy(array(), array("createdAt" => "DESC"));
 
            if (is_null($trackings)) {
                $Trackings = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Tracking - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $trackings : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()->setGroups(array("tracking_list"))));
    }

     /**
     * @Rest\Post("/new", name="tracking_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Tracking was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Tracking was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="group_id",
     *     in="body",
     *     type="string",
     *     description="The ID Group",
     *     schema={}
     * )
     *       
     * 
     * @SWG\Parameter(
     *     name="content",
     *     in="body",
     *     type="string",
     *     description="The content",
     *     schema={}
     * )     
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="string",
     *     description="language tracking",
     *     schema={}
     * )
     * 
     *  @SWG\Parameter(
     *     name="type",
     *     in="body",
     *     type="integer",
     *     description="The type of the tracking",
     *     schema={}
     * )
     * 
     *    
     * 
     * @SWG\Tag(name="Tracking")
     */ 

    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $message = "";

        
        $type = $request->request->get("type");

        

        if($type === "group"){
            $group_id= $request->request->get("group_id");
            $tracking = $em->getRepository("App:Tracking")->findOneBy(array("group" => $group_id));
            if (is_null($tracking)) {
                $tracking=new Tracking();
                
                $group = $em->getRepository("App:Groupe")->find($group_id);
                $tracking->setGroup($group);
            } 
        }
        else{
            $tracking=new Tracking();
        }

        
        //Create a form
        $form=$this->createForm(TrackingType::class, $tracking);
        $form->submit($request->request->all());
        


        try {
            $code = 200;
            $error = false;

            $em->persist($tracking);
            $em->flush();
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Tracking - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $tracking : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/show/{id}.{_format}", name="Tracking_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Tracking info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Tracking with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Tracking ID"
     * )
     *
     * @SWG\Tag(name="Tracking")
     */
    public function showAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $tracking = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $tracking_id = $id;
            $tracking = $em->getRepository("App:Tracking")->find($tracking_id);
            $user =  $serializer->deserialize($tracking->getLog(), User::class, "json" );
 
            if (is_null($tracking)) {
                $code = 500;
                $error = true;
                $message = "The Tracking does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Tracking- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $user : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    } 

    /**
     * @Rest\Get("/show/group/{id}.{_format}", name="Tracking_group_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Tracking info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Tracking with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Tracking ID"
     * )
     *
     * @SWG\Tag(name="Tracking")
     */
    public function showGroupAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $tracking = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $tracking = $em->getRepository("App:Tracking")->findOneBy(array("group" => $id));
 
            if (is_null($tracking)) {
                $code = 500;
                $error = true;
                $message = "The Tracking does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Tracking- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $tracking : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="Tracking_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The Tracking was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the Tracking."
     * )
     *
     * @SWG\Parameter(
     *     name="group_id",
     *     in="body",
     *     type="string",
     *     description="The ID Group",
     *     schema={}
     * )
     *       
     * 
     * @SWG\Parameter(
     *     name="content",
     *     in="body",
     *     type="string",
     *     description="The content",
     *     schema={}
     * )     
     * 
     *  @SWG\Parameter(
     *     name="type",
     *     in="body",
     *     type="integer",
     *     description="The type of the tracking",
     *     schema={}
     * )
     *    
     * 
     *
     * @SWG\Tag(name="Tracking")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $tracking = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $tracking = $em->getRepository("App:Tracking")->find($id);
 
            if (!is_null($tracking)) {
                $form = $this->createForm(TrackingEditType::class, $tracking);
                $form->submit($request->request->all());
                //$curse->setName($name);
 
                $em->persist($tracking);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Tracking - Error: You must to provide fields user or the Tracking id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the Tracking - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $tracking : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }


     
 
}