<?php
 
namespace App\Controller;
 
use App\Entity\Transfer;
use App\Form\TransferType;
use App\Form\TransferEditType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\UserDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class TransferController
 *
 * @Route("/transfer")
 */
class TransferController extends FOSRestController
{

     /**
     * @Rest\Get("/", name="transfer_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all transfers."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all transfers."
     * )
     *   
     *
     *
     * @SWG\Tag(name="Transfer")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $transfers = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            //$transfers = $em->getRepository("App:Transfer")->findAll();
 
            if (is_null($transfers)) {
                $transfers = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Transfer - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $transfers : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }
    
   
     /**
     * @Rest\Post("/new", name="Transfer_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Transfer was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Transfer was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="body",
     *     type="string",
     *     description="Id Ambassador",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The name of Transfer",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="bankName",
     *     in="body",
     *     type="string",
     *     description="The bank name",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="swiftCode",
     *     in="body",
     *     type="string",
     *     description="The swift code",
     *     schema={}
     * )
     *    
     * 
     * @SWG\Parameter(
     *     name="accountNumber",
     *     in="body",
     *     type="string",
     *     description="The account number",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="type",
     *     in="body",
     *     type="string",
     *     description="type of account",
     *     schema={}
     * )
     * 
     * 
     *    
     * @SWG\Tag(name="Transfer")
     */ 

    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";
        $id_ambassador = $request->request->get('id_ambassador');
        $transfer=new Transfer();
        //Create a form
        $form=$this->createForm(TransferType::class, $transfer);
        $form->submit($request->request->all());
        
        
        try {
            $code = 200;
            $error = false;

            $ambassador = $em->getRepository("App:User")->find($id_ambassador);
 
            if (is_null($ambassador)) {
                $code = 500;
                $error = true;
                $message = "The Ambassador does not exist";
            }
            else{
                $transfer->setStudent($ambassador);              
                $em->persist($transfer);
                $em->flush();
            }

            
  
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Transfer - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $transfer : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/show/{id}.{_format}", name="transfer_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets transfer info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The transfer with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Transfer ID"
     * )
     *
     * @SWG\Tag(name="Transfer")
     */
    public function showAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $transfer = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $transfer_id = $id;
            $transfer = $em->getRepository("App:Transfer")->findOneBy(array("student" => $transfer_id));
 
            if (is_null($transfer)) {
                $code = 500;
                $error = true;
                $message = "The Transfer does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Transfer- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $transfer : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="transfer_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The transfer was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the transfer."
     * )
     *
     * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="body",
     *     type="string",
     *     description="Id Ambassador",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The name of Transfer",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="bankName",
     *     in="body",
     *     type="string",
     *     description="The bank name",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="swiftCode",
     *     in="body",
     *     type="string",
     *     description="The swift code",
     *     schema={}
     * )
     *    
     * 
     * @SWG\Parameter(
     *     name="accountNumber",
     *     in="body",
     *     type="string",
     *     description="The account number",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="type",
     *     in="body",
     *     type="string",
     *     description="type of account",
     *     schema={}
     * )
     *
     * @SWG\Tag(name="Transfer")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $transfer = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $transfer = $em->getRepository("App:Transfer")->findOneBy(array("student" => $id));
 
            if (!is_null($transfer)) {
                $form = $this->createForm(TransferType::class, $transfer);
                $form->submit($request->request->all());

                $em->persist($transfer);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a transfer - Error: You must to provide fields user or the transfer id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the transfer - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $transfer : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="transfer_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="transfer was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the transfer"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Transfer ID"
     * )
     *
     * @SWG\Tag(name="Transfer")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $students = 0;
 
        try {
            $code = 200;
            $error = false;
            $transfer = $em->getRepository("App:Transfer")->find($id);
            $certificates = $em->getRepository("App:StudentTransfer")->studentsMbsStateByTransfer($transfer->getId(), "state.approved"); 
 
            if (!is_null($transfer) && count($certificates) == 0 ) {
                $students = $em->getRepository("App:User")->deleteStudentByTransfer($transfer->getId());
                $em->remove($transfer);
                $em->flush();
                
 
                $message = "The transfer was removed successfully!";
 
            } else {
                $code = 400;
                $error = true;
                $message = "An error has occurred trying to remove the currrent transfer - Error: The transfer id does not exist or this transfer have Certified Students";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current transfer - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => count($certificates),
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

   

}