<?php
 
namespace App\Controller;
 
use App\Entity\User;
use App\Entity\Translation;
use App\Form\TranslationType;
use App\Form\TranslationEditType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\AdminDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class TranslationController
 *
 * @Route("/translation")
 */
class TranslationController extends FOSRestController
{
    
 
    /**
     * @Rest\Get("/", name="translation_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all translations."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all translation translations."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Translation")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $translations = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $translations = $em->getRepository("App:Translation")->findBy(array(), array('label' => 'ASC'));
 
            if (is_null($translations)) {
                $translations = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Admins - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $translations : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array("translation_list"))));
    }

    /**
     * @Rest\Get("/languages", name="translation_languages", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all translations."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all translation translations."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Translation")
     */
    public function languagesAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $translations = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $list = $em->getRepository("App:Translation")->findBy(array('language' => 'en'), array('label' => 'ASC'));
            foreach ($list as $trans) {

                $en_state = "updated";
                $es_state = "missing";
                $pt_state = "missing";
                $zh_state = "missing";
                $fr_state = "missing";
                $general_state = "updated";

                $en_tr = $em->getRepository("App:Translation")->findOneBy(array('label' => $trans->getLabel(), 'language' => 'en'), array('label' => 'ASC'));
                $es_tr = $em->getRepository("App:Translation")->findOneBy(array('label' => $trans->getLabel(), 'language' => 'es'), array('label' => 'ASC'));
                $pt_tr = $em->getRepository("App:Translation")->findOneBy(array('label' => $trans->getLabel(), 'language' => 'pt'), array('label' => 'ASC'));
                $zh_tr = $em->getRepository("App:Translation")->findOneBy(array('label' => $trans->getLabel(), 'language' => 'zh'), array('label' => 'ASC'));
                $fr_tr = $em->getRepository("App:Translation")->findOneBy(array('label' => $trans->getLabel(), 'language' => 'fr'), array('label' => 'ASC'));

                if($es_tr){
                    if($en_tr->getUpdatedAt() > $es_tr->getUpdatedAt()){
                        $es_state = "outdated";
                    }
                    else{
                        $es_state = "updated";
                    }
                }

                if($pt_tr){
                    if($en_tr->getUpdatedAt() > $pt_tr->getUpdatedAt()){
                        $pt_state = "outdated";
                    }
                    else{
                        $pt_state = "updated";
                    }
                }

                if($fr_tr){
                    if($en_tr->getUpdatedAt() > $fr_tr->getUpdatedAt()){
                        $fr_state = "outdated";
                    }
                    else{
                        $fr_state = "updated";
                    }
                }

                if($zh_tr){
                    if($en_tr->getUpdatedAt() > $zh_tr->getUpdatedAt()){
                        $zh_state = "outdated";
                    }
                    else{
                        $zh_state = "updated";
                    }
                }

                if($es_state != "updated" || $pt_state != "updated" || $fr_state != "updated" || $zh_state != "updated"){
                    $general_state = "pending";
                }

                $translations[] = [
                    'label' => $en_tr->getLabel(),
                    'en_id' => $en_tr ? $en_tr->getId() : "undefined",                    
                    'es_id' => $es_tr ? $es_tr->getId() : "undefined",
                    'pt_id' => $pt_tr ? $pt_tr->getId() : "undefined",
                    'zh_id' => $zh_tr ? $zh_tr->getId() : "undefined",
                    'fr_id' => $fr_tr ? $fr_tr->getId() : "undefined",
                    'en_description' => $en_tr ? $en_tr->getDescription() : "undefined",                    
                    'es_description' => $es_tr ? $es_tr->getDescription() : "undefined",
                    'pt_description' => $pt_tr ? $pt_tr->getDescription() : "undefined",
                    'zh_description' => $zh_tr ? $zh_tr->getDescription() : "undefined",
                    'fr_description' => $fr_tr ? $fr_tr->getDescription() : "undefined",
                    'en_update' => $en_tr ? $en_tr->getUpdatedAt() : "undefined",                    
                    'es_update' => $es_tr ? $es_tr->getUpdatedAt() : "undefined",
                    'pt_update' => $pt_tr ? $pt_tr->getUpdatedAt() : "undefined",
                    'zh_update' => $zh_tr ? $zh_tr->getUpdatedAt() : "undefined",
                    'fr_update' => $fr_tr ? $fr_tr->getUpdatedAt() : "undefined",
                    'en_state' => $en_state,                    
                    'es_state' => $es_state,
                    'pt_state' => $pt_state,
                    'zh_state' => $zh_state,
                    'fr_state' => $fr_state,
                    'general_state' => $general_state
                    
                ];
            }
           
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Admins - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $translations : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array("translation_list"))));
    }

 

    /**
     * @Rest\Post("/new", name="translation_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="User was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="User was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="label",
     *     in="body",
     *     type="string",
     *     description="The translation label",
     *     schema={}
     * )
     *      
     *
     * @SWG\Parameter(
     *     name="user_id",
     *     in="body",
     *     type="integer",
     *     description="The Admin id of the new Label",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="string",
     *     description="The translation Language",
     *     schema={}
     * )
     *
     *      
     *
     * @SWG\Tag(name="Translation")
     */ 
    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";

        $translation = new Translation();
        //Create a form
        $form=$this->createForm(TranslationType::class, $translation);
        $form->submit($request->request->all());
        $admin = $em->getRepository("App:User")->find($request->request->get('user_id'));

        $tr = $em->getRepository("App:Translation")->findOneBy(array('label' => $translation->getLabel(), 'language' => $translation->getLanguage()));
       
        try {

            if(!is_null($admin) && is_null($tr)){
                $code = 200;
                $error = false;
                $translation->setAdmin($admin);
                $em->persist($translation);
                $em->flush();
            }
            else{
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to register the translation, this label/language already exist";
            }
            
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the translation - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $translation : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }


    /**
     * @Rest\Get("/show/{id}.{_format}", name="translation_show_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets translation info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The translation with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Translation ID"
     * )
     * 
     *
     * @SWG\Tag(name="Translation")
     */
    public function showAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $translation = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $translation_id = $id;
            $translation = $em->getRepository("App:Translation")->find($translation_id);
 
            if (is_null($translation)) {
                $code = 500;
                $error = true;
                $message = "The Translation does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Translation- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $translation : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Get("/show/pending/{language}.{_format}", name="translation_show_language", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets translation info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The translation with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Translation ID"
     * )
     * 
     *
     * @SWG\Tag(name="Translation")
     */
    public function showPendingAction(Request $request, $language ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $translation = [];
        $message = "";
        $label = "undefined";
        $state = "updated";
        
        try {
            $code = 200;
            $error = false;
 
            $en_translations = $translation = $em->getRepository("App:Translation")->findBy(array("language" => "en"));
            foreach ($en_translations as $tr) {
                $label = "undefined";
                $state = "updated";                
                $translation = $em->getRepository("App:Translation")->findOneBy(array("label" => $tr->getLabel(), "language" => $language));
                if (is_null($translation)) {
                    $label = $tr;
                    $state = "missing";    
                    break; 
                }
                else{
                    if($tr->getUpdatedAt() > $translation->getUpdatedAt()){
                        $label = $translation;
                        $state = "outdated";
                        break;
                    }
                }
            }

            $data = [
                "state" => $state,
                "label" => $label                
            ];
            
 
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Translation- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }


    /**
     * @Rest\Get("/show/list/{language}.{_format}", name="translation_show_list_language", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets translation info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The translation with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description="The Translation Language"
     * )
     * 
     *
     * @SWG\Tag(name="Translation")
     */
    public function showListAction(Request $request, $language ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $translation = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $translations = $em->getRepository("App:Translation")->findBy(array("language" => $language));
            $state_labels = $em->getRepository("App:Translation")->getLabels("state.", $language);
            $requirement_labels = $em->getRepository("App:Translation")->getLabels("requirement.", $language);
            $option_labels = $em->getRepository("App:Translation")->getLabels("option.", $language);
 
            if (is_null($translations)) {
                $code = 500;
                $error = true;
                $message = "The Translation does not exist";
            }

           
            foreach ($state_labels as $tr) {
                $lab = explode(".", $tr->getLabel());
                $state_array[ $lab[1] ] = $tr->getDescription() ;
            }

            foreach ($requirement_labels as $tr) {
                $lab = explode(".", $tr->getLabel());
                $requirement_array[ $lab[1] ]  = $tr->getDescription() ;
            }

            foreach ($option_labels as $tr) {
                $lab = explode(".", $tr->getLabel());
                $option_array[ $lab[1] ]  = $tr->getDescription() ;
            }

            foreach ($translations as $tr) {
                $translation_array[ $tr->getLabel() ] = $tr->getDescription() ;
            }

            $translation_array[ "state" ] = $state_array ;
            $translation_array[ "option" ] = $option_array ;
            $translation_array[ "requirement" ] = $requirement_array ;



           
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Translation- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $translation_array : $message,
        ];

       

        
 
        return new Response($serializer->serialize($translation_array, "json", SerializationContext::create()->setGroups(array("translation_list"))));
    }

    

    /**
     * @Rest\Put("/edit/{id}/{user_id}.{_format}", name="translation_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The translation was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the translation."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The translation ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="user_id",
     *     in="path",
     *     type="string",
     *     description="The Admin ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The translation description",
     *     schema={}
     * )
     *     
     *
     * @SWG\Tag(name="Translation")
     */
    public function editAction(Request $request, $id, $user_id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $translation = [];
        $message = "";
        

        try {
            $code = 200;
            $error = false;
            $translation = $em->getRepository("App:Translation")->find($id);
            $admin = $em->getRepository("App:User")->find($user_id);
 
            if (!is_null($translation) && !is_null($admin)) {

                $translation->setAdmin($admin);
                $translation->setDescription("");
                $em->persist($translation);
                $em->flush();

                $form = $this->createForm(TranslationEditType::class, $translation);
                $form->submit($request->request->all()); 
                
                $em->persist($translation);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Admin - Error: You must to provide fields translation or the translation id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the translation - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $translation : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="translation_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Admin was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the translation"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The translation ID"
     * )
     *
     * @SWG\Tag(name="Translation")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $translation = $em->getRepository("App:Translation")->find($id);
 
            if (!is_null($translation)) {
                $em->remove($translation);
                $em->flush();
 
                $message = "The translation was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent translation - Error: The translation id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current translation - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

}