<?php
 
namespace App\Controller;
 
use App\Entity\User;
use App\Entity\Tutorial;
use App\Form\TutorialType;
use App\Form\UserPasswordEditType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\AdminDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class TutorialController
 *
 * @Route("/tutorial")
 */
class TutorialController extends FOSRestController
{
    
 
    /**
     * @Rest\Get("/", name="tutorial_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all categories."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all tutorial categories."
     * )
     *    
     *
     *
     * @SWG\Tag(name="Tutorial")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $categories = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $categories = $em->getRepository("App:Tutorial")->findAll(array(), array("language" => 'DESC'));
 
            if (is_null($categories)) {
                $categories = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Admins - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $categories : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/showlist/{language}.{_format}", name="tutorial_show_list_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets tutorial info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The tutorial with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="lang",
     *     in="path",
     *     type="string",
     *     description="The Tutorial language"
     * )
     * 
     *
     * @SWG\Tag(name="Tutorial")
     */
    public function showListAction(Request $request, $language ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $tutorial = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $tutorial = $em->getRepository("App:Tutorial")->findBy(array('language' => $language));
 
            if (is_null($tutorial)) {
                $code = 500;
                $error = true;
                $message = "The Tutorial does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Tutorial- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $tutorial : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/show/available", name="tutorial_show_available_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets tutorial info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The tutorial with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="string",
     *     description="The Tutorial language"
     * )
     * 
     * @SWG\Parameter(
     *     name="role",
     *     in="body",
     *     type="string",
     *     description="The User Role"
     * )
     * 
     * @SWG\Parameter(
     *     name="keyword",
     *     in="body",
     *     type="string",
     *     description="The Search Keyword"
     * )
     * 
     * @SWG\Parameter(
     *     name="device",
     *     in="body",
     *     type="string",
     *     description="The device"
     * )
     * 
     *
     * @SWG\Tag(name="Tutorial")
     */
    public function showAvailableAction(Request $request ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $tutorial = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
            $role = $request->request->get('role');
            $language = $request->request->get('language');
            $keyword = $request->request->get('keyword');
            $device = $request->request->get('device');
 
            $tutorial = $em->getRepository("App:Tutorial")->tutorialsByKeyword($role, $language, $keyword, $device);
 
            if (is_null($tutorial)) {
                $code = 500;
                $error = true;
                $message = "The Tutorial does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Tutorial- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $tutorial : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

 

    /**
     * @Rest\Post("/new", name="tutorial_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="User was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="User was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The tutorial name",
     *     schema={}
     * )
     *    
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     *     
     *    
     * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="array",
     *     description="The language assigned to this tutorial",
     *     schema={}
     * ) 
     * 
     * @SWG\Parameter(
     *     name="content",
     *     in="body",
     *     type="array",
     *     description="The content assigned to this tutorial",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="roles",
     *     in="body",
     *     type="array",
     *     description="The roles assigned to this tutorial",
     *     schema={}
     * )
     * 
     *       
     *
     * @SWG\Tag(name="Tutorial")
     */ 
    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $roles = explode(',', $request->request->get('roles'));
        $section_id = $request->request->get('section');
 
        $message = "";

        $tutorial = new Tutorial();
        //Create a form
        $form=$this->createForm(TutorialType::class, $tutorial);
        $form->submit($request->request->all());

        $section = $em->getRepository("App:Section")->find($section_id);
       
        try {
            $code = 200;
            $error = false;
            $tutorial->setRoles($roles);
            $tutorial->setSection($section);
            $em->persist($tutorial);
            $em->flush();
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the tutorial - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $tutorial : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }


    /**
     * @Rest\Get("/show/{id}.{_format}", name="tutorial_show_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets tutorial info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The tutorial with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Tutorial ID"
     * )
     * 
     *
     * @SWG\Tag(name="Tutorial")
     */
    public function showAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $tutorial = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $tutorial_id = $id;
            $tutorial = $em->getRepository("App:Tutorial")->find($tutorial_id);
 
            if (is_null($tutorial)) {
                $code = 500;
                $error = true;
                $message = "The Tutorial does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Tutorial- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $tutorial : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="tutorial_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The tutorial was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the tutorial."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The tutorial ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The tutorial name",
     *     schema={}
     * )
     *    
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     *     
     *    
     * @SWG\Parameter(
     *     name="language",
     *     in="body",
     *     type="array",
     *     description="The language assigned to this tutorial",
     *     schema={}
     * ) 
     * 
     * @SWG\Parameter(
     *     name="content",
     *     in="body",
     *     type="array",
     *     description="The content assigned to this tutorial",
     *     schema={}
     * )  
     * 
     * @SWG\Parameter(
     *     name="roles",
     *     in="body",
     *     type="array",
     *     description="The roles assigned to this tutorial",
     *     schema={}
     * )
     *
     * 
     * @SWG\Tag(name="Tutorial")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $roles = explode(',', $request->request->get('roles'));
        $section_id = $request->request->get('section');
        $message = "";
        

        try {
            $code = 200;
            $error = false;
            $tutorial = $em->getRepository("App:Tutorial")->find($id);
            $section = $em->getRepository("App:Section")->find($section_id);
 
            if (!is_null($tutorial)) {
                $form = $this->createForm(TutorialType::class, $tutorial);
                $form->submit($request->request->all()); 
                
                $tutorial->setRoles($roles);
                $tutorial->setSection($section);
                $em->persist($tutorial);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Admin - Error: You must to provide fields tutorial or the tutorial id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the tutorial - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $tutorial : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

   

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="tutorial_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="resource tutorial was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the tutorial"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The tutorial ID"
     * )
     *
     * @SWG\Tag(name="Tutorial")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $tutorial = $em->getRepository("App:Tutorial")->find($id);
 
            if (!is_null($tutorial)) {
                $em->remove($tutorial);
                $em->flush();
 
                $message = "The tutorial was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent tutorial - Error: The tutorial id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current tutorial - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

}