<?php

 
namespace App\Controller;
 
use App\Entity\Unit;
use App\Form\UnitType;
use App\Form\UnitEditType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Nelmio\UserDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use Doctrine\Common\Collections\ArrayCollection;
use JMS\Serializer\SerializationContext;
 
/**
 * Class UnitController
 *
 * @Route("/unit")
 */
class UnitController extends FOSRestController
{
    
    /**
     * @Rest\Get("/", name="unit_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all units."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all units."
     * )
     *   
     *
     *
     * @SWG\Tag(name="Unit")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $units = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $units = $em->getRepository("App:Unit")->findAll();
 
            if (is_null($units)) {
                $units = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Unit - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $units : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Post("/new", name="unit_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Unit was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Unit was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="name",
     *     in="body",
     *     type="string",
     *     description="The name",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="state",
     *     in="body",
     *     type="string",
     *     description="The state",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="course_id",
     *     in="body",
     *     type="integer",
     *     description="The Course id of the new unit",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="content",
     *     in="body",
     *     type="string",
     *     description="The content",
     *     schema={}
     * )
     *     
     * 
     * @SWG\Tag(name="Unit")
     */ 

    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";
        $unit=new Unit();
        //Create a form
        $form=$this->createForm(UnitType::class, $unit);
        $form->submit($request->request->all());
        $courseId= $request->request->get("course_id");
        $course = $em->getRepository("App:Course")->find($courseId);
        $unit->setCourse($course);

        $consecutive = $em->getRepository("App:Unit")->unitConsecutive($courseId);
        $unit->setPosition($consecutive + 1);

        try {
            $code = 200;
            $error = false;

            $em->persist($unit);
            $em->flush();
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Unit - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $unit : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }


    /**
     * @Rest\Put("/edit/{id}.{_format}", name="Unit_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The Unit was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the Unit."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Unit ID"
     * )
     *
     * @SWG\Tag(name="Unit")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $unit = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $unit = $em->getRepository("App:Unit")->find($id);
 
            if (!is_null($unit)) {
                $form = $this->createForm(UnitEditType::class, $unit);
                $form->submit($request->request->all());
                //$curse->setName($name);
 
                $em->persist($unit);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Unit - Error: You must to provide fields user or the Unit id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the Unit - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $unit : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/edit/position/{id}.{_format}", name="Unit_edit_position", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The Unit was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the Unit."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Unit ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="position",
     *     in="path",
     *     type="string",
     *     description="new position"
     * )
     *     
     *
     * @SWG\Tag(name="Unit")
     */
    public function editPositionAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $unit = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $unit = $em->getRepository("App:Unit")->find($id);
 
            if (!is_null($unit)) {
                $unit->setPosition($request->request->get("position"));
 
                $em->persist($unit);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Unit - Error: You must to provide fields user or the Unit id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the Unit - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $unit : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/show/{id}.{_format}", name="unit_show_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Unit info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Unit with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Unit ID"
     * )
     *
     * @SWG\Tag(name="Unit")
     */
    public function showAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $unit = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $unit_id = $id;
            $unit = $em->getRepository("App:Unit")->find($unit_id);
 
            if (is_null($unit)) {
                $code = 500;
                $error = true;
                $message = "The Unit does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Unit- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $unit : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/show/list/{id}.{_format}", name="unit_show_list_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all Units of Course Id Parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The list Units the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Course ID"
     * )
     *
     * @SWG\Tag(name="Unit")
     */
    public function showListAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $unit = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
            $learner_view = "false";
 
            $course_id = $id;
            $course = $em->getRepository("App:Course")->find($course_id);
            $units = $em->getRepository("App:Unit")->findBy(array("course" => $course_id), array("position" => "ASC"));

            foreach ($units as $unit) {
                $principles = $em->getRepository("App:Principle")->findBy(array("unit" => $unit->getId()), array("position" => "ASC"));
                $unit->setPrinciples(new ArrayCollection( $principles));
                if(!empty($principles) && $learner_view == "false"){
                    $learner_view = $principles[0]->getId();
                }
            }
            //$units = $em->getRepository("App:Unit")->unitsByCourse($course_id);
 
            if (is_null($course)) {
                $code = 500;
                $error = true;
                $message = "The Course does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Unit- Error: {$ex->getMessage()}";
        }

        $data = [
            "units"  => $units,
            "course" => $course,
            "learner_view" => $learner_view
        ];
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()->setGroups(array('unit_list'))));
    }

    /**
     * @Rest\Post("/show/student/list/{id}.{_format}", name="unit_show_student_list_id", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all Units of Course Id Parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The list Units the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Course ID"
     * )
     * 
     * @SWG\Parameter(
     *     name="student_id",
     *     in="path",
     *     type="string",
     *     description="The Student ID"
     * )
     *
     * @SWG\Tag(name="Unit")
     */
    public function showStudentListAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $student_id = $request->request->get("student_id");
        $unit = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
            $learner_view = "false";
 
            $course_id = $id;
            $course = $em->getRepository("App:Course")->find($course_id);
            $student = $em->getRepository("App:User")->find($student_id);
            $units = $em->getRepository("App:Unit")->findBy(array("course" => $course_id), array("position" => "ASC"));

            foreach ($units as $unit) {
                $principles = $em->getRepository("App:Principle")->findBy(array("unit" => $unit->getId()), array("position" => "ASC"));
                foreach ($principles as $pr) {
                    $progress = $em->getRepository("App:Progress")->findOneBy( array( "student" => $student->getId(), "principle" => $pr->getId() ) );
                    if(!is_null($progress)){
                        $pr->setDescription($progress->getId());
                    }
                    
                }
                $unit->setPrinciples(new ArrayCollection( $principles));
                if(!empty($principles) && $learner_view == "false"){
                    $learner_view = $principles[0]->getId();
                }
            }
 
            if (is_null($course)) {
                $code = 500;
                $error = true;
                $message = "The Course does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Unit- Error: {$ex->getMessage()}";
        }

        $data = [
            "units"  => $units,
            "course" => $course,
            "learner_view" => $learner_view
        ];
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()->setGroups(array('unit_list'))));
    }

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="Unit_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Unit was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the Unit"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Unit ID"
     * )
     *
     * @SWG\Tag(name="Unit")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $unit = $em->getRepository("App:Unit")->find($id);
 
            if (!is_null($unit)) {
                $em->remove($unit);
                $em->flush();
 
                $message = "The Unit was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent Unit - Error: The Unit id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current Unit - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }
 
}