<?php

 
namespace App\Controller;
 
use App\Entity\Wellness;
use App\Entity\Certificate;
use App\Form\WellnessType;
use App\Form\WellnessUpdateRevisionType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\UserDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class WellnessController
 *
 * @Route("/wellness")
 */
class WellnessController extends FOSRestController
{
    
    /**
     * @Rest\Get("/", name="wellness_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all Wellnesss."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all Wellnesss."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="Wellness ID"
     * )
     *
     *
     * @SWG\Tag(name="Wellness")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $wellnesss = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $wellnesss = $em->getRepository("App:Wellness")->findAll();
 
            if (is_null($wellnesss)) {
                $Wellnesss = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Wellness - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $wellnesss : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Post("/new", name="wellness_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Wellness was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Wellness was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="wellness1",
     *     in="body",
     *     type="string",
     *     description="The wellness 1 answer",
     *     schema={}
     * )
     * 
      * @SWG\Parameter(
     *     name="wellness2",
     *     in="body",
     *     type="string",
     *     description="The wellness 1 answer",
     *     schema={}
     * )
     * 
      * @SWG\Parameter(
     *     name="wellness3",
     *     in="body",
     *     type="string",
     *     description="The wellness 1 answer",
     *     schema={}
     * )
     * 
      * @SWG\Parameter(
     *     name="wellness4",
     *     in="body",
     *     type="string",
     *     description="The wellness 1 answer",
     *     schema={}
     * )
     * 
      * @SWG\Parameter(
     *     name="wellness5",
     *     in="body",
     *     type="string",
     *     description="The wellness 1 answer",
     *     schema={}
     * )
     * 
    * @SWG\Parameter(
     *     name="wellness6",
     *     in="body",
     *     type="string",
     *     description="The wellness 1 answer",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="wellness7",
     *     in="body",
     *     type="string",
     *     description="The wellness 1 answer",
     *     schema={}
     * ) 
     * 
     * @SWG\Parameter(
     *     name="student_id",
     *     in="body",
     *     type="integer",
     *     description="The user Id",
     *     schema={}
     * )
     * 
     * @SWG\Tag(name="Wellness")
     */ 

    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";
       
        $student_id= $request->request->get("student_id");
        $student = $em->getRepository("App:User")->find($student_id);
        $wellness = $em->getRepository("App:Wellness")->findOneBy(array('student' => $student_id) );

        if(is_null($wellness)){
            $wellness=new Wellness();
        }

        //Create a form
        $form=$this->createForm(WellnessType::class, $wellness);
        $form->submit($request->request->all());
        
        try {
            $code = 200;
            $error = false;

            $wellness->setStudent($student);
            $wellness->setState("state.development");
            $em->persist($wellness);
            $em->flush();
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the Wellness - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $wellness : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/show/{id}.{_format}", name="Wellness_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets Wellness info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The Wellness with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The User ID"
     * )
     *
     * @SWG\Tag(name="Wellness")
     */
    public function showAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $wellness = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $wellness_id = $id;
            $wellness = $em->getRepository("App:Wellness")->findOneBy(array('student' => $wellness_id) );
 
            if (is_null($wellness)) {
                $code = 500;
                $error = true;
                $message = "The Wellness does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Wellness- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $wellness : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    } 

    

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="Wellness_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The Wellness was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the Wellness."
     * )
     *
     * @SWG\Parameter(
     *     name="wellness1",
     *     in="body",
     *     type="string",
     *     description="The wellness 1 answer",
     *     schema={}
     * )
     * 
      * @SWG\Parameter(
     *     name="wellness2",
     *     in="body",
     *     type="string",
     *     description="The wellness 1 answer",
     *     schema={}
     * )
     * 
      * @SWG\Parameter(
     *     name="wellness3",
     *     in="body",
     *     type="string",
     *     description="The wellness 1 answer",
     *     schema={}
     * )
     * 
      * @SWG\Parameter(
     *     name="wellness4",
     *     in="body",
     *     type="string",
     *     description="The wellness 1 answer",
     *     schema={}
     * )
     * 
      * @SWG\Parameter(
     *     name="wellness5",
     *     in="body",
     *     type="string",
     *     description="The wellness 1 answer",
     *     schema={}
     * )
     * 
    * @SWG\Parameter(
     *     name="wellness6",
     *     in="body",
     *     type="string",
     *     description="The wellness 1 answer",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="wellness7",
     *     in="body",
     *     type="string",
     *     description="The wellness 1 answer",
     *     schema={}
     * ) 
     *
     * @SWG\Tag(name="Wellness")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $wellness = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $wellness = $em->getRepository("App:Wellness")->find($id);
 
            if (!is_null($wellness)) {
                $form = $this->createForm(WellnessType::class, $wellness);
                $form->submit($request->request->all());
 
                $em->persist($wellness);
                $wellness->setState("state.development");
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Wellness - Error: You must to provide fields user or the Wellness id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the Wellness - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $wellness : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="Wellness_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Wellness was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the Wellness"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Wellness ID"
     * )
     *
     * @SWG\Tag(name="Wellness")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $wellness = $em->getRepository("App:Wellness")->find($id);
 
            if (!is_null($wellness)) {
                $em->remove($wellness);
                $em->flush();
 
                $message = "The Wellness was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent Wellness - Error: The Wellness id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current Wellness - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/update_revision/{id}", name="update_revision_wellness")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Revision was successfully update"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Revision was not successfully update"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="body",
     *     type="string",
     *     description="The Id Wellness Record",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionplans",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="revisionskills",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionpilot",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionconclusions",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Tag(name="Wellness")
     */

    public function updateRevisionAction(Request $request, $id)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $wellness = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $wellness = $em->getRepository('App:Wellness')->find($id);
 
            if (!is_null($wellness)) {
                $form = $this->createForm(WellnessUpdateRevisionType::class, $wellness);
                $form->submit($request->request->all());
 
                $em->persist($wellness);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Wellness - Error: You must to provide fields wellness or the wellness id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the wellness - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $wellness : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/approved", name="approved_wellness")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Project mbs approval was successful"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Project mbs was not successfully approved"
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="body",
     *     type="string",
     *     description="The id wellness",
     *     schema={}
     * )
     * 
     *  * @SWG\Parameter(
     *     name="admin",
     *     in="body",
     *     type="string",
     *     description="The id admin",
     *     schema={}
     * )
     * @SWG\Tag(name="Wellness")
     */

    public function approvedAction(Request $request)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $wellness = [];
        $message = ""; 

        try {
            $code = 200;
            $error = false;
            $id = $request->request->get('id');
            $admin = $request->request->get('admin');

            $wellness = $em->getRepository('App:Wellness')->find($id);
            $admin = $em->getRepository('App:User')->find($admin);
 
            if (!is_null($wellness) && !is_null($admin)) {
                $em = $this->getDoctrine()->getManager();
                
                $wellness->setState('state.approved');
                $wellness->setAdmin($admin);
                $wellness->setApprovalDate(new \DateTime('now', (new \DateTimeZone('America/New_York'))));
                if(!$wellness->getCode()){
                    $wellness->setCode($wellness->getStudent()->getCountry()."-".$this->getNumberCode($wellness, $request));
                }

                $em->persist($wellness);
                $em->flush();
                
                //$message_list =  $this->sendMessageApproved($wellness->getStudent());
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Wellness - Error: You must to provide fields wellness or the wellness id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the wellness - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $wellness : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/revision", name="revision_wellness")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Project mbs approval was successful"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Project mbs was not successfully revision"
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="body",
     *     type="string",
     *     description="The id wellness",
     *     schema={}
     * )
     * @SWG\Tag(name="Wellness")
     */

    public function revisionAction(Request $request)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $wellness = [];
        $message = ""; 

        try {
            $code = 200;
            $error = false;
            $id = $request->request->get('id');
            $wellness = $em->getRepository('App:Wellness')->find($id);
 
            if (!is_null($wellness)) {
                $em = $this->getDoctrine()->getManager();

                
                $wellness->setState('state.revision');
                $em->persist($wellness);
                $em->flush();
                
                //$message_list = $this->sendMessageList($wellness->getStudent());
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Wellness - Error: You must to provide fields wellness or the wellness id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the wellness - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $wellness : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/sendrevision", name="sendrevision_wellness")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Project mbs sendrevision was successful"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Project mbs was not successfully sendrevision"
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="body",
     *     type="string",
     *     description="The id wellness",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionplans",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="revisionskills",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionpilot",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revisionconclusions",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * @SWG\Tag(name="Wellness")
     */

    public function sendRevisionAction(Request $request)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $wellness = [];
        $message = ""; 

        try {
            $code = 200;
            $error = false;
            $id = $request->request->get('id');
            $wellness = $em->getRepository('App:Wellness')->find($id);
 
            if (!is_null($wellness)) {
                $em = $this->getDoctrine()->getManager();

                $form = $this->createForm(WellnessUpdateRevisionType::class, $wellness);
                $form->submit($request->request->all());

                $wellness->setState('state.correction');
                //$email = $this->sendCorrectionsMessage($wellness->getStudent());
            
                $em->persist($wellness);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to send revision Wellness - Error: You must to provide fields wellness or the wellness id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying send revision of wellness - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $wellness : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/show/progress/{id}.{_format}", name="wellness_requirements_show_progress", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets course info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The course with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Student ID"
     * )
     *
     * @SWG\Tag(name="Wellness")
     */
    public function showProgressAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $wellness = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $wellness = $em->getRepository("App:Wellness")->findOneBy(array('student' => $id));
 
            if (is_null($wellness)) {
                $code = 200;
                $error = true;
                $requirements = [
                    'ambassador_skills' => 0,
                    'pilot_group' => 0,
                    'plans_future' => 0,
                    'conclusions' => 0                    
                ];
        
                $progress =[
                   'requirements' => $requirements,
                   'total_progress' => 0
                ];
            }
            else{
                $progress = $this->requirementWellnessProgress($wellness);
            }
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Programmbs- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $progress : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Post("/pagination", name="wellness_pagination")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all students."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all students."
     * )
     *
     *
     * @SWG\Parameter(
     *     name="keyword",
     *     in="path",
     *     type="string",
     *     description="The search keyword"
     * )
     * 
     * @SWG\Parameter(
     *     name="page",
     *     in="path",
     *     type="string",
     *     description="The search Page"
     * )
     * 
     * @SWG\Parameter(
     *     name="page_size",
     *     in="path",
     *     type="string",
     *     description="The number of records for page"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_column",
     *     in="path",
     *     type="string",
     *     description="Search order Column"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_direction",
     *     in="path",
     *     type="string",
     *     description="Search order Direction"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description=" Array Language Project"
     * )
     * 
     * @SWG\Parameter(
     *     name="state",
     *     in="path",
     *     type="string",
     *     description="State Project"
     * )
     * 
     * @SWG\Parameter(
     *     name="role",
     *     in="path",
     *     type="string",
     *     description="User Role"
     * )
     *    
     *
     * @SWG\Tag(name="Wellness")
     */
    public function paginationAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $groups = [];
        $message = "";
        $students = [];
 
        try {
            $code = 200;
            $error = false;
            
            $keyword    = $request->request->get('keyword');
            $page   = $request->request->get('page');
            $page_size = $request->request->get('page_size');
            $order_column = $request->request->get('order_column');
            $order_direction = $request->request->get('order_direction');
            $language = $request->request->get("language");
            $state = $request->request->get("state");
            $role = $request->request->get("role");

            $language = explode(",", preg_replace('([^A-Za-z0-9,])', '', $language));

            if($role == "ROLE_ADMIN" ){
                if($state === "state.approved"){
                    $studentsWellness = $em->getRepository('App:Wellness')->wellnessApprovedPagination($keyword, $page, $page_size, $order_column, $order_direction);    
                }
                else{
                    $studentsWellness = $em->getRepository('App:Wellness')->wellnessByStatePagination($keyword, $page, $page_size, $order_column, $order_direction, $state);
                }
            }
            if($role == "ROLE_LANGUAGE_ADMIN"  || $role == "ROLE_PROJECT_QUALIFIER"){
                if($state === "state.approved"){
                    $studentsWellness = $em->getRepository('App:Wellness')->wellnessByStateLanguagePagination($keyword, $page, $page_size, $order_column, $order_direction, $state, $language);
                }
                else{
                    $studentsWellness = $em->getRepository('App:Wellness')->wellnessApprovedLanguagePagination($keyword, $page, $page_size, $order_column, $order_direction, $language);
                }
                    
            }

            foreach ($studentsWellness['list'] as $student) {
                $st = $student[0];
                $course = $em->getRepository('App:Course')->getCourseByRequirementsLanguage($st->getStudent(), 'requirement.wellness', $st->getStudent()->getLanguage());
                $admin = $st->getAdmin();
                $students[] = [
                    'participant_id'            => $student['participant_id'],
                    'participant_name'          => $student['participant_name'],
                    'country'                   => $student['country'],
                    'wellness_id'               => $student['id'],
                    'updated_at'                => $student['updated_at'],
                    'approval_date'             => $student['approval_date'],
                    'group_program'             => $student['group_program'],
                    'group_name'                => $student['group_name'],
                    'ambassador_name'           => $student['ambassador_name'],
                    'admin_name'                => $admin ?  $admin->getFirstName(). " " .$admin->getLastName() : "",
                    'wellness_course'           => $course ? $course->getId() : "",
                ];
            }

            $data_array = [
                'list'              => $students,
                'items_total'       => $studentsWellness['items_total'],
                'pages_total'       => $studentsWellness['pages_total']
            ];
           
           
         
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data_array : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('participant_list'))));
    }

    

    public function requirementWellnessProgress($wellness){

        $ambassador_skills = 0;
        $pilot_group = 0;
        $plans_future = 0;
        $conclusions = 0;


        if( $wellness->getWellness1() )              { $ambassador_skills = $ambassador_skills + 50; }
        if( $wellness->getWellness2() )              { $ambassador_skills = $ambassador_skills + 50; }
        if( $wellness->getWellness3() )              { $pilot_group = 100; }
        if( $wellness->getWellness4() )              { $plans_future = $plans_future + 33; }
        if( $wellness->getWellness5() )              { $plans_future = $plans_future + 33; }
        if( $wellness->getWellness6() )              { $plans_future = $plans_future + 34; }
        if( $wellness->getWellness7() )              { $conclusions = 100; }
        
     

        $total =  $ambassador_skills + $pilot_group + $plans_future + $conclusions;
        
        $requirements = [
            'ambassador_skills' => $ambassador_skills,
            'pilot_group' => $pilot_group,
            'plans_future' => $plans_future,
            'conclusions' => $conclusions,           
        ];

        $totals =[
           'requirements' => $requirements,
           'total_progress' => $total / 4
        ];      
        
        return $totals;

    }

    public function getNumberCode(Wellness $wellnesss){

        $em = $this->getDoctrine()->getManager();
        $number = $em->getRepository('App:Certificate')->findOneBy(array('country' => $wellnesss->getStudent()->getCountry(), 'program' => 'WELLNESS'));
        if($number){
          $number->setNumber($number->getNumber() + 1);
          $em->persist($number);
          $em->flush();
        }
        else{
          $number = new Certificate();
          $number->setCountry($wellnesss->getStudent()->getCountry());
          $number->setProgram("WELLNESS");
          $number->setNumber(1);
          $number->setInitial(0);
          $number->setLanguage("en");
          $em->persist($number);
          $em->flush();
        }
  
        return $number->getNumber();
    }

   
 
}