<?php

 
namespace App\Controller;
 
use App\Entity\WellnessParticipant;
use App\Entity\Certificate;
use App\Form\WellnessParticipantType;
use App\Form\WellnessParticipantUpdateRevisionType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\UserDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class WellnessParticipantController
 *
 * @Route("/wellnessparticipant")
 */
class WellnessParticipantController extends FOSRestController
{
    
    /**
     * @Rest\Get("/", name="wellness_participant_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all WellnessParticipants."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all WellnessParticipants."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="WellnessParticipant ID"
     * )
     *
     *
     * @SWG\Tag(name="WellnessParticipant")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $wellness_participants = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $wellness_participants = $em->getRepository("App:WellnessParticipant")->findAll();
 
            if (is_null($wellness_participants)) {
                $WellnessParticipants = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all WellnessParticipant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $wellness_participants : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Post("/new", name="wellness_participant_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="WellnessParticipant was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="WellnessParticipant was not successfully registered"
     * )
     *    
     * 
     * @SWG\Parameter(
     *     name="student_id",
     *     in="body",
     *     type="integer",
     *     description="The user Id",
     *     schema={}
     * )
     * 
     * @SWG\Tag(name="WellnessParticipant")
     */ 

    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";
       
        $student_id= $request->request->get("student_id");
        $student = $em->getRepository("App:User")->find($student_id);
        $wellness_participant = $em->getRepository("App:WellnessParticipant")->findOneBy(array('student' => $student_id) );

        if(is_null($wellness_participant)){
            $wellness_participant=new WellnessParticipant();
        }

        //Create a form
        $form=$this->createForm(WellnessParticipantType::class, $wellness_participant);
        $form->submit($request->request->all());
        
        try {
            $code = 200;
            $error = false;

            $wellness_participant->setStudent($student);
            $wellness_participant->setState("state.development");
            $em->persist($wellness_participant);
            $em->flush();
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the WellnessParticipant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $wellness_participant : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/newfile", name="well_participant_new_file")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Programsa was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Programsa was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="id_student",
     *     in="body",
     *     type="string",
     *     description="The id student",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="file_name",
     *     in="body",
     *     type="string",
     *     description="The name of file",
     *     schema={}
     * )
     *     
     *
     * @SWG\Tag(name="WellnessParticipant")
     */ 
    public function newFileAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";        
        $id = $request->request->get('id_student');
        $filename = $request->request->get('file_name');
 
        try {
            $code = 200;
            $error = false;
           
            $student = $em->getRepository("App:User")->find($id);
            $well_participant = $em->getRepository("App:WellnessParticipant")->findOneBy(array('student' => $id));

            if(is_null($well_participant)){
                $well_participant=new WellnessParticipant();
            }            
 
            if (is_null($student)) {
                $code = 500;
                $error = true;
                $message = "The Student does not exist";
            }
            else{
                $well_participant->setFilestudent($filename);
                $well_participant->setStudent($student);
                $well_participant->setModality("option.modality1");
                $well_participant->setUploadDateStudent(new \DateTime('now', (new \DateTimeZone('America/New_York') ) ) ); 

                $well_participant->setState("state.revision");
                               
                $em->persist($well_participant);
                $em->flush();


            }            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the programsa - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $well_participant : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    /**
     * @Rest\Get("/show/{id}.{_format}", name="WellnessParticipant_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets WellnessParticipant info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The WellnessParticipant with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The User ID"
     * )
     *
     * @SWG\Tag(name="WellnessParticipant")
     */
    public function showAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $wellness_participant = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $wellness_participant_id = $id;
            $wellness_participant = $em->getRepository("App:WellnessParticipant")->find($wellness_participant_id);
 
            if (is_null($wellness_participant)) {
                $code = 500;
                $error = true;
                $message = "The WellnessParticipant does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current WellnessParticipant- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $wellness_participant : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    } 

    

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="WellnessParticipant_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The WellnessParticipant was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the WellnessParticipant."
     * )
     *    
     *
     * @SWG\Tag(name="WellnessParticipant")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $wellness_participant = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $wellness_participant = $em->getRepository("App:WellnessParticipant")->find($id);
 
            if (!is_null($wellness_participant)) {
                $form = $this->createForm(WellnessParticipantType::class, $wellness_participant);
                $form->submit($request->request->all());
 
                $em->persist($wellness_participant);
                $wellness_participant->setState("state.development");
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a WellnessParticipant - Error: You must to provide fields user or the WellnessParticipant id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the WellnessParticipant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $wellness_participant : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/sendrevision", name="sendrevision_wellnessparticipant")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Project mbs sendrevision was successful"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Project mbs was not successfully sendrevision"
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="body",
     *     type="string",
     *     description="The id wellness participant",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="revision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     *
    
     * @SWG\Tag(name="WellnessParticipant")
     */

     public function sendRevisionAction(Request $request)
     {
 
         $serializer = $this->get('jms_serializer');
         $em = $this->getDoctrine()->getManager();
         $wellnessParticipant = [];
         $message = ""; 
 
         try {
             $code = 200;
             $error = false;
             $id = $request->request->get('id');
             $wellnessParticipant = $em->getRepository('App:WellnessParticipant')->find($id);
  
             if (!is_null($wellnessParticipant)) {
                 $em = $this->getDoctrine()->getManager();
 
                 $form = $this->createForm(WellnessParticipantUpdateRevisionType::class, $wellnessParticipant);
                 $form->submit($request->request->all());
 
                 $wellnessParticipant->setState('state.correction');
                 //$email = $this->sendCorrectionsMessage($wellnessParticipant->getStudent());
             
                 $em->persist($wellnessParticipant);
                 $em->flush();
  
             } else {
                 $code = 500;
                 $error = true;
                 $message = "An error has occurred trying to send revision Programmbs - Error: You must to provide fields programmbs or the programmbs id does not exist";
             }
  
         } catch (Exception $ex) {
             $code = 500;
             $error = true;
             $message = "An error has occurred trying send revision of programmbs - Error: {$ex->getMessage()}";
         }
  
         $response = [
             'code' => $code,
             'error' => $error,
             'data' => $code == 200 ? $wellnessParticipant : $message,
         ];
  
         return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('future_ambassador'))));
     }

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="WellnessParticipant_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="WellnessParticipant was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the WellnessParticipant"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The WellnessParticipant ID"
     * )
     *
     * @SWG\Tag(name="WellnessParticipant")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $wellness_participant = $em->getRepository("App:WellnessParticipant")->find($id);
 
            if (!is_null($wellness_participant)) {
                $em->remove($wellness_participant);
                $em->flush();
 
                $message = "The WellnessParticipant was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent WellnessParticipant - Error: The WellnessParticipant id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current WellnessParticipant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }


    /**
     * @Rest\Put("/approved", name="approved_wellness_participant")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Project mbs approval was successful"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Project mbs was not successfully approved"
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="body",
     *     type="string",
     *     description="The id wellness_participant",
     *     schema={}
     * )
     * 
     *  * @SWG\Parameter(
     *     name="admin",
     *     in="body",
     *     type="string",
     *     description="The id admin",
     *     schema={}
     * )
     * @SWG\Tag(name="WellnessParticipant")
     */

    public function approvedAction(Request $request)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $wellness_participant = [];
        $message = ""; 

        try {
            $code = 200;
            $error = false;
            $id = $request->request->get('id');
            $admin = $request->request->get('admin');

            $wellness_participant = $em->getRepository('App:WellnessParticipant')->find($id);
            $admin = $em->getRepository('App:User')->find($admin);
 
            if (!is_null($wellness_participant) && !is_null($admin)) {
                $em = $this->getDoctrine()->getManager();
                
                $wellness_participant->setState('state.approved');
                $wellness_participant->setAdmin($admin);
                $wellness_participant->setApprovalDate(new \DateTime('now', (new \DateTimeZone('America/New_York'))));
                if(!$wellness_participant->getCode()){
                    $wellness_participant->setCode($wellness_participant->getStudent()->getCountry()."-".$this->getNumberCode($wellness_participant, $request));
                }

                $em->persist($wellness_participant);
                $em->flush();
                
                //$message_list =  $this->sendMessageApproved($wellness_participant->getStudent());
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a WellnessParticipant - Error: You must to provide fields wellness_participant or the wellness_participant id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the wellness_participant - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $wellness_participant : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->enableMaxDepthChecks()));
    }

    

     /**
     * @Rest\Post("/pagination", name="wellness_participant_pagination")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all students."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all students."
     * )
     *
     *
     * @SWG\Parameter(
     *     name="keyword",
     *     in="path",
     *     type="string",
     *     description="The search keyword"
     * )
     * 
     * @SWG\Parameter(
     *     name="page",
     *     in="path",
     *     type="string",
     *     description="The search Page"
     * )
     * 
     * @SWG\Parameter(
     *     name="page_size",
     *     in="path",
     *     type="string",
     *     description="The number of records for page"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_column",
     *     in="path",
     *     type="string",
     *     description="Search order Column"
     * )
     * 
     * @SWG\Parameter(
     *     name="order_direction",
     *     in="path",
     *     type="string",
     *     description="Search order Direction"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description=" Array Language Project"
     * )
     * 
     * @SWG\Parameter(
     *     name="state",
     *     in="path",
     *     type="string",
     *     description="State Project"
     * )
     * 
     * @SWG\Parameter(
     *     name="role",
     *     in="path",
     *     type="string",
     *     description="User Role"
     * )
     *    
     *
     * @SWG\Tag(name="WellnessParticipant")
     */
    public function paginationAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $groups = [];
        $message = "";
        $students = [];
 
        try {
            $code = 200;
            $error = false;
            
            $keyword    = $request->request->get('keyword');
            $page   = $request->request->get('page');
            $page_size = $request->request->get('page_size');
            $order_column = $request->request->get('order_column');
            $order_direction = $request->request->get('order_direction');
            $language = $request->request->get("language");
            $state = $request->request->get("state");
            $role = $request->request->get("role");

            $language = explode(",", preg_replace('([^A-Za-z0-9,])', '', $language));

            if($role == "ROLE_ADMIN" ){
                if($state === "state.approved"){
                    $studentsWellnessParticipant = $em->getRepository('App:WellnessParticipant')->wellness_participantApprovedPagination($keyword, $page, $page_size, $order_column, $order_direction);    
                }
                else{
                    $studentsWellnessParticipant = $em->getRepository('App:WellnessParticipant')->wellness_participantByStatePagination($keyword, $page, $page_size, $order_column, $order_direction, $state);
                }
            }
            if($role == "ROLE_LANGUAGE_ADMIN"  || $role == "ROLE_PROJECT_QUALIFIER"){
                if($state === "state.approved"){
                    $studentsWellnessParticipant = $em->getRepository('App:WellnessParticipant')->wellness_participantByStateLanguagePagination($keyword, $page, $page_size, $order_column, $order_direction, $state, $language);
                }
                else{
                    $studentsWellnessParticipant = $em->getRepository('App:WellnessParticipant')->wellness_participantApprovedLanguagePagination($keyword, $page, $page_size, $order_column, $order_direction, $language);
                }
                    
            }

            foreach ($studentsWellnessParticipant['list'] as $student) {
                $st = $student[0];
                $course = $em->getRepository('App:Course')->getCourseByRequirementsLanguage($st->getStudent(), 'requirement.wellness_participant', $st->getStudent()->getLanguage());
                $admin = $st->getAdmin();
                $students[] = [
                    'participant_id'            => $student['participant_id'],
                    'participant_name'          => $student['participant_name'],
                    'country'                   => $student['country'],
                    'wellness_participant_id'               => $student['id'],
                    'updated_at'                => $student['updated_at'],
                    'approval_date'             => $student['approval_date'],
                    'group_program'             => $student['group_program'],
                    'group_name'                => $student['group_name'],
                    'ambassador_name'           => $student['ambassador_name'],
                    'admin_name'                => $admin ?  $admin->getFirstName(). " " .$admin->getLastName() : "",
                    'wellness_participant_course'           => $course ? $course->getId() : "",
                ];
            }

            $data_array = [
                'list'              => $students,
                'items_total'       => $studentsWellnessParticipant['items_total'],
                'pages_total'       => $studentsWellnessParticipant['pages_total']
            ];
           
           
         
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Group - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $data_array : $message,
        ];
 
        return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('participant_list'))));
    }

     /**
     * @Rest\Put("/approvedlist", name="approved_wellness_participant_list")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Project mbs approval was successful"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Project mbs was not successfully approved"
     * )
     * 
     * @SWG\Parameter(
     *     name="list",
     *     in="body",
     *     type="string",
     *     description="The array id programsa",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="admin_id",
     *     in="body",
     *     type="string",
     *     description="The admin id",
     *     schema={}
     * ) 
     * 
     * @SWG\Tag(name="WellnessParticipant")
     */

     public function approvedListAction(Request $request)
     {
 
         $serializer = $this->get('jms_serializer');
         $em = $this->getDoctrine()->getManager();
         $wellnessParticipant = [];
         $message = ""; 
 
         try {
             $code = 200;
             $error = false;
             $list = explode(',', $request->request->get('list'));
             $admin_id = $request->request->get('admin');
             $admin = $em->getRepository('App:User')->find($admin_id);
 
             foreach ($list as $key) {
 
                 $wellnessParticipant = $em->getRepository('App:WellnessParticipant')->findOneBy(array('student' => $key));
                 $student = $em->getRepository('App:User')->find($key);
 
                 if (!is_null($student) && !is_null($admin)) {
 
                     if (!is_null($wellnessParticipant) ) {
                         $em = $this->getDoctrine()->getManager();
  
                         $wellnessParticipant->setState('state.approved');
                         $wellnessParticipant->setAdmin($admin);
 
                         $wellnessParticipant->setApprovalDate(new \DateTime('now', (new \DateTimeZone('America/New_York'))));
                         if(!$wellnessParticipant->getCode()){
                             $wellnessParticipant->setCode($wellnessParticipant->getStudent()->getCountry()."-".$this->getNumberCode($wellnessParticipant, $request));
                             $student->setCode($wellnessParticipant->getCode());
                         }
 
                         $em->persist($wellnessParticipant);
                         $em->flush();
 
                         $em->persist($student);
                         $em->flush();
 
                     } else {
                         
                         $wellnessParticipant=new WellnessParticipant();
                         $wellnessParticipant->setStudent($student);
                         $em = $this->getDoctrine()->getManager();
  
                         $wellnessParticipant->setState('state.approved');
                         $wellnessParticipant->setAdmin($admin);
                         
                         $wellnessParticipant->setApprovalDate(new \DateTime('now', (new \DateTimeZone('America/New_York'))));
                         if(!$wellnessParticipant->getCode()){
                             $wellnessParticipant->setCode($wellnessParticipant->getStudent()->getCountry()."-".$this->getNumberCode($wellnessParticipant, $request));
                             $student->setCode($wellnessParticipant->getCode());
                         }
 
                         $em->persist($wellnessParticipant);
                         $em->flush();
 
                         $em->persist($student);
                         $em->flush();
         
 
                     }
 
                 }
             }
             
  
             
  
         } catch (Exception $ex) {
             $code = 500;
             $error = true;
             $message = "An error has occurred trying to edit the programmbs - Error: {$ex->getMessage()}";
         }
  
         $response = [
             'code' => $code,
             'error' => $error,
             'data' => $code == 200 ? $list : $message,
         ];
  
         return new Response($serializer->serialize($response, "json"));
     }
 

    
    public function getNumberCode(WellnessParticipant $wellness_participant){

        $em = $this->getDoctrine()->getManager();
        $number = $em->getRepository('App:Certificate')->findOneBy(array('country' => $wellness_participant->getStudent()->getCountry(), 'program' => 'WELLNESS_PART'));
        if($number){
          $number->setNumber($number->getNumber() + 1);
          $em->persist($number);
          $em->flush();
        }
        else{
          $number = new Certificate();
          $number->setCountry($wellness_participant->getStudent()->getCountry());
          $number->setProgram("WELLNESS_PART");
          $number->setNumber(1);
          $number->setInitial(0);
          $number->setLanguage("en");
          $em->persist($number);
          $em->flush();
        }
  
        return $number->getNumber();
    }

   
 
}