<?php

namespace App\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use DateTime;
use Symfony\Component\Security\Core\User\UserInterface;
use JMS\Serializer\Annotation as Serializer;
use JMS\Serializer\Annotation\Groups;

/**
 * Course
 *
 * @ORM\Table(name="course")
 * @ORM\Entity(repositoryClass="App\Repository\CourseRepository")
 * @ORM\HasLifecycleCallbacks() 
 */
class Course
{
    /**
     * @var int
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     * @Groups({"course_list", "show_course", "correction_list"})
     */
    private $id;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\User", inversedBy="courses")
     * @ORM\JoinColumn(name="user_id", referencedColumnName="id", onDelete="CASCADE")
     * @Groups({"course_list", "show_course"})     
     * 
     */
    private $admin;
    

    /**
     * @var string
     *
     * @ORM\Column(name="name", type="string", length=255)
     * @Groups({"unit_list", "course_list", "show_course", "correction_list"})
     */
    private $name;

    /**
     * @var string
     *
     * @ORM\Column(name="code", type="string", length=255, nullable=true)
     * @Groups({"unit_list", "course_list", "show_course"})
     */
    private $code;

    /**
     * @var string
     *
     * @ORM\Column(name="state", type="string", length=255)
     * @Groups({"course_list", "show_course"})
     */
    private $state;

    /**
     * @var string
     *
     * @ORM\Column(name="language", type="string", length=255)
     * @Groups({"show_course"})
     */
    private $language;

    /**
     * @var string
     *
     * @ORM\Column(name="picture", type="string", length=255, nullable=true)
     * @Groups({"show_course"})
     */
    private $picture;

    /**
     * @var string
     *
     * @ORM\Column(name="description", type="text", nullable=true)
     * @Groups({"unit_list", "show_course"})
     */
    private $description;

    /**
     * @var string
     *
     * @ORM\Column(name="requirements", type="string", length=255, nullable=true)
     * @Groups({"course_list", "show_course"})
     */
    private $requirements;

    /**
     * @var string
     *
     * @ORM\Column(name="payment_code", type="string", length=255, nullable=true)
     */
    private $paymentcode;

    /**
     * @var string
     *
     * @ORM\Column(name="price", type="integer", options={"default":"0"})
     * @Groups({"unit_list", "show_course"})
     */
    private $price;

    /**
     * @var string
     *
     * @ORM\Column(name="roles", type="json_array")
     * @Groups({"show_course"})
     */
    private $roles = array();

    /**
    * @ORM\OneToMany(targetEntity="App\Entity\Unit", mappedBy="course")
    * @Serializer\Exclude()
    */
    private $units;

    /**
    * @ORM\OneToMany(targetEntity="App\Entity\Payment", mappedBy="course")
    * @Serializer\Exclude()
    */
    private $payments;

    /**
    * @ORM\OneToMany(targetEntity="App\Entity\Progress", mappedBy="course")
    * @Serializer\Exclude()
    */
    private $progress;

    /**
    * @ORM\OneToMany(targetEntity="App\Entity\Stop", mappedBy="course")
    */
    private $stop;
    

    /**
     * @ORM\Column(name="created_at", type="datetime")
     */
    protected $createdAt;

    /**
     * @ORM\Column(name="updated_at", type="datetime")
     */
    protected $updatedAt;

    public function __construct()
    {
        $this->units = new ArrayCollection();
        $this->progress = new ArrayCollection();
        $this->stop = new ArrayCollection();
        $this->payments = new ArrayCollection();
    }

    /**
     * @param mixed $updatedAt
     * @return self
     */
    public function setUpdatedAt($updatedAt)
    {
        $this->updatedAt = $updatedAt;

        return $this;
    }

    /**
     * @ORM\PrePersist
     * @ORM\PreUpdate
     */
    public function updatedTimestamps()
    {
        $dateTimeNow = new DateTime('now');
        $this->setUpdatedAt($dateTimeNow);
        if ($this->getCreatedAt() === null) {
            $this->setCreatedAt($dateTimeNow);
        }
    }

    public function getCreatedAt(): ?\DateTimeInterface
    {
        return $this->createdAt;
    }

    public function setCreatedAt(\DateTimeInterface $createdAt): self
    {
        $this->createdAt = $createdAt;

        return $this;
    }

    public function getUpdatedAt(): ?\DateTimeInterface
    {
        return $this->updatedAt;
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(string $name): self
    {
        $this->name = $name;

        return $this;
    }

    public function getCode(): ?string
    {
        return $this->code;
    }

    public function setCode(?string $code): self
    {
        $this->code = $code;

        return $this;
    }

    public function getState(): ?string
    {
        return $this->state;
    }

    public function setState(string $state): self
    {
        $this->state = $state;

        return $this;
    }

    public function getLanguage(): ?string
    {
        return $this->language;
    }

    public function setLanguage(string $language): self
    {
        $this->language = $language;

        return $this;
    }

    public function getPicture(): ?string
    {
        return $this->picture;
    }

    public function setPicture(?string $picture): self
    {
        $this->picture = $picture;

        return $this;
    }

    public function getDescription(): ?string
    {
        return $this->description;
    }

    public function setDescription(?string $description): self
    {
        $this->description = $description;

        return $this;
    }

    public function getRequirements(): ?string
    {
        return $this->requirements;
    }

    public function setRequirements(?string $requirements): self
    {
        $this->requirements = $requirements;

        return $this;
    }

    public function getPaymentcode(): ?string
    {
        return $this->paymentcode;
    }

    public function setPaymentcode(?string $paymentcode): self
    {
        $this->paymentcode = $paymentcode;

        return $this;
    }

    public function getRoles(): ?array
    {
        return $this->roles;
    }

    public function setRoles(array $roles): self
    {
        $this->roles = $roles;

        return $this;
    }

    public function getAdmin(): ?User
    {
        return $this->admin;
    }

    public function setAdmin(?User $admin): self
    {
        $this->admin = $admin;

        return $this;
    }

    /**
     * @return Collection|Unit[]
     */
    public function getUnits(): Collection
    {
        return $this->units;
    }

    public function addUnit(Unit $unit): self
    {
        if (!$this->units->contains($unit)) {
            $this->units[] = $unit;
            $unit->setCourse($this);
        }

        return $this;
    }

    public function removeUnit(Unit $unit): self
    {
        if ($this->units->contains($unit)) {
            $this->units->removeElement($unit);
            // set the owning side to null (unless already changed)
            if ($unit->getCourse() === $this) {
                $unit->setCourse(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|Payment[]
     */
    public function getPayments(): Collection
    {
        return $this->payments;
    }

    public function addPayment(Payment $payment): self
    {
        if (!$this->payments->contains($payment)) {
            $this->payments[] = $payment;
            $payment->setCourse($this);
        }

        return $this;
    }

    public function removePayment(Payment $payment): self
    {
        if ($this->payments->contains($payment)) {
            $this->payments->removeElement($payment);
            // set the owning side to null (unless already changed)
            if ($payment->getCourse() === $this) {
                $payment->setCourse(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|Progress[]
     */
    public function getProgress(): Collection
    {
        return $this->progress;
    }

    public function addProgress(Progress $progress): self
    {
        if (!$this->progress->contains($progress)) {
            $this->progress[] = $progress;
            $progress->setCourse($this);
        }

        return $this;
    }

    public function removeProgress(Progress $progress): self
    {
        if ($this->progress->contains($progress)) {
            $this->progress->removeElement($progress);
            // set the owning side to null (unless already changed)
            if ($progress->getCourse() === $this) {
                $progress->setCourse(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|Stop[]
     */
    public function getStop(): Collection
    {
        return $this->stop;
    }

    public function addStop(Stop $stop): self
    {
        if (!$this->stop->contains($stop)) {
            $this->stop[] = $stop;
            $stop->setCourse($this);
        }

        return $this;
    }

    public function removeStop(Stop $stop): self
    {
        if ($this->stop->contains($stop)) {
            $this->stop->removeElement($stop);
            // set the owning side to null (unless already changed)
            if ($stop->getCourse() === $this) {
                $stop->setCourse(null);
            }
        }

        return $this;
    }

    public function getPrice(): ?int
    {
        return $this->price;
    }

    public function setPrice(int $price): self
    {
        $this->price = $price;

        return $this;
    }

   
}
