<?php

namespace App\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use DateTime;
use Symfony\Component\Security\Core\User\UserInterface;
use JMS\Serializer\Annotation as Serializer;
use JMS\Serializer\Annotation\MaxDepth;
use JMS\Serializer\Annotation\Groups;

/**
 * Principle
 *
 * @ORM\Table(name="principle");
 * @ORM\Entity(repositoryClass="App\Repository\PrincipleRepository");
 * @ORM\HasLifecycleCallbacks()
 */
class Principle
{
    /**
     * @ORM\Column(name="id", type="integer") 
     * @ORM\Id()
     * @ORM\GeneratedValue(strategy="AUTO")
     * @Groups({"unit_list"})
     */
    protected $id;

    /**
     * @ORM\Column(name="name", type="string", length=150)
     * @Groups({"unit_list"})
     */
    protected $name;

   /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Unit", inversedBy="principles")
     * @ORM\JoinColumn(name="unit_id", referencedColumnName="id", onDelete="CASCADE")
     * @MaxDepth(1)
     */
    protected $unit;

    /**
    * @ORM\OneToMany(targetEntity="App\Entity\Progress", mappedBy="principle")
    * @Serializer\Exclude()
    */
    private $progress;

    /**
    * @ORM\OneToMany(targetEntity="App\Entity\Stop", mappedBy="principle")
    * @Serializer\Exclude()
    */
    private $stop;


    /**
     * @var string
     *
     * @ORM\Column(name="state", type="text", nullable=true)
     * @Groups({"unit_list"})
     */
    private $state;
    
    /**
     * @var string
     *
     * @ORM\Column(name="description", type="text", nullable=true)
     * @Groups({"unit_list"})
     */
    private $description;

    /**
     * @var string
     *
     * @ORM\Column(name="content", type="text", nullable=true)
     */
    private $content;

    /**
     * @ORM\Column(name="type", type="string", length=150)
     * @Groups({"unit_list"})
     */
    protected $type;

    /**
     * @var int
     *
     * @ORM\Column(name="position", type="integer")
     * @Groups({"unit_list"})
     */
    private $position;

    /**
     * @ORM\Column(name="final_answer_type", type="string", length=150)
     * @Groups({"unit_list"})
     */
    protected $finalAnswertype;

    /**
     * @var string
     *
     * @ORM\Column(name="final_answer", type="text", nullable=true)
     * @Groups({"unit_list"})
     */
    private $finalAnswer;

    /**
     * @ORM\Column(name="stop_state", type="string", length=150)
     * @Groups({"unit_list"})
     */
    protected $stopState;

    /**
     * @var string
     *
     * @ORM\Column(name="stop_content", type="text", nullable=true)
     * @Groups({"unit_list"})
     */
    private $stopContent;

    public function __construct()
    {
        $this->progress = new ArrayCollection();
        $this->stop = new ArrayCollection();
    }


    public function getId(): ?int
    {
        return $this->id;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(string $name): self
    {
        $this->name = $name;

        return $this;
    }

    public function getState(): ?string
    {
        return $this->state;
    }

    public function setState(?string $state): self
    {
        $this->state = $state;

        return $this;
    }

    public function getDescription(): ?string
    {
        return $this->description;
    }

    public function setDescription(?string $description): self
    {
        $this->description = $description;

        return $this;
    }

    public function getContent(): ?string
    {
        return $this->content;
    }

    public function setContent(?string $content): self
    {
        $this->content = $content;

        return $this;
    }

    public function getPosition(): ?int
    {
        return $this->position;
    }

    public function setPosition(int $position): self
    {
        $this->position = $position;

        return $this;
    }

    public function getUnit(): ?Unit
    {
        return $this->unit;
    }

    public function setUnit(?Unit $unit): self
    {
        $this->unit = $unit;

        return $this;
    }

    public function getType(): ?string
    {
        return $this->type;
    }

    public function setType(string $type): self
    {
        $this->type = $type;

        return $this;
    }

    public function getFinalAnswertype(): ?string
    {
        return $this->finalAnswertype;
    }

    public function setFinalAnswertype(string $finalAnswertype): self
    {
        $this->finalAnswertype = $finalAnswertype;

        return $this;
    }

    public function getFinalAnswer(): ?string
    {
        return $this->finalAnswer;
    }

    public function setFinalAnswer(?string $finalAnswer): self
    {
        $this->finalAnswer = $finalAnswer;

        return $this;
    }

    /**
     * @return Collection|Progress[]
     */
    public function getProgress(): Collection
    {
        return $this->progress;
    }

    public function setProgress($progress): self
    {
            $this->progress = $progress;
            return $this;
    }

    public function addProgress(Progress $progress): self
    {
        if (!$this->progress->contains($progress)) {
            $this->progress[] = $progress;
            $progress->setPrinciple($this);
        }

        return $this;
    }

    public function removeProgress(Progress $progress): self
    {
        if ($this->progress->contains($progress)) {
            $this->progress->removeElement($progress);
            // set the owning side to null (unless already changed)
            if ($progress->getPrinciple() === $this) {
                $progress->setPrinciple(null);
            }
        }

        return $this;
    }

    public function getStopState(): ?string
    {
        return $this->stopState;
    }

    public function setStopState(string $stopState): self
    {
        $this->stopState = $stopState;

        return $this;
    }

    public function getStopContent(): ?string
    {
        return $this->stopContent;
    }

    public function setStopContent(?string $stopContent): self
    {
        $this->stopContent = $stopContent;

        return $this;
    }

    /**
     * @return Collection|Stop[]
     */
    public function getStop(): Collection
    {
        return $this->stop;
    }

    public function addStop(Stop $stop): self
    {
        if (!$this->stop->contains($stop)) {
            $this->stop[] = $stop;
            $stop->setPrinciple($this);
        }

        return $this;
    }

    public function removeStop(Stop $stop): self
    {
        if ($this->stop->contains($stop)) {
            $this->stop->removeElement($stop);
            // set the owning side to null (unless already changed)
            if ($stop->getPrinciple() === $this) {
                $stop->setPrinciple(null);
            }
        }

        return $this;
    }

  
    
}