<?php

namespace App\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use DateTime;
use Symfony\Component\Security\Core\User\UserInterface;
use JMS\Serializer\Annotation as Serializer;
use JMS\Serializer\Annotation\MaxDepth;
use JMS\Serializer\Annotation\Groups;

/**
 * Tracking
 *
 * @ORM\Table(name="tracking");
 * @ORM\Entity(repositoryClass="App\Repository\TrackingRepository");
 * @ORM\HasLifecycleCallbacks()
 */
class Tracking
{
    /**
     * @ORM\Column(name="id", type="integer") 
     * @ORM\Id()
     * @ORM\GeneratedValue(strategy="AUTO")
     * @Groups({"tracking_list"})
     */
    protected $id;

    /**
     * @ORM\Column(name="entity_id", type="string", length=150)
     * @Groups({"tracking_list"})
     */
    protected $entityId;

    /**
     * @ORM\Column(name="entity", type="string", length=150)
     * @Groups({"tracking_list"})
     */
    protected $entity;

    /**
     * @ORM\Column(name="action", type="string", length=150)
     * @Groups({"tracking_list"})
     */
    protected $action;   

    /**
     * @var string
     *
     * @ORM\Column(name="name", type="string", length=150)
     * @Groups({"tracking_list"})
     */
    private $name;    

    /**
     * @var string
     *
     * @ORM\Column(name="log", type="text", nullable=true)     * 
     */
    private $log;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\User", inversedBy="trackingusers")
     * @ORM\JoinColumn(name="user_id", referencedColumnName="id", onDelete="CASCADE")
     * @Groups({"tracking_list"})
     * @MaxDepth(1)
     */
    private $user;

     /**
     * @ORM\Column(name="created_at", type="datetime")
     * @Groups({"tracking_list"})
     */
    protected $createdAt;

    /**
     * @ORM\Column(name="updated_at", type="datetime")
     * @Groups({"tracking_list"})
     */
    protected $updatedAt;

  
  
    /**
     * @param mixed $updatedAt
     * @return self
     */
    public function setUpdatedAt($updatedAt)
    {
        $this->updatedAt = $updatedAt;

        return $this;
    }

    /**
     * @ORM\PrePersist
     * @ORM\PreUpdate
     */
    public function updatedTimestamps()
    {
        $dateTimeNow = new DateTime('now');
        $this->setUpdatedAt($dateTimeNow);
        if ($this->getCreatedAt() === null) {
            $this->setCreatedAt($dateTimeNow);
        }
    }

    public function getCreatedAt(): ?\DateTimeInterface
    {
        return $this->createdAt;
    }

    public function setCreatedAt(\DateTimeInterface $createdAt): self
    {
        $this->createdAt = $createdAt;

        return $this;
    }

    public function getUpdatedAt(): ?\DateTimeInterface
    {
        return $this->updatedAt;
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getEntityId(): ?string
    {
        return $this->entityId;
    }

    public function setEntityId(string $entityId): self
    {
        $this->entityId = $entityId;

        return $this;
    }

    public function getEntity(): ?string
    {
        return $this->entity;
    }

    public function setEntity(string $entity): self
    {
        $this->entity = $entity;

        return $this;
    }

    public function getAction(): ?string
    {
        return $this->action;
    }

    public function setAction(string $action): self
    {
        $this->action = $action;

        return $this;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(?string $name): self
    {
        $this->name = $name;

        return $this;
    }

    public function getUser(): ?User
    {
        return $this->user;
    }

    public function setUser(?User $user): self
    {
        $this->user = $user;

        return $this;
    }

    public function getLog(): ?string
    {
        return $this->log;
    }

    public function setLog(?string $log): self
    {
        $this->log = $log;

        return $this;
    }

    

    
}