<?php

namespace App\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use DateTime;
use Symfony\Component\Security\Core\User\UserInterface;
use JMS\Serializer\Annotation as Serializer;
use JMS\Serializer\Annotation\Groups;

/**
 * Unit
 *
 * @ORM\Table(name="unit");
 * @ORM\Entity(repositoryClass="App\Repository\UnitRepository");
 * @ORM\HasLifecycleCallbacks()
 */
class Unit
{
    /**
     * @ORM\Column(name="id", type="integer") 
     * @ORM\Id()
     * @ORM\GeneratedValue(strategy="AUTO")
     * @Groups({"unit_list"})
     */
    protected $id;

    /**
     * @ORM\Column(name="name", type="string", length=150)
     * @Groups({"unit_list", "content_list"})
     */
    protected $name;

    /**
     * @ORM\Column(name="position", type="integer")
     * @Groups({"unit_list"})
     */
    protected $position;

   /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Course", inversedBy="units")
     * @ORM\JoinColumn(name="course_id", referencedColumnName="id", onDelete="CASCADE")
     */
    protected $course;

    /**
     * @var string
     *
     * @ORM\Column(name="state", type="text", nullable=true)
     * @Groups({"unit_list"})
     */
    private $state;
    
    /**
     * @var string
     *
     * @ORM\Column(name="description", type="text", nullable=true)
     * @Groups({"unit_list"})
     */
    private $description;

    /**
     * @var string
     *
     * @ORM\Column(name="content", type="text", nullable=true)
     * @Groups({"unit_list"})
     */
    private $content;
    

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\Principle", mappedBy="unit")
     * @Groups({"unit_list"})
     */
    protected $principles;

    public function __construct()
    {
        $this->principles = new ArrayCollection();
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(string $name): self
    {
        $this->name = $name;

        return $this;
    }

    public function getState(): ?string
    {
        return $this->state;
    }

    public function setState(?string $state): self
    {
        $this->state = $state;

        return $this;
    }

    public function getDescription(): ?string
    {
        return $this->description;
    }

    public function setDescription(?string $description): self
    {
        $this->description = $description;

        return $this;
    }

    public function getContent(): ?string
    {
        return $this->content;
    }

    public function setContent(?string $content): self
    {
        $this->content = $content;

        return $this;
    }

    public function getCourse(): ?Course
    {
        return $this->course;
    }

    public function setCourse(?Course $course): self
    {
        $this->course = $course;

        return $this;
    }

    /**
     * @return Collection|Principle[]
     */
    public function getPrinciples(): Collection
    {
        return $this->principles;
    }

    public function addPrinciple(Principle $principle): self
    {
        if (!$this->principles->contains($principle)) {
            $this->principles[] = $principle;
            $principle->setUnit($this);
        }

        return $this;
    }

    public function setPrinciples($principles): self
    {
            $this->principles = $principles;
            return $this;
    }

    public function removePrinciple(Principle $principle): self
    {
        if ($this->principles->contains($principle)) {
            $this->principles->removeElement($principle);
            // set the owning side to null (unless already changed)
            if ($principle->getUnit() === $this) {
                $principle->setUnit(null);
            }
        }

        return $this;
    }

    public function getPosition(): ?string
    {
        return $this->position;
    }

    public function setPosition(string $position): self
    {
        $this->position = $position;

        return $this;
    }

}