<?php

namespace App\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use DateTime;
use Symfony\Component\Security\Core\User\UserInterface;
use JMS\Serializer\Annotation as Serializer;
use JMS\Serializer\Annotation\Groups;
use JMS\Serializer\Annotation\MaxDepth;

/**
 * User
 *
 * @ORM\Table(name="user");
 * @ORM\Entity(repositoryClass="App\Repository\UserRepository");
 * @ORM\HasLifecycleCallbacks()
 */
class User implements UserInterface
{
    /**
     * @ORM\Column(name="id", type="integer") 
     * @ORM\Id()
     * @ORM\GeneratedValue(strategy="AUTO")
     * @Groups({"tracking_list", "student_list", "future_ambassador", "student_group", "report_list", "ambassador_list", "participant_list", "project_list", "grant_ambassador_list", "profile", "show_course" , "correction_list", "reset_password"})
     */
    protected $id;


    /**
     * @ORM\Column(name="username", type="string", length=255)
     * @Groups({"student_list", "future_ambassador", "ambassador_list", "profile", "reset_password"})
     */
    protected $username;

    protected $salt;

    /**
     * @ORM\Column(name="password", type="string", length=255)
     * @Serializer\Exclude()
     */
    protected $password;

    /**
     * @var string
     */
    protected $plainPassword;

    /**
     * @var string
     *
     * @ORM\Column(name="language", type="string", length=255)
     * @Groups({"student_list", "ambassador_list", "participant_list", "profile", "student_group"})
     * 
     */
    private $language;

     /**
     * @var string
     *
     * @ORM\Column(name="language_grader", type="json_array", nullable=true)
     */
    private $languageGrader = array();

    /**
     * @var string
     *
     * @ORM\Column(name="message", type="json_array", nullable=true)
     */
    private $message = array();

     /**
     * @var string
     *
     * @ORM\Column(name="first_name", type="string", length=255)
     * @Groups({"tracking_list", "student_list", "reset_password", "future_ambassador", "student_group", "group_list", "grant_ambassador_list", "report_list", "ambassador_list", "participant_list", "project_list", "profile", "course_list", "show_course"})
     */
    private $firstName;

    /**
     * @var string
     *
     * @ORM\Column(name="last_name", type="string", length=255)
     * @Groups({"tracking_list", "student_list", "reset_password", "future_ambassador", "student_group", "group_list", "grant_ambassador_list", "report_list", "ambassador_list", "participant_list", "project_list", "profile", "course_list" , "show_course"})
     */
    private $lastName;

    /**
     * @var string
     *
     * @ORM\Column(name="country", type="string", nullable=true, length=255)
     * @Groups({"tracking_list", "student_list", "student_group", "future_ambassador", "report_list", "ambassador_list", "grant_ambassador_list", "profile"})
     */
    private $country;

    /**
     * @var string
     *
     * @ORM\Column(name="city", type="string", nullable=true,  length=255)
     * @Groups({"student_list"})
     */
    private $city;

    /**
     * @var string
     *
     * @ORM\Column(name="picture", type="string", nullable=true,  length=255)
     */
    private $picture;

    /**
     * @var string
     *
     * @ORM\Column(name="whatsapp", nullable=true, type="string",  length=255)
     * @Groups({"student_list", "profile"})
     */
    private $whatsapp;

    /**
     * @var array
     *
     * @ORM\Column(name="roles", type="json_array")
     * @Groups({"tracking_list", "student_list", "participant_list", "profile"})
     */
    protected $roles = [];

    /**
     * @var string
     *
     * @ORM\Column(name="code", nullable=true, type="string", length=255 )
     * @Groups({"student_list", "ambassador_list", "profile"})
     */
    private $code;

    /**
     * @var string
     *
     * @ORM\Column(name="id_number", type="string", nullable=true,  length=255)
     */
    private $idnumber;

    /**
     * @var string
     *
     * @ORM\Column(name="areacode", type="string", nullable=true,  length=255)
     * @Groups({"student_list", "participant_list", "profile"})
     */
    private $areacode;

    /**
     * @var string
     *
     * @ORM\Column(name="verifiedemail", type="string", length=255, nullable=true, options={"default":"false"})
     * @Groups({"student_list", "participant_list", "profile"})
     */
    private $verifiedemail;

    /**
     * @var string
     *
     * @ORM\Column(name="verifiedphone", type="string", length=255, nullable=true, options={"default":"false"})
     * @Groups({"student_list", "participant_list", "profile"})
     */
    private $verifiedphone;

    /**
     * @var string
     *
     * @ORM\Column(name="verifiedwhatsapp", type="string", length=255, nullable=true, options={"default":"false"})
     * @Groups({"student_list", "participant_list", "profile"})
     */
    private $verifiedwhatsapp;

    /**
     * @var string
     *
     * @ORM\Column(name="otpcode", type="string", nullable=true,  length=255)
     */
    private $otpcode;

    /**
    * @ORM\OneToMany(targetEntity="App\Entity\Groupe", mappedBy="embassador")
    * @Serializer\Exclude()
    */
    private $groupes;

    /**
    * @ORM\OneToMany(targetEntity="App\Entity\Tracking", mappedBy="user")
    * @Serializer\Exclude()
    */
    private $trackingusers;

   /**
    * @ORM\OneToMany(targetEntity="App\Entity\Course", mappedBy="admin")
    * @Serializer\Exclude()
    */
    private $courses;

   /**
    * @ORM\OneToMany(targetEntity="App\Entity\GrantUpdate", mappedBy="user")
    * @Serializer\Exclude()
    */
    private $grantupdates;

   /**
    * @ORM\OneToMany(targetEntity="App\Entity\Grant", mappedBy="administrator")
    * @Serializer\Exclude()
    */
    private $grants;

    /**
    * @ORM\OneToOne(targetEntity="App\Entity\Transfer", mappedBy="student")
    * @Groups({"grant_ambassador_list"})
    */
    private $transfer;

    /**
    * @ORM\OneToMany(targetEntity="App\Entity\GrantAmbassador", mappedBy="ambassador")
    * @Serializer\Exclude()
    */
    private $grantsambassador;

    /**
    * @ORM\OneToMany(targetEntity="App\Entity\Progress", mappedBy="student")
    * @Serializer\Exclude()
    */
    private $progress;

    /**
    * @ORM\OneToMany(targetEntity="App\Entity\Stop", mappedBy="student")
    * @Serializer\Exclude()
    */
    private $stop;

    /**
    * @ORM\OneToMany(targetEntity="App\Entity\GrantAmbassador", mappedBy="mentoredambassador")
    * @Serializer\Exclude()
    */
    private $grantsmentoredambassador;

   /**
    * @ORM\OneToOne(targetEntity="App\Entity\StudentGroup", mappedBy="student")
    * @Groups({"future_ambassador", "student_list", "student_group", "report_list", "participant_list", "project_list", "grant_ambassador_list"})
    * @MaxDepth(3)
    */
   private $studentgroup;

   /**
    * @ORM\OneToMany(targetEntity="App\Entity\Payment", mappedBy="student")
    */
    private $payments;

   /**
    * @ORM\OneToOne(targetEntity="App\Entity\PilotGroup", mappedBy="ambassador")
    */
    private $pilotgroup;

   /**
    * @ORM\OneToOne(targetEntity="App\Entity\StudentAmbassadorGroup", mappedBy="student")
    * @Groups({"student_list", "participant_list", "project_list", "grant_ambassador_list"})
    */
   private $studentambassadorgroup;

   /** 
    * @ORM\OneToOne(targetEntity="App\Entity\Evaluation", mappedBy="student")
    * @Groups({"student_list", "student_group"})
    */
   private $evaluation;

   /**
    * @ORM\OneToOne(targetEntity="App\Entity\ProgramMbs", mappedBy="student")
    * @Groups({"student_list", "student_group", "future_ambassador", "participant_list"})
    */
   private $programmbs;

   /**
    * @ORM\OneToOne(targetEntity="App\Entity\Wellness", mappedBy="student")
    * @Groups({"student_list", "student_group", "future_ambassador", "participant_list"})
    */
    private $wellness;

     /**
    * @ORM\OneToOne(targetEntity="App\Entity\Wellness", mappedBy="admin")
    * @Groups({"student_list", "student_group", "future_ambassador", "participant_list"})
    */
    private $wellnessadmin;

    /**
    * @ORM\OneToOne(targetEntity="App\Entity\WellnessParticipant", mappedBy="student")
    * @Groups({"student_list", "student_group", "future_ambassador", "participant_list"})
    */
    private $wellness_participant;

    /**
    * @ORM\OneToOne(targetEntity="App\Entity\WellnessParticipant", mappedBy="admin")
    * @Groups({"student_list", "student_group", "future_ambassador", "participant_list"})
    */
    private $wellness_participant_admin;
   

   /**
    * @ORM\OneToOne(targetEntity="App\Entity\ProgramSa", mappedBy="student")
    * @Groups({"student_list", "student_group", "future_ambassador", "participant_list"})
    */
   private $programsa;

   /**
    * @ORM\OneToOne(targetEntity="App\Entity\GrantMember", mappedBy="member")
    * @Groups({"student_list", "student_group", "future_ambassador", "participant_list"})
    */
    private $grantmember;

   /**
     * @ORM\Column(name="contract_date", nullable=true, type="date")
     * @Groups({"student_list", "ambassador_list"})
     */
    private $contractDate;

    /**
     * @ORM\Column(name="created_at", type="datetime")
     * @Groups({"student_list", "ambassador_list"})
     */
    protected $createdAt;

    /**
     * @ORM\Column(name="updated_at", type="datetime")
     * @Groups({"student_list", "ambassador_list"})
     */
    protected $updatedAt;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\Board", mappedBy="user")
     */
    protected $boards;

    public function __construct()
    {
        $this->boards = new ArrayCollection();
        $this->groupes = new ArrayCollection();
        $this->grants = new ArrayCollection();
        $this->grantsambassador = new ArrayCollection();
        $this->grantupdates = new ArrayCollection();
        $this->courses = new ArrayCollection();
        $this->grantsmentoredambassador = new ArrayCollection();
        $this->progress = new ArrayCollection();
        $this->stop = new ArrayCollection();
        $this->payments = new ArrayCollection();
        $this->trackingusers = new ArrayCollection();
    }

    /**
     * @return mixed
     */
    public function getId()
    {
        return $this->id;
    }

   
    /**
     * @return mixed
     */
    public function getUsername()
    {
        return $this->username;
    }

    /**
     * @param mixed $username
     * @return self
     */
    public function setUsername($username)
    {
        $this->username = $username;

        return $this;
    }

    /**
     * @return mixed
     */
    public function getPassword()
    {
        return $this->password;
    }

    /**
     * @param mixed $password
     * @return self
     */
    public function setPassword($password)
    {
        $this->password = $password;

        return $this;
    }

    /**
     * @return string
     */
    public function getPlainPassword()
    {
        return $this->plainPassword;
    }

    /**
     * @param $plainPassword
     */
    public function setPlainPassword($plainPassword)
    {
        $this->plainPassword = $plainPassword;

        $this->password = null;
    }

    /**
     * Set roles
     *
     * @param array $roles
     *
     * @return User
     */
    public function setRoles($roles)
    {
        $this->roles = $roles;

        return $this;
    }

    /**
     * Get roles
     *
     * @return array
     */
    public function getRoles()
    {
        return $this->roles;
    }

    public function getSalt() {}

    public function eraseCredentials() {}

    /**
     * @return mixed
     */
    public function getCreatedAt()
    {
        return $this->createdAt;
    }

    /**
     * @param mixed $createdAt
     * @return self
     */
    public function setCreatedAt($createdAt)
    {
        $this->createdAt = $createdAt;

        return $this;
    }

    /**
     * @return mixed
     */
    public function getUpdatedAt()
    {
        return $this->updatedAt;
    }

    /**
     * @param mixed $updatedAt
     * @return self
     */
    public function setUpdatedAt($updatedAt)
    {
        $this->updatedAt = $updatedAt;

        return $this;
    }

    /**
     * @ORM\PrePersist
     * @ORM\PreUpdate
     */
    public function updatedTimestamps()
    {
        $dateTimeNow = new DateTime('now');
        $this->setUpdatedAt($dateTimeNow);
        if ($this->getCreatedAt() === null) {
            $this->setCreatedAt($dateTimeNow);
        }
    }

    /**
     * @return mixed
     */
    public function getBoards()
    {
        return $this->boards->toArray();
    }

    public function addBoard(Board $board): self
    {
        if (!$this->boards->contains($board)) {
            $this->boards[] = $board;
            $board->setUser($this);
        }

        return $this;
    }

    public function removeBoard(Board $board): self
    {
        if ($this->boards->contains($board)) {
            $this->boards->removeElement($board);
            // set the owning side to null (unless already changed)
            if ($board->getUser() === $this) {
                $board->setUser(null);
            }
        }

        return $this;
    }

    public function getLanguage(): ?string
    {
        return $this->language;
    }

    public function setLanguage(string $language): self
    {
        $this->language = $language;

        return $this;
    }

    public function getLanguageGrader(): ?array
    {
        return $this->languageGrader;
    }

    public function setLanguageGrader(array $languageGrader): self
    {
        $this->languageGrader = $languageGrader;

        return $this;
    }

    public function getFirstName(): ?string
    {
        return $this->firstName;
    }

    public function setFirstName(string $firstName): self
    {
        $this->firstName = $firstName;

        return $this;
    }

    public function getLastName(): ?string
    {
        return $this->lastName;
    }

    public function setLastName(string $lastName): self
    {
        $this->lastName = $lastName;

        return $this;
    }

    public function getCountry(): ?string
    {
        return $this->country;
    }

    public function setCountry(?string $country): self
    {
        $this->country = $country;

        return $this;
    }

    public function getCity(): ?string
    {
        return $this->city;
    }

    public function setCity(?string $city): self
    {
        $this->city = $city;

        return $this;
    }

    public function getWhatsapp(): ?string
    {
        return $this->whatsapp;
    }

    public function setWhatsapp(?string $whatsapp): self
    {
        $this->whatsapp = $whatsapp;

        return $this;
    }

    public function getCode(): ?string
    {
        return $this->code;
    }

    public function setCode(?string $code): self
    {
        $this->code = $code;

        return $this;
    }

    /**
     * @return Collection|Groupe[]
     */
    public function getGroupes(): Collection
    {
        return $this->groupes;
    }

    public function addGroupe(Groupe $groupe): self
    {
        if (!$this->groupes->contains($groupe)) {
            $this->groupes[] = $groupe;
            $groupe->setEmbassador($this);
        }

        return $this;
    }

    public function removeGroupe(Groupe $groupe): self
    {
        if ($this->groupes->contains($groupe)) {
            $this->groupes->removeElement($groupe);
            // set the owning side to null (unless already changed)
            if ($groupe->getEmbassador() === $this) {
                $groupe->setEmbassador(null);
            }
        }

        return $this;
    }

    public function getStudentgroup(): ?StudentGroup
    {
        return $this->studentgroup;
    }

    public function setStudentgroup(?StudentGroup $studentgroup): self
    {
        $this->studentgroup = $studentgroup;

        // set (or unset) the owning side of the relation if necessary
        $newStudent = null === $studentgroup ? null : $this;
        if ($studentgroup->getStudent() !== $newStudent) {
            $studentgroup->setStudent($newStudent);
        }

        return $this;
    }

    public function getStudentambassadorgroup(): ?StudentAmbassadorGroup
    {
        return $this->studentambassadorgroup;
    }

    public function setStudentambassadorgroup(?StudentAmbassadorGroup $studentambassadorgroup): self
    {
        $this->studentambassadorgroup = $studentambassadorgroup;

        // set (or unset) the owning side of the relation if necessary
        $newStudent = null === $studentambassadorgroup ? null : $this;
        if ($studentambassadorgroup->getStudent() !== $newStudent) {
            $studentambassadorgroup->setStudent($newStudent);
        }

        return $this;
    }

    public function getEvaluation(): ?Evaluation
    {
        return $this->evaluation;
    }

    public function setEvaluation(?Evaluation $evaluation): self
    {
        $this->evaluation = $evaluation;

        // set (or unset) the owning side of the relation if necessary
        $newStudent = null === $evaluation ? null : $this;
        if ($evaluation->getStudent() !== $newStudent) {
            $evaluation->setStudent($newStudent);
        }

        return $this;
    }

    public function getProgrammbs(): ?ProgramMbs
    {
        return $this->programmbs;
    }

    public function setProgrammbs(?ProgramMbs $programmbs): self
    {
        $this->programmbs = $programmbs;

        // set (or unset) the owning side of the relation if necessary
        $newStudent = null === $programmbs ? null : $this;
        if ($programmbs->getStudent() !== $newStudent) {
            $programmbs->setStudent($newStudent);
        }

        return $this;
    }

    public function getProgramsa(): ?ProgramSa
    {
        return $this->programsa;
    }

    public function setProgramsa(?ProgramSa $programsa): self
    {
        $this->programsa = $programsa;

        // set (or unset) the owning side of the relation if necessary
        $newStudent = null === $programsa ? null : $this;
        if ($programsa->getStudent() !== $newStudent) {
            $programsa->setStudent($newStudent);
        }

        return $this;
    }

    /**
     * @return Collection|Grant[]
     */
    public function getGrants(): Collection
    {
        return $this->grants;
    }

    public function addGrant(Grant $grant): self
    {
        if (!$this->grants->contains($grant)) {
            $this->grants[] = $grant;
            $grant->setEmbassador($this);
        }

        return $this;
    }

    public function removeGrant(Grant $grant): self
    {
        if ($this->grants->contains($grant)) {
            $this->grants->removeElement($grant);
            // set the owning side to null (unless already changed)
            if ($grant->getEmbassador() === $this) {
                $grant->setEmbassador(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|GrantAmbassador[]
     */
    public function getGrantsambassador(): Collection
    {
        return $this->grantsambassador;
    }

    public function addGrantsambassador(GrantAmbassador $grantsambassador): self
    {
        if (!$this->grantsambassador->contains($grantsambassador)) {
            $this->grantsambassador[] = $grantsambassador;
            $grantsambassador->setAmbassador($this);
        }

        return $this;
    }

    public function removeGrantsambassador(GrantAmbassador $grantsambassador): self
    {
        if ($this->grantsambassador->contains($grantsambassador)) {
            $this->grantsambassador->removeElement($grantsambassador);
            // set the owning side to null (unless already changed)
            if ($grantsambassador->getAmbassador() === $this) {
                $grantsambassador->setAmbassador(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|GrantUpdate[]
     */
    public function getGrantupdates(): Collection
    {
        return $this->grantupdates;
    }

    public function addGrantupdate(GrantUpdate $grantupdate): self
    {
        if (!$this->grantupdates->contains($grantupdate)) {
            $this->grantupdates[] = $grantupdate;
            $grantupdate->setUser($this);
        }

        return $this;
    }

    public function removeGrantupdate(GrantUpdate $grantupdate): self
    {
        if ($this->grantupdates->contains($grantupdate)) {
            $this->grantupdates->removeElement($grantupdate);
            // set the owning side to null (unless already changed)
            if ($grantupdate->getUser() === $this) {
                $grantupdate->setUser(null);
            }
        }

        return $this;
    }

    public function getMessage(): ?array
    {
        return $this->message;
    }

    public function setMessage(?array $message): self
    {
        $this->message = $message;

        return $this;
    }

    public function getPicture(): ?string
    {
        return $this->picture;
    }

    public function setPicture(?string $picture): self
    {
        $this->picture = $picture;

        return $this;
    }

    public function getIdnumber(): ?string
    {
        return $this->idnumber;
    }

    public function setIdnumber(?string $idnumber): self
    {
        $this->idnumber = $idnumber;

        return $this;
    }

    public function getContractDate(): ?\DateTimeInterface
    {
        return $this->contractDate;
    }

    public function setContractDate(?\DateTimeInterface $contractDate): self
    {
        $this->contractDate = $contractDate;

        return $this;
    }

    public function getPilotgroup(): ?PilotGroup
    {
        return $this->pilotgroup;
    }

    public function setPilotgroup(?PilotGroup $pilotgroup): self
    {
        $this->pilotgroup = $pilotgroup;

        // set (or unset) the owning side of the relation if necessary
        $newAmbassador = null === $pilotgroup ? null : $this;
        if ($pilotgroup->getAmbassador() !== $newAmbassador) {
            $pilotgroup->setAmbassador($newAmbassador);
        }

        return $this;
    }

    /**
     * @return Collection|Course[]
     */
    public function getCourses(): Collection
    {
        return $this->courses;
    }

    public function addCourse(Course $course): self
    {
        if (!$this->courses->contains($course)) {
            $this->courses[] = $course;
            $course->setAdmin($this);
        }

        return $this;
    }

    public function removeCourse(Course $course): self
    {
        if ($this->courses->contains($course)) {
            $this->courses->removeElement($course);
            // set the owning side to null (unless already changed)
            if ($course->getAdmin() === $this) {
                $course->setAdmin(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|GrantAmbassador[]
     */
    public function getGrantsmentoredambassador(): Collection
    {
        return $this->grantsmentoredambassador;
    }

    public function addGrantsmentoredambassador(GrantAmbassador $grantsmentoredambassador): self
    {
        if (!$this->grantsmentoredambassador->contains($grantsmentoredambassador)) {
            $this->grantsmentoredambassador[] = $grantsmentoredambassador;
            $grantsmentoredambassador->setMentoredambassador($this);
        }

        return $this;
    }

    public function removeGrantsmentoredambassador(GrantAmbassador $grantsmentoredambassador): self
    {
        if ($this->grantsmentoredambassador->contains($grantsmentoredambassador)) {
            $this->grantsmentoredambassador->removeElement($grantsmentoredambassador);
            // set the owning side to null (unless already changed)
            if ($grantsmentoredambassador->getMentoredambassador() === $this) {
                $grantsmentoredambassador->setMentoredambassador(null);
            }
        }

        return $this;
    }

    public function getTransfer(): ?Transfer
    {
        return $this->transfer;
    }

    public function setTransfer(?Transfer $transfer): self
    {
        $this->transfer = $transfer;

        // set (or unset) the owning side of the relation if necessary
        $newStudent = null === $transfer ? null : $this;
        if ($transfer->getStudent() !== $newStudent) {
            $transfer->setStudent($newStudent);
        }

        return $this;
    }

    /**
     * @return Collection|Progress[]
     */
    public function getProgress(): Collection
    {
        return $this->progress;
    }

    public function addProgress(Progress $progress): self
    {
        if (!$this->progress->contains($progress)) {
            $this->progress[] = $progress;
            $progress->setStudent($this);
        }

        return $this;
    }

    public function removeProgress(Progress $progress): self
    {
        if ($this->progress->contains($progress)) {
            $this->progress->removeElement($progress);
            // set the owning side to null (unless already changed)
            if ($progress->getStudent() === $this) {
                $progress->setStudent(null);
            }
        }

        return $this;
    }

    public function getWellness(): ?Wellness
    {
        return $this->wellness;
    }

    public function setWellness(?Wellness $wellness): self
    {
        $this->wellness = $wellness;

        // set (or unset) the owning side of the relation if necessary
        $newStudent = null === $wellness ? null : $this;
        if ($wellness->getStudent() !== $newStudent) {
            $wellness->setStudent($newStudent);
        }

        return $this;
    }

    public function getWellnessadmin(): ?Wellness
    {
        return $this->wellnessadmin;
    }

    public function setWellnessadmin(?Wellness $wellnessadmin): self
    {
        $this->wellnessadmin = $wellnessadmin;

        // set (or unset) the owning side of the relation if necessary
        $newAdmin = null === $wellnessadmin ? null : $this;
        if ($wellnessadmin->getAdmin() !== $newAdmin) {
            $wellnessadmin->setAdmin($newAdmin);
        }

        return $this;
    }

    /**
     * @return Collection|Stop[]
     */
    public function getStop(): Collection
    {
        return $this->stop;
    }

    public function addStop(Stop $stop): self
    {
        if (!$this->stop->contains($stop)) {
            $this->stop[] = $stop;
            $stop->setStudent($this);
        }

        return $this;
    }

    public function removeStop(Stop $stop): self
    {
        if ($this->stop->contains($stop)) {
            $this->stop->removeElement($stop);
            // set the owning side to null (unless already changed)
            if ($stop->getStudent() === $this) {
                $stop->setStudent(null);
            }
        }

        return $this;
    }

    public function getAreacode(): ?string
    {
        return $this->areacode;
    }

    public function setAreacode(?string $areacode): self
    {
        $this->areacode = $areacode;

        return $this;
    }

    public function getVerifiedemail(): ?string
    {
        return $this->verifiedemail;
    }

    public function setVerifiedemail(string $verifiedemail): self
    {
        $this->verifiedemail = $verifiedemail;

        return $this;
    }

    public function getVerifiedphone(): ?string
    {
        return $this->verifiedphone;
    }

    public function setVerifiedphone(string $verifiedphone): self
    {
        $this->verifiedphone = $verifiedphone;

        return $this;
    }

    public function getOtpcode(): ?string
    {
        return $this->otpcode;
    }

    public function setOtpcode(?string $otpcode): self
    {
        $this->otpcode = $otpcode;

        return $this;
    }

    public function getVerifiedwhatsapp(): ?string
    {
        return $this->verifiedwhatsapp;
    }

    public function setVerifiedwhatsapp(?string $verifiedwhatsapp): self
    {
        $this->verifiedwhatsapp = $verifiedwhatsapp;

        return $this;
    }

    /**
     * @return Collection|Payment[]
     */
    public function getPayments(): Collection
    {
        return $this->payments;
    }

    public function addPayment(Payment $payment): self
    {
        if (!$this->payments->contains($payment)) {
            $this->payments[] = $payment;
            $payment->setStudent($this);
        }

        return $this;
    }

    public function removePayment(Payment $payment): self
    {
        if ($this->payments->contains($payment)) {
            $this->payments->removeElement($payment);
            // set the owning side to null (unless already changed)
            if ($payment->getStudent() === $this) {
                $payment->setStudent(null);
            }
        }

        return $this;
    }

    public function getWellnessParticipant(): ?WellnessParticipant
    {
        return $this->wellness_participant;
    }

    public function setWellnessParticipant(?WellnessParticipant $wellness_participant): self
    {
        $this->wellness_participant = $wellness_participant;

        // set (or unset) the owning side of the relation if necessary
        $newStudent = null === $wellness_participant ? null : $this;
        if ($wellness_participant->getStudent() !== $newStudent) {
            $wellness_participant->setStudent($newStudent);
        }

        return $this;
    }

    public function getWellnessParticipantAdmin(): ?WellnessParticipant
    {
        return $this->wellness_participant_admin;
    }

    public function setWellnessParticipantAdmin(?WellnessParticipant $wellness_participant_admin): self
    {
        $this->wellness_participant_admin = $wellness_participant_admin;

        // set (or unset) the owning side of the relation if necessary
        $newAdmin = null === $wellness_participant_admin ? null : $this;
        if ($wellness_participant_admin->getAdmin() !== $newAdmin) {
            $wellness_participant_admin->setAdmin($newAdmin);
        }

        return $this;
    }

    public function getGrantmember(): ?GrantMember
    {
        return $this->grantmember;
    }

    public function setGrantmember(?GrantMember $grantmember): self
    {
        $this->grantmember = $grantmember;

        // set (or unset) the owning side of the relation if necessary
        $newMember = null === $grantmember ? null : $this;
        if ($grantmember->getMember() !== $newMember) {
            $grantmember->setMember($newMember);
        }

        return $this;
    }

    /**
     * @return Collection|Tracking[]
     */
    public function getTrackingusers(): Collection
    {
        return $this->trackingusers;
    }

    public function addTrackinguser(Tracking $trackinguser): self
    {
        if (!$this->trackingusers->contains($trackinguser)) {
            $this->trackingusers[] = $trackinguser;
            $trackinguser->setUser($this);
        }

        return $this;
    }

    public function removeTrackinguser(Tracking $trackinguser): self
    {
        if ($this->trackingusers->contains($trackinguser)) {
            $this->trackingusers->removeElement($trackinguser);
            // set the owning side to null (unless already changed)
            if ($trackinguser->getUser() === $this) {
                $trackinguser->setUser(null);
            }
        }

        return $this;
    }

    

}
