<?php

namespace App\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\ORM\Mapping as ORM;
use DateTime;
use Symfony\Component\Security\Core\User\UserInterface;
use JMS\Serializer\Annotation as Serializer;
use JMS\Serializer\Annotation\Groups;
use JMS\Serializer\Annotation\MaxDepth;

/**
 * Wellness
 *
 * @ORM\Table(name="wellness")
 * @ORM\Entity(repositoryClass="App\Repository\WellnessRepository")
 * @ORM\HasLifecycleCallbacks()
 */
class Wellness
{
    /**
     * @var int
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     * @Groups({"student_list", "future_ambassador", "student_group", "report_list", "participant_list", "project_list"})
     */
    private $id;

    /**
     * @var string
     *
     * @ORM\Column(name="wellness1", type="text", nullable=true)
     */
    private $wellness1;

    /**
     * @var string
     *
     * @ORM\Column(name="wellness2", type="text", nullable=true)
     */
    private $wellness2;

    /**
     * @var string
     *
     * @ORM\Column(name="wellness3", type="text", nullable=true)
     */
    private $wellness3;

    /**
     * @var string
     *
     * @ORM\Column(name="wellness4", type="text", nullable=true)
     */
    private $wellness4;

    /**
     * @var string
     *
     * @ORM\Column(name="wellness5", type="text", nullable=true)
     */
    private $wellness5;

    /**
     * @var string
     *
     * @ORM\Column(name="wellness6", type="text", nullable=true)
     */
    private $wellness6;

    /**
     * @var string
     *
     * @ORM\Column(name="wellness7", type="text", nullable=true)
     */
    private $wellness7;


    /**
     * @var string
     *
     * @ORM\Column(name="state", type="string", nullable=true, length=255)
     * @Groups({"student_list", "student_group", "report_list", "participant_list"})
     */
    private $state;

   
    /**
     * @var string
     *
     * @ORM\Column(name="filestudent", type="string", nullable=true, length=255)
     * @Groups({"student_list", "future_ambassador", "student_group", "participant_list"})
     */
    private $filestudent;

    /**
     * @var string
     *
     * @ORM\Column(name="fileambassador", type="string", nullable=true, length=255)
     */
    private $fileambassador;

    /**
     * @var string
     *
     * @ORM\Column(name="modality", type="string", nullable=true, length=255)
     * @Groups({"student_list", "future_ambassador", "student_group", "report_list", "participant_list", "project_list"}) 
     * 
     */
    private $modality;

    /**
     * @var string
     *
     * @ORM\Column(name="code", type="string", nullable=true, length=255)
     * @Groups({"student_group"}) 
     */
    private $code;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="student_file_upload_date", nullable=true, type="datetime")
     */
    private $uploadDateStudent;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="admin_file_upload_date", nullable=true, type="datetime")
     */
    private $uploadDateAdmin;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="approval_date", nullable=true, type="date")
     * @Groups({"student_list", "student_group", "report_list", "project_list"})
     */
    private $approvalDate;

    /**
     * @var string
     *
     * @ORM\Column(name="authorization_code", type="string", nullable=true, length=255)
     */
    private $authorizationCode;

    /**
     * @var string
     *
     * @ORM\Column(name="attendance_code", type="string", nullable=true, length=255)
     */
    private $attendanceCode;

     /**
     * @var string
     *
     * @ORM\Column(name="revisionskills", type="text", nullable=true)
     */
    private $revisionskills;

    /**
     * @var string
     *
     * @ORM\Column(name="revisionplans", type="text", nullable=true)
     */
    private $revisionplans;

    /**
     * @var string
     *
     * @ORM\Column(name="revisionpilot", type="text", nullable=true)
     */
    private $revisionpilot;

    /**
     * @var string
     *
     * @ORM\Column(name="revisionconclusions", type="text", nullable=true)
     */
    private $revisionconclusions;

  
    /**
     * @ORM\OneToOne(targetEntity="App\Entity\User", inversedBy="wellness")
     * @ORM\JoinColumn(name="student_id", referencedColumnName="id", onDelete="CASCADE")
     * @Groups({"student_list", "report_list", "project_list"})
     * @MaxDepth(4)
     */
    private $student;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\User", inversedBy="wellnessadmin")
     * @ORM\JoinColumn(name="admin_id", referencedColumnName="id")
     * @Groups({"project_list"})
     */
    private $admin;

   

    /**
     * @ORM\Column(name="created_at", type="datetime")
     * @Groups({"student_list"})
     */
    protected $createdAt;

    /**
     * @ORM\Column(name="updated_at", type="datetime")
     * @Groups({"student_list", "future_ambassador"})
     */
    protected $updatedAt;



     /**
     * @param mixed $updatedAt
     * @return self
     */
    public function setUpdatedAt($updatedAt)
    {
        $this->updatedAt = $updatedAt;

        return $this;
    }

    /**
     * @ORM\PrePersist
     * @ORM\PreUpdate
     */
    public function updatedTimestamps()
    {
        $dateTimeNow = new DateTime('now');
        $this->setUpdatedAt($dateTimeNow);
        if ($this->getCreatedAt() === null) {
            $this->setCreatedAt($dateTimeNow);
        }
    }

    public function getCreatedAt(): ?\DateTimeInterface
    {
        return $this->createdAt;
    }

    public function setCreatedAt(\DateTimeInterface $createdAt): self
    {
        $this->createdAt = $createdAt;

        return $this;
    }

    public function getUpdatedAt(): ?\DateTimeInterface
    {
        return $this->updatedAt;
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getWellness1(): ?string
    {
        return $this->wellness1;
    }

    public function setWellness1(?string $wellness1): self
    {
        $this->wellness1 = $wellness1;

        return $this;
    }

    public function getWellness2(): ?string
    {
        return $this->wellness2;
    }

    public function setWellness2(?string $wellness2): self
    {
        $this->wellness2 = $wellness2;

        return $this;
    }

    public function getWellness3(): ?string
    {
        return $this->wellness3;
    }

    public function setWellness3(?string $wellness3): self
    {
        $this->wellness3 = $wellness3;

        return $this;
    }

    public function getWellness4(): ?string
    {
        return $this->wellness4;
    }

    public function setWellness4(?string $wellness4): self
    {
        $this->wellness4 = $wellness4;

        return $this;
    }

    public function getWellness5(): ?string
    {
        return $this->wellness5;
    }

    public function setWellness5(?string $wellness5): self
    {
        $this->wellness5 = $wellness5;

        return $this;
    }

    public function getWellness6(): ?string
    {
        return $this->wellness6;
    }

    public function setWellness6(?string $wellness6): self
    {
        $this->wellness6 = $wellness6;

        return $this;
    }

    public function getWellness7(): ?string
    {
        return $this->wellness7;
    }

    public function setWellness7(?string $wellness7): self
    {
        $this->wellness7 = $wellness7;

        return $this;
    }

    public function getState(): ?string
    {
        return $this->state;
    }

    public function setState(?string $state): self
    {
        $this->state = $state;

        return $this;
    }

    public function getFilestudent(): ?string
    {
        return $this->filestudent;
    }

    public function setFilestudent(?string $filestudent): self
    {
        $this->filestudent = $filestudent;

        return $this;
    }

    public function getFileambassador(): ?string
    {
        return $this->fileambassador;
    }

    public function setFileambassador(?string $fileambassador): self
    {
        $this->fileambassador = $fileambassador;

        return $this;
    }

    public function getModality(): ?string
    {
        return $this->modality;
    }

    public function setModality(?string $modality): self
    {
        $this->modality = $modality;

        return $this;
    }

    public function getCode(): ?string
    {
        return $this->code;
    }

    public function setCode(?string $code): self
    {
        $this->code = $code;

        return $this;
    }

    public function getUploadDateStudent(): ?\DateTimeInterface
    {
        return $this->uploadDateStudent;
    }

    public function setUploadDateStudent(?\DateTimeInterface $uploadDateStudent): self
    {
        $this->uploadDateStudent = $uploadDateStudent;

        return $this;
    }

    public function getUploadDateAdmin(): ?\DateTimeInterface
    {
        return $this->uploadDateAdmin;
    }

    public function setUploadDateAdmin(?\DateTimeInterface $uploadDateAdmin): self
    {
        $this->uploadDateAdmin = $uploadDateAdmin;

        return $this;
    }

    public function getApprovalDate(): ?\DateTimeInterface
    {
        return $this->approvalDate;
    }

    public function setApprovalDate(?\DateTimeInterface $approvalDate): self
    {
        $this->approvalDate = $approvalDate;

        return $this;
    }

    public function getAuthorizationCode(): ?string
    {
        return $this->authorizationCode;
    }

    public function setAuthorizationCode(?string $authorizationCode): self
    {
        $this->authorizationCode = $authorizationCode;

        return $this;
    }

    public function getAttendanceCode(): ?string
    {
        return $this->attendanceCode;
    }

    public function setAttendanceCode(?string $attendanceCode): self
    {
        $this->attendanceCode = $attendanceCode;

        return $this;
    }

    public function getStudent(): ?User
    {
        return $this->student;
    }

    public function setStudent(?User $student): self
    {
        $this->student = $student;

        return $this;
    }

    public function getAdmin(): ?User
    {
        return $this->admin;
    }

    public function setAdmin(?User $admin): self
    {
        $this->admin = $admin;

        return $this;
    }

    public function getRevisionskills(): ?string
    {
        return $this->revisionskills;
    }

    public function setRevisionskills(?string $revisionskills): self
    {
        $this->revisionskills = $revisionskills;

        return $this;
    }

    public function getRevisionplans(): ?string
    {
        return $this->revisionplans;
    }

    public function setRevisionplans(?string $revisionplans): self
    {
        $this->revisionplans = $revisionplans;

        return $this;
    }

    public function getRevisionpilot(): ?string
    {
        return $this->revisionpilot;
    }

    public function setRevisionpilot(?string $revisionpilot): self
    {
        $this->revisionpilot = $revisionpilot;

        return $this;
    }

    public function getRevisionconclusions(): ?string
    {
        return $this->revisionconclusions;
    }

    public function setRevisionconclusions(?string $revisionconclusions): self
    {
        $this->revisionconclusions = $revisionconclusions;

        return $this;
    }

   
    
}
