<?php

namespace App\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\ORM\Mapping as ORM;
use DateTime;
use Symfony\Component\Security\Core\User\UserInterface;
use JMS\Serializer\Annotation as Serializer;
use JMS\Serializer\Annotation\Groups;
use JMS\Serializer\Annotation\MaxDepth;

/**
 * WellnessParticipant
 *
 * @ORM\Table(name="welness_participant")
 * @ORM\Entity(repositoryClass="App\Repository\WellnessParticipantRepository")
 * @ORM\HasLifecycleCallbacks()
 */
class WellnessParticipant
{
    /**
     * @var int
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     * @Groups({"student_list", "future_ambassador", "student_group", "report_list", "participant_list", "project_list"})
     */
    private $id;

   
    /**
     * @var string
     *
     * @ORM\Column(name="state", type="string", nullable=true, length=255)
     * @Groups({"student_list", "student_group", "report_list", "participant_list"})
     */
    private $state;

   
    /**
     * @var string
     *
     * @ORM\Column(name="filestudent", type="string", nullable=true, length=255)
     * @Groups({"student_list", "future_ambassador", "student_group", "participant_list"})
     */
    private $filestudent;

    /**
     * @var string
     *
     * @ORM\Column(name="fileambassador", type="string", nullable=true, length=255)
     */
    private $fileambassador;

    /**
     * @var string
     *
     * @ORM\Column(name="modality", type="string", nullable=true, length=255)
     * @Groups({"student_list", "future_ambassador", "student_group", "report_list", "participant_list", "project_list"}) 
     * 
     */
    private $modality;

    /**
     * @var string
     *
     * @ORM\Column(name="code", type="string", nullable=true, length=255)
     * @Groups({"student_group"}) 
     */
    private $code;

    /**
     * @var string
     *
     * @ORM\Column(name="revision", type="text", nullable=true)
     */
    private $revision;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="student_file_upload_date", nullable=true, type="datetime")
     */
    private $uploadDateStudent;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="admin_file_upload_date", nullable=true, type="datetime")
     */
    private $uploadDateAdmin;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="approval_date", nullable=true, type="date")
     * @Groups({"student_list", "student_group", "report_list", "project_list"})
     */
    private $approvalDate;

    /**
     * @var string
     *
     * @ORM\Column(name="authorization_code", type="string", nullable=true, length=255)
     */
    private $authorizationCode;

    /**
     * @var string
     *
     * @ORM\Column(name="attendance_code", type="string", nullable=true, length=255)
     */
    private $attendanceCode;

     
    /**
     * @ORM\OneToOne(targetEntity="App\Entity\User", inversedBy="wellness_participant")
     * @ORM\JoinColumn(name="student_id", referencedColumnName="id", onDelete="CASCADE")
     * @Groups({"student_list", "report_list", "project_list"})
     * @MaxDepth(4)
     */
    private $student;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\User", inversedBy="wellness_participant_admin")
     * @ORM\JoinColumn(name="admin_id", referencedColumnName="id")
     * @Groups({"project_list"})
     */
    private $admin;

   

    /**
     * @ORM\Column(name="created_at", type="datetime")
     * @Groups({"student_list"})
     */
    protected $createdAt;

    /**
     * @ORM\Column(name="updated_at", type="datetime")
     * @Groups({"student_list", "future_ambassador"})
     */
    protected $updatedAt;



     /**
     * @param mixed $updatedAt
     * @return self
     */
    public function setUpdatedAt($updatedAt)
    {
        $this->updatedAt = $updatedAt;

        return $this;
    }

    /**
     * @ORM\PrePersist
     * @ORM\PreUpdate
     */
    public function updatedTimestamps()
    {
        $dateTimeNow = new DateTime('now');
        $this->setUpdatedAt($dateTimeNow);
        if ($this->getCreatedAt() === null) {
            $this->setCreatedAt($dateTimeNow);
        }
    }

    public function getCreatedAt(): ?\DateTimeInterface
    {
        return $this->createdAt;
    }

    public function setCreatedAt(\DateTimeInterface $createdAt): self
    {
        $this->createdAt = $createdAt;

        return $this;
    }

    public function getUpdatedAt(): ?\DateTimeInterface
    {
        return $this->updatedAt;
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getState(): ?string
    {
        return $this->state;
    }

    public function setState(?string $state): self
    {
        $this->state = $state;

        return $this;
    }

    public function getFilestudent(): ?string
    {
        return $this->filestudent;
    }

    public function setFilestudent(?string $filestudent): self
    {
        $this->filestudent = $filestudent;

        return $this;
    }

    public function getFileambassador(): ?string
    {
        return $this->fileambassador;
    }

    public function setFileambassador(?string $fileambassador): self
    {
        $this->fileambassador = $fileambassador;

        return $this;
    }

    public function getModality(): ?string
    {
        return $this->modality;
    }

    public function setModality(?string $modality): self
    {
        $this->modality = $modality;

        return $this;
    }

    public function getCode(): ?string
    {
        return $this->code;
    }

    public function setCode(?string $code): self
    {
        $this->code = $code;

        return $this;
    }

    public function getUploadDateStudent(): ?\DateTimeInterface
    {
        return $this->uploadDateStudent;
    }

    public function setUploadDateStudent(?\DateTimeInterface $uploadDateStudent): self
    {
        $this->uploadDateStudent = $uploadDateStudent;

        return $this;
    }

    public function getUploadDateAdmin(): ?\DateTimeInterface
    {
        return $this->uploadDateAdmin;
    }

    public function setUploadDateAdmin(?\DateTimeInterface $uploadDateAdmin): self
    {
        $this->uploadDateAdmin = $uploadDateAdmin;

        return $this;
    }

    public function getApprovalDate(): ?\DateTimeInterface
    {
        return $this->approvalDate;
    }

    public function setApprovalDate(?\DateTimeInterface $approvalDate): self
    {
        $this->approvalDate = $approvalDate;

        return $this;
    }

    public function getAuthorizationCode(): ?string
    {
        return $this->authorizationCode;
    }

    public function setAuthorizationCode(?string $authorizationCode): self
    {
        $this->authorizationCode = $authorizationCode;

        return $this;
    }

    public function getAttendanceCode(): ?string
    {
        return $this->attendanceCode;
    }

    public function setAttendanceCode(?string $attendanceCode): self
    {
        $this->attendanceCode = $attendanceCode;

        return $this;
    }

    public function getStudent(): ?User
    {
        return $this->student;
    }

    public function setStudent(?User $student): self
    {
        $this->student = $student;

        return $this;
    }

    public function getAdmin(): ?User
    {
        return $this->admin;
    }

    public function setAdmin(?User $admin): self
    {
        $this->admin = $admin;

        return $this;
    }

    public function getRevision(): ?string
    {
        return $this->revision;
    }

    public function setRevision(?string $revision): self
    {
        $this->revision = $revision;

        return $this;
    }

    
}
