<?php

namespace App\Repository;


use Doctrine\ORM\EntityRepository;

class EvaluationRepository extends EntityRepository
{

    public function evaluationByCountry($country)
    {
        $query = $this->getEntityManager()
            ->createQuery(
            'SELECT e, s FROM App:Evaluation e
            JOIN e.student s
            WHERE s.country = :country'
        )->setParameters(array(
        'country' => $country
        ));

        try {
            return $query->getResult();
        } catch (\Doctrine\ORM\NoResultException $exception) {
            return null;
        }
    }

    public function evaluationWithoutCountry($country)
    {
        $query = $this->getEntityManager()
            ->createQuery(
            'SELECT e, s FROM App:Evaluation e
            JOIN e.student s
            WHERE s.country != :country'
        )->setParameters(array(
        'country' => $country
        ));

        try {
            return $query->getResult();
        } catch (\Doctrine\ORM\NoResultException $exception) {
            return null;
        }
    }

    public function unusableEvaluationById($id)
    {
        $query = $this->getEntityManager()
            ->createQuery(
            'SELECT e, s FROM App:Evaluation e
            JOIN e.student s
            WHERE e.id = :id
            AND e.question1 = e.postquestion1
            AND e.question2 = e.postquestion2
            AND e.question3 = e.postquestion3
            AND e.question4 = e.postquestion4
            AND e.question5 = e.postquestion5
            AND e.question6 = e.postquestion6
            AND e.question7 = e.postquestion7'
        )->setParameters(array(
        'id' => $id
        ));

        try {
            return count($query->getResult()) > 0 ? false : true ;
        } catch (\Doctrine\ORM\NoResultException $exception) {
            return null;
        }
    }

    public function unusableEvaluationForm($pre)
    {
        $query = $this->getEntityManager()
            ->createQuery(
            'SELECT e, s FROM App:Evaluation e
            JOIN e.student s
            WHERE e.id = :id
            AND e.question1 = :postquestion1
            AND e.question2 = :postquestion2
            AND e.question3 = :postquestion3
            AND e.question4 = :postquestion4
            AND e.question5 = :postquestion5
            AND e.question6 = :postquestion6
            AND e.question7 = :postquestion7'
        )->setParameters(array(
            'id'            => $pre->getId(),
            'postquestion1' => $pre->getPostquestion1(),
            'postquestion2' => $pre->getPostquestion2(),
            'postquestion3' => $pre->getPostquestion3(),
            'postquestion4' => $pre->getPostquestion4(),
            'postquestion5' => $pre->getPostquestion5(),
            'postquestion6' => $pre->getPostquestion6(),
            'postquestion7' => $pre->getPostquestion7(),
        ));

        try {
            return count($query->getResult()) > 0 ? false : true ;
        } catch (\Doctrine\ORM\NoResultException $exception) {
            return null;
        }
    }

    public function unusableEvaluationByCountry($country)
    {
        $query = $this->getEntityManager()
            ->createQuery(
            'SELECT e, s FROM App:Evaluation e
            JOIN e.student s
            WHERE s.country = :country
            AND e.question1 = e.postquestion1
            AND e.question2 = e.postquestion2
            AND e.question3 = e.postquestion3
            AND e.question4 = e.postquestion4
            AND e.question5 = e.postquestion5
            AND e.question6 = e.postquestion6
            AND e.question7 = e.postquestion7'
        )->setParameters(array(
        'country' => $country
        ));

        try {
            return $query->getResult();
        } catch (\Doctrine\ORM\NoResultException $exception) {
            return null;
        }
    }

    

}