<?php

namespace App\Repository;

use App\Entity\GrantAmbassador;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Common\Persistence\ManagerRegistry;

/**
 * @method GrantAmbassador|null find($id, $lockMode = null, $lockVersion = null)
 * @method GrantAmbassador|null findOneBy(array $criteria, array $orderBy = null)
 * @method GrantAmbassador[]    findAll()
 * @method GrantAmbassador[]    findBy(array $criteria, array $orderBy = null, $limit = null, $offset = null)
 */
class GrantAmbassadorRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, GrantAmbassador::class);
    }

    public function ambassadorGrant($user_id)
    {
      $query = $this->getEntityManager()
          ->createQuery( 
          'SELECT ga FROM App:GrantAmbassador ga
           WHERE ga.ambassador = :option
           AND ga.state = :state'
      )->setParameters(array(
        'option' => $user_id,
        'state'  => "state.approved"
       ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function ambassadorGrantByType($user_id, $type)
    {
        $query = $this->getEntityManager()
            ->createQuery( 
            'SELECT ga FROM App:GrantAmbassador ga
             JOIN ga.grant gr
             WHERE ga.ambassador = :id
             AND gr.type = :type
             AND ga.state = :state'
        )->setParameters(array(
        'id' => $user_id,
        'state'  => "state.approved",
        'type'  => $type
        ));

        try {
            return $query->getResult();
        } catch (\Doctrine\ORM\NoResultException $exception) {
            return null;
        }
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function ambassadorGrantByTypeDate($user_id, $type, $init_date)
    {
        $query = $this->getEntityManager()
            ->createQuery( 
            'SELECT ga FROM App:GrantAmbassador ga
             JOIN ga.grant gr
             WHERE ga.ambassador = :id
             AND ga.updatedAt >= :init_date
             AND gr.type = :type
             AND ga.state = :state'
        )->setParameters(array(
            'id'          => $user_id,
            'type'        => $type,
            'init_date'   => $init_date,
            'state'       => "state.approved"        
        ));

        try {
            return $query->getResult();
        } catch (\Doctrine\ORM\NoResultException $exception) {
            return null;
        }
    }

    /**
     * @param int $userId
     *
     * @return int|string
     */
    public function monthsAmbassadorGrant($user_id, $type)
    {
        try {
            $qb = $this->_em->createQueryBuilder();

            $result = $qb
                ->select("COALESCE(DATE_DIFF(CURRENT_DATE(), MAX(g.updatedAt)), -30) AS days, MAX(g.updatedAt) AS approval_date")
                ->from('App:GrantAmbassador', 'g')
                ->join('g.grant', 'gr')
                ->where('g.ambassador = :userId')
                ->andWhere('g.state = :state')
                ->andWhere('gr.type = :type')
                ->setParameters(array(
                    'userId' => $user_id,
                    'state'  => "state.approved",
                    'type'        => $type,
                ))
                ->getQuery()
                ->getOneOrNullResult();

            if($result){
                $array = [
                    "months" => intval($result['days'] / 30),
                    "approval_date" => $result['approval_date']
                ];
            }
            else {
                $array = [
                    "months" => "-1",
                    "approval_date" => "never"
                ];
            }

            return $array;

            
        } catch (\Doctrine\ORM\NoResultException $exception) {
            return 'never';
        }
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function ambassadorGrantByTypeState($user_id, $type, $state)
    {
        $query = $this->getEntityManager()
            ->createQuery( 
            'SELECT ga FROM App:GrantAmbassador ga
             JOIN ga.grant gr
             WHERE ga.ambassador = :id
             AND gr.type = :type
             AND ga.state = :state'
        )->setParameters(array(
            'id'          => $user_id,
            'type'        => $type,
            'state'       => $state        
        ));

        try {
            return $query->getResult();
        } catch (\Doctrine\ORM\NoResultException $exception) {
            return null;
        }
    }
}
