<?php

namespace App\Repository;


use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Tools\Pagination\Paginator;

class GroupeRepository extends EntityRepository
{

    /**
    * @param string $name
    *
    * @return array
    */
    public function getGroupsPagination($key, $page, $page_size, $order_column, $order_direction )
    {
        $query = $this->_em->createQueryBuilder();
        
        $query->select('g.id, g.name AS group_name, e.language AS language, g.startDate AS start_date, g.modality AS modality, CONCAT(e.firstName, \' \', e.lastName) AS ambassador_name, g')
           ->from('App:Groupe', 'g')
           ->join('g.embassador' , 'e')
           ->where('CONCAT(e.firstName, \' \', e.lastName, g.name) LIKE :name')
           ->setParameters(array(
             'name'      => '%'.$key.'%',
           ))
           
           ->orderBy($order_column, $order_direction);


        $paginator = new Paginator($query);
        $total_items = $paginator->count();
        $total_pages = (int) ceil($total_items / $page_size);

        $paginator->getQuery()
            ->setFirstResult($page_size * ($page - 1))       
            ->setMaxResults($page_size);
        
        $result = [
            'list'              => $paginator->getIterator()->getArrayCopy(),
            'items_total'       => $total_items,
            'pages_total'       => $total_pages
        ];
       
        return $result;
    }

    /**
    * @param string $name
    *
    * @return array
    */
    public function getGroupsByUserPagination($key, $page, $page_size, $order_column, $order_direction, $user_id )
    {
        $query = $this->_em->createQueryBuilder();
        
        $query->select('g.id, g.name AS group_name, e.language AS language, g.startDate AS start_date, g.modality AS modality, CONCAT(e.firstName, \' \', e.lastName) AS ambassador_name, g')
           ->from('App:Groupe', 'g')
           ->join('g.embassador' , 'e')
           ->where('e.id = :user')
           ->andWhere('CONCAT(e.firstName, \' \', e.lastName, g.name) LIKE :name')
           ->setParameters(array(
             'user'      => $user_id,
             'name'      => '%'.$key.'%',
           ))
           
           ->orderBy($order_column, $order_direction);


        $paginator = new Paginator($query);
        $total_items = $paginator->count();
        $total_pages = (int) ceil($total_items / $page_size);

        $paginator->getQuery()
            ->setFirstResult($page_size * ($page - 1))       
            ->setMaxResults($page_size);
        
        $result = [
            'list'              => $paginator->getIterator()->getArrayCopy(),
            'items_total'       => $total_items,
            'pages_total'       => $total_pages
        ];
       
        return $result;
    }

} 