<?php

namespace App\Repository;


use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Tools\Pagination\Paginator;
use Doctrine\ORM\Query\ResultSetMapping;

class ProgramMbsRepository extends EntityRepository
{

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesbyDate($init_date, $final_date)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('pm')
           ->from('App:ProgramMbs', 'pm')
           ->where('pm.state = :state')
           ->andWhere('pm.approvalDate >= :init_date')
           ->andWhere('pm.approvalDate < :final_date')
           ->setParameters(array(
             'state'         => 'state.approved',
             'init_date'     => $init_date,
             'final_date'      => $final_date,
           ))
           ->orderBy('pm.approvalDate', 'ASC');

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function getMbsArray($id)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('pm')
           ->from('App:ProgramMbs', 'pm')
           ->where('pm.id = :id')
           ->setParameters(array(
             'id'     => $id
           ));

       return $qb->getQuery()->getResult(\Doctrine\ORM\Query::HYDRATE_ARRAY);
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduates()
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('pm')
           ->from('App:ProgramMbs', 'pm')
           ->where('pm.state = :state')
           ->setParameters(array(
             'state'         => 'state.approved'
           ))
           ->orderBy('pm.approvalDate', 'ASC');

       return $qb->getQuery()->getResult();
    }

     /**
    * @param string $role
    *
    * @return array
    */
    public function projectsbyDate($init_date, $final_date)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('pm')
           ->from('App:ProgramMbs', 'pm')
           ->where('pm.createdAt >= :init_date')
           ->andWhere('pm.createdAt < :final_date')
           ->setParameters(array(
             'init_date'     => $init_date,
             'final_date'      => $final_date,
           ))
           ->orderBy('pm.createdAt', 'ASC');

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesbyDateDesc($init_date, $final_date)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('pm')
           ->from('App:ProgramMbs', 'pm')
           ->where('pm.state = :state')
           ->andWhere('pm.approvalDate >= :init_date')
           ->andWhere('pm.approvalDate < :final_date')
           ->setParameters(array(
             'state'         => 'state.approved',
             'init_date'     => $init_date,
             'final_date'      => $final_date,
           ))
           ->orderBy('pm.approvalDate', 'DESC');

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesDateRange($init_date, $final_date)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('pm')
           ->from('App:ProgramMbs', 'pm')
           ->where('pm.state = :state')
           ->andWhere('pm.approvalDate >= :init_date')
           ->andWhere('pm.approvalDate <= :final_date')
           ->setParameters(array(
             'state'         => 'state.approved',
             'init_date'     => $init_date,
             'final_date'      => $final_date,
           ))
           ->orderBy('pm.approvalDate', 'ASC');

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesDateRangeByAmbassador($init_date, $final_date, $ambassador_id)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('pm')
           ->from('App:ProgramMbs', 'pm')
           ->join('pm.student', 'st')
           ->join('st.studentgroup', 'sg')
           ->join('sg.group', 'g')
           ->where('pm.state = :state')
           ->andWhere('pm.approvalDate >= :init_date')
           ->andWhere('pm.approvalDate <= :final_date')
           ->andWhere('g.embassador = :ambassador')
           ->setParameters(array(
             'state'         => 'state.approved',
             'init_date'     => $init_date,
             'final_date'    => $final_date,
             'ambassador'    => $ambassador_id,
           ))
           ->orderBy('pm.approvalDate', 'ASC');

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesCountryLanguageDateRange($init_date, $final_date, $country, $language)
    {
       $qb = $this->_em->createQueryBuilder();

       if($country != "ALL" && $language == "ALL"){
          $qb->select('pm')
          ->from('App:ProgramMbs', 'pm')
          ->join('pm.student', 's')
          ->where('pm.state = :state')
          ->andWhere('pm.approvalDate >= :init_date')
          ->andWhere('pm.approvalDate <= :final_date')
          ->andWhere('s.country = :country')
          ->setParameters(array(
            'state'         => 'state.approved',
            'init_date'     => $init_date,
            'final_date'    => $final_date,
            'country'       => $country
          ))
          ->orderBy('pm.approvalDate', 'ASC');
       }
       else if($country == "ALL" && $language != "ALL"){
         $qb->select('pm')
          ->from('App:ProgramMbs', 'pm')
          ->join('pm.student', 's')
          ->where('pm.state = :state')
          ->andWhere('pm.approvalDate >= :init_date')
          ->andWhere('pm.approvalDate <= :final_date')
          ->andWhere('s.language = :language')
          ->setParameters(array(
            'state'         => 'state.approved',
            'init_date'     => $init_date,
            'final_date'    => $final_date,
            'language'       => $language
          ))
          ->orderBy('pm.approvalDate', 'ASC');
       }
       else if($country != "ALL" && $language != "ALL"){
         $qb->select('pm')
          ->from('App:ProgramMbs', 'pm')
          ->join('pm.student', 's')
          ->where('pm.state = :state')
          ->andWhere('pm.approvalDate >= :init_date')
          ->andWhere('pm.approvalDate <= :final_date')
          ->andWhere('s.language = :language')
          ->andWhere('s.country = :country')
          ->setParameters(array(
            'state'         => 'state.approved',
            'init_date'     => $init_date,
            'final_date'    => $final_date,
            'language'       => $language,
            'country'       => $country
          ))
          ->orderBy('pm.approvalDate', 'ASC');
       }
       

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesbyDateCount($init_date, $final_date)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('count(pm.id)')
           ->from('App:ProgramMbs', 'pm')
           ->where('pm.state = :state')
           ->andWhere('pm.approvalDate >= :init_date')
           ->andWhere('pm.approvalDate < :final_date')
           ->setParameters(array(
             'state'         => 'state.approved',
             'init_date'     => $init_date,
             'final_date'      => $final_date,
           ))
           ->orderBy('pm.approvalDate', 'ASC');

       return $qb->getQuery()->getSingleScalarResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesbyDateAmbassadorCount($init_date, $final_date, $ambassador_id)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('count(pm.id)')
           ->from('App:ProgramMbs', 'pm')
           ->join('pm.student', 's')
           ->join('s.studentgroup', 'sg')
           ->join('sg.group', 'g')
           ->where('pm.state = :state')
           ->andWhere('pm.approvalDate >= :init_date')
           ->andWhere('pm.approvalDate < :final_date')
           ->andWhere('g.embassador = :ambassador')
           ->setParameters(array(
             'state'         => 'state.approved',
             'init_date'     => $init_date,
             'final_date'    => $final_date,
             'ambassador'    => $ambassador_id,
           ))
           ->orderBy('pm.approvalDate', 'ASC');

       return $qb->getQuery()->getSingleScalarResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesbyDateCountryLanguageCount($init_date, $final_date, $country, $language)
    {
       $qb = $this->_em->createQueryBuilder();
       if($country != "ALL" && $language == "ALL"){
          $qb->select('count(pm.id)')
              ->from('App:ProgramMbs', 'pm')
              ->join('pm.student', 'u')
              ->where('pm.state = :state')
              ->andWhere('pm.approvalDate >= :init_date')
              ->andWhere('pm.approvalDate <= :final_date')
              ->andWhere('u.country = :country')
              ->setParameters(array(
                'state'           => 'state.approved',
                'init_date'       => $init_date,
                'final_date'      => $final_date,
                'country'         => $country,
              ))
              ->orderBy('pm.approvalDate', 'ASC');
       }
       else if($country == "ALL" && $language != "ALL"){
          $qb->select('count(pm.id)')
              ->from('App:ProgramMbs', 'pm')
              ->join('pm.student', 'u')
              ->where('pm.state = :state')
              ->andWhere('pm.approvalDate >= :init_date')
              ->andWhere('pm.approvalDate <= :final_date')
              ->andWhere('u.language = :language')
              ->setParameters(array(
                'state'           => 'state.approved',
                'init_date'       => $init_date,
                'final_date'      => $final_date,
                'language'         => $language,
              ))
              ->orderBy('pm.approvalDate', 'ASC');
       }
       else if($country != "ALL" && $language != "ALL"){
        $qb->select('count(pm.id)')
            ->from('App:ProgramMbs', 'pm')
            ->join('pm.student', 'u')
            ->where('pm.state = :state')
            ->andWhere('pm.approvalDate >= :init_date')
            ->andWhere('pm.approvalDate <= :final_date')
            ->andWhere('u.language = :language')
            ->andWhere('u.country = :country')
            ->setParameters(array(
              'state'           => 'state.approved',
              'init_date'       => $init_date,
              'final_date'      => $final_date,
              'language'        => $language,
              'country'         => $country,
            ))
            ->orderBy('pm.approvalDate', 'ASC');
     }

       return $qb->getQuery()->getSingleScalarResult();
    }
    

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesDateRangeCount($init_date, $final_date)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('count(pm.id)')
           ->from('App:ProgramMbs', 'pm')
           ->where('pm.state = :state')
           ->andWhere('pm.approvalDate >= :init_date')
           ->andWhere('pm.approvalDate <= :final_date')
           ->setParameters(array(
             'state'         => 'state.approved',
             'init_date'     => $init_date,
             'final_date'      => $final_date,
           ))
           ->orderBy('pm.approvalDate', 'ASC');

       return $qb->getQuery()->getSingleScalarResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesDateRangeByAmbassadorCount($init_date, $final_date, $ambassador_id)
    {
        $qb = $this->_em->createQueryBuilder();
        $qb->select('pm')
            ->from('App:ProgramMbs', 'pm')
            ->join('pm.student', 'st')
            ->join('st.studentgroup', 'sg')
            ->join('sg.group', 'g')
            ->where('pm.state = :state')
            ->andWhere('pm.approvalDate >= :init_date')
            ->andWhere('pm.approvalDate <= :final_date')
            ->andWhere('g.embassador = :ambassador')
            ->setParameters(array(
              'state'         => 'state.approved',
              'init_date'     => $init_date,
              'final_date'    => $final_date,
              'ambassador'    => $ambassador_id,
            ))
            ->orderBy('pm.approvalDate', 'ASC');

       return count($qb->getQuery()->getResult());
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesOnlineByCountry($country)
    {
        $qb = $this->_em->createQueryBuilder();
        $qb->select('count(pm.id)')
            ->from('App:ProgramMbs', 'pm')
            ->join('pm.student', 'st')
            ->where('pm.state = :state')
            ->andWhere('st.country   = :country')
            ->andWhere('pm.modality is null')
            ->setParameters(array(
              'state'         => 'state.approved',
              'country'       => $country,
            ))
            ->orderBy('pm.approvalDate', 'ASC');

       return $qb->getQuery()->getSingleScalarResult();
    }


    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesOnlineLanguage()
    {
        $qb = $this->_em->createQueryBuilder();
        $qb->select('count(pm.id)')
            ->from('App:ProgramMbs', 'pm')
            ->join('pm.student', 'st')
            ->where('pm.state = :state')
            ->andWhere('pm.modality  is null')
            ->setParameters(array(
              'state'         => 'state.approved',
            ))
            ->orderBy('st.language', 'ASC')
            ->groupBy('st.language');

       $result = $qb->getQuery()->getResult();
       $array = [
          'EN' => $result[0][1],
          'ES' => $result[1][1],
          'FR' => $result[2][1],
          'PT' => $result[3][1],
          'ZH' => $result[4][1],
       ];
       return $array;
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesCountryLanguageDateRangeCount($init_date, $final_date, $country, $language)
    {
       $qb = $this->_em->createQueryBuilder();
       if($country != "ALL" && $language == "ALL"){
         $qb->select('count(pm.id)')
         ->from('App:ProgramMbs', 'pm')
         ->join('pm.student', 's')
         ->where('pm.state = :state')
         ->andWhere('pm.approvalDate >= :init_date')
         ->andWhere('pm.approvalDate <= :final_date')
         ->andWhere('s.country = :country')
         ->setParameters(array(
           'state'         => 'state.approved',
           'init_date'     => $init_date,
           'final_date'    => $final_date,
           'country'       => $country
         ))
         ->orderBy('pm.approvalDate', 'ASC');
      }
      else if($country == "ALL" && $language != "ALL"){
         $qb->select('count(pm.id)')
         ->from('App:ProgramMbs', 'pm')
         ->join('pm.student', 's')
         ->where('pm.state = :state')
         ->andWhere('pm.approvalDate >= :init_date')
         ->andWhere('pm.approvalDate <= :final_date')
         ->andWhere('s.language = :language')
         ->setParameters(array(
           'state'         => 'state.approved',
           'init_date'     => $init_date,
           'final_date'    => $final_date,
           'language'       => $language
         ))
         ->orderBy('pm.approvalDate', 'ASC');
      }
      else if($country != "ALL" && $language != "ALL"){
         $qb->select('count(pm.id)')
         ->from('App:ProgramMbs', 'pm')
         ->join('pm.student', 's')
         ->where('pm.state = :state')
         ->andWhere('pm.approvalDate >= :init_date')
         ->andWhere('pm.approvalDate <= :final_date')
         ->andWhere('s.language = :language')
         ->andWhere('s.country = :country')
         ->setParameters(array(
           'state'         => 'state.approved',
           'init_date'     => $init_date,
           'final_date'    => $final_date,
           'language'       => $language,
           'country'       => $country
         ))
         ->orderBy('pm.approvalDate', 'ASC');
      }

       return $qb->getQuery()->getSingleScalarResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesCountryLanguageCount($country, $language)
    {

       $qb = $this->_em->createQueryBuilder();
       
       if($country != "ALL" && $language == "ALL"){
         $qb->select('count(pm.id)')
         ->from('App:ProgramMbs', 'pm')
         ->join('pm.student', 's')
         ->where('pm.state = :state')
         ->andWhere('s.country = :country')
         ->setParameters(array(
           'state'         => 'state.approved',
           'country'       => $country
         ))
         ->orderBy('pm.approvalDate', 'ASC');
      }
      else if($country == "ALL" && $language != "ALL"){
         $qb->select('count(pm.id)')
         ->from('App:ProgramMbs', 'pm')
         ->join('pm.student', 's')
         ->where('pm.state = :state')
         ->andWhere('s.language = :language')
         ->setParameters(array(
           'state'         => 'state.approved',
           'language'       => $language
         ))
         ->orderBy('pm.approvalDate', 'ASC');
      }
      else if($country != "ALL" && $language != "ALL"){
         $qb->select('count(pm.id)')
         ->from('App:ProgramMbs', 'pm')
         ->join('pm.student', 's')
         ->where('pm.state = :state')
         ->andWhere('s.language = :language')
         ->andWhere('s.country = :country')
         ->setParameters(array(
           'state'         => 'state.approved',
           'language'       => $language,
           'country'       => $country
         ))
         ->orderBy('pm.approvalDate', 'ASC');
      }

      try {
        return $qb->getQuery()->getSingleScalarResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
        return 0;
      }
       
    }

    /**
    * @param string $name
    *
    * @return array
    */
    public function mbsByStatePagination($key, $page, $page_size, $order_column, $order_direction, $state )
    {
        
        $query = $this->_em->createQueryBuilder();
        $query->select('p.id AS id, s.id AS participant_id, CONCAT(e.firstName, \' \', e.lastName) AS ambassador_name, g.name AS group_name,  s.country AS country, p.updatedAt AS updated_at, p.approvalDate AS approval_date, p.modality AS programmbs_modality, CONCAT(s.firstName, \' \', s.lastName) AS participant_name, g.program AS group_program, s , p')
            ->from('App:ProgramMbs', 'p')
            ->leftJoin('p.student', 's')
            ->leftJoin('s.studentgroup', 'sg')
            ->join('sg.group', 'g')
            ->join('g.embassador', 'e')
            ->where('CONCAT(s.firstName, \' \', s.lastName , \' \', e.firstName, \' \', e.lastName, \' \', g.name) LIKE :name')   
            ->andWhere( 'p.state = :state') 
            ->setParameters(array(
                'state'     => $state,
                'name'      => '%'.$key.'%'
            ))
            ->orderBy($order_column, $order_direction);


        $paginator = new Paginator($query);
        $total_items = $paginator->count();
        $total_pages = (int) ceil($total_items / $page_size);

        $paginator->getQuery()
            ->setFirstResult($page_size * ($page - 1))       
            ->setMaxResults($page_size);
        
        $result = [
            'list'              => $paginator->getIterator()->getArrayCopy(),
            'items_total'       => $total_items,
            'pages_total'       => $total_pages
        ];
       
        return $result;
    }

     /**
    * @param string $name
    *
    * @return array
    */
    public function mbsApprovedPagination($key, $page, $page_size, $order_column, $order_direction )
    {
        
        $query = $this->_em->createQueryBuilder();
        $query->select('p.id AS id, s.id AS participant_id, CONCAT(e.firstName, \' \', e.lastName) AS ambassador_name, g.name AS group_name,  s.country AS country, p.updatedAt AS updated_at, p.approvalDate AS approval_date, p.modality AS programmbs_modality, CONCAT(s.firstName, \' \', s.lastName) AS participant_name,CONCAT(a.firstName, \' \', a.lastName) AS admin_name,  g.program AS group_program, s , p')
            ->from('App:ProgramMbs', 'p')
            ->leftJoin('p.student', 's')
            ->leftJoin('s.studentgroup', 'sg')
            ->join('sg.group', 'g')
            ->join('g.embassador', 'e')
            ->join('p.admin', 'a')
            ->where('CONCAT(s.firstName, \' \', s.lastName , \' \', e.firstName, \' \', e.lastName, \' \', g.name) LIKE :name')   
            ->andWhere( 'p.state = :state') 
            ->setParameters(array(
                'state'     => "state.approved",
                'name'      => '%'.$key.'%'
            ))
            ->orderBy($order_column, $order_direction);


        $paginator = new Paginator($query);
        $total_items = $paginator->count();
        $total_pages = (int) ceil($total_items / $page_size);

        $paginator->getQuery()
            ->setFirstResult($page_size * ($page - 1))       
            ->setMaxResults($page_size);
        
        $result = [
            'list'              => $paginator->getIterator()->getArrayCopy(),
            'items_total'       => $total_items,
            'pages_total'       => $total_pages
        ];
       
        return $result;
    }

    /**
    * @param string $name
    *
    * @return array
    */
    public function mbsByStateLanguagePagination($key, $page, $page_size, $order_column, $order_direction, $state, $language )
    {
        
      $query = $this->_em->createQueryBuilder();
      $query->select('p.id AS id, s.id AS participant_id, CONCAT(e.firstName, \' \', e.lastName) AS ambassador_name, g.name AS group_name,  s.country AS country, p.updatedAt AS updated_at, p.approvalDate AS approval_date, p.modality AS programmbs_modality, CONCAT(s.firstName, \' \', s.lastName) AS participant_name, g.program AS group_program, s , p')
          ->from('App:ProgramMbs', 'p')
          ->leftJoin('p.student', 's')
          ->leftJoin('s.studentgroup', 'sg')
          ->join('sg.group', 'g')
          ->join('g.embassador', 'e')
          ->where('CONCAT(s.firstName, \' \', s.lastName , \' \', s.firstName, \' \', s.lastName, \' \', g.name) LIKE :name')   
          ->andWhere( 'p.state = :state') 
          ->andWhere( 's.language IN (:language)')
          ->setParameters(array(
              'state'     => $state,
              'language'     => $language,
              'name'      => '%'.$key.'%'
          ))
          ->orderBy($order_column, $order_direction);


      $paginator = new Paginator($query);
      $total_items = $paginator->count();
      $total_pages = (int) ceil($total_items / $page_size);

      $paginator->getQuery()
          ->setFirstResult($page_size * ($page - 1))       
          ->setMaxResults($page_size);
      
      $result = [
          'list'              => $paginator->getIterator()->getArrayCopy(),
          'items_total'       => $total_items,
          'pages_total'       => $total_pages
      ];
     
      return $result;
    }

     /**
    * @param string $name
    *
    * @return array
    */
    public function mbsApprovedLanguagePagination($key, $page, $page_size, $order_column, $order_direction, $language )
    {
        
      $query = $this->_em->createQueryBuilder();
      $query->select('p.id AS id, s.id AS participant_id, CONCAT(e.firstName, \' \', e.lastName) AS ambassador_name, g.name AS group_name,  s.country AS country, p.updatedAt AS updated_at, p.approvalDate AS approval_date, p.modality AS programmbs_modality, CONCAT(s.firstName, \' \', s.lastName) AS participant_name, CONCAT(a.firstName, \' \', a.lastName) AS admin_name, g.program AS group_program, s , p')
          ->from('App:ProgramMbs', 'p')
          ->leftJoin('p.student', 's')
          ->leftJoin('s.studentgroup', 'sg')
          ->join('sg.group', 'g')
          ->join('g.embassador', 'e')
          ->join('p.admin', 'a')
          ->where('CONCAT(s.firstName, \' \', s.lastName , \' \', s.firstName, \' \', s.lastName, \' \', g.name) LIKE :name')   
          ->andWhere( 'p.state = :state') 
          ->andWhere( 's.language IN (:language)')
          ->setParameters(array(
              'state'     => "state.approved",
              'language'     => $language,
              'name'      => '%'.$key.'%'
          ))
          ->orderBy($order_column, $order_direction);


      $paginator = new Paginator($query);
      $total_items = $paginator->count();
      $total_pages = (int) ceil($total_items / $page_size);

      $paginator->getQuery()
          ->setFirstResult($page_size * ($page - 1))       
          ->setMaxResults($page_size);
      
      $result = [
          'list'              => $paginator->getIterator()->getArrayCopy(),
          'items_total'       => $total_items,
          'pages_total'       => $total_pages
      ];
     
      return $result;
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function stringReplace($id)
    {
      
        $rsm = new ResultSetMapping();
        // build rsm here
        $replace = '\"\"';
        $sql = "UPDATE program_mbs SET paperwork10 = REPLACE(paperwork10, 'null', '".$replace."') WHERE program_mbs.id = ".$id ;
        

        try {
          $query = $this->_em->createNativeQuery($sql, $rsm);
          $result = $query->getResult();
          return $result;
      } catch (\Doctrine\DBAL\DBALException $e) {
          // Manejar la excepción, mostrar detalles o registrarla
          echo "Error: " . $e->getMessage();
      }
    }


      /**
    * @param string $role
    *
    * @return array
    */
    public function stringReplaceNull($id)
    {
      $replace = '\"\"';

      $query = $this->_em->createQueryBuilder();
      
      $query
        ->update('App:ProgramMbs', 'p')
        ->set('p.paperwork10', 'REPLACE(p.paperwork10, :search, :string)')
        ->where('p.id = :id')
        ->setParameter('search', 'null')
        ->setParameter('string', $replace)
        ->setParameter('id', $id);
        

        try {
          return $query->getQuery()->getResult();
        } catch (\Doctrine\DBAL\DBALException $e) {
            // Manejar la excepción, mostrar detalles o registrarla
            echo "Error: " . $e->getMessage();
        }

    }

}