<?php

namespace App\Repository;

use App\Entity\Stop;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Common\Persistence\ManagerRegistry;

/**
 * @method Stop|null find($id, $lockMode = null, $lockVersion = null)
 * @method Stop|null findOneBy(array $criteria, array $orderBy = null)
 * @method Stop[]    findAll()
 * @method Stop[]    findBy(array $criteria, array $orderBy = null, $limit = null, $offset = null)
 */
class StopRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, Stop::class);
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function stopByState($state)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('s')
           ->from('App:Stop', 's')
           ->where('s.state = :state')
           ->setParameters(array(
             'state'         => $state,
           ))
           ->orderBy('s.createdAt', 'DESC');

       return $qb->getQuery()->getResult();
    }

   

    public function stopByLanguageState($state, $lang)
    {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s FROM App:Stop s
           JOIN s.student st
           WHERE st.language IN (:lang)
           AND s.state = :state
           ORDER BY s.createdAt DESC'
      )->setParameters(array(
        'lang' => $lang,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
    }

     /**
    * @param string $course_id
    *
    * @return array
    */
    public function deleteStopByCourse($course_id, $student_id)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->delete('App:Stop', 's')
            ->where('s.course = :course')
            ->andWhere('s.student = :student')
           ->setParameters(array(
            'course'         => $course_id,
            'student'        => $student_id,
           ));

       return $qb->getQuery()->getResult();
    }
}
