<?php

namespace App\Repository;


use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Tools\Pagination\Paginator;
use Doctrine\ORM\Query\Expr\Join;

class StudentGroupRepository extends EntityRepository
{
    public function studentsMbsByEmbassador($embassador_id)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           WHERE g.embassador = :id'
      )->setParameter('id', $embassador_id);

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function successStoryByEmbassador($embassador_id)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programmbs p
           WHERE g.embassador = :id
           AND p.history1 IS NOT NULL'
      )->setParameter('id', $embassador_id);

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function listSuccessStory()
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programmbs p
           WHERE p.history1 IS NOT NULL
           ORDER BY p.approvalDate DESC'
      );

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  /**
    * @param string $name
    *
    * @return array
    */
    public function listSuccessStoryPagination($key, $page, $page_size, $order_column, $order_direction )
    {
        
        $query = $this->_em->createQueryBuilder();
        $query->select('s.id AS id, s.country AS country, p.approvalDate AS approval_date, p.id AS programmbs_id, g.name AS group_name , CONCAT(s.firstName, \' \', s.lastName) AS student_name, CONCAT(e.firstName, \' \', e.lastName) AS ambassador_name,  sg')
            ->from('App:StudentGroup', 'sg')
            ->join('sg.group', 'g')
            ->join('g.embassador', 'e')
            ->join('sg.student', 's')
            ->join('s.programmbs', 'p')

            ->where('p.history1 is not null')
            ->andWhere('CONCAT(s.firstName, \' \', s.lastName, g.name, s.country, e.firstName, \' \', e.lastName ) LIKE :name')            
            ->setParameters(array(
                'name'      => '%'.$key.'%'
            ))
            ->orderBy($order_column, $order_direction);


        $paginator = new Paginator($query);
        $total_items = $paginator->count();
        $total_pages = (int) ceil($total_items / $page_size);

        $paginator->getQuery()
            ->setFirstResult($page_size * ($page - 1))       
            ->setMaxResults($page_size);
        
        $result = [
            'list'              => $paginator->getIterator()->getArrayCopy(),
            'items_total'       => $total_items,
            'pages_total'       => $total_pages
        ];
       
        return $result;
    }

  public function videoPromotionStatement()
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programmbs p
           WHERE p.promotion6 IS NOT NULL
           ORDER BY p.updatedAt DESC'
      );

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentMbsByState($state)
  {
    $query = $this->getEntityManager()
        ->createQuery(
        'SELECT s, g FROM App:StudentGroup s
         JOIN s.group g
         JOIN s.student st
         JOIN st.programmbs p
         WHERE p.state = :state
         ORDER BY p.updatedAt'
    )->setParameters(array(
      'state' => $state
    ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsByLanguage($lang)
  {
    $query = $this->getEntityManager()
        ->createQuery(
        'SELECT s FROM App:StudentGroup s
         JOIN s.student st
         WHERE st.language IN (:lang)'
    )->setParameters(array(
      'lang' => $lang
    ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentAmbassadorByState($state)
  {
    $query = $this->getEntityManager()
        ->createQuery(
        'SELECT s, g FROM App:StudentGroup s
         JOIN s.group g
         JOIN s.student st
         JOIN st.programsa p
         WHERE p.state = :state'
    )->setParameters(array(
      'state' => $state
    ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentWellnessByState($state)
  {
    $query = $this->getEntityManager()
        ->createQuery(
        'SELECT s, g FROM App:StudentGroup s
         JOIN s.group g
         JOIN s.student st
         JOIN st.wellness p
         WHERE p.state = :state'
    )->setParameters(array(
      'state' => $state
    ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }


  public function studentsMbsStateByEmbassador($embassador_id, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programmbs p
           WHERE g.embassador = :id
           AND p.state = :state'
      )->setParameters(array(
        'id' => $embassador_id,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsMbsStateByEmbassadorFromDate($embassador_id, $state, $date)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programmbs p
           WHERE g.embassador = :id
           AND p.state = :state
           AND p.approvalDate >= :init_date'
      )->setParameters(array(
        'id' => $embassador_id,
        'state' => $state,
        'init_date' => $date
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function lastMbsGraduatedByEmbassador($embassador_id, $state)
  {
    $qb = $this->_em->createQueryBuilder();
    $qb->select('count(p.id)') 
        ->from('App:ProgramMbs', 'p')
        ->join('p.student', 's')
        ->join('s.studentgroup', 'st')
        ->join('st.group', 'g')
        ->where('g.embassador = :id')
        ->andWhere('p.state = :state')
        ->orderBy('p.approvalDate', 'DESC')
        ->setParameters(array(
          'id'        => $embassador_id,
          'state'     => $state,
        ));

        return  $qb->getQuery()->getSingleScalarResult();
        
  }

  public function lastMbsGraduatedByEmbassadorDate($embassador_id, $state)
  {
    $qb = $this->_em->createQueryBuilder();
    $qb->select('p') 
        ->from('App:ProgramMbs', 'p')
        ->join('p.student', 's')
        ->join('s.studentgroup', 'st')
        ->join('st.group', 'g')
        ->setMaxResults(1)
        ->where('g.embassador = :id')
        ->andWhere('p.state = :state')
        ->orderBy('p.approvalDate', 'DESC')
        ->setParameters(array(
          'id'        => $embassador_id,
          'state'     => $state,
        ));

        $result =  $qb->getQuery()->getResult();
        return $result[0]->getApprovalDate();
        
  }

  public function studentsMbsStateByEmbassadorProgram($embassador_id, $state, $program)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programmbs p
           WHERE g.embassador = :id
           AND g.program = :program
           AND p.state = :state'
      )->setParameters(array(
        'id' => $embassador_id,
        'state' => $state,
        'program' => $program
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsMbsStateByGroup($group_id, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programmbs p
           WHERE g.id = :id
           AND p.state = :state'
      )->setParameters(array(
        'id' => $group_id,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsMbsByGroup($group_id)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           WHERE g.id = :id'
      )->setParameters(array(
        'id' => $group_id,
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsWellnessStateByGroup($group_id, $state)
  {

       

       $qb = $this->_em->createQueryBuilder();
       $qb->addSelect('sg')
          ->from('App:StudentGroup', 'sg')
          ->join('sg.student', 'st')
          ->join('st.wellness', 'w')
          ->andWhere('sg.group   = :group')
          ->andWhere('w.state   = :state')
          ->setParameters(array(
            'group'     => $group_id,
            'state'     => $state,
          )); 

        $qbResult = $qb->getQuery()->getResult();

        $qb2 = $this->_em->createQueryBuilder();
        $qb2->select('sag')
            ->from('App:StudentAmbassadorGroup', 'sag')
            ->join('sag.student', 'sta')
            ->join('sta.wellness', 'wa')
            ->andWhere('sag.group   = :group')
            ->andWhere('wa.state   = :state')       
            ->setParameters(array(
            'group'     => $group_id,
            'state'     => $state,
            ));
        
        $qb2Result = $qb2->getQuery()->getResult();


      try {
          return array_merge($qbResult, $qb2Result);
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsWellnessParticipantStateByGroup($group_id, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.wellness_participant p
           WHERE g.id = :id
           AND p.state = :state'
      )->setParameters(array(
        'id' => $group_id,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsMbsStateByAmbassador($ambassador_id, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programmbs p
           WHERE g.embassador = :id
           AND p.state = :state'
      )->setParameters(array(
        'id' => $ambassador_id,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsMbsDifferentStateByGroup($group_id, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programmbs p
           WHERE g.id = :id
           AND p.state != :state'
      )->setParameters(array(
        'id' => $group_id,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsByGroup($group_id)
  {
    $qb2 = $this->_em->createQueryBuilder();
    $qb2->addSelect('sg', 'sag')
        ->from('App:StudentGroup', 'sg')
        ->from('App:StudentAmbassadorGroup', 'sag')
        ->andWhere( $qb2->expr()->orX('sg.group = :group',  'sag.group = :group') )       
        ->setParameters(array(
        'group'     => $group_id,
        ));

      try {
          return $qb2->getQuery()->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsDifferentStateByGroup($group_id, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programmbs p
           WHERE g.id = :id
           AND p.state = :state'
      )->setParameters(array(
        'id' => $group_id,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  /**
    * @param string $role
    *
    * @return array
    */
    public function studentsDifferentS3333tateByGroup($group_id, $state)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('s')
           ->from('App:StudentGroup', 's')
           ->join('s.group', 'g')
           ->join('s.student', 'st')
           ->join('st.programmbs', 'p')
           ->where('g.id = :id')
           ->andWhere('p.state = :state')
           ->setParameters(array(
             'id'        => $group_id,
             'state'     => $state,
           ));

       return $qb->getQuery()->getResult();
    }

  public function studentsMbsStateByLanguage($lang, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programmbs p
           WHERE st.language IN (:lang)
           AND p.state = :state 
           ORDER BY p.updatedAt'
      )->setParameters(array(
        'lang' => $lang,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsMbsStateModalityByEmbassador($embassador_id, $state, $modality)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programmbs p
           WHERE g.embassador = :id
           AND p.modality = :modality
           AND p.state = :state'
      )->setParameters(array(
        'id' => $embassador_id,
        'state' => $state,
        'modality' => $modality
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsAmbassadorStateByEmbassador($embassador_id, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programsa p
           WHERE g.embassador = :id
           AND p.state = :state'
      )->setParameters(array(
        'id' => $embassador_id,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsWellnessParticipantStateByEmbassador($embassador_id, $state)
  {
   
        $query = $this->getEntityManager()
            ->createQuery(
            'SELECT s, g FROM App:StudentGroup s
             JOIN s.group g
             JOIN s.student st
             JOIN st.wellness_participant p
             WHERE g.embassador = :id
             AND p.state = :state'
        )->setParameters(array(
          'id' => $embassador_id,
          'state' => $state
        ));
  
        try {
            return $query->getResult();
        } catch (\Doctrine\ORM\NoResultException $exception) {
            return null;
        }
  }

  public function studentsWellnessStateByEmbassador($embassador_id, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.wellness p
           WHERE g.embassador = :id
           AND p.state = :state'
      )->setParameters(array(
        'id' => $embassador_id,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsAmbassadorStateByEmbassadorCount($embassador_id, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT COUNT(s.id) FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programsa p
           WHERE g.embassador = :id
           AND p.state = :state'
      )->setParameters(array(
        'id' => $embassador_id,
        'state' => $state
      ));

      try {
          return $query->getSingleScalarResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsWellnessParticipantStateByEmbassadorCount($embassador_id, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT COUNT(s.id) FROM App:WellnessParticipant s
           JOIN s.group g
           JOIN s.student st
           JOIN st.wellness_participant p
           WHERE g.embassador = :id
           AND p.state = :state'
      )->setParameters(array(
        'id' => $embassador_id,
        'state' => $state
      ));

      try {
          return $query->getSingleScalarResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  /**
    * @param string $role
    *
    * @return array
    */
    public function nsaByAmbassadorCount($id_ambassador)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('count(s.id)')
           ->from('App:StudentGroup', 's')
           ->join('s.group', 'g')
           ->join('s.student', 'st')
           ->where('st.roles = :role1')
           ->andWhere('g.embassador = :embassador')
           ->setParameters(array(
             'role1'            => '["ROLE_EMBASSADOR"]',
             'embassador'       => $id_ambassador,
           ));

       return $qb->getQuery()->getSingleScalarResult(); 
    }

   /**
    * @param string $role
    *
    * @return array
    */
    public function nsaByAmbassador($id_ambassador)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('s')
       ->from('App:StudentGroup', 's')
       ->join('s.group', 'g')
       ->join('s.student', 'st')
       ->where('st.roles = :role1')
       ->andWhere('g.embassador = :embassador')
       ->setParameters(array(
         'role1'            => '["ROLE_EMBASSADOR"]',
         'embassador'       => $id_ambassador,
       ));

       return $qb->getQuery()->getResult(); 
    }

    

  public function studentsAmbassadorStateByLanguage($lang, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programsa p
           WHERE st.language IN  (:lang)
           AND p.state = :state'
      )->setParameters(array(
        'lang' => $lang,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsWellnessStateByLanguage($lang, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.wellness p
           WHERE st.language IN  (:lang)
           AND p.state = :state'
      )->setParameters(array(
        'lang' => $lang,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsAmbassadorStateByGroup($group_id, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programsa p
           WHERE g.id = :id
           AND p.state = :state'
      )->setParameters(array(
        'id' => $group_id,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsAmbassadorStateModalityByEmbassador($embassador_id, $state, $modality)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programsa p
           WHERE g.embassador = :id
           AND p.modality = :modality
           AND p.state = :state'
      )->setParameters(array(
        'id' => $embassador_id,
        'state' => $state,
        'modality' => $modality
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

 
  public function studentListbyGroupPagination($group_id, $sort_field, $order_key )
  {
    $qb = $this->_em->createQueryBuilder();
    $qb->addSelect('count(sg.id)', 'count(sag.id)')
           ->from('App:StudentGroup', 'sg')
           ->from('App:StudentAmbassadorGroup', 'sag')           
           ->andWhere('sg.group   = :group')
           ->andWhere('sag.group   = :group')
           ->setParameters(array(
             'group'     => $group_id,
           ));

    $qbsg = $this->_em->createQueryBuilder();
    $qbsg->addSelect('count(sg.id)')
        ->from('App:StudentGroup', 'sg')
        ->andWhere('sg.group   = :group')
        ->setParameters(array(
            'group'     => $group_id,
        ));

    $qbsg_total = $qbsg->getQuery()->getSingleScalarResult() > 0 ? true : false ;

    $qbsag = $this->_em->createQueryBuilder();
    $qbsag->addSelect('count(sag.id)')
        ->from('App:StudentAmbassadorGroup', 'sag')
        ->andWhere('sag.group   = :group')
        ->setParameters(array(
            'group'     => $group_id,
        ));

    $qbsag_total = $qbsag->getQuery()->getSingleScalarResult() > 0 ? true : false ;

    if($qbsag_total && $qbsg_total){
        $qb = $this->_em->createQueryBuilder();
        $qb->addSelect('sg', 'sag')
           ->from('App:StudentGroup', 'sg')
           ->from('App:StudentAmbassadorGroup', 'sag')
           ->join('sag.student', 'sta')
           ->join('sg.student', 'st')
           ->andWhere('sg.group   = :group')
           ->andWhere('sag.group   = :group')
           ->addOrderBy('sta.'.$sort_field, $order_key)
           ->addOrderBy('st.'.$sort_field, $order_key)
           ->setParameters(array(
             'group'     => $group_id,
           ));
    }
    else if($qbsag_total && !$qbsg_total){
        $qb = $this->_em->createQueryBuilder();
        $qb->addSelect('sag')
           ->from('App:StudentAmbassadorGroup', 'sag')  
           ->join('sag.student', 'sta')
           ->andWhere('sag.group   = :group')
           ->addOrderBy('sta.'.$sort_field, $order_key)
           ->andWhere('sag.group   = :group')
           ->setParameters(array(
             'group'     => $group_id,
           ));

    }
    else if(!$qbsag_total && $qbsg_total){
        $qb = $this->_em->createQueryBuilder();
        $qb->addSelect('sg')
           ->from('App:StudentGroup', 'sg')
           ->andWhere('sg.group   = :group')
           ->join('sg.student', 'st')
           ->orderBy('st.'.$sort_field, $order_key)
           ->setParameters(array(
             'group'     => $group_id,
           ));

    }
    else{
        $qb = $this->_em->createQueryBuilder();
        $qb->addSelect('sg')
           ->from('App:StudentGroup', 'sg')
           ->andWhere('sg.group   = :group')
           ->setParameters(array(
             'group'     => $group_id,
           ));
    }



      try {
        return $qb->getQuery()->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

}