<?php

namespace App\Repository;


use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Tools\Pagination\Paginator;

class UserRepository extends EntityRepository
{
    public function userSearch($input)
    {
        $query = $this->getEntityManager()
            ->createQuery(
            'SELECT u FROM App:User u
             WHERE  CONCAT(u.firstName, \' \', u.lastName) LIKE :input'
        )->setParameter('input', '%' . $input . '%');

        try {
            return $query->getResult();
        } catch (\Doctrine\ORM\NoResultException $exception) {
            return null;
        }
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function getStudents()
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('u')
           ->from('App:User', 'u')
           ->where('u.roles LIKE :role1')
           ->setParameters(array(
             'role1'     => '%ROLE_STUDENT%',
           ))
           ->orderBy('u.firstName', 'ASC');

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $name
    *
    * @return array
    */
    public function getStudentsByNamePagination($name, $page, $postsPerPage)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('u')
           ->from('App:User', 'u')
           ->where('u.roles LIKE :role1')
           ->andWhere('u.firstName LIKE :name')
           ->setParameters(array(
             'role1'     => '%ROLE_STUDENT%',
             'name'      => '%'.$name.'%',
           ))
           ->orderBy('u.firstName', 'ASC');

           $query = $this->getEntityManager()
            ->createQuery(
            'SELECT u FROM App:User u
             WHERE  CONCAT(u.firstName, \' \', u.lastName) LIKE :input'
           )->setParameter('input', '%' . $name . '%');

           $paginator = new Paginator($query->setHydrationMode(\Doctrine\ORM\Query::HYDRATE_ARRAY));

           $paginator->getQuery()
       
             ->setFirstResult($postsPerPage * ($page - 1))
       
             ->setMaxResults($postsPerPage);
       
           return $paginator->getIterator()->getArrayCopy();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function getMbsStudents()
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('u')
           ->from('App:User', 'u')
           ->where('u.roles = :role1')
           ->setParameters(array(
             'role1'     => '["ROLE_STUDENT"]',
           ))
           ->orderBy('u.firstName', 'ASC');

       return $qb->getQuery()->getResult(); 
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function getAmbassadors()
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('u')
           ->from('App:User', 'u')
           ->where('u.roles = :role1')
           
           ->setParameters(array(
            'role1'     => '["ROLE_EMBASSADOR"]',
           ))
           ->addOrderBy('u.country','ASC')
           ->addOrderBy('u.firstName' , 'ASC');

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function getAmbassadorsContract()
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('u')
           ->from('App:User', 'u')
           ->where('u.roles = :role1')
           ->setParameters(array(
             'role1'     => '["ROLE_EMBASSADOR"]',
           ))
           ->addOrderBy('u.contractDate' , 'DESC');

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $name
    *
    * @return array
    */
    public function getAmbassadorsPagination($key, $page, $page_size, $order_column, $order_direction )
    {
        
        $query = $this->_em->createQueryBuilder();
        $query->select('u.id AS id, u.username AS username, u.language AS language, u.country AS country, u.code AS code, CONCAT(u.firstName, \' \', u.lastName) AS ambassador_name, u')
            ->from('App:User', 'u')
            ->where('u.roles = :role')
            ->andWhere('CONCAT(u.firstName, \' \', u.lastName, \' \', u.username) LIKE :name')            
            ->setParameters(array(
                'role'     => '["ROLE_EMBASSADOR"]',
                'name'      => '%'.$key.'%'
            ))
            ->orderBy($order_column, $order_direction); 


        $paginator = new Paginator($query);
        $total_items = $paginator->count();
        $total_pages = (int) ceil($total_items / $page_size);

        $paginator->getQuery()
            //->useResultCache(true)
            ->setFirstResult($page_size * ($page - 1))       
            ->setMaxResults($page_size);
        
        $result = [
            'list'              => $paginator->getIterator()->getArrayCopy(),
            'items_total'       => $total_items,
            'pages_total'       => $total_pages
        ];
       
        return $result;
    }

    /**
    * @param string $name
    *
    * @return array
    */
    public function getParticipantListPagination($key, $page, $page_size, $order_column, $order_direction )
    {
        
        $query = $this->_em->createQueryBuilder();
        $query->select('u.id AS id, u.username AS username, u.createdAt AS created_at, u.whatsapp AS whatsapp, u.language AS language, u.roles AS role, u.country AS country, u.code AS code, CONCAT(u.firstName, \' \', u.lastName) AS participant_name, u')
            ->from('App:User', 'u')
            ->where('CONCAT(u.firstName, \' \', u.lastName) LIKE :name')   
            ->andWhere( $query->expr()->orX('u.roles = :role1',  'u.roles = :role2' , 'u.roles = :role3' ) ) 
            ->setParameters(array(
                'role1'     => '["ROLE_STUDENT"]',
                'role2'     => '["ROLE_STUDENT_EMBASSADOR"]',
                'role3'     => '["ROLE_FACILITATOR"]',
                'name'      => '%'.$key.'%'
            ))
            ->orderBy($order_column, $order_direction);


        $paginator = new Paginator($query);
        $total_items = $paginator->count();
        $total_pages = (int) ceil($total_items / $page_size);

        $paginator->getQuery()
            ->setFirstResult($page_size * ($page - 1))       
            ->setMaxResults($page_size);
        
        $result = [
            'list'              => $paginator->getIterator()->getArrayCopy(),
            'items_total'       => $total_items,
            'pages_total'       => $total_pages
        ];
       
        return $result;
    }

    /**
    * @param string $name
    *
    * @return array
    */
    public function getGrantMemberListPagination($key, $page, $page_size, $order_column, $order_direction )
    {
        
        $query = $this->_em->createQueryBuilder();
        $query->select('u.id AS id, u.username AS username, u.createdAt AS created_at, CONCAT(u.firstName, \' \', u.lastName) AS participant_name, CONCAT(a.firstName, \' \', a.lastName) AS ambassador_name, g.name AS group_name, u')
            ->from('App:User', 'u')
            ->leftJoin('u.studentgroup', 'sg')
            ->join('sg.group', 'g')
            ->join('g.embassador', 'a')
            ->where('CONCAT(u.firstName, \' \', u.lastName, \' \', a.firstName, \' \', a.lastName, \' \', g.name) LIKE :key') 
            ->andWhere( $query->expr()->orX('u.roles = :role1',  'u.roles = :role2' , 'u.roles = :role3' , 'u.roles = :role4' ) )
            ->setParameters(array(
                'role1'     => '["ROLE_STUDENT"]',
                'role2'     => '["ROLE_STUDENT_EMBASSADOR"]',
                'role3'     => '["ROLE_EMBASSADOR"]',
                'role4'     => '["ROLE_FACILITATOR"]',
                'key'      => '%'.$key.'%'
            ))
            ->orderBy($order_column, $order_direction);


        $paginator = new Paginator($query);
        $total_items = $paginator->count();
        $total_pages = (int) ceil($total_items / $page_size);

        $paginator->getQuery()
            ->setFirstResult($page_size * ($page - 1))       
            ->setMaxResults($page_size);
        
        $result = [
            'list'              => $paginator->getIterator()->getArrayCopy(),
            'items_total'       => $total_items,
            'pages_total'       => $total_pages
        ];
       
        return $result;
    }

    /**
    * @param string $name
    *
    * @return array
    */
    public function getPotentialSaListPagination($key, $page, $page_size, $order_column, $order_direction )
    {
        
        $query = $this->_em->createQueryBuilder();
        $query->select('u.id AS id, u.username AS username, u.createdAt AS created_at, CONCAT(u.firstName, \' \', u.lastName) AS participant_name, CONCAT(a.firstName, \' \', a.lastName) AS ambassador_name, g.name AS group_name, pm.state AS programmbs_state, u')
            ->from('App:User', 'u')
            ->leftJoin('u.studentgroup', 'sg')
            ->leftJoin('u.programmbs', 'pm')
            ->join('sg.group', 'g')
            ->join('g.embassador', 'a')
            ->where('CONCAT(u.firstName, \' \', u.lastName, \' \', a.firstName, \' \', a.lastName, \' \', g.name) LIKE :key')   
            ->andWhere( 'u.roles = :role1'  ) 
            ->setParameters(array(
                'role1'     => '["ROLE_STUDENT"]',
                'key'      => '%'.$key.'%'
            ))
            ->orderBy($order_column, $order_direction);


        $paginator = new Paginator($query);
        $total_items = $paginator->count();
        $total_pages = (int) ceil($total_items / $page_size);

        $paginator->getQuery()
            ->setFirstResult($page_size * ($page - 1))       
            ->setMaxResults($page_size);
        
        $result = [
            'list'              => $paginator->getIterator()->getArrayCopy(),
            'items_total'       => $total_items,
            'pages_total'       => $total_pages
        ];
       
        return $result;
    }

    /**
    * @param string $name
    *
    * @return array
    */
    public function getParticipantByGroupPagination($key, $page, $page_size, $order_column, $order_direction, $group )
    {
        
        $query = $this->_em->createQueryBuilder();
        $query->select('u.id AS id, u.username AS username,  u.createdAt AS created_at, u.whatsapp AS whatsapp, u.language AS language, u.roles AS role, u.country AS country, u.code AS code, CONCAT(u.firstName, \' \', u.lastName) AS participant_name, u')
            ->from('App:User', 'u')
            ->leftJoin('u.studentgroup', 'sg')    
            ->leftJoin('u.studentambassadorgroup', 'sag')         
            ->where('CONCAT(u.firstName, \' \', u.lastName) LIKE :name')   
            ->andWhere( $query->expr()->orX('sg.group = :group',  'sag.group = :group') )        
            ->setParameters(array(
                'name'      => '%'.$key.'%',
                'group'     => $group
            ))
            ->orderBy($order_column, $order_direction);


        $paginator = new Paginator($query);
        $total_items = $paginator->count();
        $total_pages = (int) ceil($total_items / $page_size);

        $paginator->getQuery()
            ->setFirstResult($page_size * ($page - 1))       
            ->setMaxResults($page_size);
        
        $result = [
            'list'              => $paginator->getIterator(),
            'items_total'       => $total_items,
            'pages_total'       => $total_pages
        ];
       
        return $result;
    }
    

    /**
    * @param string $name
    *
    * @return array
    */
    public function getParticipantByGroup($group )
    {
        
        $qb = $this->_em->createQueryBuilder();
        $qb->select('u')
            ->from('App:User', 'u')
            ->leftJoin('u.studentgroup', 'sg')    
            ->leftJoin('u.studentambassadorgroup', 'sag')         
            ->andWhere( $qb->expr()->orX('sg.group = :group',  'sag.group = :group') )
            ->setParameters(array(
                'group'     => $group
            ))
            ->addOrderBy('u.createdAt' , 'DESC');
    
        return $qb->getQuery()->getResult();
    }


    /**
    * @param string $role
    *
    * @return array
    */
    public function getAdmins()
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('u')
           ->from('App:User', 'u')
           ->where('u.roles LIKE :role1')
           ->setParameters(array(
             'role1'     => '%ROLE_ADMIN%',
           ))
           ->orderBy('u.firstName', 'ASC');

       return $qb->getQuery()->getResult();
    }

    
    /**
    * @param string $role
    *
    * @return array
    */
    public function getLanguageAdmins()
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('u')
           ->from('App:User', 'u')
           ->where('u.roles LIKE :role1')
           ->setParameters(array(
             'role1'     => '%ROLE_LANGUAGE_ADMIN%',
           ))
           ->orderBy('u.firstName', 'ASC');

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function getQualifierAdmins()
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('u')
           ->from('App:User', 'u')
           ->where('u.roles LIKE :role1')
           ->setParameters(array(
             'role1'     => '%ROLE_PROJECT_QUALIFIER%',
           ))
           ->orderBy('u.firstName', 'ASC');

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function getAdminsLanguageMessage($language, $type_message)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('u')
           ->from('App:User', 'u')
           ->where('u.roles = :role')
           ->andWhere('u.languageGrader LIKE :language')
           ->andWhere('u.message LIKE        :message')
           ->setParameters(array(
             'role'         => '["ROLE_LANGUAGE_ADMIN"]',
             'language'     => '%'.$language.'%',
             'message'      => '%'.$type_message.'%',
           ))
           ->orderBy('u.firstName', 'ASC');

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function getAdminsMessage($language, $type_message)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('u')
           ->from('App:User', 'u')
           ->where('u.roles = :role')
           ->andWhere('u.message LIKE        :message')
           ->setParameters(array(
             'role'         => '["ROLE_ADMIN"]',
             'message'      => '%'.$type_message.'%',
           ))
           ->orderBy('u.firstName', 'ASC');

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function userByRole($role)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('u')
           ->from('App:User', 'u')
           ->where('u.roles LIKE :roles')
           ->setParameter('roles', '%"'.$role.'"%')
           ->orderBy('u.firstName', 'ASC');

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function ambassadorsTotal()
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('u')
           ->from('App:User', 'u')
           ->where('u.roles = :role')
           ->setParameters(array(
            'role'         => '["ROLE_EMBASSADOR"]',
           ));

        return count($qb->getQuery()->getScalarResult());
    }


    /**
    * @param string $role
    *
    * @return array
    */
    public function userByRoleXLanguage($role, $lang)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('u')
           ->from('App:User', 'u')
           ->where('u.roles LIKE :roles')
           ->andWhere('u.language = :lang')
           ->setParameters(array(
             'roles'     => '%"'.$role.'"%',
             'language'  => '%"'.$lang.'"%',
           ))
           ->orderBy('u.firstName', 'ASC');

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function userByRoleCountry($role, $country)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('u')
           ->from('App:User', 'u')
           ->where('u.roles LIKE :roles')
           ->andWhere('u.country = :country')
           ->setParameters(array(
             'roles'     => '%"'.$role.'"%',
             'country'   => $country,
           ))
           ->orderBy('u.firstName', 'ASC');

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function userByRoleWithoutCountry($role, $country)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('u')
           ->from('App:User', 'u')
           ->where('u.roles LIKE :roles')
           ->andWhere('u.country != :country')
           ->setParameters(array(
             'roles'     => '%"'.$role.'"%',
             'country'   => $country,
           ))
           ->orderBy('u.firstName', 'ASC');

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function userSuccessStory()
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('p')
           ->from('App:Programmbs', 'p')
           ->where($qb->expr()->isNotNull("p.history1"));

       return $qb->getQuery()->getResult();
    }



    public function futureEmbassadors()
    {
      $query = $this->getEntityManager()
          ->createQuery( 
          'SELECT u, e FROM App:User u
           JOIN u.evaluation e
           JOIN u.programmbs p
           WHERE e.postquestion10 = :option
           AND u.roles LIKE :role
           AND p.state = :state' 
      )->setParameters(array(
        'option' => 'option1',
        'role' => "%ROLE_STUDENT%",
        'state' => 'state.approved'
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
    }

    public function futureEmbassadorsByLanguage($lang)
    {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT u, e FROM App:User u
           JOIN u.evaluation e
           JOIN u.programmbs p
           WHERE e.postquestion10 = :option
           AND u.roles LIKE :role
           AND u.language IN  (:lang)
           AND p.state = :state'
      )->setParameters(array(
        'option' => 'option1',
        'role' => "%ROLE_STUDENT%",
        'lang' => $lang,
        'state' => 'state.approved'
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
    }

    public function searchStudent($input){
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT u
           FROM App:User u
           WHERE CONCAT( u.firstName, :lit, u.lastName ) LIKE :input
           ORDER BY u.firstName ASC'
      )->setParameters(array(
        'input' => '%' . $input . '%',
        'lit' => " "
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
    }

    public function studentGroupByAmbassador($id_ambassador)
    {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT u FROM App:User u
           JOIN App:StudentGroup sg
           WITH sg.student = u.id
           JOIN sg.group g
           WHERE g.embassador = :ambassador'
      )->setParameters(array(
        'ambassador' => $id_ambassador,
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
    }

    public function deleteStudentByGroup($id_group)
    {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT u FROM App:User u
           JOIN App:StudentGroup sg
           WITH sg.student = u.id
           WHERE sg.group = :group'
      )->setParameters(array(
        'group' => $id_group,
      ));

      $ids = $query->getResult();

      $deleteQuery = $this->getEntityManager()
          ->createQuery(
          'DELETE App:User u
           WHERE u.id IN (:ids)'
      )->setParameters(array(
        'ids' => $ids,
      ));

      try {
          return $deleteQuery->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
    }

    public function studentAmbassadorGroupByAmbassador($id_ambassador)
    {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT u FROM App:User u
           JOIN App:StudentAmbassadorGroup sg
           WITH sg.student = u.id
           JOIN sg.group g
           WHERE g.embassador = :ambassador'
      )->setParameters(array(
        'ambassador' => $id_ambassador,
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
    }

    public function studentGroupByAmbassadorXstate($id_ambassador, $state)
    {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT u FROM App:User u
           JOIN App:StudentGroup sg
           WITH sg.student = u.id
           JOIN sg.group g
           WHERE g.embassador = :ambassador'
      )->setParameters(array(
        'ambassador' => $id_ambassador,
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
    }

    public function studentAmbassadorGroupByAmbassadorXstate($id_ambassador, $state)
    {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT u FROM App:User u
           JOIN App:StudentAmbassadorGroup sg
           WITH sg.student = u.id
           JOIN sg.group g
           WHERE g.embassador = :ambassador'
      )->setParameters(array(
        'ambassador' => $id_ambassador,
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function ambassadorByDate($id, $init_date)
    {
        $query = $this->getEntityManager()
            ->createQuery( 
            'SELECT ps FROM App:ProgramSa ps
             WHERE ps.id = :id
             AND ps.approvalDate <= :init_date'
        )->setParameters(array(
            'init_date'   => $init_date,
            'id'          => $id,
        ));

        try {
            return $query->getResult();
        } catch (\Doctrine\ORM\NoResultException $exception) {
            return null;
        }
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function participantsByDate($init_date)
    {
        $query = $this->getEntityManager()
            ->createQuery( 
            'SELECT u FROM App:User u
             WHERE u.updatedAt >= :init_date'
        )->setParameters(array(
            'init_date'   => $init_date,
        ));

        try {
            return $query->getResult();
        } catch (\Doctrine\ORM\NoResultException $exception) {
            return null;
        }
    }


}