<?php

namespace App\Repository;

use App\Entity\WellnessParticipant;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Common\Persistence\ManagerRegistry;

/**
 * @method WellnessParticipant|null find($id, $lockMode = null, $lockVersion = null)
 * @method WellnessParticipant|null findOneBy(array $criteria, array $orderBy = null)
 * @method WellnessParticipant[]    findAll()
 * @method WellnessParticipant[]    findBy(array $criteria, array $orderBy = null, $limit = null, $offset = null)
 */
class WellnessParticipantRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, WellnessParticipant::class);
    }

    /**
    * @param string $name
    *
    * @return array
    */
    public function wellnessParticipantByStatePagination($key, $page, $page_size, $order_column, $order_direction, $state )
    {
        
        $query = $this->_em->createQueryBuilder();
        $query->select('p.id AS id, s.id AS participant_id, CONCAT(e.firstName, \' \', e.lastName) AS ambassador_name, g.name AS group_name,  s.country AS country, p.updatedAt AS updated_at, p.approvalDate AS approval_date, CONCAT(s.firstName, \' \', s.lastName) AS participant_name, g.program AS group_program, s , p')
            ->from('App:WellnessParticipant', 'p')
            ->leftJoin('p.student', 's')
            ->leftJoin('s.studentgroup', 'sg')
            ->join('sg.group', 'g')
            ->join('g.embassador', 'e')
            ->where('CONCAT(s.firstName, \' \', s.lastName , \' \', s.firstName, \' \', s.lastName, \' \', g.name) LIKE :name')   
            ->andWhere( 'p.state = :state') 
            ->setParameters(array(
                'state'     => $state,
                'name'      => '%'.$key.'%'
            ))
            ->orderBy($order_column, $order_direction);


        $paginator = new Paginator($query);
        $total_items = $paginator->count();
        $total_pages = (int) ceil($total_items / $page_size);

        $paginator->getQuery()
            ->setFirstResult($page_size * ($page - 1))       
            ->setMaxResults($page_size);
        
        $result = [
            'list'              => $paginator->getIterator()->getArrayCopy(),
            'items_total'       => $total_items,
            'pages_total'       => $total_pages
        ];
       
        return $result;
    }

    /**
    * @param string $name
    *
    * @return array
    */
    public function wellnessParticipantByState($state)
    {
        
        $query = $this->_em->createQueryBuilder();
        $query->select('p.id AS id, s.id AS participant_id, CONCAT(e.firstName, \' \', e.lastName) AS ambassador_name, g.name AS group_name,  s.country AS country, p.updatedAt AS updated_at, p.approvalDate AS approval_date, CONCAT(s.firstName, \' \', s.lastName) AS participant_name, g.program AS group_program, s , p')
            ->from('App:WellnessParticipant', 'p')
            ->leftJoin('p.student', 's')
            ->leftJoin('s.studentgroup', 'sg')
            ->join('sg.group', 'g')
            ->join('g.embassador', 'e')
            ->where( 'p.state = :state') 
            ->setParameters(array(
                'state'     => $state,
            ))
            ->orderBy('approval_date', 'DESC');


        return $query->getQuery()->getResult();
    }

    /**
    * @param string $name
    *
    * @return array
    */
    public function wellnessParticipantByStateEmbassador($state, $embassador_id)
    {
        
        $query = $this->_em->createQueryBuilder();
        $query->select('p.id AS id, s.id AS participant_id, CONCAT(e.firstName, \' \', e.lastName) AS ambassador_name, g.name AS group_name,  s.country AS country, p.updatedAt AS updated_at, p.approvalDate AS approval_date, CONCAT(s.firstName, \' \', s.lastName) AS participant_name, g.program AS group_program, s , p')
            ->from('App:WellnessParticipant', 'p')
            ->leftJoin('p.student', 's')
            ->leftJoin('s.studentgroup', 'sg')
            ->join('sg.group', 'g')
            ->join('g.embassador', 'e')
            ->where( 'p.state = :state') 
            ->andWhere( 'g.embassador = :embassador_id')
            ->setParameters(array(
                'state'     => $state,
                'embassador_id' => $embassador_id
            ))
            ->orderBy('approval_date', 'DESC');


        return $query->getQuery()->getResult();
    }

     /**
    * @param string $name
    *
    * @return array
    */
    public function wellnessParticipantApprovedPagination($key, $page, $page_size, $order_column, $order_direction)
    {
        
        $query = $this->_em->createQueryBuilder();
        $query->select('p.id AS id, s.id AS participant_id, CONCAT(e.firstName, \' \', e.lastName) AS ambassador_name, g.name AS group_name,  s.country AS country, p.updatedAt AS updated_at, p.approvalDate AS approval_date, CONCAT(s.firstName, \' \', s.lastName) AS participant_name, CONCAT(a.firstName, \' \', a.lastName) AS admin_name, g.program AS group_program, s , p')
            ->from('App:WellnessParticipant', 'p')
            ->leftJoin('p.student', 's')
            ->leftJoin('s.studentgroup', 'sg')
            ->join('sg.group', 'g')
            ->join('g.embassador', 'e')
            ->join('p.admin', 'a')
            ->where('CONCAT(s.firstName, \' \', s.lastName , \' \', s.firstName, \' \', s.lastName, \' \', g.name) LIKE :name')   
            ->andWhere( 'p.state = :state') 
            ->setParameters(array(
                'state'     => "state.approved",
                'name'      => '%'.$key.'%'
            ))
            ->orderBy($order_column, $order_direction);


        $paginator = new Paginator($query);
        $total_items = $paginator->count();
        $total_pages = (int) ceil($total_items / $page_size);

        $paginator->getQuery()
            ->setFirstResult($page_size * ($page - 1))       
            ->setMaxResults($page_size);
        
        $result = [
            'list'              => $paginator->getIterator()->getArrayCopy(),
            'items_total'       => 99,
            'pages_total'       => $total_pages
        ];
       
        return $result;
    }

    /**
    * @param string $name
    *
    * @return array
    */
    public function wellnessParticipantByStateLanguagePagination($key, $page, $page_size, $order_column, $order_direction, $state, $language )
    {
        
      $query = $this->_em->createQueryBuilder();
      $query->select('p.id AS id, s.id AS participant_id, CONCAT(e.firstName, \' \', e.lastName) AS ambassador_name, g.name AS group_name,  s.country AS country, p.updatedAt AS updated_at, p.approvalDate AS approval_date, CONCAT(s.firstName, \' \', s.lastName) AS participant_name, g.program AS group_program, s , p')
          ->from('App:WellnessParticipant', 'p')
          ->leftJoin('p.student', 's')
          ->leftJoin('s.studentgroup', 'sg')
          ->join('sg.group', 'g')
          ->join('g.embassador', 'e')
          ->where('CONCAT(s.firstName, \' \', s.lastName , \' \', e.firstName, \' \', e.lastName, \' \', g.name) LIKE :name')   
          ->andWhere( 'p.state = :state') 
          ->andWhere( 's.language IN (:language)')
          ->setParameters(array(
              'state'     => $state,
              'language'     => $language,
              'name'      => '%'.$key.'%'
          ))
          ->orderBy($order_column, $order_direction);


      $paginator = new Paginator($query);
      $total_items = $paginator->count();
      $total_pages = (int) ceil($total_items / $page_size);

      $paginator->getQuery()
          ->setFirstResult($page_size * ($page - 1))       
          ->setMaxResults($page_size);
      
      $result = [
          'list'              => $paginator->getIterator()->getArrayCopy(),
          'items_total'       => $total_items,
          'pages_total'       => $total_pages
      ];
     
      return $result;
    }

    /**
    * @param string $name
    *
    * @return array
    */
    public function wellnessParticipantByStateLanguage($state, $language)
    {
        
      $query = $this->_em->createQueryBuilder();
      $query->select('p.id AS id, s.id AS participant_id, CONCAT(e.firstName, \' \', e.lastName) AS ambassador_name, g.name AS group_name,  s.country AS country, p.updatedAt AS updated_at, p.approvalDate AS approval_date, CONCAT(s.firstName, \' \', s.lastName) AS participant_name, g.program AS group_program, s , p')
          ->from('App:WellnessParticipant', 'p')
          ->leftJoin('p.student', 's')
          ->leftJoin('s.studentgroup', 'sg')
          ->join('sg.group', 'g')
          ->join('g.embassador', 'e')
          ->andWhere( 'p.state = :state') 
          ->andWhere( 's.language IN (:language)')
          ->setParameters(array(
              'state'     => $state,
              'language'     => $language,
          ))
          ->orderBy('approval_date', 'DESC');


        return $query->getQuery()->getResult();
    }

     /**
    * @param string $name
    *
    * @return array
    */
    public function wellnessParticipantApprovedLanguagePagination($key, $page, $page_size, $order_column, $order_direction, $language )
    {
        
      $query = $this->_em->createQueryBuilder();
      $query->select('p.id AS id, s.id AS participant_id, CONCAT(e.firstName, \' \', e.lastName) AS ambassador_name, g.name AS group_name,  s.country AS country, p.updatedAt AS updated_at, p.approvalDate AS approval_date, CONCAT(s.firstName, \' \', s.lastName) AS participant_name, CONCAT(a.firstName, \' \', a.lastName) AS admin_name,  g.program AS group_program,  s , p')
          ->from('App:WellnessParticipant', 'p')
          ->leftJoin('p.student', 's')
          ->leftJoin('s.studentgroup', 'sg')
          ->join('sg.group', 'g')
          ->join('g.embassador', 'e')
          ->join('p.admin', 'a')
          ->where('CONCAT(s.firstName, \' \', s.lastName , \' \', e.firstName, \' \', e.lastName, \' \', g.name) LIKE :name')   
          ->andWhere( 'p.state = :state') 
          ->andWhere( 's.language IN (:language)')
          ->setParameters(array(
              'state'     => "state.approved",
              'language'     => $language,
              'name'      => '%'.$key.'%'
          ))
          ->orderBy($order_column, $order_direction);


      $paginator = new Paginator($query);
      $total_items = $paginator->count();
      $total_pages = (int) ceil($total_items / $page_size);

      $paginator->getQuery()
          ->setFirstResult($page_size * ($page - 1))       
          ->setMaxResults($page_size);
      
      $result = [
          'list'              => $paginator->getIterator()->getArrayCopy(),
          'items_total'       => $total_items,
          'pages_total'       => $total_pages
      ];
     
      return $result;
    }

    ///////

     /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesbyDate($init_date, $final_date)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('pm')
           ->from('App:WellnessParticipant', 'pm')
           ->where('pm.state = :state')
           ->andWhere('pm.approvalDate >= :init_date')
           ->andWhere('pm.approvalDate < :final_date')
           ->setParameters(array(
             'state'         => 'state.approved',
             'init_date'     => $init_date,
             'final_date'      => $final_date,
           ))
           ->orderBy('pm.approvalDate', 'ASC');

       return $qb->getQuery()->getResult();
    }

     /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesbyDateDesc($init_date, $final_date)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('pm')
           ->from('App:WellnessParticipant', 'pm')
           ->where('pm.state = :state')
           ->andWhere('pm.approvalDate >= :init_date')
           ->andWhere('pm.approvalDate < :final_date')
           ->setParameters(array(
             'state'         => 'state.approved',
             'init_date'     => $init_date,
             'final_date'      => $final_date,
           ))
           ->orderBy('pm.approvalDate', 'DESC');

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesDateRange($init_date, $final_date)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('pm')
           ->from('App:WellnessParticipant', 'pm')
           ->where('pm.state = :state')
           ->andWhere('pm.approvalDate >= :init_date')
           ->andWhere('pm.approvalDate <= :final_date')
           ->setParameters(array(
             'state'         => 'state.approved',
             'init_date'     => $init_date,
             'final_date'      => $final_date,
           ))
           ->orderBy('pm.approvalDate', 'ASC');

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesCountryDateRange($init_date, $final_date, $country)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('pm')
           ->from('App:WellnessParticipant', 'pm')
           ->join('pm.student', 's')
           ->where('pm.state = :state')
           ->andWhere('pm.approvalDate >= :init_date')
           ->andWhere('pm.approvalDate <= :final_date')
           ->andWhere('s.country = :country')
           ->setParameters(array(
             'state'         => 'state.approved',
             'init_date'     => $init_date,
             'final_date'    => $final_date,
             'country'       => $country
           ))
           ->orderBy('pm.approvalDate', 'ASC');

       return $qb->getQuery()->getResult();
    }

     /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesbyDateCount($init_date, $final_date)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('count(pm.id)')
           ->from('App:WellnessParticipant', 'pm')
           ->where('pm.state = :state')
           ->andWhere('pm.approvalDate >= :init_date')
           ->andWhere('pm.approvalDate < :final_date')
           ->setParameters(array(
             'state'         => 'state.approved',
             'init_date'     => $init_date,
             'final_date'      => $final_date,
           ))
           ->orderBy('pm.approvalDate', 'ASC');

       return $qb->getQuery()->getSingleScalarResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesbyDateCountryCount($init_date, $final_date, $country)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('count(pm.id)')
           ->from('App:WellnessParticipant', 'pm')
           ->join('pm.student', 'u')
           ->where('pm.state = :state')
           ->andWhere('pm.approvalDate >= :init_date')
           ->andWhere('pm.approvalDate < :final_date')
           ->andWhere('u.country = :country')
           ->setParameters(array(
             'state'           => 'state.approved',
             'init_date'       => $init_date,
             'final_date'      => $final_date,
             'country'         => $country,
           ))
           ->orderBy('pm.approvalDate', 'ASC');

       return $qb->getQuery()->getSingleScalarResult();
    }
    

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesDateRangeCount($init_date, $final_date)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('count(pm.id)')
           ->from('App:WellnessParticipant', 'pm')
           ->where('pm.state = :state')
           ->andWhere('pm.approvalDate >= :init_date')
           ->andWhere('pm.approvalDate <= :final_date')
           ->setParameters(array(
             'state'         => 'state.approved',
             'init_date'     => $init_date,
             'final_date'      => $final_date,
           ))
           ->orderBy('pm.approvalDate', 'ASC');

       return $qb->getQuery()->getSingleScalarResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesCountryDateRangeCount($init_date, $final_date, $country)
    {
       $qb = $this->_em->createQueryBuilder();
       $qb->select('count(pm.id)')
           ->from('App:WellnessParticipant', 'pm')
           ->join('pm.student', 's')
           ->where('pm.state = :state')
           ->andWhere('pm.approvalDate >= :init_date')
           ->andWhere('pm.approvalDate <= :final_date')
           ->andWhere('s.country = :country')
           ->setParameters(array(
             'state'         => 'state.approved',
             'init_date'     => $init_date,
             'final_date'    => $final_date,
             'country'       => $country
           ))
           ->orderBy('pm.approvalDate', 'ASC');

       return $qb->getQuery()->getSingleScalarResult();
    }

     /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesCountryLanguageCount($country, $language)
    {

       $qb = $this->_em->createQueryBuilder();
       
       if($country != "ALL" && $language == "ALL"){
         $qb->select('count(pm.id)')
         ->from('App:WellnessParticipant', 'pm')
         ->join('pm.student', 's')
         ->where('pm.state = :state')
         ->andWhere('s.country = :country')
         ->setParameters(array(
           'state'         => 'state.approved',
           'country'       => $country
         ))
         ->orderBy('pm.approvalDate', 'ASC');
      }
      else if($country == "ALL" && $language != "ALL"){
         $qb->select('count(pm.id)')
         ->from('App:WellnessParticipant', 'pm')
         ->join('pm.student', 's')
         ->where('pm.state = :state')
         ->andWhere('s.language = :language')
         ->setParameters(array(
           'state'         => 'state.approved',
           'language'       => $language
         ))
         ->orderBy('pm.approvalDate', 'ASC');
      }
      else if($country != "ALL" && $language != "ALL"){
         $qb->select('count(pm.id)')
         ->from('App:WellnessParticipant', 'pm')
         ->join('pm.student', 's')
         ->where('pm.state = :state')
         ->andWhere('s.language = :language')
         ->andWhere('s.country = :country')
         ->setParameters(array(
           'state'         => 'state.approved',
           'language'       => $language,
           'country'       => $country
         ))
         ->orderBy('pm.approvalDate', 'ASC');
      }

      try {
        return $qb->getQuery()->getSingleScalarResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
        return 0;
      }
       
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesCountryLanguageDateRangeCount($init_date, $final_date, $country, $language)
    {
       $qb = $this->_em->createQueryBuilder();
       if($country != "ALL" && $language == "ALL"){
         $qb->select('count(pm.id)')
         ->from('App:WellnessParticipant', 'pm')
         ->join('pm.student', 's')
         ->where('pm.state = :state')
         ->andWhere('pm.approvalDate >= :init_date')
         ->andWhere('pm.approvalDate <= :final_date')
         ->andWhere('s.country = :country')
         ->setParameters(array(
           'state'         => 'state.approved',
           'init_date'     => $init_date,
           'final_date'    => $final_date,
           'country'       => $country
         ))
         ->orderBy('pm.approvalDate', 'ASC');
      }
      else if($country == "ALL" && $language != "ALL"){
         $qb->select('count(pm.id)')
         ->from('App:WellnessParticipant', 'pm')
         ->join('pm.student', 's')
         ->where('pm.state = :state')
         ->andWhere('pm.approvalDate >= :init_date')
         ->andWhere('pm.approvalDate <= :final_date')
         ->andWhere('s.language = :language')
         ->setParameters(array(
           'state'         => 'state.approved',
           'init_date'     => $init_date,
           'final_date'    => $final_date,
           'language'       => $language
         ))
         ->orderBy('pm.approvalDate', 'ASC');
      }
      else if($country != "ALL" && $language != "ALL"){
         $qb->select('count(pm.id)')
         ->from('App:WellnessParticipant', 'pm')
         ->join('pm.student', 's')
         ->where('pm.state = :state')
         ->andWhere('pm.approvalDate >= :init_date')
         ->andWhere('pm.approvalDate <= :final_date')
         ->andWhere('s.language = :language')
         ->andWhere('s.country = :country')
         ->setParameters(array(
           'state'         => 'state.approved',
           'init_date'     => $init_date,
           'final_date'    => $final_date,
           'language'       => $language,
           'country'       => $country
         ))
         ->orderBy('pm.approvalDate', 'ASC');
      }

       return $qb->getQuery()->getSingleScalarResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesCountryLanguageDateRange($init_date, $final_date, $country, $language)
    {
       $qb = $this->_em->createQueryBuilder();

       if($country != "ALL" && $language == "ALL"){
          $qb->select('pm')
          ->from('App:WellnessParticipant', 'pm')
          ->join('pm.student', 's')
          ->where('pm.state = :state')
          ->andWhere('pm.approvalDate >= :init_date')
          ->andWhere('pm.approvalDate <= :final_date')
          ->andWhere('s.country = :country')
          ->setParameters(array(
            'state'         => 'state.approved',
            'init_date'     => $init_date,
            'final_date'    => $final_date,
            'country'       => $country
          ))
          ->orderBy('pm.approvalDate', 'ASC');
       }
       else if($country == "ALL" && $language != "ALL"){
         $qb->select('pm')
          ->from('App:WellnessParticipant', 'pm')
          ->join('pm.student', 's')
          ->where('pm.state = :state')
          ->andWhere('pm.approvalDate >= :init_date')
          ->andWhere('pm.approvalDate <= :final_date')
          ->andWhere('s.language = :language')
          ->setParameters(array(
            'state'         => 'state.approved',
            'init_date'     => $init_date,
            'final_date'    => $final_date,
            'language'       => $language
          ))
          ->orderBy('pm.approvalDate', 'ASC');
       }
       else if($country != "ALL" && $language != "ALL"){
         $qb->select('pm')
          ->from('App:WellnessParticipant', 'pm')
          ->join('pm.student', 's')
          ->where('pm.state = :state')
          ->andWhere('pm.approvalDate >= :init_date')
          ->andWhere('pm.approvalDate <= :final_date')
          ->andWhere('s.language = :language')
          ->andWhere('s.country = :country')
          ->setParameters(array(
            'state'         => 'state.approved',
            'init_date'     => $init_date,
            'final_date'    => $final_date,
            'language'       => $language,
            'country'       => $country
          ))
          ->orderBy('pm.approvalDate', 'ASC');
       }
       

       return $qb->getQuery()->getResult();
    }

    /**
    * @param string $role
    *
    * @return array
    */
    public function graduatesbyDateCountryLanguageCount($init_date, $final_date, $country, $language)
    {
       $qb = $this->_em->createQueryBuilder();
       if($country != "ALL" && $language == "ALL"){
          $qb->select('count(pm.id)')
              ->from('App:WellnessParticipant', 'pm')
              ->join('pm.student', 'u')
              ->where('pm.state = :state')
              ->andWhere('pm.approvalDate >= :init_date')
              ->andWhere('pm.approvalDate <= :final_date')
              ->andWhere('u.country = :country')
              ->setParameters(array(
                'state'           => 'state.approved',
                'init_date'       => $init_date,
                'final_date'      => $final_date,
                'country'         => $country,
              ))
              ->orderBy('pm.approvalDate', 'ASC');
       }
       else if($country == "ALL" && $language != "ALL"){
          $qb->select('count(pm.id)')
              ->from('App:WellnessParticipant', 'pm')
              ->join('pm.student', 'u')
              ->where('pm.state = :state')
              ->andWhere('pm.approvalDate >= :init_date')
              ->andWhere('pm.approvalDate <= :final_date')
              ->andWhere('u.language = :language')
              ->setParameters(array(
                'state'           => 'state.approved',
                'init_date'       => $init_date,
                'final_date'      => $final_date,
                'language'         => $language,
              ))
              ->orderBy('pm.approvalDate', 'ASC');
       }
       else if($country != "ALL" && $language != "ALL"){
        $qb->select('count(pm.id)')
            ->from('App:WellnessParticipant', 'pm')
            ->join('pm.student', 'u')
            ->where('pm.state = :state')
            ->andWhere('pm.approvalDate >= :init_date')
            ->andWhere('pm.approvalDate <= :final_date')
            ->andWhere('u.language = :language')
            ->andWhere('u.country = :country')
            ->setParameters(array(
              'state'           => 'state.approved',
              'init_date'       => $init_date,
              'final_date'      => $final_date,
              'language'        => $language,
              'country'         => $country,
            ))
            ->orderBy('pm.approvalDate', 'ASC');
     }

       return $qb->getQuery()->getSingleScalarResult();
    }


   
}
