<?php
/**
 * ProgrammbsController.php
 *
 */
 
namespace App\Controller;
 
use App\Entity\ProgramMbs;
use App\Entity\Task;
use App\Entity\Certificate;
use App\Form\ProgramMbsUpdateRevisionType;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Nelmio\ProgrammbsDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
 
/**
 * Class ProgrammbsController
 *
 * @Route("/programmbs")
 */
class ProgrammbsController extends FOSRestController
{
    
 
    /**
     * @Rest\Get("/", name="programmbss_index", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all programmbss."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all programmbs programmbss."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="Programmbs ID"
     * )
     *
     *
     * @SWG\Tag(name="Programmbs")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programmbss = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            //$programmbsId = $this->getProgrammbs()->getId();
            $programmbss = $em->getRepository("App:ProgramMbs")->findBy(array(), array(), 20);
 
            if (is_null($programmbss)) {
                $programmbss = [];
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all Programmbss - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programmbss : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/new", name="programmbs_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Programmbs was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Programmbs was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="firtName",
     *     in="body",
     *     type="string",
     *     description="The first Name",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="lasName",
     *     in="body",
     *     type="string",
     *     description="The last name",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="programmbsname",
     *     in="body",
     *     type="string",
     *     description="The programmbsname",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="password",
     *     in="query",
     *     type="string",
     *     description="The password"
     * )
     * 
     * * @SWG\Parameter(
     *     name="language",
     *     in="query",
     *     type="string",
     *     description="The language"
     * )
     * 
     *  * * @SWG\Parameter(
     *     name="country",
     *     in="query",
     *     type="string",
     *     description="The country code"
     * )
     * 
     *  * * @SWG\Parameter(
     *     name="whatsapp",
     *     in="query",
     *     type="integer",
     *     description="The whatsapp"
     * )
     * 
     *  * * @SWG\Parameter(
     *     name="code",
     *     in="query",
     *     type="string",
     *     description="The code"
     * )
     *
     * @SWG\Tag(name="Programmbs")
     */ 
    public function newAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        $message = "";

        $programmbs=new Programmbs();
        //Create a form
        $form=$this->createForm(ProgrammbsType::class, $programmbs);
        $form->submit($request->request->all());
 
        try {
            $code = 200;
            $error = false;


            $em->persist($programmbs);
            $em->flush();
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programmbs : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/show/{id}.{_format}", name="course_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets course info based on passed ID parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The course with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The Programmbs ID"
     * )
     *
     * @SWG\Tag(name="Programmbs")
     */
    public function showAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programmbs = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            $programmbs_id = $id;
            $programmbs = $em->getRepository("App:ProgramMbs")->find($programmbs_id);
 
            if (is_null($programmbs)) {
                $code = 500;
                $error = true;
                $message = "The Programmbs does not exist";
            }
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Programmbs- Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programmbs : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/edit/{id}.{_format}", name="programmbs_edit", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="The programmbs was edited successfully."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to edit the programmbs."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The programmbs ID"
     * )
     *
     *
     *
     * @SWG\Tag(name="Programmbs")
     */
    public function editAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programmbs = [];
        $message = "";

        
 
        try {
            $code = 200;
            $error = false;
            $programmbs = $em->getRepository("App:ProgramMbs")->find($id);
 
            if (!is_null($programmbs)) {
                $form = $this->createForm(ProgrammbsEditType::class, $programmbs);
                $form->submit($request->request->all());
                //$programmbs->setName($name);
 
                $em->persist($programmbs);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Programmbs - Error: You must to provide fields programmbs or the programmbs id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programmbs : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Delete("/delete/{id}.{_format}", name="programmbs_delete", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Programmbs was successfully removed"
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="An error was occurred trying to remove the programmbs"
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The programmbs ID"
     * )
     *
     * @SWG\Tag(name="Programmbs")
     */
    public function deleteAction(Request $request, $id) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
            $programmbs = $em->getRepository("App:ProgramMbs")->find($id);
 
            if (!is_null($programmbs)) {
                $em->remove($programmbs);
                $em->flush();
 
                $message = "The programmbs was removed successfully!";
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to remove the currrent programmbs - Error: The programmbs id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to remove the current programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

     /**
     * @Rest\Get("/search/{key}.{_format}", name="programmbs_show", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets programmbs info based on passed key parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The programmbs with the passed key parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="key",
     *     in="path",
     *     type="string",
     *     description="The programmbs key"
     * )
     *
     *
     * @SWG\Tag(name="Programmbs")
     */
    public function searchAction(Request $request, $key ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programmbs = [];
        $message = "";
        
        try {
            $code = 200;
            $error = false;
 
            
            $programmbs = $em->getRepository("App:ProgramMbs")->programmbsSearch($key);
 
            if (is_null($programmbs)) {
                $code = 500;
                $error = true;
                $message = "The programmbs does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get the current Programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programmbs : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Post("/active_programmbs", name="active_new")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Programmbs was successfully registered"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Programmbs was not successfully registered"
     * )
     *
     * @SWG\Parameter(
     *     name="state",
     *     in="body",
     *     type="string",
     *     description="The state",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="description",
     *     in="body",
     *     type="string",
     *     description="The description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="query",
     *     type="string",
     *     description="The language",
     * )
     * @SWG\Tag(name="Programmbs")
     */ 

    public function activeprogrammbsAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
 
        try {
            $code = 200;
            $error = false;
 
            $programmbs = $this->getProgrammbs();
            $em = $this->getDoctrine()->getManager();
            $programmbs = $em->getRepository("App:ProgramMbs")->find($programmbs->getId());
            
            
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to register the programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programmbs : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/update_revision/{id}", name="update_revision_programmbs")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Revision was successfully update"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Revision was not successfully update"
     * )
     *
     * @SWG\Parameter(
     *     name="planrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="productrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="pricerevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="promotionrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="paperworkrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="processrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * @SWG\Tag(name="Programmbs")
     */

    public function updateRevisionAction(Request $request, $id)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programmbs = [];
        $message = "";

        try {
            $code = 200;
            $error = false;
            $programmbs = $em->getRepository('App:ProgramMbs')->find($id);
 
            if (!is_null($programmbs)) {
                $form = $this->createForm(ProgramMbsUpdateRevisionType::class, $programmbs);
                $form->submit($request->request->all());
 
                $em->persist($programmbs);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Programmbs - Error: You must to provide fields programmbs or the programmbs id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programmbs : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/approved", name="approved_programmbs")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Project mbs approval was successful"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Project mbs was not successfully approved"
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="body",
     *     type="string",
     *     description="The id programmbs",
     *     schema={}
     * )
     * @SWG\Tag(name="Programmbs")
     */

    public function approvedAction(Request $request)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programMb = [];
        $message = ""; 

        try {
            $code = 200;
            $error = false;
            $id = $request->request->get('id');
            $programMb = $em->getRepository('App:ProgramMbs')->find($id);
 
            if (!is_null($programMb)) {
                $em = $this->getDoctrine()->getManager();

                
                $programMb->setState('state.approved');
                $programMb->setApprovalDate(new \DateTime('now', (new \DateTimeZone('America/New_York'))));
                if(!$programMb->getCode()){
                    $programMb->setCode($programMb->getStudent()->getCountry()."-".$this->getNumberCode($programMb, $request));
                }

                $em->persist($programMb);
                $em->flush();
                
                //$this->sendEmail("subject.approved_project", $programMb->getStudent());
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to get a Programmbs - Error: You must to provide fields programmbs or the programmbs id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to edit the programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programMb : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Put("/sendrevision", name="sendrevision_programmbs")
     *
     * @SWG\Response(
     *     response=201,
     *     description="Project mbs sendrevision was successful"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="Project mbs was not successfully sendrevision"
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="body",
     *     type="string",
     *     description="The id programmbs",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="planrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     *
     * @SWG\Parameter(
     *     name="productrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="pricerevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="promotionrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="paperworkrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * 
     * @SWG\Parameter(
     *     name="processrevision",
     *     in="body",
     *     type="string",
     *     description="The revision description",
     *     schema={}
     * )
     * @SWG\Tag(name="Programmbs")
     */

    public function sendRevisionAction(Request $request)
    {

        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $programMb = [];
        $message = ""; 

        try {
            $code = 200;
            $error = false;
            $id = $request->request->get('id');
            $programMb = $em->getRepository('App:ProgramMbs')->find($id);
 
            if (!is_null($programMb)) {
                $em = $this->getDoctrine()->getManager();

                $form = $this->createForm(ProgramMbsUpdateRevisionType::class, $programMb);
                $form->submit($request->request->all());

                $programMb->setState('state.correction');
                //$this->sendEmail("subject.pending_correction", $programMb->getStudent());
            
                $em->persist($programMb);
                $em->flush();
 
            } else {
                $code = 500;
                $error = true;
                $message = "An error has occurred trying to send revision Programmbs - Error: You must to provide fields programmbs or the programmbs id does not exist";
            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying send revision of programmbs - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $programMb : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    public function getNumberCode(ProgramMbs $programMbs){

        $em = $this->getDoctrine()->getManager();
        $number = $em->getRepository('App:Certificate')->findOneBy(array('country' => $programMbs->getStudent()->getCountry(), 'program' => 'MBS'));
        if($number){
          $number->setNumber($number->getNumber() + 1);
          $em->persist($number);
          $em->flush();
        }
        else{
          $number = new Certificate();
          $number->setCountry($programMbs->getStudent()->getCountry());
          $number->setProgram("MBS");
          $number->setNumber(1);
          $em->persist($number);
          $em->flush();
        }
  
        return $number->getNumber();
    }

    public function sendEmail($subject, $student){

        $em = $this->getDoctrine()->getManager();
        $admins = $em->getRepository('App:User')->userByRole("ROLE_ADMIN");
  
        if( $subject == "subject.pending_revision"){
  
           foreach ($admins as $admin ) {
               if($admin->getLanguage() == "en"){
                     $subjectEmail = $this->get('translator')->trans($subject, [] , null, "en");
                     $bodyEmail = $this->get('translator')->trans('message.pending_revision', [] , null, "en")." ".$student->getFirstName()." ".$student->getLastName();
  
                     $message = (new \Swift_Message($subjectEmail))
                      ->setFrom('myplatform@interweavesolutions.com')
                      ->setTo($admin->getUsername())
                      ->setBody($bodyEmail);
  
                      //$mailer->send($message);
                      $this->get('mailer')->send($message);
                }
                elseif($admin->getLanguage() == $student->getLanguage()){
                    $subjectEmail = $this->get('translator')->trans($subject, [] , null, $student->getLanguage());
                    $bodyEmail = $this->get('translator')->trans('message.pending_revision', [] , null, $student->getLanguage())." ".$student->getFirstName()." ".$student->getLastName();
  
                    $message = (new \Swift_Message($subjectEmail))
                     ->setFrom('myplatform@interweavesolutions.com')
                     ->setTo($admin->getUsername())
                     ->setBody($bodyEmail);
  
                     //$mailer->send($message);
                     $this->get('mailer')->send($message);
                }
           }
        }
  
        if($subject == "subject.approved_project") {
          $em = $this->getDoctrine()->getManager();
          $studentGroup = $student->getStudentgroup();
  
          // Send Notification to Ambbasador
          $subjectEmail = $this->get('translator')->trans($subject, [] , null, $studentGroup->getGroup()->getEmbassador()->getLanguage());
          $bodyEmail = $this->get('translator')->trans('message.approved_project', [] , null, $studentGroup->getGroup()->getEmbassador()->getLanguage())." ".$student->getFirstName()." ".$student->getLastName()." ".$student->getProgrammbs()->getCode();
  
          $message = (new \Swift_Message($subjectEmail))
           ->setFrom('myplatform@interweavesolutions.com')
           ->setTo($studentGroup->getGroup()->getEmbassador()->getUsername())
           ->setBody($bodyEmail);
  
           //$mailer->send($message);
           $this->get('mailer')->send($message);
  
           // Sent Notification to Student
           $subjectEmail = $this->get('translator')->trans($subject, [] , null, $student->getLanguage());
           $bodyEmail = $this->get('translator')->trans('message.approved_project', [] , null, $student->getLanguage())." ".$student->getFirstName()." ".$student->getLastName()." ".$student->getProgrammbs()->getCode();
  
           $message = (new \Swift_Message($subjectEmail))
            ->setFrom('myplatform@interweavesolutions.com')
            ->setTo($student->getUsername())
            ->setBody($bodyEmail);
  
            //$mailer->send($message);
            $this->get('mailer')->send($message);
  
            // Sent Notification to $admin
            foreach($admins as $admin){
              if($admin->getLanguage() == "en"){
                    $subjectEmail = $this->get('translator')->trans($subject, [] , null, "en");
                    $bodyEmail = $this->get('translator')->trans('message.approved_project_admin', [] , null, "en")." ".$student->getFirstName()." ".$student->getLastName()." whith the follow code ".$student->getProgrammbs()->getCode();
  
                    $message = (new \Swift_Message($subjectEmail))
                     ->setFrom('myplatform@interweavesolutions.com')
                     ->setTo($admin->getUsername())
                     ->setBody($bodyEmail);
  
                     //$mailer->send($message);
                     $this->get('mailer')->send($message);
               }
            }
          }
  
          if($subject == "subject.pending_correction") {
            $em = $this->getDoctrine()->getManager();
            $studentGroup = $student->getStudentgroup();
  
            // Send Notification to Ambbasador
            $subjectEmail = $this->get('translator')->trans($subject, [] , null, $studentGroup->getGroup()->getEmbassador()->getLanguage());
            $bodyEmail = $this->get('translator')->trans('message.pending_correction', [] , null, $studentGroup->getGroup()->getEmbassador()->getLanguage())." ".$student->getFirstName()." ".$student->getLastName();
  
            $message = (new \Swift_Message($subjectEmail))
             ->setFrom('myplatform@interweavesolutions.com')
             ->setTo($studentGroup->getGroup()->getEmbassador()->getUsername())
             ->setBody($bodyEmail);
  
             //$mailer->send($message);
             $this->get('mailer')->send($message);
  
             // Sent Notification to Student
             $subjectEmail = $this->get('translator')->trans($subject, [] , null, $student->getLanguage());
             $bodyEmail = $this->get('translator')->trans('message.pending_correction', [] , null, $student->getLanguage())." ".$student->getFirstName()." ".$student->getLastName();
  
             $message = (new \Swift_Message($subjectEmail))
              ->setFrom('myplatform@interweavesolutions.com')
              ->setTo($student->getUsername())
              ->setBody($bodyEmail);
  
              //$mailer->send($message);
              $this->get('mailer')->send($message);
  
  
            }
      }

   
 
}