<?php

namespace App\Repository;


use Doctrine\ORM\EntityRepository;

class StudentGroupRepository extends EntityRepository
{
    public function studentsMbsByEmbassador($embassador_id)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           WHERE g.embassador = :id'
      )->setParameter('id', $embassador_id);

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentMbsByState($state)
  {
    $query = $this->getEntityManager()
        ->createQuery(
        'SELECT s, g FROM App:StudentGroup s
         JOIN s.group g
         JOIN s.student st
         JOIN st.programmbs p
         WHERE p.state = :state'
    )->setParameters(array(
      'state' => $state
    ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsByLanguage($lang)
  {
    $query = $this->getEntityManager()
        ->createQuery(
        'SELECT s FROM App:StudentGroup s
         JOIN s.student st
         WHERE st.language IN (:lang)'
    )->setParameters(array(
      'lang' => $lang
    ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentAmbassadorByState($state)
  {
    $query = $this->getEntityManager()
        ->createQuery(
        'SELECT s, g FROM App:StudentGroup s
         JOIN s.group g
         JOIN s.student st
         JOIN st.programsa p
         WHERE p.state = :state'
    )->setParameters(array(
      'state' => $state
    ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }


  public function studentsMbsStateByEmbassador($embassador_id, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programmbs p
           WHERE g.embassador = :id
           AND p.state = :state'
      )->setParameters(array(
        'id' => $embassador_id,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsMbsStateByGroup($group_id, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programmbs p
           WHERE g.id = :id
           AND p.state = :state'
      )->setParameters(array(
        'id' => $group_id,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsByGroup($group_id)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           WHERE g.id = :id'
      )->setParameters(array(
        'id' => $group_id
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsDiferentStateByGroup($group_id, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programmbs p
           WHERE g.id = :id
           AND p.state != :state'
      )->setParameters(array(
        'id' => $group_id,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsMbsStateByLanguage($lang, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programmbs p
           WHERE st.language IN (:lang)
           AND p.state = :state'
      )->setParameters(array(
        'lang' => $lang,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsMbsStateModalityByEmbassador($embassador_id, $state, $modality)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programmbs p
           WHERE g.embassador = :id
           AND p.modality = :modality
           AND p.state = :state'
      )->setParameters(array(
        'id' => $embassador_id,
        'state' => $state,
        'modality' => $modality
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsAmbassadorStateByEmbassador($embassador_id, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programsa p
           WHERE g.embassador = :id
           AND p.state = :state'
      )->setParameters(array(
        'id' => $embassador_id,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsAmbassadorStateByLanguage($lang, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programsa p
           WHERE st.language IN  (:lang)
           AND p.state = :state'
      )->setParameters(array(
        'lang' => $lang,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsAmbassadorStateByGroup($group_id, $state)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programsa p
           WHERE g.id = :id
           AND p.state = :state'
      )->setParameters(array(
        'id' => $group_id,
        'state' => $state
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

  public function studentsAmbassadorStateModalityByEmbassador($embassador_id, $state, $modality)
  {
      $query = $this->getEntityManager()
          ->createQuery(
          'SELECT s, g FROM App:StudentGroup s
           JOIN s.group g
           JOIN s.student st
           JOIN st.programsa p
           WHERE g.embassador = :id
           AND p.modality = :modality
           AND p.state = :state'
      )->setParameters(array(
        'id' => $embassador_id,
        'state' => $state,
        'modality' => $modality
      ));

      try {
          return $query->getResult();
      } catch (\Doctrine\ORM\NoResultException $exception) {
          return null;
      }
  }

}