<?php
namespace App\Controller;
 
use App\Entity\User;
use App\Entity\Task;
use App\Form\UserType;
use App\Form\UserEditType;
use Doctrine\Common\Collections\ArrayCollection;
use FOS\RestBundle\Controller\Annotations as Rest;
use FOS\RestBundle\Controller\FOSRestController;
use Symfony\Component\Config\Definition\Exception\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Nelmio\UserDocBundle\Annotation\Model;
use Swagger\Annotations as SWG;
use JMS\Serializer\SerializationContext;
 
/**
 * Class ReportController
 *
 * @Route("/report")
 */
class ReportController extends FOSRestController
{
    
   /**
     * @Rest\Post("/", name="report_index")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all report."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     *
     * @SWG\Parameter(
     *     name="role",
     *     in="path",
     *     type="string",
     *     description="The Role of User"
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The id of Ambassador"
     * )
     *
     *
     * @SWG\Tag(name="Report")
     */
    public function indexAction(Request $request) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $reports = [];
        $message = "";
 
        try {
            $code = 200;
            $error = false;
 
            $role = $request->request->get("role");
            $id_ambassador = $request->request->get("id");

            if($role == "ROLE_EMBASSADOR"){
                
                $evaluations = $this->evaluationReportXAmbassadorFull($id_ambassador);               

                $reports = [                  
                    'evaluations'         => $evaluations,                  
                ];
            }

            if($role == "ROLE_ADMIN" or $role == "ROLE_LANGUAGE_ADMIN"){

                $evaluations = $this->evaluationReportByCountry(null);                

                $reports = [                    
                    'evaluations'         => $evaluations,                   
                ];

            }
 
        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
        }
 
        $response = [
            'code' => $code,
            'error' => $error,
            'data' => $code == 200 ? $reports : $message,
        ];
 
        return new Response($serializer->serialize($response, "json"));
    }

    /**
     * @Rest\Get("/evaluation/unusable/{country}", name="report_evaluation_unusable")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all report."
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     *
     * @SWG\Parameter(
     *     name="role",
     *     in="path",
     *     type="string",
     *     description="The Role of User"
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The id of Ambassador"
     * )
     *
     *
     * @SWG\Tag(name="Report")
     */
    public function unusableEvaluationAction(Request $request, $country) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";

      try {
          $code = 200;
          $error = false;
          $evaluations = $em->getRepository('App:Evaluation')->unusableEvaluationByCountry($country);

                    

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $evaluations : $message,
      ];

      return new Response($serializer->serialize($response, "json"));
  }

     /**
     * @Rest\Get("/globalmap", name="global_map")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all report."
     * )
     *     
     *
     *
     * @SWG\Tag(name="Report")
     */
    public function globalMapAction(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";

      try {
          $code = 200;
          $error = false;

       
              $mbsNumbers = $em->getRepository('App:Certificate')->findBy(array('program' => 'MBS'), array('number' => 'DESC'));
            

              foreach ($mbsNumbers as $key => $mbs) {
              $sa = $em->getRepository('App:Certificate')->findOneBy(array('program' => 'SA', 'country' => $mbs->getCountry()));
              $jr = $em->getRepository('App:Certificate')->findOneBy(array('program' => 'JR', 'country' => $mbs->getCountry()));
              $wellness = $em->getRepository('App:Certificate')->findOneBy(array('program' => 'WELLNESS', 'country' => $mbs->getCountry()));
              $wellness_participant = $em->getRepository('App:Certificate')->findOneBy(array('program' => 'WELLNESS_PART', 'country' => $mbs->getCountry()));


              $jrNumber = 0;
              $saNumber = 0;
              $wellnessNumber = 0;
              $wellnessParticipantNumber = 0;

              if($sa){
                $saNumber = $sa->getNumber();
              }
              if($jr){
                $jrNumber = $jr->getNumber();
              }
              if($wellness){
                $wellnessNumber = $wellness->getNumber();
              }
              if($wellness_participant){
                $wellnessParticipantNumber = $wellness_participant->getNumber();
              }                  
              $topNumbers[] = array(
                  'code' => $mbs->getCountry(),
                  'flag' => $this->getParameter($mbs->getCountry()),
                  'country' => $this->getParameter($this->getParameter($mbs->getCountry())),
                  'mbs'=> $mbs->getNumber(),
                  'jr'=> $jrNumber, 
                  'sa' => $saNumber,
                  'wellness' => $wellnessNumber,
                  'wellness_participant' => $wellnessParticipantNumber,
              );

              $vectorMap[] = array(
                'code' => $mbs->getCountry(),
                'flag' => $this->getParameter($mbs->getCountry()),
                'country' => $this->getParameter($this->getParameter($mbs->getCountry())),
                'mbs'=> $mbs->getNumber(),
                'jr'=> $jrNumber,
                'sa' => $saNumber,
                'wellness' => $wellnessNumber,
                'wellness_participant' => $wellnessParticipantNumber,
              );  

              $numMap[$this->getParameter($mbs->getCountry())] = (
                $mbs->getNumber().", ".$jrNumber.", ".$saNumber.", ".$wellnessNumber
              );
            }                           
            
            $reports = [                 
              'vectorMap'   => $topNumbers,
              'topNumbers'  => $vectorMap,
              'numCountries'  => $numMap,
            ];


      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $reports : $message,
      ];

      return new Response($serializer->serialize($response, "json"));
  }

  /**
     * @Rest\Get("/modalitymap", name="modality_map")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all report."
     * )
     *     
     *
     *
     * @SWG\Tag(name="Report")
     */
    public function modalityMapAction(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";

      try {
          $code = 200;
          $error = false;

              $online_language_graduates = $em->getRepository('App:ProgramMbs')->graduatesOnlineLanguage();

              $en_mbs_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("MBS", "ALL", "en");
              $en_jr_init  = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("JR", "ALL", "en");
              $en_total_graduates = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageCount("ALL", "en");
              $en_accumulate_graduates = $en_mbs_init + $en_jr_init +  $en_total_graduates;
              $en_total_graduates_online = $online_language_graduates['EN'];
              $en_total_graduates_face_to_face = $en_accumulate_graduates - $online_language_graduates['EN'];

              $es_mbs_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("MBS", "ALL", "es");
              $es_jr_init  = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("JR", "ALL", "es");
              $es_total_graduates = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageCount("ALL", "es");
              $es_accumulate_graduates = $es_mbs_init + $es_jr_init +  $es_total_graduates;
              $es_total_graduates_online = $online_language_graduates['ES'];
              $es_total_graduates_face_to_face = $es_accumulate_graduates - $online_language_graduates['ES'];          

              $fr_mbs_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("MBS", "ALL", "fr");
              $fr_jr_init  = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("JR", "ALL", "fr");
              $fr_total_graduates = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageCount("ALL", "fr");
              $fr_accumulate_graduates = $fr_mbs_init + $fr_jr_init +  $fr_total_graduates;
              $fr_total_graduates_online = $online_language_graduates['FR'];
              $fr_total_graduates_face_to_face = $fr_accumulate_graduates - $online_language_graduates['FR'];

              $pt_mbs_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("MBS", "ALL", "pt");
              $pt_jr_init  = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("JR", "ALL", "pt");
              $pt_total_graduates = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageCount("ALL", "pt");
              $pt_accumulate_graduates = $pt_mbs_init + $pt_jr_init +  $pt_total_graduates;
              $pt_total_graduates_online = $online_language_graduates['PT'];
              $pt_total_graduates_face_to_face = $pt_accumulate_graduates - $online_language_graduates['PT'];

              $zh_mbs_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("MBS", "ALL", "zh");
              $zh_jr_init  = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("JR", "ALL", "zh");
              $zh_total_graduates = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageCount("ALL", "zh");
              $zh_accumulate_graduates = $zh_mbs_init + $pt_jr_init +  $zh_total_graduates;
              $zh_total_graduates_online = $online_language_graduates['ZH'];
              $zh_total_graduates_face_to_face = $zh_accumulate_graduates - $online_language_graduates['ZH'];

              $modalityLanguage = [
                'en_total_graduates_online'           => $en_total_graduates_online,
                'en_total_graduates_face_to_face'     => $en_total_graduates_face_to_face,
                'es_total_graduates_online'           => $es_total_graduates_online,
                'es_total_graduates_face_to_face'     => $es_total_graduates_face_to_face,
                'fr_total_graduates_online'           => $fr_total_graduates_online,
                'fr_total_graduates_face_to_face'     => $fr_total_graduates_face_to_face,
                'pt_total_graduates_online'           => $pt_total_graduates_online,
                'pt_total_graduates_face_to_face'     => $pt_total_graduates_face_to_face,
                'zh_total_graduates_online'           => $zh_total_graduates_online,
                'zh_total_graduates_face_to_face'     => $zh_total_graduates_face_to_face,
              ];
       
              $mbsNumbers = $em->getRepository('App:Certificate')->findBy(array('program' => 'MBS'), array('number' => 'DESC'));
              

              foreach ($mbsNumbers as $key => $mbs) {
              $online_graduates = $em->getRepository('App:ProgramMbs')->graduatesOnlineByCountry($mbs->getCountry());
              

              $modalityMap[] = array(
                  'code' => $mbs->getCountry(),
                  'flag' => $this->getParameter($mbs->getCountry()),
                  'country' => $this->getParameter($this->getParameter($mbs->getCountry())),
                  'mbs' => $mbs->getNumber(),                
                  'face_to_face_graduates' => $mbs->getNumber() - $online_graduates,
                  'online_graduates' => $online_graduates
              );

            }                           
            
            $reports = [                 
              'modalityCountry'       => $modalityMap,
              'modalityLanguage'      => $modalityLanguage,
            ];


      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $reports : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('report_list'))));
  }

  /**
     * @Rest\Get("/graduates/mbs/language", name="report_graduates_mbs_language")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     *    
     * 
     * @SWG\Tag(name="Report")
     */
    public function mbsLanguageGraduates(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];     
      $message = "";
     
      try {
          $code = 200;
          $error = false;

         
    
          $es_mbs_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("MBS", "ALL", "es");
          $es_jr_init  = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("JR", "ALL", "es");

          $es_total_graduates = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageCount("ALL", "es");
          $es_accumulate_graduates = $es_mbs_init + $es_jr_init +  $es_total_graduates;

          $en_mbs_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("MBS", "ALL", "en");
          $en_jr_init  = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("JR", "ALL", "en");

          $en_total_graduates = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageCount("ALL", "en");
          $en_accumulate_graduates = $en_mbs_init + $en_jr_init +  $en_total_graduates;           

          $fr_mbs_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("MBS", "ALL", "fr");
          $fr_jr_init  = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("JR", "ALL", "fr");

          $fr_total_graduates = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageCount("ALL", "fr");
          $fr_accumulate_graduates = $fr_mbs_init + $fr_jr_init +  $fr_total_graduates;

          $pt_mbs_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("MBS", "ALL", "pt");
          $pt_jr_init  = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("JR", "ALL", "pt");

          $pt_total_graduates = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageCount("ALL", "pt");
          $pt_accumulate_graduates = $pt_mbs_init + $pt_jr_init +  $pt_total_graduates;

          $numberNgaMbs = $em->getRepository('App:Certificate')->findOneBy(array('program' => 'MBS', 'country' => 'NGA'));
          $numberNgaJr  = $em->getRepository('App:Certificate')->findOneBy(array('program' => 'JR', 'country' => 'NGA'));
          $en_nga_mbs = is_null($numberNgaMbs) ?  0 : $numberNgaMbs->getNumber();
          $en_nga_jr  = is_null($numberNgaJr) ?   0 : $numberNgaJr->getNumber();
          $en_nga_accumulate_graduates = $en_accumulate_graduates - ($en_nga_mbs + $en_nga_jr);
          $en_country_nga_accumulate_graduates = $en_nga_mbs + $en_nga_jr;

         

          $es_sa_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("SA", "ALL", "es");

          $es_sa_total_graduates = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageCount("ALL", "es");
          $es_sa_accumulate_graduates = $es_sa_init +  $es_sa_total_graduates;

          $en_sa_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("SA", "ALL", "en");

          $en_sa_total_graduates = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageCount("ALL", "en");
          $en_sa_accumulate_graduates = $en_sa_init +  $en_sa_total_graduates;

          $fr_sa_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("SA", "ALL", "fr");

          $fr_sa_total_graduates = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageCount("ALL", "fr");
          $fr_sa_accumulate_graduates = $fr_sa_init +  $fr_sa_total_graduates;

          $pt_sa_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("SA", "ALL", "pt");

          $pt_sa_total_graduates = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageCount("ALL", "pt");
          $pt_sa_accumulate_graduates = $pt_sa_init +  $pt_sa_total_graduates;

          $numberNgaSa  = $em->getRepository('App:Certificate')->findOneBy(array('program' => 'SA', 'country' => 'NGA'));
          $en_sa_nga = is_null($numberNgaSa) ?  0 : $numberNgaSa->getNumber();
          $en_sa_nga_accumulate_graduates = $en_sa_accumulate_graduates - $en_sa_nga;
          $en_sa_country_nga_accumulate_graduates = $en_sa_nga;

          

          $es_wellness_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("WELLNESS", "ALL", "es");

          $es_wellness_total_graduates = $em->getRepository('App:Wellness')->graduatesCountryLanguageCount("ALL", "es");
          $es_wellness_accumulate_graduates = $es_wellness_init +  $es_wellness_total_graduates;

          $en_wellness_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("WELLNESS", "ALL", "en");

          $en_wellness_total_graduates = $em->getRepository('App:Wellness')->graduatesCountryLanguageCount("ALL", "en");
          $en_wellness_accumulate_graduates = $en_wellness_init +  $en_wellness_total_graduates;

          $fr_wellness_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("WELLNESS", "ALL", "fr");

          $fr_wellness_total_graduates = $em->getRepository('App:Wellness')->graduatesCountryLanguageCount("ALL", "fr");
          $fr_wellness_accumulate_graduates = $fr_wellness_init +  $fr_wellness_total_graduates;

          $pt_wellness_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("WELLNESS", "ALL", "pt");

          $pt_wellness_total_graduates = $em->getRepository('App:Wellness')->graduatesCountryLanguageCount("ALL", "pt");
          $pt_wellness_accumulate_graduates = $pt_wellness_init +  $pt_wellness_total_graduates;

          $numberNgaCis = $em->getRepository('App:Certificate')->findOneBy(array('program' => 'WELLNESS', 'country' => 'NGA'));
          $en_wellness_nga = is_null($numberNgaCis) ?  0 : $numberNgaCis->getNumber();
          $en_wellness_nga_accumulate_graduates = $en_wellness_accumulate_graduates - $en_wellness_nga;
          $en_wellness_country_nga_accumulate_graduates = $en_wellness_nga;



          $es_wellness_participant_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("WELLNESS_PART", "ALL", "es");

          $es_wellness_participant_total_graduates = $em->getRepository('App:WellnessParticipant')->graduatesCountryLanguageCount("ALL", "es");
          $es_wellness_participant_accumulate_graduates = $es_wellness_participant_init +  $es_wellness_participant_total_graduates;

          $en_wellness_participant_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("WELLNESS_PART", "ALL", "en");

          $en_wellness_participant_total_graduates = $em->getRepository('App:WellnessParticipant')->graduatesCountryLanguageCount("ALL", "en");
          $en_wellness_participant_accumulate_graduates = $en_wellness_participant_init +  $en_wellness_participant_total_graduates;

          $fr_wellness_participant_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("WELLNESS_PART", "ALL", "fr");

          $fr_wellness_participant_total_graduates = $em->getRepository('App:WellnessParticipant')->graduatesCountryLanguageCount("ALL", "fr");
          $fr_wellness_participant_accumulate_graduates = $fr_wellness_participant_init +  $fr_wellness_participant_total_graduates;

          $pt_wellness_participant_init = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("WELLNESS_PART", "ALL", "pt");

          $pt_wellness_participant_total_graduates = $em->getRepository('App:WellnessParticipant')->graduatesCountryLanguageCount("ALL", "pt");
          $pt_wellness_participant_accumulate_graduates = $pt_wellness_participant_init +  $pt_wellness_participant_total_graduates;

          $numberNgaPcg = $em->getRepository('App:Certificate')->findOneBy(array('program' => 'WELLNESS_PART', 'country' => 'NGA'));
          $en_wellness_participant_nga = is_null($numberNgaPcg) ?  0 : $numberNgaPcg->getNumber();
          $en_wellness_participant_nga_accumulate_graduates = $en_wellness_participant_accumulate_graduates - $en_wellness_participant_nga;
          $en_wellness_participant_country_nga_accumulate_graduates = $en_wellness_participant_nga;

          

         

          $statistics = array(
            'es_mbs'                            => $es_accumulate_graduates,
            'en_mbs'                            => $en_accumulate_graduates,
            'fr_mbs'                            => $fr_accumulate_graduates,
            'pt_mbs'                            => $pt_accumulate_graduates,  
            'es_sa'                             => $es_sa_accumulate_graduates,
            'en_sa'                             => $en_sa_accumulate_graduates,
            'fr_sa'                             => $fr_sa_accumulate_graduates,
            'pt_sa'                             => $pt_sa_accumulate_graduates,   
            'es_wellness'                       => $es_wellness_accumulate_graduates,
            'en_wellness'                       => $en_wellness_accumulate_graduates,
            'fr_wellness'                       => $fr_wellness_accumulate_graduates,
            'pt_wellness'                       => $pt_wellness_accumulate_graduates, 
            'es_wellness_participant'           => $es_wellness_participant_accumulate_graduates,
            'en_wellness_participant'           => $en_wellness_participant_accumulate_graduates,
            'fr_wellness_participant'           => $fr_wellness_participant_accumulate_graduates,
            'pt_wellness_participant'           => $pt_wellness_participant_accumulate_graduates,
            'es_nga_mbs'                        => $es_accumulate_graduates,
            'en_nga_mbs'                        => $en_nga_accumulate_graduates,
            'fr_nga_mbs'                        => $fr_accumulate_graduates,
            'pt_nga_mbs'                        => $pt_accumulate_graduates,
            'en_country_nga_mbs'                => $en_country_nga_accumulate_graduates,  
            'es_nga_sa'                         => $es_sa_accumulate_graduates,
            'en_nga_sa'                         => $en_sa_nga_accumulate_graduates,
            'fr_nga_sa'                         => $fr_sa_accumulate_graduates,
            'pt_nga_sa'                         => $pt_sa_accumulate_graduates,
            'en_country_nga_sa'                 => $en_sa_country_nga_accumulate_graduates,   
            'es_nga_wellness'                   => $es_wellness_accumulate_graduates,
            'en_nga_wellness'                   => $en_wellness_nga_accumulate_graduates,
            'fr_nga_wellness'                   => $fr_wellness_accumulate_graduates,
            'pt_nga_wellness'                   => $pt_wellness_accumulate_graduates, 
            'en_country_nga_wellness'           => $en_wellness_country_nga_accumulate_graduates,
            'es_nga_wellness_participant'       => $es_wellness_participant_accumulate_graduates,
            'en_nga_wellness_participant'       => $en_wellness_participant_nga_accumulate_graduates,
            'fr_nga_wellness_participant'       => $fr_wellness_participant_accumulate_graduates,
            'pt_nga_wellness_participant'       => $pt_wellness_participant_accumulate_graduates,  
            'en_country_nga_wellness_participant'  => $en_wellness_participant_country_nga_accumulate_graduates,    
          );

          
          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('report_list'))));
  }

  /**
     * @Rest\Post("/group/daterange", name="report_group_date_range")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     *
     * @SWG\Parameter(
     *     name="start_date",
     *     in="path",
     *     type="string",
     *     description="The start date"
     * )
     * 
     * @SWG\Parameter(
     *     name="final_date",
     *     in="path",
     *     type="string",
     *     description="The final date"
     * )
     *
     *
     * @SWG\Tag(name="Report")
     */
    public function groupDateRangeAction(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";

      try {
          $code = 200;
          $error = false;

          $start_date = $request->request->get("start_date");
          $final_date = $request->request->get("final_date");

          $until = new \DateTime();
          $interval = new \DateInterval('P2M');//2 months
          $from = $until->sub($interval);
          $mm =  'from' . $from->format('Y-m-d') . 'until' . $until->format('Y-m-d');
          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $mm : $message,
      ];

      return new Response($serializer->serialize($response, "json"));
  }


    /**
     * @Rest\Post("/globalnumbers", name="global_numbers")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all report."
     * )  
     * 
     * @SWG\Parameter(
     *     name="role",
     *     in="path",
     *     type="string",
     *     description="The Role of User"
     * )
     * 
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The id of Ambassador"
     * )   
     *
     * @SWG\Tag(name="Report")
     */
    public function globalnumbersAction(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";

      try {
          $code = 200;
          $error = false;

          $globalMbs = 0;
          $globalMbsJr = 0;
          $globalSa = 0; 
          $globalParticipants = 0; 
          $globalGroups = 0;
          $globalStories = 0;
          $globalPartners = 0;
          $globalWellness = 0;
          $globalMentoredAmb = 0;
          $globalWellnessParticipant = 0;

          $globalNgaMbs = 0;
          $globalJrMbs = 0;
          $globalNgaSa = 0;
          $globalNgaCis = 0;
          $globalNgaPcg = 0;

          $role = $request->request->get("role");
          $id_ambassador = $request->request->get("id");

          $numberNgaMbs = $em->getRepository('App:Certificate')->findOneBy(array('program' => 'MBS', 'country' => 'NGA'));
          $numberNgaSa  = $em->getRepository('App:Certificate')->findOneBy(array('program' => 'SA', 'country' => 'NGA'));
          $numberNgaJr  = $em->getRepository('App:Certificate')->findOneBy(array('program' => 'JR', 'country' => 'NGA'));
          $numberNgaCis = $em->getRepository('App:Certificate')->findOneBy(array('program' => 'WELLNESS', 'country' => 'NGA'));
          $numberNgaPcg = $em->getRepository('App:Certificate')->findOneBy(array('program' => 'WELLNESS_PART', 'country' => 'NGA'));

          $globalNgaMbs = is_null($numberNgaMbs) ?  0 : $numberNgaMbs->getNumber();
          $globalNgaJr  = is_null($numberNgaJr)  ?  0 : $numberNgaJr->getNumber();
          $globalNgaSa  = is_null($numberNgaSa) ?  0 : $numberNgaSa->getNumber();
          $globalNgaCis = is_null($numberNgaCis) ?  0 : $numberNgaCis->getNumber();
          $globalNgaPcg = is_null($numberNgaPcg) ?  0 : $numberNgaPcg->getNumber();

          if($role == "ROLE_ADMIN" or $role == "ROLE_LANGUAGE_ADMIN"){

              $totalMbs = $em->getRepository('App:Certificate')->graduatesTotalNumbers("MBS");
              $globalMbsJr = $em->getRepository('App:Certificate')->graduatesTotalNumbers("JR");
              $saNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("SA");
              $partnerNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("PARTNER");
              $wellnessNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("WELLNESS");
              $wellnessParticipantsNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("WELLNESS_PART");
              

              $globalMbs = $totalMbs + $globalMbsJr;
              $globalPartners = $partnerNumbers;
              $globalWellness = $wellnessNumbers;
              $globalWellnessParticipant = $wellnessParticipantsNumbers;


              $globalSa = $saNumbers;

          }
          else if($role == "ROLE_EMBASSADOR" or $role == "ROLE_STUDENT_EMBASSADOR"){
              $studentsMbs = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassador($id_ambassador, 'state.approved');
              $studentsSa = $em->getRepository('App:StudentGroup')->studentsAmbassadorStateByEmbassador($id_ambassador, 'state.approved');
              $studentsJr = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassadorProgram($id_ambassador, 'state.approved', 'option.program4');
              $participantsMbs = $em->getRepository('App:StudentGroup')->studentsMbsByEmbassador($id_ambassador);
              $groups = $em->getRepository('App:Groupe')->findBy(array("embassador" => $id_ambassador));
              $stories = $em->getRepository('App:StudentGroup')->successStoryByEmbassador($id_ambassador);
              $globalMentoredAmb = $em->getRepository('App:StudentGroup')->nsaByAmbassadorCount($id_ambassador);
              //$globalWellnessParticipant = $em->getRepository('App:StudentGroup')->studentsWellnessParticipantStateByEmbassadorCount($id_ambassador, 'state.approved');

              $globalMbs = count($studentsMbs);
              $globalMbsJr = count($studentsJr);
              $globalSa = count($studentsSa);
              $globalStories = count($stories);

              $globalParticipants = count($participantsMbs);
              $globalGroups = count($groups);
          }

          $date1 = new \DateTime("2018-12-15");
          $date2 = new \DateTime('now', (new \DateTimeZone('America/New_York') ) );
          $diff = $date1->diff($date2);

          $reports = [
              'global_mbs'                      => $globalMbs - $globalMbsJr,
              'global_mbs_junior'               => $globalMbsJr,
              'global_sa'                       => $globalSa,
              'global_wellness'                 => $globalWellness,
              'global_wellness_participant'     => $globalWellnessParticipant,
              'global_nga_mbs'                  => $globalMbs - $globalMbsJr - $globalNgaMbs,
              'global_nga_mbs_junior'           => $globalMbsJr - $globalNgaJr,
              'global_nga_sa'                   => $globalSa - $globalNgaSa,
              'global_nga_wellness'             => $globalWellness - $globalNgaCis,
              'global_nga_wellness_participant' => $globalWellnessParticipant - $globalNgaPcg,
              'global_participants'             => $globalParticipants,
              'global_groups'                   => $globalGroups,
              'global_certificates'             => $globalMbs,
              'global_stories'                  => $globalStories,
              'global_partners'                 => $globalPartners,              
              'global_mentored_amb'             => $globalMentoredAmb,              
              'global_nga_2_mbs'                  => $globalNgaMbs,
              'date_range'                      => $this->getFormat($diff),                  
          ];


      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $reports : $message,
      ];

      return new Response($serializer->serialize($response, "json"));
  }

  /**
     * @Rest\Get("/global", name="report_global")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all report."
     * )  
     * 
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     *     
     *
     * @SWG\Tag(name="Report")
     */
    public function globalAction(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";

      try {
          $code = 200;
          $error = false;

          $globalMbs = 0;
          $globalMbsJr = 0;
          $globalSa = 0; 
          $globalParticipants = 0;
          $globalGroups = 0;
          $saNumbers= 0;

          $role = $request->request->get("role");
          $id_ambassador = $request->request->get("id");


          $globalMbs = $em->getRepository('App:Certificate')->graduatesTotalNumbers("MBS");
          $globalMbsJr = $em->getRepository('App:Certificate')->graduatesTotalNumbers("JR");
          $saNumbers = $em->getRepository('App:User')->ambassadorsTotal();


          $globalSa = $saNumbers;

          $globalCountries = $em->getRepository('App:Certificate')->countriesTotal();

          $date1 = new \DateTime("2018-12-15");
          $date2 = new \DateTime('now', (new \DateTimeZone('America/New_York') ) );
          $diff = $date1->diff($date2);

          $reports = [
              'global_mbs'          => $globalMbs + $globalMbsJr,
              'global_mbs_junior'   => $globalMbsJr,
              'global_sa'           => $globalSa,
              'global_groups'       => $globalGroups,
              'countries'           => $globalCountries,
              'date_range'           => $this->getFormat($diff),                  
          ];


      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $reports : $message,
      ];

      return new Response($serializer->serialize($response, "json"));
  }

   /**
     * @Rest\Post("/ambassadorstatistics", name="ambassador_statistics")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all report of Ambassador."
     * )  
     *     
    * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="path",
     *     type="string",
     *     description="The id of Ambassador"
     * )   
     * 
     * @SWG\Tag(name="Report")
     */
    public function ambassadorStatisticsAction(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $statistics = [];
      $message = "";

      try {
          $code = 200;
          $error = false;

          $id_ambassador = $request->request->get("id_ambassador");

          $ambassador = $em->getRepository('App:User')->find($id_ambassador);

          $participantsMbs = $em->getRepository('App:StudentGroup')->studentsMbsByEmbassador($ambassador->getId());
          $certificates = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassador($ambassador->getId(), 'state.approved');
          $groups = $em->getRepository('App:Groupe')->findBy(array("embassador" => $ambassador->getId()));
          $stories = $em->getRepository('App:StudentGroup')->successStoryByEmbassador($ambassador->getId());

          $statistics = [
            'id' => $ambassador->getId(),
            'first_name' => $ambassador->getFirstName(),
            'last_name' => $ambassador->getLastName(),
            'participants' => count($participantsMbs),
            'certificates' => count($certificates),
            'groups'=> count($groups),
            'stories'=> count($stories)
          ];

         


      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json"));
  }

  /**
     * @Rest\Get("/listambassadorstatistics", name="list_ambassador_statistics")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets all report of Ambassador."
     * )  
     *     
     *
     * @SWG\Tag(name="Report")
     */
    public function listAmbassadorStatisticsAction(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";

      try {
          $code = 200;
          $error = false;

          $globalMbs = 0;
          $globalMbsJr = 0;
          $globalSa = 0; 
          $globalParticipants = 0;
          $globalGroups = 0;

          $ambassadors = $em->getRepository('App:User')->userByRole("ROLE_EMBASSADOR");

          foreach ($ambassadors as $key => $ambassador) {
              $participantsMbs = $em->getRepository('App:StudentGroup')->studentsMbsByEmbassador($ambassador->getId());
              $certificates = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassador($ambassador->getId(), 'state.approved');
              $groups = $em->getRepository('App:Groupe')->findBy(array("embassador" => $ambassador->getId()));
              $stories = $em->getRepository('App:StudentGroup')->successStoryByEmbassador($ambassador->getId());
              $mentored_amb = $em->getRepository('App:StudentGroup')->nsaByAmbassadorCount($ambassador->getId());
              $sa_project = $em->getRepository('App:ProgramSa')->findOneBy(array('student' => $ambassador->getId()));

              $last_graduate = "Never";
              $sa_approval_date = "2019-20-01";
              if(!is_null($sa_project)){
                if(!is_null($sa_project->getApprovalDate())){
                  $sa_approval_date = $sa_project->getApprovalDate()->format('Y-d-m');
                }
              }

              
              $graduate = $em->getRepository('App:StudentGroup')->lastMbsGraduatedByEmbassador($ambassador->getId(), 'state.approved');
              if($graduate > 0){
                  $last_graduate = $em->getRepository('App:StudentGroup')->lastMbsGraduatedByEmbassadorDate($ambassador->getId(), 'state.approved');
                  if(!is_null($last_graduate )){
                      $last_graduate = $last_graduate->format('Y-d-m');
                  }
                  
              }

              $statistics[] = array(
                'id' => $ambassador->getId(),
                'first_name' => $ambassador->getFirstName(), 
                'last_name' => $ambassador->getLastName(), 
                'country' => $ambassador->getCountry(),
                'whatsapp' => $ambassador->getWhatsapp(),
                'username' => $ambassador->getUsername(),
                'sa_approval_date' => $sa_approval_date,
                'last_graduate' => $last_graduate,
                'graduates' => count($certificates),
                'mentored_success_ambassadors' => $mentored_amb,
                'groups'=> count($groups),
                'success_stories'=> count($stories), 
                'participants' => count($participantsMbs),
                'certificates' => count($certificates),
                'stories'=> count($stories), 
                'mentored_ambassadors' => $mentored_amb
              );
          }

         


      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json"));
  }

    /**
     * @Rest\Get("/ambassador/{id}.{_format}", name="report_ambassador", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets statistics info based on passed ID Ambassador parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The statistics with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The ambassador ID"
     * )
     *
     *
     * @SWG\Tag(name="Report")
     */
    public function ambassadorAction(Request $request, $id ) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $statistics = [];
      $message = "";
      
      try {
          $code = 200;
          $error = false;

          $ambassador_id = $id;
          $evaluations = $this->evaluationReportXAmbassador($ambassador_id);
          $statisticsMbs = $this->showStatistics($evaluations['mbs'], "MBS");
          $statisticsJr = $this->showStatistics($evaluations['jr'], "JR");

          $statistics = array(
            'MBS' => $statisticsMbs,
            'JR'  => $statisticsJr
          );

          if (is_null($statistics)) {
              $code = 500;
              $error = true;
              $message = "The ambassador statistics does not exist";
          }

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get the statistics ambassador - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json"));
  }

  /**
     * @Rest\Get("/country/{id}.{_format}", name="report_country", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets statistics info based on passed ID Country parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The statistics with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The country ID"
     * )
     *
     *
     * @SWG\Tag(name="Report")
     */
    public function countryAction(Request $request, $id ) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $statistics = [];
      $message = "";
      
      try {
          $code = 200;
          $error = false;

          $country_id = $id;
          
          $evaluations = $this->evaluationReportByCountry($country_id);
          $statistics = $this->showStatistics($evaluations, "MBS");

          if (is_null($statistics)) {
              $code = 500;
              $error = true;
              $message = "The country statistics does not exist";
          }

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get the statistics country - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json"));
  }

  /**
     * @Rest\Get("/evaluations/{id}.{_format}", name="report_evaluations", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets statistics info based on passed ID Country parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The statistics with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The country ID"
     * )
     *
     *
     * @SWG\Tag(name="Report")
     */
    public function evaluationsAction(Request $request, $id ) {
        $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $users = [];
        $message = "";

        try {
            $code = 200;
            $error = false;

            $file = fopen($this->container->getparameter('kernel.project_dir')."/web/query/evaluations/".$id.".json", "r");
            $response = fread($file, filesize($this->container->getparameter('kernel.project_dir')."/web/query/evaluations/".$id.".json"));
            fclose($file);


        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all evaluations - Error: {$ex->getMessage()}";
        } 

        return new Response($response);
    }

  /**
     * @Rest\Get("/evaluations/update/{id}.{_format}", name="report_update_evaluations", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets statistics info based on passed ID Country parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The statistics with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The country ID"
     * )
     *
     *
     * @SWG\Tag(name="Report")
     */
    public function evaluationsUpdateAction(Request $request, $id ) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $statistics = [];
      $message = "";
      
      try {
          $code = 200;
          $error = false;

          $country_id = $id;

          $iso_array = array(
            'ALL'=>'All',
            'ABW'=>'Aruba',
            'AFG'=>'Afghanistan',
            'AGO'=>'Angola',
            'AIA'=>'Anguilla',
            'ALA'=>'Åland Islands',
            'ALB'=>'Albania',
            'AND'=>'Andorra',
            'ARE'=>'United Arab Emirates',
            'ARG'=>'Argentina',
            'ARM'=>'Armenia',
            'ASM'=>'American Samoa',
            'ATA'=>'Antarctica',
            'ATF'=>'French Southern Territories',
            'ATG'=>'Antigua and Barbuda',
            'AUS'=>'Australia',
            'AUT'=>'Austria',
            'AZE'=>'Azerbaijan',
            'BDI'=>'Burundi',
            'BEL'=>'Belgium',
            'BEN'=>'Benin',
            'BES'=>'Bonaire, Sint Eustatius and Saba',
            'BFA'=>'Burkina Faso',
            'BGD'=>'Bangladesh',
            'BGR'=>'Bulgaria',
            'BHR'=>'Bahrain',
            'BHS'=>'Bahamas',
            'BIH'=>'Bosnia and Herzegovina',
            'BLM'=>'Saint Barthélemy',
            'BLR'=>'Belarus',
            'BLZ'=>'Belize',
            'BMU'=>'Bermuda',
            'BOL'=>'Bolivia (Plurinational State of)',
            'BRA'=>'Brazil',
            'BRB'=>'Barbados',
            'BRN'=>'Brunei Darussalam',
            'BTN'=>'Bhutan',
            'BVT'=>'Bouvet Island',
            'BWA'=>'Botswana',
            'CAF'=>'Central African Republic',
            'CAN'=>'Canada',
            'CCK'=>'Cocos (Keeling) Islands',
            'CHE'=>'Switzerland',
            'CHL'=>'Chile',
            'CHN'=>'China',
            'CIV'=>'Côte dIvoire',
            'CMR'=>'Cameroon',
            'COD'=>'Congo, Democratic Republic of the',
            'COG'=>'Congo',
            'COK'=>'Cook Islands',
            'COL'=>'Colombia',
            'COM'=>'Comoros',
            'CPV'=>'Cabo Verde',
            'CRI'=>'Costa Rica',
            'CUB'=>'Cuba',
            'CUW'=>'Curaçao',
            'CXR'=>'Christmas Island',
            'CYM'=>'Cayman Islands',
            'CYP'=>'Cyprus',
            'CZE'=>'Czechia',
            'DEU'=>'Germany',
            'DJI'=>'Djibouti',
            'DMA'=>'Dominica',
            'DNK'=>'Denmark',
            'DOM'=>'Dominican Republic',
            'DZA'=>'Algeria',
            'DZA'=>'Algeria',
            'ECU'=>'Ecuador',
            'EGY'=>'Egypt',
            'ERI'=>'Eritrea',
            'ESH'=>'Western Sahara',
            'ESP'=>'Spain',
            'EST'=>'Estonia',
            'ETH'=>'Ethiopia',
            'FIN'=>'Finland',
            'FJI'=>'Fiji',
            'FLK'=>'Falkland Islands (Malvinas)',
            'FRA'=>'France',
            'FRO'=>'Faroe Islands',
            'FSM'=>'Micronesia, Federated States of',
            'GAB'=>'Gabon',
            'GBR'=>'United Kingdom',
            'GEO'=>'Georgia',
            'GGY'=>'Guernsey',
            'GHA'=>'Ghana',
            'GIB'=>'Gibraltar',
            'GIN'=>'Guinea',
            'GLP'=>'Guadeloupe',
            'GMB'=>'Gambia',
            'GNB'=>'Guinea-Bissau',
            'GNQ'=>'Equatorial Guinea',
            'GRC'=>'Greece',
            'GRD'=>'Grenada',
            'GRL'=>'Greenland',
            'GTM'=>'Guatemala',
            'GUF'=>'French Guiana',
            'GUM'=>'Guam',
            'GUY'=>'Guyana',
            'HKG'=>'Hong Kong',
            'HMD'=>'Heard Island and McDonald Islands',
            'HND'=>'Honduras',
            'HRV'=>'Croatia',
            'HTI'=>'Haiti',
            'HUN'=>'Hungary',
            'IDN'=>'Indonesia',
            'IMN'=>'Isle of Man',
            'IND'=>'India',
            'IOT'=>'British Indian Ocean Territory',
            'IRL'=>'Ireland',
            'IRN'=>'Iran, Islamic Republic of',
            'IRQ'=>'Iraq',
            'ISL'=>'Iceland',
            'ISR'=>'Israel',
            'ITA'=>'Italy',
            'JAM'=>'Jamaica',
            'JEY'=>'Jersey',
            'JOR'=>'Jordan',
            'JPN'=>'Japan',
            'KAZ'=>'Kazakhstan',
            'KEN'=>'Kenya',
            'KGZ'=>'Kyrgyzstan',
            'KHM'=>'Cambodia',
            'KIR'=>'Kiribati',
            'KNA'=>'Saint Kitts and Nevis',
            'KOR'=>'Korea, Republic of',
            'KWT'=>'Kuwait',
            'LAO'=>'Lao People\'s Democratic Republic',
            'LBN'=>'Lebanon',
            'LBR'=>'Liberia',
            'LBY'=>'Libya',
            'LCA'=>'Saint Lucia',
            'LIE'=>'Liechtenstein',
            'LKA'=>'Sri Lanka',
            'LSO'=>'Lesotho',
            'LTU'=>'Lithuania',
            'LUX'=>'Luxembourg',
            'LVA'=>'Latvia',
            'MAC'=>'Macao',
            'MAF'=>'Saint Martin (French part)',
            'MAR'=>'Morocco',
            'MCO'=>'Monaco',
            'MDA'=>'Moldova, Republic of',
            'MDG'=>'Madagascar',
            'MDV'=>'Maldives',
            'MEX'=>'Mexico',
            'MHL'=>'Marshall Islands',
            'MKD'=>'Macedonia, the former Yugoslav Republic of',
            'MLI'=>'Mali',
            'MLT'=>'Malta',
            'MMR'=>'Myanmar',
            'MNE'=>'Montenegro',
            'MNG'=>'Mongolia',
            'MNP'=>'Northern Mariana Islands',
            'MOZ'=>'Mozambique',
            'MRT'=>'Mauritania',
            'MSR'=>'Montserrat',
            'MTQ'=>'Martinique',
            'MUS'=>'Mauritius',
            'MWI'=>'Malawi',
            'MYS'=>'Malaysia',
            'MYT'=>'Mayotte',
            'NAM'=>'Namibia',
            'NCL'=>'New Caledonia',
            'NER'=>'Niger',
            'NFK'=>'Norfolk Island',
            'NGA'=>'Nigeria',
            'NIC'=>'Nicaragua',
            'NIU'=>'Niue',
            'NLD'=>'Netherlands',
            'NOR'=>'Norway',
            'NPL'=>'Nepal',
            'NRU'=>'Nauru',
            'NZL'=>'New Zealand',
            'OMN'=>'Oman',
            'PAK'=>'Pakistan',
            'PAN'=>'Panama',
            'PCN'=>'Pitcairn',
            'PER'=>'Peru',
            'PHL'=>'Philippines',
            'PLW'=>'Palau',
            'PNG'=>'Papua New Guinea',
            'POL'=>'Poland',
            'PRI'=>'Puerto Rico',
            'PRK'=>'Korea, Democratic People\'s Republic of',
            'PRT'=>'Portugal',
            'PRY'=>'Paraguay',
            'PSE'=>'Palestinian Territory, Occupied',
            'PYF'=>'French Polynesia',
            'QAT'=>'Qatar',
            'REU'=>'Réunion',
            'ROU'=>'Romania',
            'RUS'=>'Russian Federation',
            'RWA'=>'Rwanda',
            'SAU'=>'Saudi Arabia',
            'SDN'=>'Sudan',
            'SEN'=>'Senegal',
            'SGP'=>'Singapore',
            'SGS'=>'South Georgia and the South Sandwich Islands',
            'SHN'=>'Saint Helena, Ascension and Tristan da Cunha',
            'SJM'=>'Svalbard and Jan Mayen',
            'SLB'=>'Solomon Islands',
            'SLE'=>'Sierra Leone',
            'SLV'=>'El Salvador',
            'SMR'=>'San Marino',
            'SOM'=>'Somalia',
            'SPM'=>'Saint Pierre and Miquelon',
            'SRB'=>'Serbia',
            'SSD'=>'South Sudan',
            'STP'=>'Sao Tome and Principe',
            'SUR'=>'Suriname',
            'SVK'=>'Slovakia',
            'SVN'=>'Slovenia',
            'SWE'=>'Sweden',
            'SWZ'=>'Swaziland',
            'SXM'=>'Sint Maarten (Dutch part)',
            'SYC'=>'Seychelles',
            'SYR'=>'Syrian Arab Republic',
            'TCA'=>'Turks and Caicos Islands',
            'TCD'=>'Chad',
            'TGO'=>'Togo',
            'THA'=>'Thailand',
            'TJK'=>'Tajikistan',
            'TKL'=>'Tokelau',
            'TKM'=>'Turkmenistan',
            'TLS'=>'Timor-Leste',
            'TON'=>'Tonga',
            'TTO'=>'Trinidad and Tobago',
            'TUN'=>'Tunisia',
            'TUR'=>'Turkey',
            'TUV'=>'Tuvalu',
            'TWN'=>'Taiwan, Province of China',
            'TZA'=>'Tanzania, United Republic of',
            'UGA'=>'Uganda',
            'UKR'=>'Ukraine',
            'UMI'=>'United States Minor Outlying Islands',
            'URY'=>'Uruguay',
            'USA'=>'United States',
            'UZB'=>'Uzbekistan',
            'VAT'=>'Holy See (Vatican City State)',
            'VCT'=>'Saint Vincent and the Grenadines',
            'VEN'=>'Venezuela, Bolivarian Republic of',
            'VGB'=>'Virgin Islands, British',
            'VIR'=>'Virgin Islands, U.S.',
            'VNM'=>'Viet Nam',
            'VUT'=>'Vanuatu',
            'WLF'=>'Wallis and Futuna',
            'WSM'=>'Samoa',
            'YEM'=>'Yemen',
            'ZAF'=>'South Africa',
            'ZMB'=>'Zambia',
            'ZWE'=>'Zimbabwe',
            'WITHOUT_NGA'=>'Nigeria',
            
            );

          foreach ($iso_array as $key => $value) {
              //Reports
              $evaluations = $this->evaluationReportByCountryProgram($key);
              $statisticsJr = $this->showStatistics($evaluations['jr'], "JR");
              $statisticsMbs = $this->showStatistics($evaluations['mbs'], "MBS");

              $report_statistics = array(
                'MBS' => $statisticsMbs,
                'JR'  => $statisticsJr
              );

              //Country Page
              $mbsNumbers = $em->getRepository('App:Certificate')->findOneBy(array('program' => 'MBS', 'country' => $key));
              $jrNumbers = $em->getRepository('App:Certificate')->findOneBy(array('program' => 'JR', 'country' => $key));
              $saNumbers = $em->getRepository('App:Certificate')->findOneBy(array('program' => 'SA', 'country' => $key));

              //$eval = $this->evaluationReportByCountry($country_id);
              $show_evaluations = $this->showStatisticsCountry($evaluations['general'], "MBS");

              $statistics = array(
                'MBS' => $mbsNumbers ? $mbsNumbers->getNumber() : 0 ,
                'JR'  => $jrNumbers  ? $jrNumbers->getNumber()  : 0 , 
                'SA'  => $saNumbers  ? $saNumbers->getNumber()  : 0 ,
                'EVALUATIONS' => $show_evaluations, 
                "REPORTS" => $report_statistics
              );

              $this->forward('App\Controller\InitializationController::evaluationCreateAction', [
                'evaluations' => $statistics,
                'country' => $key
              ]);

          }  
          
          
        

          if (is_null($statistics)) {
              $code = 500;
              $error = true;
              $message = "The country statistics does not exist";
          } 

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get the statistics country - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

     
     

      return new Response($serializer->serialize($response, "json"));
  }

   /**
     * @Rest\Get("/bycountry/{id}.{_format}", name="report_by_country", defaults={"_format":"json"})
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets statistics info based on passed ID Country parameter."
     * )
     *
     * @SWG\Response(
     *     response=400,
     *     description="The statistics with the passed ID parameter was not found or doesn't exist."
     * )
     *
     * @SWG\Parameter(
     *     name="id",
     *     in="path",
     *     type="string",
     *     description="The country ID"
     * )
     *
     *
     * @SWG\Tag(name="Report")
     */
    public function byCountryAction(Request $request, $id ) {
      $serializer = $this->get('jms_serializer');
        $em = $this->getDoctrine()->getManager();
        $users = [];
        $message = "";

        try {
            $code = 200;
            $error = false;

            $file = fopen($this->container->getparameter('kernel.project_dir')."/web/query/evaluations/".$id.".json", "r");
            $response = fread($file, filesize($this->container->getparameter('kernel.project_dir')."/web/query/evaluations/".$id.".json"));
            fclose($file);


        } catch (Exception $ex) {
            $code = 500;
            $error = true;
            $message = "An error has occurred trying to get all evaluations - Error: {$ex->getMessage()}";
        } 

        return new Response($response);
    }

  


    private function evaluationReportByCountry($country){
        $em = $this->getDoctrine()->getManager();
  
        if($country == "WITHOUT_NGA"){
          $studentsEvaluations = $em->getRepository('App:Evaluation')->evaluationWithoutCountry('NGA');
        }
        else if($country and $country != "ALL"){
            $studentsEvaluations = $em->getRepository('App:Evaluation')->evaluationByCountry($country);
        }
        else{
            $studentsEvaluations = $em->getRepository('App:Evaluation')->findAll();
        }
  
  
        $evaluations = array();
        foreach ($studentsEvaluations as $s) {
          $student = $s->getStudent();
            if($s->getPostquestion1() and $student->getStudentgroup() ){
               $evaluations[] = array(
                 'name'             => $student->getFirstName()." ".$student->getLastName(),
                 'question1'        => $this->improvementMeasure($s->getQuestion1(), $s->getPostquestion1(), 'question1'),
                 'question2'        => $this->improvementMeasure($s->getQuestion2(), $s->getPostquestion2(), 'question2'),
                 'question3'        => $this->improvementMeasure($s->getQuestion3(), $s->getPostquestion3(), 'question3'),
                 'question4'        => $this->improvementMeasure($s->getQuestion4(), $s->getPostquestion4(), 'question4'),
                 'question5'        => $this->improvementMeasure($s->getQuestion5(), $s->getPostquestion5(), 'question5'),
                 'question6'        => $this->improvementMeasure($s->getQuestion6(), $s->getPostquestion6(), 'question6'),
                 'question7'        => $this->improvementMeasure($s->getQuestion7(), $s->getPostquestion7(), 'question7'),
                 'question8'        => $this->improvementMeasure('option1', $s->getPostquestion8(), 'question8'),
                 'question9'        => $this->improvementMeasure('option1', $s->getPostquestion9(), 'question9'),
                 'questionInitial1' => $this->initialState($s->getQuestion1(), 'question1'),
                 'questionInitial2' => $this->initialState($s->getQuestion2(), 'question2'),
                 'questionInitial3' => $this->initialState($s->getQuestion3(), 'question3'),
                 'questionInitial4' => $this->initialState($s->getQuestion4(), 'question4'),
                 'questionInitial5' => $this->initialState($s->getQuestion5(), 'question5'),
                 'questionInitial6' => $this->initialState($s->getQuestion6(), 'question6'),
                 'questionInitial7' => $this->initialState($s->getQuestion7(), 'question7'),
                 'questionFinal1'   => $this->potentialImprovement($s->getQuestion1(), $s->getPostquestion1(), 'question1'),
                 'questionFinal2'   => $this->potentialImprovement($s->getQuestion2(), $s->getPostquestion2(), 'question2'),
                 'questionFinal3'   => $this->potentialImprovement($s->getQuestion3(), $s->getPostquestion3(), 'question3'),
                 'questionFinal4'   => $this->potentialImprovement($s->getQuestion4(), $s->getPostquestion4(), 'question4'),
                 'questionFinal5'   => $this->potentialImprovement($s->getQuestion5(), $s->getPostquestion5(), 'question5'),
                 'questionFinal6'   => $this->potentialImprovement($s->getQuestion6(), $s->getPostquestion6(), 'question6'),
                 'questionFinal7'   => $this->potentialImprovement($s->getQuestion7(), $s->getPostquestion7(), 'question7'),
                 'questionFinal8'   => $this->potentialImprovement('option1', $s->getPostquestion8(), 'question8'),
                 'questionFinal9'   => $this->potentialImprovement('option1', $s->getPostquestion9(), 'question9'),
  
                 'group'            => $student->getStudentgroup()->getGroup()->getName(),
                 'ambassador'       => $student->getStudentgroup()->getGroup()->getEmbassador()->getFirstName()." ".$student->getStudentgroup()->getGroup()->getEmbassador()->getLastName()
               );
            }
  
        }
        return $evaluations;
  
      }

      private function evaluationReportByCountryProgram($country){
        $em = $this->getDoctrine()->getManager();

        if($country == "WITHOUT_NGA"){
            $studentsEvaluations = $em->getRepository('App:Evaluation')->evaluationWithoutCountry('NGA');
        }
        else if($country and $country != "ALL"){
            $studentsEvaluations = $em->getRepository('App:Evaluation')->evaluationByCountry($country);
        }
        else{
            $studentsEvaluations = $em->getRepository('App:Evaluation')->findAll();
        }
  
  
        $evaluationsMbs = array();
        $evaluationsJr = array();
        $evaluationsG = array();
        $evaluations = array();
        foreach ($studentsEvaluations as $s) {
            $usable_evaluation = $em->getRepository('App:Evaluation')->unusableEvaluationById($s->getId());
          
            if($s->getStudent() && $usable_evaluation){
              $student = $s->getStudent();
              if($student->getStudentgroup()){
                if($s->getPostquestion1() and $student->getStudentgroup()->getGroup()->getProgram() == 'option.program4'){
                  $evaluationsJr[] = array(
                    'name'             => $student->getFirstName()." ".$student->getLastName(),
                    'question1'        => $this->improvementMeasure($s->getQuestion1(), $s->getPostquestion1(), 'question1'),
                    'question2'        => $this->improvementMeasure($s->getQuestion2(), $s->getPostquestion2(), 'question2'),
                    'question3'        => $this->improvementMeasure($s->getQuestion3(), $s->getPostquestion3(), 'question3'),
                    'question4'        => $this->improvementMeasure($s->getQuestion4(), $s->getPostquestion4(), 'question4'),
                    'question5'        => $this->improvementMeasure($s->getQuestion5(), $s->getPostquestion5(), 'question5'),
                    'question6'        => $this->improvementMeasure($s->getQuestion6(), $s->getPostquestion6(), 'question6'),
                    'question7'        => $this->improvementMeasure($s->getQuestion7(), $s->getPostquestion7(), 'question7'),
                    'question8'        => $this->improvementMeasure('option1', $s->getPostquestion8(), 'question8'),
                    'question9'        => $this->improvementMeasure('option1', $s->getPostquestion9(), 'question9'),
                    'questionInitial1' => $this->initialState($s->getQuestion1(), 'question1'),
                    'questionInitial2' => $this->initialState($s->getQuestion2(), 'question2'),
                    'questionInitial3' => $this->initialState($s->getQuestion3(), 'question3'),
                    'questionInitial4' => $this->initialState($s->getQuestion4(), 'question4'),
                    'questionInitial5' => $this->initialState($s->getQuestion5(), 'question5'),
                    'questionInitial6' => $this->initialState($s->getQuestion6(), 'question6'),
                    'questionInitial7' => $this->initialState($s->getQuestion7(), 'question7'),
                    'questionFinal1'   => $this->potentialImprovement($s->getQuestion1(), $s->getPostquestion1(), 'question1'),
                    'questionFinal2'   => $this->potentialImprovement($s->getQuestion2(), $s->getPostquestion2(), 'question2'),
                    'questionFinal3'   => $this->potentialImprovement($s->getQuestion3(), $s->getPostquestion3(), 'question3'),
                    'questionFinal4'   => $this->potentialImprovement($s->getQuestion4(), $s->getPostquestion4(), 'question4'),
                    'questionFinal5'   => $this->potentialImprovement($s->getQuestion5(), $s->getPostquestion5(), 'question5'),
                    'questionFinal6'   => $this->potentialImprovement($s->getQuestion6(), $s->getPostquestion6(), 'question6'),
                    'questionFinal7'   => $this->potentialImprovement($s->getQuestion7(), $s->getPostquestion7(), 'question7'),
                    'questionFinal8'   => $this->potentialImprovement('option1', $s->getPostquestion8(), 'question8'),
                    'questionFinal9'   => $this->potentialImprovement('option1', $s->getPostquestion9(), 'question9'),
      
                    'group'            => $student->getStudentgroup()->getGroup()->getName(),
                    'ambassador'       => $student->getStudentgroup()->getGroup()->getEmbassador()->getFirstName()." ".$student->getStudentgroup()->getGroup()->getEmbassador()->getLastName()
                  );
                }
                else if($s->getPostquestion1()){
                  $evaluationsMbs[] = array(
                    'name'             => $student->getFirstName()." ".$student->getLastName(),
                    'question1'        => $this->improvementMeasure($s->getQuestion1(), $s->getPostquestion1(), 'question1'),
                    'question2'        => $this->improvementMeasure($s->getQuestion2(), $s->getPostquestion2(), 'question2'),
                    'question3'        => $this->improvementMeasure($s->getQuestion3(), $s->getPostquestion3(), 'question3'),
                    'question4'        => $this->improvementMeasure($s->getQuestion4(), $s->getPostquestion4(), 'question4'),
                    'question5'        => $this->improvementMeasure($s->getQuestion5(), $s->getPostquestion5(), 'question5'),
                    'question6'        => $this->improvementMeasure($s->getQuestion6(), $s->getPostquestion6(), 'question6'),
                    'question7'        => $this->improvementMeasure($s->getQuestion7(), $s->getPostquestion7(), 'question7'),
                    'question8'        => $this->improvementMeasure('option1', $s->getPostquestion8(), 'question8'),
                    'question9'        => $this->improvementMeasure('option1', $s->getPostquestion9(), 'question9'),
                    'questionInitial1' => $this->initialState($s->getQuestion1(), 'question1'),
                    'questionInitial2' => $this->initialState($s->getQuestion2(), 'question2'),
                    'questionInitial3' => $this->initialState($s->getQuestion3(), 'question3'),
                    'questionInitial4' => $this->initialState($s->getQuestion4(), 'question4'),
                    'questionInitial5' => $this->initialState($s->getQuestion5(), 'question5'),
                    'questionInitial6' => $this->initialState($s->getQuestion6(), 'question6'),
                    'questionInitial7' => $this->initialState($s->getQuestion7(), 'question7'),
                    'questionFinal1'   => $this->potentialImprovement($s->getQuestion1(), $s->getPostquestion1(), 'question1'),
                    'questionFinal2'   => $this->potentialImprovement($s->getQuestion2(), $s->getPostquestion2(), 'question2'),
                    'questionFinal3'   => $this->potentialImprovement($s->getQuestion3(), $s->getPostquestion3(), 'question3'),
                    'questionFinal4'   => $this->potentialImprovement($s->getQuestion4(), $s->getPostquestion4(), 'question4'),
                    'questionFinal5'   => $this->potentialImprovement($s->getQuestion5(), $s->getPostquestion5(), 'question5'),
                    'questionFinal6'   => $this->potentialImprovement($s->getQuestion6(), $s->getPostquestion6(), 'question6'),
                    'questionFinal7'   => $this->potentialImprovement($s->getQuestion7(), $s->getPostquestion7(), 'question7'),
                    'questionFinal8'   => $this->potentialImprovement('option1', $s->getPostquestion8(), 'question8'),
                    'questionFinal9'   => $this->potentialImprovement('option1', $s->getPostquestion9(), 'question9'),
    
                    'group'            => $student->getStudentgroup()->getGroup()->getName(),
                    'ambassador'       => $student->getStudentgroup()->getGroup()->getEmbassador()->getFirstName()." ".$student->getStudentgroup()->getGroup()->getEmbassador()->getLastName()
                  );
                }
                if($s->getPostquestion1() and $student->getStudentgroup() ){
                  $evaluationsG[] = array(
                    'name'             => $student->getFirstName()." ".$student->getLastName(),
                    'question1'        => $this->improvementMeasure($s->getQuestion1(), $s->getPostquestion1(), 'question1'),
                    'question2'        => $this->improvementMeasure($s->getQuestion2(), $s->getPostquestion2(), 'question2'),
                    'question3'        => $this->improvementMeasure($s->getQuestion3(), $s->getPostquestion3(), 'question3'),
                    'question4'        => $this->improvementMeasure($s->getQuestion4(), $s->getPostquestion4(), 'question4'),
                    'question5'        => $this->improvementMeasure($s->getQuestion5(), $s->getPostquestion5(), 'question5'),
                    'question6'        => $this->improvementMeasure($s->getQuestion6(), $s->getPostquestion6(), 'question6'),
                    'question7'        => $this->improvementMeasure($s->getQuestion7(), $s->getPostquestion7(), 'question7'),
                    'question8'        => $this->improvementMeasure('option1', $s->getPostquestion8(), 'question8'),
                    'question9'        => $this->improvementMeasure('option1', $s->getPostquestion9(), 'question9'),
                    'questionInitial1' => $this->initialState($s->getQuestion1(), 'question1'),
                    'questionInitial2' => $this->initialState($s->getQuestion2(), 'question2'),
                    'questionInitial3' => $this->initialState($s->getQuestion3(), 'question3'),
                    'questionInitial4' => $this->initialState($s->getQuestion4(), 'question4'),
                    'questionInitial5' => $this->initialState($s->getQuestion5(), 'question5'),
                    'questionInitial6' => $this->initialState($s->getQuestion6(), 'question6'),
                    'questionInitial7' => $this->initialState($s->getQuestion7(), 'question7'),
                    'questionFinal1'   => $this->potentialImprovement($s->getQuestion1(), $s->getPostquestion1(), 'question1'),
                    'questionFinal2'   => $this->potentialImprovement($s->getQuestion2(), $s->getPostquestion2(), 'question2'),
                    'questionFinal3'   => $this->potentialImprovement($s->getQuestion3(), $s->getPostquestion3(), 'question3'),
                    'questionFinal4'   => $this->potentialImprovement($s->getQuestion4(), $s->getPostquestion4(), 'question4'),
                    'questionFinal5'   => $this->potentialImprovement($s->getQuestion5(), $s->getPostquestion5(), 'question5'),
                    'questionFinal6'   => $this->potentialImprovement($s->getQuestion6(), $s->getPostquestion6(), 'question6'),
                    'questionFinal7'   => $this->potentialImprovement($s->getQuestion7(), $s->getPostquestion7(), 'question7'),
                    'questionFinal8'   => $this->potentialImprovement('option1', $s->getPostquestion8(), 'question8'),
                    'questionFinal9'   => $this->potentialImprovement('option1', $s->getPostquestion9(), 'question9'),
     
                    'group'            => $student->getStudentgroup()->getGroup()->getName(),
                    'ambassador'       => $student->getStudentgroup()->getGroup()->getEmbassador()->getFirstName()." ".$student->getStudentgroup()->getGroup()->getEmbassador()->getLastName()
                  );
               }
              }
            }
  
        }
        $evaluations['mbs'] = $evaluationsMbs;
        $evaluations['jr'] = $evaluationsJr;
        $evaluations['general'] = $evaluationsG;

        return $evaluations;
  
      }

      private function improvementMeasure($question, $postquestion, $numberQuestion){

        $postQ = (int) str_replace('option', '' , $postquestion);
        $preQ = (int) str_replace('option', '' , $question);
  
        if($numberQuestion == "question1"){
          if($postQ < $preQ){
            return "IMPROVEMENT";
  
          }
          elseif($postQ == $preQ){
            return "IQUAL";
  
          }
          else{
            return "WORSEN";
          }
        }
  
  
        if($postQ > $preQ){
          return "IMPROVEMENT";
        }
        elseif($postQ == $preQ){
          return "IQUAL";
        }
        else{
          return "WORSEN";
        }
  
      }
  
      private function potentialImprovement($question, $postquestion, $numberQuestion){
  
        $postQ = (int) str_replace('option', '' , $postquestion);
        $preQ = (int) str_replace('option', '' , $question);
  
        if($numberQuestion == "question1"){
          if($postQ == 1){
            return "YES";
          }
          else{
            return "NOT";
          }
        }
        elseif($preQ < 3){
          if($postQ > $preQ){
            return "YES";
          }
          else{
            return "NOT";
          }
        }
        else{
          if($postQ > 2){
            return "YES";
          }
          else{
            return "NOT";
          }
  
        }
  
      }

      private function initialState($question, $numberQuestion){

        $preQ = (int) str_replace('option', '' , $question);
  
        if($numberQuestion == "question1"){
          if($preQ == 1){
            return "YES";
  
          }
          elseif($preQ == 2){
            return "NOT";
  
          }
        }
  
  
        if($preQ > 2){
          return "YES";
        }
        else{
          return "NOT";
        }
  
      }
  
      private function showStatistics($evaluations, $program ){
        $statistics = array();
        $studentsPre1 = 0;
        $studentsPre2 = 0;
        $studentsPre3 = 0;
        $studentsPre4 = 0;
        $studentsPre5 = 0;
        $studentsPre6 = 0;
        $studentsPre7 = 0;
        $studentsPre8 = 0;
        $studentsPre9 = 0;
  
        $students1 = 0;
        $students2 = 0;
        $students3 = 0;
        $students4 = 0;
        $students5 = 0;
        $students6 = 0;
        $students7 = 0;
        $students8 = 0;
        $students9 = 0;
  
        $studentsInitial1 = 0;
        $studentsInitial2 = 0;
        $studentsInitial3 = 0;
        $studentsInitial4 = 0;
        $studentsInitial5 = 0;
        $studentsInitial6 = 0;
        $studentsInitial7 = 0;
        $studentsInitial8 = 0;
        $studentsInitial9 = 0;
  
        $studentsFinal1 = 0;
        $studentsFinal2 = 0;
        $studentsFinal3 = 0;
        $studentsFinal4 = 0;
        $studentsFinal5 = 0;
        $studentsFinal6 = 0;
        $studentsFinal7 = 0;
        $studentsFinal8 = 0;
        $studentsFinal9 = 0;
  
  
  
        foreach ($evaluations as $e) {
            if($e['question1']  == 'IMPROVEMENT'){
                $students1++;
            }
            if($e['question2']  == 'IMPROVEMENT'){
                $students2++;
            }
            if($e['question3']  == 'IMPROVEMENT'){
                $students3++;
            }
            if($e['question4']  == 'IMPROVEMENT'){
                $students4++;
            }
            if($e['question5']  == 'IMPROVEMENT'){
                $students5++;
            }
            if($e['question6']  == 'IMPROVEMENT'){
                $students6++;
            }
            if($e['question7']  == 'IMPROVEMENT'){
                $students7++;
            }
            if($e['question8']  == 'IMPROVEMENT'){
                $students8++;
            }
            if($e['question9']  == 'IMPROVEMENT'){
                $students9++;
            }
  
            if($e['questionInitial1']  == 'YES'){
                $studentsInitial1++;
            }
            if($e['questionInitial2']  == 'YES'){
                $studentsInitial2++;
            }
            if($e['questionInitial3']  == 'YES'){
                $studentsInitial3++;
            }
            if($e['questionInitial4']  == 'YES'){
                $studentsInitial4++;
            }
            if($e['questionInitial5']  == 'YES'){
                $studentsInitial5++;
            }
            if($e['questionInitial6']  == 'YES'){
                $studentsInitial6++;
            }
            if($e['questionInitial7']  == 'YES'){
                $studentsInitial7++;
            }
  
            if($e['questionFinal1']  == 'YES'){
                $studentsFinal1++;
            }
            if($e['questionFinal2']  == 'YES'){
                $studentsFinal2++;
            }
            if($e['questionFinal3']  == 'YES'){
                $studentsFinal3++;
            }
            if($e['questionFinal4']  == 'YES'){
                $studentsFinal4++;
            }
            if($e['questionFinal5']  == 'YES'){
                $studentsFinal5++;
            }
            if($e['questionFinal6']  == 'YES'){
                $studentsFinal6++;
            }
            if($e['questionFinal7']  == 'YES'){
                $studentsFinal7++;
            }
            if($e['questionFinal8']  == 'YES'){
                $studentsFinal8++;
            }
            if($e['questionFinal9']  == 'YES'){
                $studentsFinal9++;
            }
  
  
  
  
        }
  
        if(!$evaluations){
           $evaluations = array();
           $evaluations[] = "";
           $nst = 0;
           $nst2 = 1;
        }
        else{
          $nst = count($evaluations);
          $nst2 = $nst;
        }

        if($program === "MBS"){
          $preQuestion = "question_";
        }
        else{
          $preQuestion = "question_jr_";
        }
  
        $statistics[] = array(
          'question'      =>  $preQuestion.'evaluation_question1',
          'studentsPre'   =>  $studentsInitial1."/".$nst,
          'students'      =>  $studentsFinal1."/".$nst,
          'percentagePre' =>  intval((100 *  $studentsInitial1) / $nst2),
          'percentage'    =>  intval((100 *  $studentsFinal1) / $nst2)
        );
  
        $statistics[] = array(
          'question'      =>  $preQuestion.'evaluation_question2',
          'studentsPre'   =>  $studentsInitial2."/".$nst,
          'students'      =>  $studentsFinal2."/".$nst,
          'percentagePre' =>  intval((100 *  $studentsInitial2) / $nst2),
          'percentage'    =>  intval((100 *  $studentsFinal2) / $nst2)
        );
  
        $statistics[] = array(
          'question'      =>  $preQuestion.'evaluation_question3',
          'studentsPre'   =>  $studentsInitial3."/".$nst,
          'students'      =>  $studentsFinal3."/".$nst,
          'percentagePre' =>  intval((100 *  $studentsInitial3) / $nst2),
          'percentage'    =>  intval((100 *  $studentsFinal3) / $nst2)
        );
  
        $statistics[] = array(
          'question'      =>  $preQuestion.'evaluation_question4',
          'studentsPre'   =>  $studentsInitial4."/".$nst,
          'students'      =>  $studentsFinal4."/".$nst,
          'percentagePre' =>  intval((100 *  $studentsInitial4) / $nst2),
          'percentage'    =>  intval((100 *  $studentsFinal4) / $nst2)
        );
  
        $statistics[] = array(
          'question'      =>  $preQuestion.'evaluation_question5',
          'studentsPre'   =>  $studentsInitial5."/".$nst,
          'students'      =>  $studentsFinal5."/".$nst,
          'percentagePre' =>  intval((100 *  $studentsInitial5) / $nst2),
          'percentage'    =>  intval((100 *  $studentsFinal5) / $nst2)
        );
  
        $statistics[] = array(
          'question'      =>  $preQuestion.'evaluation_question6',
          'studentsPre'   =>  $studentsInitial6."/".$nst,
          'students'      =>  $studentsFinal6."/".$nst,
          'percentagePre' =>  intval((100 *  $studentsInitial6) / $nst2),
          'percentage'    =>  intval((100 *  $studentsFinal6) / $nst2)
        );
  
        $statistics[] = array(
          'question'      =>  $preQuestion.'evaluation_question7',
          'studentsPre'   =>  $studentsInitial7."/".$nst,
          'students'      =>  $studentsFinal7."/".$nst,
          'percentagePre' =>  intval((100 *  $studentsInitial7) / $nst2),
          'percentage'    =>  intval((100 *  $studentsFinal7) / $nst2)
        );
  
        $statistics[] = array(
          'question'      =>  $preQuestion.'evaluation_question8',
          'studentsPre'   =>  $studentsInitial8."/".$nst,
          'students'      =>  $studentsFinal8."/".$nst,
          'percentagePre' =>  intval((100 *  $studentsPre8) / $nst2),
          'percentage'    =>  intval((100 *  $studentsFinal8) / $nst2)
  
        );
  
        $statistics[] = array(
          'question'      =>  $preQuestion.'evaluation_question9',
          'studentsPre'   =>  $studentsInitial9."/".$nst,
          'students'      =>  $studentsFinal9."/".$nst,
          'percentagePre' =>  intval((100 *  $studentsPre9) / $nst2),
          'percentage'    =>  intval((100 *  $studentsFinal9) / $nst2)
        );
  
        return $statistics;
  
      }

      private function showStatisticsCountry($evaluations, $program ){
        $statistics = array();
        $studentsPre1 = 0;
        $studentsPre2 = 0;
        $studentsPre3 = 0;
        $studentsPre4 = 0;
        $studentsPre5 = 0;
        $studentsPre6 = 0;
        $studentsPre7 = 0;
        $studentsPre8 = 0;
        $studentsPre9 = 0;
  
        $students1 = 0;
        $students2 = 0;
        $students3 = 0;
        $students4 = 0;
        $students5 = 0;
        $students6 = 0;
        $students7 = 0;
        $students8 = 0;
        $students9 = 0;
  
        $studentsInitial1 = 0;
        $studentsInitial2 = 0;
        $studentsInitial3 = 0;
        $studentsInitial4 = 0;
        $studentsInitial5 = 0;
        $studentsInitial6 = 0;
        $studentsInitial7 = 0;
        $studentsInitial8 = 0;
        $studentsInitial9 = 0;
  
        $studentsFinal1 = 0;
        $studentsFinal2 = 0;
        $studentsFinal3 = 0;
        $studentsFinal4 = 0;
        $studentsFinal5 = 0;
        $studentsFinal6 = 0;
        $studentsFinal7 = 0;
        $studentsFinal8 = 0;
        $studentsFinal9 = 0;
  
  
  
        foreach ($evaluations as $e) {
            if($e['question1']  == 'IMPROVEMENT'){
                $students1++;
            }
            if($e['question2']  == 'IMPROVEMENT'){
                $students2++;
            }
            if($e['question3']  == 'IMPROVEMENT'){
                $students3++;
            }
            if($e['question4']  == 'IMPROVEMENT'){
                $students4++;
            }
            if($e['question5']  == 'IMPROVEMENT'){
                $students5++;
            }
            if($e['question6']  == 'IMPROVEMENT'){
                $students6++;
            }
            if($e['question7']  == 'IMPROVEMENT'){
                $students7++;
            }
            if($e['question8']  == 'IMPROVEMENT'){
                $students8++;
            }
            if($e['question9']  == 'IMPROVEMENT'){
                $students9++;
            }
  
            if($e['questionInitial1']  == 'YES'){
                $studentsInitial1++;
            }
            if($e['questionInitial2']  == 'YES'){
                $studentsInitial2++;
            }
            if($e['questionInitial3']  == 'YES'){
                $studentsInitial3++;
            }
            if($e['questionInitial4']  == 'YES'){
                $studentsInitial4++;
            }
            if($e['questionInitial5']  == 'YES'){
                $studentsInitial5++;
            }
            if($e['questionInitial6']  == 'YES'){
                $studentsInitial6++;
            }
            if($e['questionInitial7']  == 'YES'){
                $studentsInitial7++;
            }
  
            if($e['questionFinal1']  == 'YES'){
                $studentsFinal1++;
            }
            if($e['questionFinal2']  == 'YES'){
                $studentsFinal2++;
            }
            if($e['questionFinal3']  == 'YES'){
                $studentsFinal3++;
            }
            if($e['questionFinal4']  == 'YES'){
                $studentsFinal4++;
            }
            if($e['questionFinal5']  == 'YES'){
                $studentsFinal5++;
            }
            if($e['questionFinal6']  == 'YES'){
                $studentsFinal6++;
            }
            if($e['questionFinal7']  == 'YES'){
                $studentsFinal7++;
            }
            if($e['questionFinal8']  == 'YES'){
                $studentsFinal8++;
            }
            if($e['questionFinal9']  == 'YES'){
                $studentsFinal9++;
            }
  
  
  
  
        }
  
        if(!$evaluations){
           $evaluations = array();
           $evaluations[] = "";
           $nst = 0;
           $nst2 = 1;
        }
        else{
          $nst = count($evaluations);
          $nst2 = $nst;
        }

        if($program === "MBS"){
          $preQuestion = "question_";
        }
        else{
          $preQuestion = "question_jr_";
        }
  
        $statistics['question1'] = array(
          'question'      =>  $preQuestion.'evaluation_question1',
          'studentsPre'   =>  $studentsInitial1."/".$nst,
          'students'      =>  $studentsFinal1."/".$nst,
          'percentagePre' =>  intval((100 *  $studentsInitial1) / $nst2),
          'percentage'    =>  intval((100 *  $studentsFinal1) / $nst2)
        );
  
        $statistics['question2'] = array(
          'question'      =>  $preQuestion.'evaluation_question2',
          'studentsPre'   =>  $studentsInitial2."/".$nst,
          'students'      =>  $studentsFinal2."/".$nst,
          'percentagePre' =>  intval((100 *  $studentsInitial2) / $nst2),
          'percentage'    =>  intval((100 *  $studentsFinal2) / $nst2)
        );
  
        $statistics['question3'] = array(
          'question'      =>  $preQuestion.'evaluation_question3',
          'studentsPre'   =>  $studentsInitial3."/".$nst,
          'students'      =>  $studentsFinal3."/".$nst,
          'percentagePre' =>  intval((100 *  $studentsInitial3) / $nst2),
          'percentage'    =>  intval((100 *  $studentsFinal3) / $nst2)
        );
  
        $statistics['question4'] = array(
          'question'      =>  $preQuestion.'evaluation_question4',
          'studentsPre'   =>  $studentsInitial4."/".$nst,
          'students'      =>  $studentsFinal4."/".$nst,
          'percentagePre' =>  intval((100 *  $studentsInitial4) / $nst2),
          'percentage'    =>  intval((100 *  $studentsFinal4) / $nst2)
        );
  
        $statistics['question5'] = array(
          'question'      =>  $preQuestion.'evaluation_question5',
          'studentsPre'   =>  $studentsInitial5."/".$nst,
          'students'      =>  $studentsFinal5."/".$nst,
          'percentagePre' =>  intval((100 *  $studentsInitial5) / $nst2),
          'percentage'    =>  intval((100 *  $studentsFinal5) / $nst2)
        );
  
        $statistics['question6'] = array(
          'question'      =>  $preQuestion.'evaluation_question6',
          'studentsPre'   =>  $studentsInitial6."/".$nst,
          'students'      =>  $studentsFinal6."/".$nst,
          'percentagePre' =>  intval((100 *  $studentsInitial6) / $nst2),
          'percentage'    =>  intval((100 *  $studentsFinal6) / $nst2)
        );
  
        $statistics['question7'] = array(
          'question'      =>  $preQuestion.'evaluation_question7',
          'studentsPre'   =>  $studentsInitial7."/".$nst,
          'students'      =>  $studentsFinal7."/".$nst,
          'percentagePre' =>  intval((100 *  $studentsInitial7) / $nst2),
          'percentage'    =>  intval((100 *  $studentsFinal7) / $nst2)
        );
  
        $statistics['question8'] = array(
          'question'      =>  $preQuestion.'evaluation_question8',
          'studentsPre'   =>  $studentsInitial8."/".$nst,
          'students'      =>  $studentsFinal8."/".$nst,
          'percentagePre' =>  intval((100 *  $studentsPre8) / $nst2),
          'percentage'    =>  intval((100 *  $studentsFinal8) / $nst2)
  
        );
  
        $statistics['question9'] = array(
          'question'      =>  $preQuestion.'evaluation_question9',
          'studentsPre'   =>  $studentsInitial9."/".$nst,
          'students'      =>  $studentsFinal9."/".$nst,
          'percentagePre' =>  intval((100 *  $studentsPre9) / $nst2),
          'percentage'    =>  intval((100 *  $studentsFinal9) / $nst2)
        );

        $statistics['en'] = array(
            'stats'   => '
            <p style="text-align: center;">I have my own business. | '.intval((100 *  $studentsInitial1) / $nst2).'% / '.intval((100 *  $studentsFinal1) / $nst2).'%</p>
            <p style="text-align: center;">I have a plan to improve my personal life. | '.intval((100 *  $studentsInitial2) / $nst2).'% / '.intval((100 *  $studentsFinal2) / $nst2).'%</p>
            <p style="text-align: center;">I serve in my community. | '.intval((100 *  $studentsInitial3) / $nst2).'% / '.intval((100 *  $studentsFinal3) / $nst2).'%</p>
            <p style="text-align: center;">I save money regularly. | '.intval((100 *  $studentsInitial4) / $nst2).'% / '.intval((100 *  $studentsFinal4) / $nst2).'%</p>
            <p style="text-align: center;">My family spends less than we earn. | '.intval((100 *  $studentsInitial5) / $nst2).'% / '.intval((100 *  $studentsFinal5) / $nst2).'%</p>
            <p style="text-align: center;">My family can afford the basic necessities of life. | '.intval((100 *  $studentsInitial6) / $nst2).'% / '.intval((100 *  $studentsFinal6) / $nst2).'%</p>
            <p style="text-align: center;">I keep business records. | '.intval((100 *  $studentsInitial7) / $nst2).'% / '.intval((100 *  $studentsFinal7) / $nst2).'%</p>
            <p style="text-align: center;">My business has improved because of the MBS course. | '.intval((100 *  $studentsInitial8) / $nst2).'% / '.intval((100 *  $studentsFinal8) / $nst2).'%</p>
            <p style="text-align: center;">My income has increased because of the MBS course. | '.intval((100 *  $studentsInitial9) / $nst2).'% / '.intval((100 *  $studentsFinal9) / $nst2).'%</p>
            '
          ); 

          $statistics['es'] = array(
            'stats'   => '
            <p style="text-align: center;">Tengo mi propio negocio. | '.intval((100 *  $studentsInitial1) / $nst2).'% / '.intval((100 *  $studentsFinal1) / $nst2).'%</p>
            <p style="text-align: center;">Tengo un plan para mejorar mi vida personal. | '.intval((100 *  $studentsInitial2) / $nst2).'% / '.intval((100 *  $studentsFinal2) / $nst2).'%</p>
            <p style="text-align: center;">Presto servicio en mi comunidad. | '.intval((100 *  $studentsInitial3) / $nst2).'% / '.intval((100 *  $studentsFinal3) / $nst2).'%</p>
            <p style="text-align: center;">Ahorro dinero regularmente. | '.intval((100 *  $studentsInitial4) / $nst2).'% / '.intval((100 *  $studentsFinal4) / $nst2).'%</p>
            <p style="text-align: center;">Mi familia gasta menos de lo que gana. | '.intval((100 *  $studentsInitial5) / $nst2).'% / '.intval((100 *  $studentsFinal5) / $nst2).'%</p>
            <p style="text-align: center;">Mi familia puede pagar las necesidades básicas de la vida. | '.intval((100 *  $studentsInitial6) / $nst2).'% / '.intval((100 *  $studentsFinal6) / $nst2).'%</p>
            <p style="text-align: center;">Mantengo registros financieros. | '.intval((100 *  $studentsInitial7) / $nst2).'% / '.intval((100 *  $studentsFinal7) / $nst2).'%</p>
            <p style="text-align: center;">Mi negocio ha mejorado gracias a este programa. | '.intval((100 *  $studentsInitial8) / $nst2).'% / '.intval((100 *  $studentsFinal8) / $nst2).'%</p>
            <p style="text-align: center;">Mis ingresos han aumentado gracias a este programa. | '.intval((100 *  $studentsInitial9) / $nst2).'% / '.intval((100 *  $studentsFinal9) / $nst2).'%</p>
            '
          );

          $statistics['pt'] = array(
            'stats'   => '
          <p style="text-align: center;">Tenho meu próprio negócio. | '.intval((100 *  $studentsInitial1) / $nst2).'% / '.intval((100 *  $studentsFinal1) / $nst2).'%</p>
          <p style="text-align: center;">Tenho um plano para melhorar minha vida pessoal. | '.intval((100 *  $studentsInitial2) / $nst2).'% / '.intval((100 *  $studentsFinal2) / $nst2).'%</p>
          <p style="text-align: center;">Sirvo na minha comunidade. | '.intval((100 *  $studentsInitial3) / $nst2).'% / '.intval((100 *  $studentsFinal3) / $nst2).'%</p>
          <p style="text-align: center;">Poupo dinheiro regularmente. | '.intval((100 *  $studentsInitial4) / $nst2).'% / '.intval((100 *  $studentsFinal4) / $nst2).'%</p>
          <p style="text-align: center;">Minha família gasta menos do que nós ganhamos. | '.intval((100 *  $studentsInitial5) / $nst2).'% / '.intval((100 *  $studentsFinal5) / $nst2).'%</p>
          <p style="text-align: center;">Minha família pode comprar as necessidades básicas. | '.intval((100 *  $studentsInitial6) / $nst2).'% / '.intval((100 *  $studentsFinal6) / $nst2).'%</p>
          <p style="text-align: center;">Mantenho papelada de negócios. | '.intval((100 *  $studentsInitial7) / $nst2).'% / '.intval((100 *  $studentsFinal7) / $nst2).'%</p>
          <p style="text-align: center;">Meu negócio melhorou por causa do curso MBS. | '.intval((100 *  $studentsInitial8) / $nst2).'% / '.intval((100 *  $studentsFinal8) / $nst2).'%</p>
          <p style="text-align: center;">Minha renda aumentou por causa do curso MBS. | '.intval((100 *  $studentsInitial9) / $nst2).'% / '.intval((100 *  $studentsFinal9) / $nst2).'%</p>
          '
          );

          $statistics['fr'] = array(
            'stats'   => '
          <p style="text-align: center;">J’ai ma propre entreprise. | '.intval((100 *  $studentsInitial1) / $nst2).'% / '.intval((100 *  $studentsFinal1) / $nst2).'%</p>
          <p style="text-align: center;">J’ai un plan pour améliorer ma vie personnelle. | '.intval((100 *  $studentsInitial2) / $nst2).'% / '.intval((100 *  $studentsFinal2) / $nst2).'%</p>
          <p style="text-align: center;">Je sers dans ma communauté. | '.intval((100 *  $studentsInitial3) / $nst2).'% / '.intval((100 *  $studentsFinal3) / $nst2).'%</p>
          <p style="text-align: center;">J’économise régulièrement de l’argent. | '.intval((100 *  $studentsInitial4) / $nst2).'% / '.intval((100 *  $studentsFinal4) / $nst2).'%</p>
          <p style="text-align: center;">Ma famille dépense moins que ce qu’on gagne. | '.intval((100 *  $studentsInitial5) / $nst2).'% / '.intval((100 *  $studentsFinal5) / $nst2).'%</p>
          <p style="text-align: center;">Ma famille peut se permettre les nécessités de base. | '.intval((100 *  $studentsInitial6) / $nst2).'% / '.intval((100 *  $studentsFinal6) / $nst2).'%</p>
          <p style="text-align: center;">Je garde des papiers registres. | '.intval((100 *  $studentsInitial7) / $nst2).'% / '.intval((100 *  $studentsFinal7) / $nst2).'%</p>
          <p style="text-align: center;">Mon entreprise s’est améliorée grâce au cours MBS. | '.intval((100 *  $studentsInitial8) / $nst2).'% / '.intval((100 *  $studentsFinal8) / $nst2).'%</p>
          <p style="text-align: center;">Mon revenu a augmenté grâce au cours MBS. | '.intval((100 *  $studentsInitial9) / $nst2).'% / '.intval((100 *  $studentsFinal9) / $nst2).'%</p>
          '
          );

      

        
  
        return $statistics;
  
      }

    /**
     * @Rest\Post("/graduates/daterange", name="report_graduates_date_range")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     *
     * @SWG\Parameter(
     *     name="start_date",
     *     in="path",
     *     type="string",
     *     description="The start date"
     * )
     * 
     * @SWG\Parameter(
     *     name="final_date",
     *     in="path",
     *     type="string",
     *     description="The final date"
     * )
     * 
     * @SWG\Parameter(
     *     name="country",
     *     in="path",
     *     type="string",
     *     description="country"
     * )
     *
     *
     * @SWG\Tag(name="Report")
     */
    public function graduatesDateRange(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";

      try {
          $code = 200;
          $error = false;

          $country = $request->request->get('country');
          $language = $request->request->get('language');
          if(!isset($language)){
            $language = "ALL";
          }
          $graduates_list = [];

          $start_date = strtotime($request->request->get('start_date'));
          $start_date = date('Y-m-d', $start_date);
          $start_date = \DateTime::createFromFormat('Y-m-d', $start_date);

          $final_date = strtotime($request->request->get('final_date'));
          $final_date = date('Y-m-d', $final_date);
          $final_date = \DateTime::createFromFormat('Y-m-d', $final_date);

          $diff = date_diff($start_date, $final_date)->format('%a');

          $days_number = intval(round(($diff / 14), 0 , PHP_ROUND_HALF_DOWN));

          $current_date = $final_date;
          $t_date = $start_date;
          $current_date_desc = $current_date->format('d M');

          $final_date = $current_date->format('Y-m-d');
          $start_date = $start_date->format('Y-m-d');
          

          $s_date = $start_date;
          $s_date_desc = $t_date->format('d M');

          $t_date->modify( '+'.$days_number.' days' );
          $f_date = $t_date->format('Y-m-d');

          $f_date_desc = $t_date->format('d M');

          
          if($country == "ALL" && $language == "ALL"){
            //$graduates_list = $em->getRepository('App:ProgramMbs')->graduatesDateRange($start_date, $final_date);
            $total_graduates = $em->getRepository('App:ProgramMbs')->graduatesDateRangeCount($start_date, $final_date);
  
            $mbsNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("MBS");
            $jrNumbers  = $em->getRepository('App:Certificate')->graduatesTotalNumbers("JR");

          }
          else{
              //$graduates_list = $em->getRepository('App:ProgramMbs')->graduatesCountryDateRange($start_date, $final_date, $country);
              $total_graduates = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageDateRangeCount($start_date, $final_date, $country, $language);
    
              $mbsNumbers = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("MBS", $country, $language);
              $jrNumbers  = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("JR", $country, $language);
             
          }

          $accumulate_graduates = $mbsNumbers + $jrNumbers - $total_graduates;

          $high = 0;

          for ($i=1; $i <=14 ; $i++) { 
            
            if($country == "ALL" && $language == "ALL"){
              $amount = $em->getRepository('App:ProgramMbs')->graduatesDateRangeCount($s_date, $f_date);
            }
            else{
              $amount = $em->getRepository('App:ProgramMbs')->graduatesbyDateCountryLanguageCount($s_date, $f_date, $country, $language);
            }
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(
              'amount' => $amount,
              'month'  => $s_date_desc." - ".$f_date_desc,
              'accumulated' => $accumulate_graduates     
            );

            $t_date->modify( '+1 day' );
            $s_date_desc = $t_date->format('d M');
            $s_date = $t_date->format('Y-m-d');
            if($i == 13){
              $f_date_desc = $current_date_desc;
              $f_date = $final_date;
            }
            else{
              $f_date = $t_date->modify( '+'.$days_number.' day' )->format('Y-m-d');
              $f_date_desc = $t_date->format('d M');
            }
            
            
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('student_list'))));
    }

    /**
     * @Rest\Post("/graduates/ambassador/daterange", name="report_graduates_ambassador_date_range")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     *
     * @SWG\Parameter(
     *     name="start_date",
     *     in="path",
     *     type="string",
     *     description="The start date"
     * )
     * 
     * @SWG\Parameter(
     *     name="final_date",
     *     in="path",
     *     type="string",
     *     description="The final date"
     * )
     * 
     * @SWG\Parameter(
     *     name="ambassador_id",
     *     in="path",
     *     type="string",
     *     description="ambassador_id"
     * )
     *
     *
     * @SWG\Tag(name="Report")
     */
    public function graduatesAmbassadorDateRange(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";

      try {
          $code = 200;
          $error = false;

          $ambassador_id = $request->request->get('ambassador_id');

          $start_date = strtotime($request->request->get('start_date'));
          $start_date = date('Y-m-d', $start_date);
          $start_date = \DateTime::createFromFormat('Y-m-d', $start_date);

          $final_date = strtotime($request->request->get('final_date'));
          $final_date = date('Y-m-d', $final_date);
          $final_date = \DateTime::createFromFormat('Y-m-d', $final_date);

          $diff = date_diff($start_date, $final_date)->format('%a');

          $days_number = intval(round(($diff / 14), 0 , PHP_ROUND_HALF_DOWN));

          $current_date = $final_date;
          $t_date = $start_date;
          $current_date_desc = $current_date->format('d M');

          $final_date = $current_date->format('Y-m-d');
          $start_date = $start_date->format('Y-m-d');
          

          $s_date = $start_date;
          $s_date_desc = $t_date->format('d M');

          $t_date->modify( '+'.$days_number.' days' );
          $f_date = $t_date->format('Y-m-d');

          $f_date_desc = $t_date->format('d M');

          
          $graduates_list = $em->getRepository('App:ProgramMbs')->graduatesDateRangeByAmbassador($start_date, $final_date, $ambassador_id);
          $total_graduates = $em->getRepository('App:ProgramMbs')->graduatesDateRangeByAmbassadorCount($start_date, $final_date, $ambassador_id);

          $mbs_graduates = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassador($ambassador_id, 'state.approved');
        

          $accumulate_graduates = count($mbs_graduates) - $total_graduates;

          $high = 0;

          for ($i=1; $i <=14 ; $i++) { 
            
            $amount = $em->getRepository('App:ProgramMbs')->graduatesbyDateAmbassadorCount($s_date, $f_date, $ambassador_id);
          
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(
              'amount' => $amount,
              'month'  => $s_date_desc." - ".$f_date_desc,
              'accumulated' => $accumulate_graduates     
            );

            $t_date->modify( '+1 day' );
            $s_date_desc = $t_date->format('d M');
            $s_date = $t_date->format('Y-m-d');
            if($i == 13){
              $f_date_desc = $current_date_desc;
              $f_date = $final_date;
            }
            else{
              $f_date = $t_date->modify( '+'.$days_number.' day' )->format('Y-m-d');
              $f_date_desc = $t_date->format('d M');
            }
            
            
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('student_list'))));
    }

     /**
     * @Rest\Post("/graduates/sa/daterange", name="report_sa_graduates_date_range")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     *
     * @SWG\Parameter(
     *     name="start_date",
     *     in="path",
     *     type="string",
     *     description="The start date"
     * )
     * 
     * @SWG\Parameter(
     *     name="final_date",
     *     in="path",
     *     type="string",
     *     description="The final date"
     * )
     * 
     * @SWG\Parameter(
     *     name="country",
     *     in="path",
     *     type="string",
     *     description="country"
     * )
     *
     *
     * @SWG\Tag(name="Report")
     */
    public function graduatesSaDateRange(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";

      try {
          $code = 200;
          $error = false;

          $country = $request->request->get('country');
          $language = $request->request->get('language');
          if(!isset($language)){
            $language = "ALL";
          }

          $start_date = strtotime($request->request->get('start_date'));
          $start_date = date('Y-m-d', $start_date);
          $start_date = \DateTime::createFromFormat('Y-m-d', $start_date);

          $final_date = strtotime($request->request->get('final_date'));
          $final_date = date('Y-m-d', $final_date);
          $final_date = \DateTime::createFromFormat('Y-m-d', $final_date);

          $diff = date_diff($start_date, $final_date)->format('%a');

          $days_number = intval(round(($diff / 14), 0 , PHP_ROUND_HALF_DOWN));

          $current_date = $final_date;
          $t_date = $start_date;
          $current_date_desc = $current_date->format('d M');

          $final_date = $current_date->format('Y-m-d');
          $start_date = $start_date->format('Y-m-d');
          

          $s_date = $start_date;
          $s_date_desc = $t_date->format('d M');

          $t_date->modify( '+'.$days_number.' days' );
          $f_date = $t_date->format('Y-m-d');

          $f_date_desc = $t_date->format('d M');

          
          if($country == "ALL" && $language == "ALL"){
            $graduates_list = $em->getRepository('App:ProgramSa')->graduatesDateRange($start_date, $final_date);
            $total_graduates = $em->getRepository('App:ProgramSa')->graduatesDateRangeCount($start_date, $final_date);
  
            $saNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("SA");

          }
          else{
              $graduates_list = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageDateRange($start_date, $final_date, $country, $language);
              $total_graduates = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageDateRangeCount($start_date, $final_date, $country, $language);
    
              $saNumbers = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("SA", $country, $language);
          }

          
          $accumulate_graduates = $saNumbers - $total_graduates;

          $high = 0;

          for ($i=1; $i <=14 ; $i++) { 
            
            if($country == "ALL" && $language == "ALL"){
                $amount = $em->getRepository('App:ProgramSa')->graduatesDateRangeCount($s_date, $f_date);
            }
            else{
                $amount = $em->getRepository('App:ProgramSa')->graduatesbyDateCountryLanguageCount($s_date, $f_date, $country, $language);
            }
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(
              'amount' => $amount,
              'month'  => $s_date_desc." - ".$f_date_desc,
              'accumulated' => $accumulate_graduates     
            );

            $t_date->modify( '+1 day' );
            $s_date_desc = $t_date->format('d M');
            $s_date = $t_date->format('Y-m-d');
            if($i == 13){
              $f_date_desc = $current_date_desc;
              $f_date = $final_date;
            }
            else{
              $f_date = $t_date->modify( '+'.$days_number.' day' )->format('Y-m-d');
              $f_date_desc = $t_date->format('d M');
            }
            
            
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('student_list'))));
    }

    /**
     * @Rest\Post("/graduates/wellness/daterange", name="report_wellness_graduates_date_range")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     *
     * @SWG\Parameter(
     *     name="start_date",
     *     in="path",
     *     type="string",
     *     description="The start date"
     * )
     * 
     * @SWG\Parameter(
     *     name="final_date",
     *     in="path",
     *     type="string",
     *     description="The final date"
     * )
     * 
     * @SWG\Parameter(
     *     name="country",
     *     in="path",
     *     type="string",
     *     description="country"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description="language"
     * )
     *
     *
     * @SWG\Tag(name="Report")
     */
    public function graduatesWellnessDateRange(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";

      try {
          $code = 200;
          $error = false;

          $country = $request->request->get('country');
          $language = $request->request->get('language');
          if(!isset($language)){
            $language = "ALL";
          }

          $start_date = strtotime($request->request->get('start_date'));
          $start_date = date('Y-m-d', $start_date);
          $start_date = \DateTime::createFromFormat('Y-m-d', $start_date);

          $final_date = strtotime($request->request->get('final_date'));
          $final_date = date('Y-m-d', $final_date);
          $final_date = \DateTime::createFromFormat('Y-m-d', $final_date);

          $diff = date_diff($start_date, $final_date)->format('%a');

          $days_number = intval(round(($diff / 14), 0 , PHP_ROUND_HALF_DOWN));

          $current_date = $final_date;
          $t_date = $start_date;
          $current_date_desc = $current_date->format('d M');

          $final_date = $current_date->format('Y-m-d');
          $start_date = $start_date->format('Y-m-d');
          

          $s_date = $start_date;
          $s_date_desc = $t_date->format('d M');

          $t_date->modify( '+'.$days_number.' days' );
          $f_date = $t_date->format('Y-m-d');

          $f_date_desc = $t_date->format('d M');

          
          if($country == "ALL" && $language == "ALL"){
            $graduates_list = $em->getRepository('App:Wellness')->graduatesDateRange($start_date, $final_date);
            $total_graduates = $em->getRepository('App:Wellness')->graduatesDateRangeCount($start_date, $final_date);
  
            $saNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("WELLNESS");

          }
          else{
              $graduates_list = $em->getRepository('App:Wellness')->graduatesCountryLanguageDateRange($start_date, $final_date, $country, $language);
              $total_graduates = $em->getRepository('App:Wellness')->graduatesCountryLanguageDateRangeCount($start_date, $final_date, $country, $language);
    
              $saNumbers = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("WELLNESS", $country, $language);
          }

          
          $accumulate_graduates = $saNumbers - $total_graduates;

          $high = 0;

          for ($i=1; $i <=14 ; $i++) { 
            
            if($country == "ALL" && $language == "ALL"){
                $amount = $em->getRepository('App:Wellness')->graduatesDateRangeCount($s_date, $f_date);
            }
            else{
                $amount = $em->getRepository('App:Wellness')->graduatesbyDateCountryLanguageCount($s_date, $f_date, $country, $language);
            }
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(
              'amount' => $amount,
              'month'  => $s_date_desc." - ".$f_date_desc,
              'accumulated' => $accumulate_graduates     
            );

            $t_date->modify( '+1 day' );
            $s_date_desc = $t_date->format('d M');
            $s_date = $t_date->format('Y-m-d');
            if($i == 13){
              $f_date_desc = $current_date_desc;
              $f_date = $final_date;
            }
            else{
              $f_date = $t_date->modify( '+'.$days_number.' day' )->format('Y-m-d');
              $f_date_desc = $t_date->format('d M');
            }
            
            
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('student_list'))));
    }

    /**
     * @Rest\Post("/graduates/wellnessparticipant/daterange", name="report_wellness_participant_graduates_date_range")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     *
     * @SWG\Parameter(
     *     name="start_date",
     *     in="path",
     *     type="string",
     *     description="The start date"
     * )
     * 
     * @SWG\Parameter(
     *     name="final_date",
     *     in="path",
     *     type="string",
     *     description="The final date"
     * )
     * 
     * @SWG\Parameter(
     *     name="country",
     *     in="path",
     *     type="string",
     *     description="country"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description="language"
     * )
     *
     *
     * @SWG\Tag(name="Report")
     */
    public function graduatesWellnessParticipantDateRange(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";

      try {
          $code = 200;
          $error = false;

          $country = $request->request->get('country');
          $language = $request->request->get('language');
          if(!isset($language)){
            $language = "ALL";
          }

          $start_date = strtotime($request->request->get('start_date'));
          $start_date = date('Y-m-d', $start_date);
          $start_date = \DateTime::createFromFormat('Y-m-d', $start_date);

          $final_date = strtotime($request->request->get('final_date'));
          $final_date = date('Y-m-d', $final_date);
          $final_date = \DateTime::createFromFormat('Y-m-d', $final_date);

          $diff = date_diff($start_date, $final_date)->format('%a');

          $days_number = intval(round(($diff / 14), 0 , PHP_ROUND_HALF_DOWN));

          $current_date = $final_date;
          $t_date = $start_date;
          $current_date_desc = $current_date->format('d M');

          $final_date = $current_date->format('Y-m-d');
          $start_date = $start_date->format('Y-m-d');
          

          $s_date = $start_date;
          $s_date_desc = $t_date->format('d M');

          $t_date->modify( '+'.$days_number.' days' );
          $f_date = $t_date->format('Y-m-d');

          $f_date_desc = $t_date->format('d M');

          
          if($country == "ALL" && $language == "ALL"){
            $graduates_list = $em->getRepository('App:WellnessParticipant')->graduatesDateRange($start_date, $final_date);
            $total_graduates = $em->getRepository('App:WellnessParticipant')->graduatesDateRangeCount($start_date, $final_date);
  
            $saNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("WELLNESS_PART");

          }
          else{
              $graduates_list = $em->getRepository('App:WellnessParticipant')->graduatesCountryLanguageDateRange($start_date, $final_date, $country, $language);
              $total_graduates = $em->getRepository('App:WellnessParticipant')->graduatesCountryLanguageDateRangeCount($start_date, $final_date, $country, $language);
    
              $saNumbers = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("WELLNESS_PART", $country, $language);
          }

          
          $accumulate_graduates = $saNumbers - $total_graduates;

          $high = 0;

          for ($i=1; $i <=14 ; $i++) { 
            
            if($country == "ALL" && $language == "ALL"){
                $amount = $em->getRepository('App:WellnessParticipant')->graduatesDateRangeCount($s_date, $f_date);
            }
            else{
                $amount = $em->getRepository('App:WellnessParticipant')->graduatesbyDateCountryLanguageCount($s_date, $f_date, $country, $language);
            }
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(
              'amount' => $amount,
              'month'  => $s_date_desc." - ".$f_date_desc,
              'accumulated' => $accumulate_graduates     
            );

            $t_date->modify( '+1 day' );
            $s_date_desc = $t_date->format('d M');
            $s_date = $t_date->format('Y-m-d');
            if($i == 13){
              $f_date_desc = $current_date_desc;
              $f_date = $final_date;
            }
            else{
              $f_date = $t_date->modify( '+'.$days_number.' day' )->format('Y-m-d');
              $f_date_desc = $t_date->format('d M');
            }
            
            
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('student_list'))));
    }

    /**
     * @Rest\Post("/graduates/lastyear", name="report_graduates_last_year")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     * 
     * @SWG\Parameter(
     *     name="country",
     *     in="path",
     *     type="string",
     *     description="country"
     * )     
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description="language"
     * )
     *
     * @SWG\Tag(name="Report")
     */
    public function graduatesLastYear(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";
      $graduates_list = [];

      $country = $request->request->get('country');
      $language = $request->request->get('language');

      try {
          $code = 200;
          $error = false;

          $current_date = new \DateTime();          
          $final_date = $current_date->format('Y-m-d');
          $init = $current_date->modify( '-12 month' );
          $start_date = $init->format('Y-m-01');

          $s_date = $start_date;
          $t_date = $init->modify( '+1 month' );
          $f_date = $t_date->format('Y-m-01');


          if($country == "ALL" && $language == "ALL"){
            //$graduates_list = $em->getRepository('App:ProgramMbs')->graduatesDateRange($start_date, $final_date);
            $total_data_range_graduates = $em->getRepository('App:ProgramMbs')->graduatesDateRangeCount($start_date, $final_date);
  
            $mbsNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("MBS");
            $jrNumbers  = $em->getRepository('App:Certificate')->graduatesTotalNumbers("JR");

            $accumulate_graduates = $mbsNumbers + $jrNumbers - $total_data_range_graduates;

          }
          else{
              //$graduates_list = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageDateRange($start_date, $final_date, $country, $language);
              $total_data_range_graduates = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageDateRangeCount($start_date, $final_date, $country, $language);
    
              $mbsInitialNumbers = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("MBS", $country, $language);
              $jrInitialNumbers  = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("JR", $country, $language);

              $total_graduates = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageCount($country, $language);
              $accumulate_graduates = $mbsInitialNumbers + $jrInitialNumbers +  $total_graduates - $total_data_range_graduates;

          }

          
          $high = 0;

          for ($i=1; $i <=13 ; $i++) { 
            $month = \DateTime::createFromFormat('Y-m-d', $s_date);
            if($country == "ALL" && $language == "ALL"){
              $amount = $em->getRepository('App:ProgramMbs')->graduatesbyDateCount($s_date, $f_date);
            }
            else{
              $amount = $em->getRepository('App:ProgramMbs')->graduatesbyDateCountryLanguageCount($s_date, $f_date, $country, $language);
            }
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(              
              'amount' => $amount,
              'month'  => $month->format('M')." ".$month->format('Y'),
              'accumulated' => $accumulate_graduates     
            );

            $s_date = $f_date;
            $f_date = $t_date->modify( '+1 month' )->format('Y-m-01');
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_data_range_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          
          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('report_list'))));
  }

   /**
     * @Rest\Post("/graduates/ambassador/lastyear", name="report_graduates_ambassador_last_year")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets last year graduates by one ambassador"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     * 
     * @SWG\Parameter(
     *     name="id_ambassador",
     *     in="path",
     *     type="string",
     *     description="Id Ambassador"
     * )     
     *
     * @SWG\Tag(name="Report")
     */
    public function graduatesAmbassadorLastYear(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";

      $ambassador_id = $request->request->get('ambassador_id');

      try {
          $code = 200;
          $error = false;

          $current_date = new \DateTime();          
          $final_date = $current_date->format('Y-m-d');
          $init = $current_date->modify( '-12 month' );
          $start_date = $init->format('Y-m-01');

          $s_date = $start_date;
          $t_date = $init->modify( '+1 month' );
          $f_date = $t_date->format('Y-m-01');


          $graduates_list = $em->getRepository('App:ProgramMbs')->graduatesDateRangeByAmbassador($start_date, $final_date, $ambassador_id);
          $total_graduates = $em->getRepository('App:ProgramMbs')->graduatesDateRangeByAmbassadorCount($start_date, $final_date, $ambassador_id);

          $mbs_graduates = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassador($ambassador_id, 'state.approved');
        

          $accumulate_graduates = count($mbs_graduates) - $total_graduates;
          $high = 0;

          for ($i=1; $i <=13 ; $i++) { 
            $month = \DateTime::createFromFormat('Y-m-d', $s_date);
            $amount = $em->getRepository('App:ProgramMbs')->graduatesbyDateAmbassadorCount($s_date, $f_date, $ambassador_id);
           
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(              
              'amount' => $amount,
              'month'  => $month->format('M')." ".$month->format('Y'),
              'accumulated' => $accumulate_graduates     
            );

            $s_date = $f_date;
            $f_date = $t_date->modify( '+1 month' )->format('Y-m-01');
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          
          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('report_list'))));
    }

  /**
     * @Rest\Post("/graduates/sa/lastyear", name="report_sa_graduates_last_year")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     * 
     * @SWG\Parameter(
     *     name="country",
     *     in="path",
     *     type="string",
     *     description="country"
     * )     
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description="language"
     * )
     *
     * @SWG\Tag(name="Report")
     */
    public function graduatesSaLastYear(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";
      $graduates_list = [];

      $country = $request->request->get('country');
      $language = $request->request->get('language');

      try {
          $code = 200;
          $error = false;

          $current_date = new \DateTime();          
          $final_date = $current_date->format('Y-m-d');
          $init = $current_date->modify( '-12 month' );
          $start_date = $init->format('Y-m-01');

          $s_date = $start_date;
          $t_date = $init->modify( '+1 month' );
          $f_date = $t_date->format('Y-m-01');


          if($country == "ALL" && $language == "ALL"){
            $graduates_list = $em->getRepository('App:ProgramSa')->graduatesDateRange($start_date, $final_date);
            $total_data_range_graduates = $em->getRepository('App:ProgramSa')->graduatesDateRangeCount($start_date, $final_date);
  
            $saNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("SA");

            $accumulate_graduates = $saNumbers - $total_data_range_graduates;

          }
          else{

              $graduates_list = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageDateRange($start_date, $final_date, $country, $language);
              $total_data_range_graduates = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageDateRangeCount($start_date, $final_date, $country, $language);
    
              $saInitialNumbers = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("SA", $country, $language);

              $total_graduates = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageCount($country, $language);
              $accumulate_graduates = $saInitialNumbers +  $total_graduates - $total_data_range_graduates;

          }

          
          $high = 0;

          for ($i=1; $i <=13 ; $i++) { 
            $month = \DateTime::createFromFormat('Y-m-d', $s_date);
            if($country == "ALL" && $language == "ALL"){
              $amount = $em->getRepository('App:ProgramSa')->graduatesbyDateCount($s_date, $f_date);
            }
            else{
              $amount = $em->getRepository('App:ProgramSa')->graduatesbyDateCountryLanguageCount($s_date, $f_date, $country, $language);
            }
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(              
              'amount' => $amount,
              'month'  => $month->format('M')." ".$month->format('Y'),
              'accumulated' => $accumulate_graduates     
            );

            $s_date = $f_date;
            $f_date = $t_date->modify( '+1 month' )->format('Y-m-01');
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_data_range_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          
          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('report_list'))));
  }

  /**
     * @Rest\Post("/graduates/wellness/lastyear", name="report_wellness_graduates_last_year")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     * 
     * @SWG\Parameter(
     *     name="country",
     *     in="path",
     *     type="string",
     *     description="country"
     * )     
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description="language"
     * )
     *
     * @SWG\Tag(name="Report")
     */
    public function graduatesWellnessLastYear(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";
      $graduates_list = [];

      $country = $request->request->get('country');
      $language = $request->request->get('language');

      try {
          $code = 200;
          $error = false;

          $current_date = new \DateTime();          
          $final_date = $current_date->format('Y-m-d');
          $init = $current_date->modify( '-12 month' );
          $start_date = $init->format('Y-m-01');

          $s_date = $start_date;
          $t_date = $init->modify( '+1 month' );
          $f_date = $t_date->format('Y-m-01');


          if($country == "ALL" && $language == "ALL"){
            $graduates_list = $em->getRepository('App:Wellness')->graduatesDateRange($start_date, $final_date);
            $total_data_range_graduates = $em->getRepository('App:Wellness')->graduatesDateRangeCount($start_date, $final_date);
  
            $saNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("WELLNESS");

            $accumulate_graduates = $saNumbers - $total_data_range_graduates;

          }
          else{

              $graduates_list = $em->getRepository('App:Wellness')->graduatesCountryLanguageDateRange($start_date, $final_date, $country, $language);
              $total_data_range_graduates = $em->getRepository('App:Wellness')->graduatesCountryLanguageDateRangeCount($start_date, $final_date, $country, $language);
    
              $saInitialNumbers = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("WELLNESS", $country, $language);

              $total_graduates = $em->getRepository('App:Wellness')->graduatesCountryLanguageCount($country, $language);
              $accumulate_graduates = $saInitialNumbers +  $total_graduates - $total_data_range_graduates;

          }

          
          $high = 0;

          for ($i=1; $i <=13 ; $i++) { 
            $month = \DateTime::createFromFormat('Y-m-d', $s_date);
            if($country == "ALL" && $language == "ALL"){
              $amount = $em->getRepository('App:Wellness')->graduatesbyDateCount($s_date, $f_date);
            }
            else{
              $amount = $em->getRepository('App:Wellness')->graduatesbyDateCountryLanguageCount($s_date, $f_date, $country, $language);
            }
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(              
              'amount' => $amount,
              'month'  => $month->format('M')." ".$month->format('Y'),
              'accumulated' => $accumulate_graduates     
            );

            $s_date = $f_date;
            $f_date = $t_date->modify( '+1 month' )->format('Y-m-01');
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_data_range_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          
          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('report_list'))));
  }
  

  /**
     * @Rest\Post("/graduates/wellnessparticipant/lastyear", name="report_wellness_participant_graduates_last_year")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     * 
     * @SWG\Parameter(
     *     name="country",
     *     in="path",
     *     type="string",
     *     description="country"
     * )     
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description="language"
     * )
     *
     * @SWG\Tag(name="Report")
     */
    public function graduatesWellnessParticipantLastYear(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";
      $graduates_list = [];

      $country = $request->request->get('country');
      $language = $request->request->get('language');

      try {
          $code = 200;
          $error = false;

          $current_date = new \DateTime();          
          $final_date = $current_date->format('Y-m-d');
          $init = $current_date->modify( '-12 month' );
          $start_date = $init->format('Y-m-01');

          $s_date = $start_date;
          $t_date = $init->modify( '+1 month' );
          $f_date = $t_date->format('Y-m-01');


          if($country == "ALL" && $language == "ALL"){
            $graduates_list = $em->getRepository('App:WellnessParticipant')->graduatesDateRange($start_date, $final_date);
            $total_data_range_graduates = $em->getRepository('App:WellnessParticipant')->graduatesDateRangeCount($start_date, $final_date);
  
            $saNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("WELLNESS_PART");

            $accumulate_graduates = $saNumbers - $total_data_range_graduates;

          }
          else{

              $graduates_list = $em->getRepository('App:WellnessParticipant')->graduatesCountryLanguageDateRange($start_date, $final_date, $country, $language);
              $total_data_range_graduates = $em->getRepository('App:WellnessParticipant')->graduatesCountryLanguageDateRangeCount($start_date, $final_date, $country, $language);
    
              $saInitialNumbers = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("WELLNESS_PART", $country, $language);

              $total_graduates = $em->getRepository('App:WellnessParticipant')->graduatesCountryLanguageCount($country, $language);
              $accumulate_graduates = $saInitialNumbers +  $total_graduates - $total_data_range_graduates;

          }

          
          $high = 0;

          for ($i=1; $i <=13 ; $i++) { 
            $month = \DateTime::createFromFormat('Y-m-d', $s_date);
            if($country == "ALL" && $language == "ALL"){
              $amount = $em->getRepository('App:WellnessParticipant')->graduatesbyDateCount($s_date, $f_date);
            }
            else{
              $amount = $em->getRepository('App:WellnessParticipant')->graduatesbyDateCountryLanguageCount($s_date, $f_date, $country, $language);
            }
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(              
              'amount' => $amount,
              'month'  => $month->format('M')." ".$month->format('Y'),
              'accumulated' => $accumulate_graduates     
            );

            $s_date = $f_date;
            $f_date = $t_date->modify( '+1 month' )->format('Y-m-01');
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_data_range_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          
          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('report_list'))));
  }

  /**
     * @Rest\Post("/graduates/lastsixmonths", name="report_graduates_last_six_months")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     * 
     * @SWG\Parameter(
     *     name="country",
     *     in="path",
     *     type="string",
     *     description="country"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description="language"
     * )
     *     
     *
     * @SWG\Tag(name="Report")
     */
    public function graduatesLastSixMonths(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $graduates_list = [];
      $message = "";
      $country = $request->request->get('country');
      $language = $request->request->get('language');

      try {
          $code = 200;
          $error = false;

          $current_date = new \DateTime();          
          $final_date = $current_date->format('Y-m-d');
          $init = $current_date->modify( '-6 month' );
          $start_date = $init->format('Y-m-01');

          $s_date = $start_date;
          $t_date = $init->modify( '+1 month' );
          $f_date = $t_date->format('Y-m-01');

          
          if($country == "ALL" && $language == "ALL"){
            //$graduates_list = $em->getRepository('App:ProgramMbs')->graduatesDateRange($start_date, $final_date);
            $total_data_range_graduates = $em->getRepository('App:ProgramMbs')->graduatesDateRangeCount($start_date, $final_date);
  
            $mbsNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("MBS");
            $jrNumbers  = $em->getRepository('App:Certificate')->graduatesTotalNumbers("JR");

            $accumulate_graduates = $mbsNumbers + $jrNumbers - $total_data_range_graduates;

          }
          else{
              //$graduates_list = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageDateRange($start_date, $final_date, $country, $language);
              $total_data_range_graduates = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageDateRangeCount($start_date, $final_date, $country, $language);
    
              $mbsInitialNumbers = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("MBS", $country, $language);
              $jrInitialNumbers  = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("JR", $country, $language);

              $total_graduates = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageCount($country, $language);
              $accumulate_graduates = $mbsInitialNumbers + $jrInitialNumbers +  $total_graduates - $total_data_range_graduates;

          }

          $high = 0;

          for ($i=1; $i <=7 ; $i++) { 
            $month = \DateTime::createFromFormat('Y-m-d', $s_date);
            if($country == "ALL" && $language == "ALL"){
              $amount = $em->getRepository('App:ProgramMbs')->graduatesbyDateCount($s_date, $f_date);
            }
            else{
              $amount = $em->getRepository('App:ProgramMbs')->graduatesbyDateCountryLanguageCount($s_date, $f_date, $country, $language);
            }
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(
              'amount' => $amount,
              'month'  => $month->format('M')." ".$month->format('Y'),
              'accumulated' => $accumulate_graduates     
            );

            $s_date = $f_date;
            $f_date = $t_date->modify( '+1 month' )->format('Y-m-01');
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_data_range_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          
          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('report_list'))));
  }

  /**
     * @Rest\Post("/graduates/ambassador/lastsixmonths", name="report_graduates_ambassador_last_six_months")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range graduates by ambassador reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     * 
     * @SWG\Parameter(
     *     name="ambassador_id",
     *     in="path",
     *     type="string",
     *     description="Ambassador Id"
     * )
     *     
     *
     * @SWG\Tag(name="Report")
     */
    public function graduatesAmbassadorLastSixMonths(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";
      $ambassador_id = $request->request->get('ambassador_id');

      try {
          $code = 200;
          $error = false;

          $current_date = new \DateTime();          
          $final_date = $current_date->format('Y-m-d');
          $init = $current_date->modify( '-6 month' );
          $start_date = $init->format('Y-m-01');

          $s_date = $start_date;
          $t_date = $init->modify( '+1 month' );
          $f_date = $t_date->format('Y-m-01');

          
          $graduates_list = $em->getRepository('App:ProgramMbs')->graduatesDateRangeByAmbassador($start_date, $final_date, $ambassador_id);
          $total_graduates = $em->getRepository('App:ProgramMbs')->graduatesDateRangeByAmbassadorCount($start_date, $final_date, $ambassador_id);

          $mbs_graduates = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassador($ambassador_id, 'state.approved');
        

          $accumulate_graduates = count($mbs_graduates) - $total_graduates;

          $high = 0;

          for ($i=1; $i <=7 ; $i++) { 
            $month = \DateTime::createFromFormat('Y-m-d', $s_date);
            $amount = $em->getRepository('App:ProgramMbs')->graduatesbyDateAmbassadorCount($s_date, $f_date, $ambassador_id);
         
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(
              'amount' => $amount,
              'month'  => $month->format('M')." ".$month->format('Y'),
              'accumulated' => $accumulate_graduates     
            );

            $s_date = $f_date;
            $f_date = $t_date->modify( '+1 month' )->format('Y-m-01');
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          
          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('report_list'))));
    }

  /**
     * @Rest\Post("/graduates/sa/lastsixmonths", name="report_sa_graduates_last_six_months")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     * 
     * @SWG\Parameter(
     *     name="country",
     *     in="path",
     *     type="string",
     *     description="country"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description="language"
     * )
     *     
     *
     * @SWG\Tag(name="Report")
     */
    public function graduatesSaLastSixMonths(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $graduates_list = [];
      $message = "";
      $country = $request->request->get('country');
      $language = $request->request->get('language');

      try {
          $code = 200;
          $error = false;

          $current_date = new \DateTime();          
          $final_date = $current_date->format('Y-m-d');
          $init = $current_date->modify( '-6 month' );
          $start_date = $init->format('Y-m-01');

          $s_date = $start_date;
          $t_date = $init->modify( '+1 month' );
          $f_date = $t_date->format('Y-m-01');

          
          if($country == "ALL" && $language == "ALL"){
            $graduates_list = $em->getRepository('App:ProgramSa')->graduatesDateRange($start_date, $final_date);
            $total_data_range_graduates = $em->getRepository('App:ProgramSa')->graduatesDateRangeCount($start_date, $final_date);
  
            $saNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("SA");

            $accumulate_graduates = $saNumbers - $total_data_range_graduates;

          }
          else{
              $graduates_list = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageDateRange($start_date, $final_date, $country, $language);
              $total_data_range_graduates = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageDateRangeCount($start_date, $final_date, $country, $language);
    
              $saInitialNumbers = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("SA", $country, $language);

              $total_graduates = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageCount($country, $language);
              $accumulate_graduates = $saInitialNumbers + $total_graduates - $total_data_range_graduates;

          }

          $high = 0;

          for ($i=1; $i <=7 ; $i++) { 
            $month = \DateTime::createFromFormat('Y-m-d', $s_date);
            if($country == "ALL" && $language == "ALL"){
              $amount = $em->getRepository('App:ProgramSa')->graduatesbyDateCount($s_date, $f_date);
            }
            else{
              $amount = $em->getRepository('App:ProgramSa')->graduatesbyDateCountryLanguageCount($s_date, $f_date, $country, $language);
            }
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(
              'amount' => $amount,
              'month'  => $month->format('M')." ".$month->format('Y'),
              'accumulated' => $accumulate_graduates     
            );

            $s_date = $f_date;
            $f_date = $t_date->modify( '+1 month' )->format('Y-m-01');
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_data_range_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          
          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('report_list'))));
  }

  /**
     * @Rest\Post("/graduates/wellness/lastsixmonths", name="report_wellness_graduates_last_six_months")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     * 
     * @SWG\Parameter(
     *     name="country",
     *     in="path",
     *     type="string",
     *     description="country"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description="language"
     * )
     *     
     *
     * @SWG\Tag(name="Report")
     */
    public function graduatesWellnessLastSixMonths(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $graduates_list = [];
      $message = "";
      $country = $request->request->get('country');
      $language = $request->request->get('language');

      try {
          $code = 200;
          $error = false;

          $current_date = new \DateTime();          
          $final_date = $current_date->format('Y-m-d');
          $init = $current_date->modify( '-6 month' );
          $start_date = $init->format('Y-m-01');

          $s_date = $start_date;
          $t_date = $init->modify( '+1 month' );
          $f_date = $t_date->format('Y-m-01');

          
          if($country == "ALL" && $language == "ALL"){
            $graduates_list = $em->getRepository('App:Wellness')->graduatesDateRange($start_date, $final_date);
            $total_data_range_graduates = $em->getRepository('App:Wellness')->graduatesDateRangeCount($start_date, $final_date);
  
            $saNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("WELLNESS");

            $accumulate_graduates = $saNumbers - $total_data_range_graduates;

          }
          else{
              $graduates_list = $em->getRepository('App:Wellness')->graduatesCountryLanguageDateRange($start_date, $final_date, $country, $language);
              $total_data_range_graduates = $em->getRepository('App:Wellness')->graduatesCountryLanguageDateRangeCount($start_date, $final_date, $country, $language);
    
              $saInitialNumbers = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("WELLNESS", $country, $language);

              $total_graduates = $em->getRepository('App:Wellness')->graduatesCountryLanguageCount($country, $language);
              $accumulate_graduates = $saInitialNumbers + $total_graduates - $total_data_range_graduates;

          }

          $high = 0;

          for ($i=1; $i <=7 ; $i++) { 
            $month = \DateTime::createFromFormat('Y-m-d', $s_date);
            if($country == "ALL" && $language == "ALL"){
              $amount = $em->getRepository('App:Wellness')->graduatesbyDateCount($s_date, $f_date);
            }
            else{
              $amount = $em->getRepository('App:Wellness')->graduatesbyDateCountryLanguageCount($s_date, $f_date, $country, $language);
            }
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(
              'amount' => $amount,
              'month'  => $month->format('M')." ".$month->format('Y'),
              'accumulated' => $accumulate_graduates     
            );

            $s_date = $f_date;
            $f_date = $t_date->modify( '+1 month' )->format('Y-m-01');
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_data_range_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          
          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('report_list'))));
  }

  /**
     * @Rest\Post("/graduates/wellnessparticipant/lastsixmonths", name="report_wellness_participant_graduates_last_six_months")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     * 
     * @SWG\Parameter(
     *     name="country",
     *     in="path",
     *     type="string",
     *     description="country"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description="language"
     * )
     *     
     *
     * @SWG\Tag(name="Report")
     */
    public function graduatesWellnessParticipantLastSixMonths(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $graduates_list = [];
      $message = "";
      $country = $request->request->get('country');
      $language = $request->request->get('language');

      try {
          $code = 200;
          $error = false;

          $current_date = new \DateTime();          
          $final_date = $current_date->format('Y-m-d');
          $init = $current_date->modify( '-6 month' );
          $start_date = $init->format('Y-m-01');

          $s_date = $start_date;
          $t_date = $init->modify( '+1 month' );
          $f_date = $t_date->format('Y-m-01');

          
          if($country == "ALL" && $language == "ALL"){
            $graduates_list = $em->getRepository('App:WellnessParticipant')->graduatesDateRange($start_date, $final_date);
            $total_data_range_graduates = $em->getRepository('App:WellnessParticipant')->graduatesDateRangeCount($start_date, $final_date);
  
            $saNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("WELLNESS_PART");

            $accumulate_graduates = $saNumbers - $total_data_range_graduates;

          }
          else{
              $graduates_list = $em->getRepository('App:WellnessParticipant')->graduatesCountryLanguageDateRange($start_date, $final_date, $country, $language);
              $total_data_range_graduates = $em->getRepository('App:WellnessParticipant')->graduatesCountryLanguageDateRangeCount($start_date, $final_date, $country, $language);
    
              $saInitialNumbers = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("WELLNESS_PART", $country, $language);

              $total_graduates = $em->getRepository('App:WellnessParticipant')->graduatesCountryLanguageCount($country, $language);
              $accumulate_graduates = $saInitialNumbers + $total_graduates - $total_data_range_graduates;

          }

          $high = 0;

          for ($i=1; $i <=7 ; $i++) { 
            $month = \DateTime::createFromFormat('Y-m-d', $s_date);
            if($country == "ALL" && $language == "ALL"){
              $amount = $em->getRepository('App:WellnessParticipant')->graduatesbyDateCount($s_date, $f_date);
            }
            else{
              $amount = $em->getRepository('App:WellnessParticipant')->graduatesbyDateCountryLanguageCount($s_date, $f_date, $country, $language);
            }
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(
              'amount' => $amount,
              'month'  => $month->format('M')." ".$month->format('Y'),
              'accumulated' => $accumulate_graduates     
            );

            $s_date = $f_date;
            $f_date = $t_date->modify( '+1 month' )->format('Y-m-01');
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_data_range_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          
          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('report_list'))));
  }



  /**
     * @Rest\Post("/graduates/sa/lastsixmonths/beau", name="report_sa_graduates_last_six_months_beau")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     * 
     * @SWG\Parameter(
     *     name="country",
     *     in="path",
     *     type="string",
     *     description="country"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description="language"
     * )
     *     
     *
     * @SWG\Tag(name="Report")
     */
    public function graduatesSaLastSixMonthsBeau(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $graduates_list = [];
      $message = "";
      $country = $request->request->get('country');
      $language = $request->request->get('language');

      try {
          $code = 200;
          $error = false;

          $current_date = new \DateTime();          
          $final_date = $current_date->format('Y-m-d');
          $init = $current_date->modify( '-6 month' );
          $start_date = $init->format('Y-m-01');

          $s_date = $start_date;
          $t_date = $init->modify( '+1 month' );
          $f_date = $t_date->format('Y-m-01');

          
          if($country == "ALL" && $language == "ALL"){
            $graduates_list = $em->getRepository('App:ProgramSa')->graduatesDateRange($start_date, $final_date);
            $total_data_range_graduates = $em->getRepository('App:ProgramSa')->graduatesDateRangeCount($start_date, $final_date);
  
            $saNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("SA");

            $accumulate_graduates = $saNumbers - $total_data_range_graduates;

          }
          else{
              $graduates_list = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageDateRange($start_date, $final_date, $country, $language);
              $total_data_range_graduates = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageDateRangeCount($start_date, $final_date, $country, $language);
    
              $saInitialNumbers = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("SA", $country, $language);

              $total_graduates = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageCount($country, $language);
              $accumulate_graduates = $saInitialNumbers + $total_graduates - $total_data_range_graduates;

          }

          $high = 0;

          for ($i=1; $i <=7 ; $i++) { 
            $month = \DateTime::createFromFormat('Y-m-d', $s_date);
            if($country == "ALL" && $language == "ALL"){
              $amount = $em->getRepository('App:ProgramSa')->graduatesbyDateCount($s_date, $f_date);
            }
            else{
              $amount = $em->getRepository('App:ProgramSa')->graduatesbyDateCountryLanguageCount($s_date, $f_date, $country, $language);
            }
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(
              'amount' => $amount,
              'month'  => $month->format('M')." ".$month->format('Y'),
              'accumulated' => $accumulate_graduates     
            );

            $s_date = $f_date;
            $f_date = $t_date->modify( '+1 month' )->format('Y-m-01');
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_data_range_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          $graduates = [];

          foreach ($graduates_list as $gr) {
            $graduate = $gr->getStudent();
            $graduates[] = [
              'name' => $graduate->getFirstName(). " " . $graduate->getLastName(),
              'code' => $graduate->getCode(),
              'country' => $graduate->getCountry(),
              'picture' => $graduate->getPicture() === "undefined" || is_null($graduate->getPicture()) ? "Not Available" :  "https://apifile.interweavesolutions.org/web/file/".$graduate->getPicture()
            ];
          }

          
          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $graduates : $message,
      ];

      return new Response($serializer->serialize($graduates, "json", SerializationContext::create()->setGroups(array('report_list'))));
  }

  /**
     * @Rest\Post("/graduates/lastmonth", name="report_graduates_last_month")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     *     
     *
     * @SWG\Parameter(
     *     name="country",
     *     in="path",
     *     type="string",
     *     description="country"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description="language"
     * )
     * 
     * @SWG\Tag(name="Report")
     */
    public function graduatesLastMonth(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $graduates_list = [];
      $message = "";
      $country = $request->request->get('country');
      $language = $request->request->get('language');

      try {
          $code = 200;
          $error = false;

          $current_date = new \DateTime();
          $t_date = $current_date;
          $current_date_desc = $current_date->format('d M');

          $final_date = $current_date->format('Y-m-d');
          $start_date = $t_date->modify( '-1 month' )->format('Y-m-d');
          

          $s_date = $start_date;
          $s_date_desc = $t_date->format('d M');

          $t_date->modify( '+4 days' );
          $f_date = $t_date->format('Y-m-d');

          $f_date_desc = $t_date->format('d M');

          if($country == "ALL" && $language == "ALL"){
              //$graduates_list = $em->getRepository('App:ProgramMbs')->graduatesDateRange($start_date, $final_date);
              $total_data_range_graduates = $em->getRepository('App:ProgramMbs')->graduatesDateRangeCount($start_date, $final_date);
    
              $mbsNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("MBS");
              $jrNumbers  = $em->getRepository('App:Certificate')->graduatesTotalNumbers("JR");

              $accumulate_graduates = $mbsNumbers + $jrNumbers - $total_data_range_graduates;

          }
          else{
              //$graduates_list = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageDateRange($start_date, $final_date, $country, $language);
              $total_data_range_graduates = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageDateRangeCount($start_date, $final_date, $country, $language);
    
              $mbsInitialNumbers = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("MBS", $country, $language);
              $jrInitialNumbers  = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("JR", $country, $language);

              $total_graduates = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageCount($country, $language);
              $accumulate_graduates = $mbsInitialNumbers + $jrInitialNumbers +  $total_graduates - $total_data_range_graduates;

          }
          

          $high = 0;

          for ($i=1; $i <=6 ; $i++) { 
            
            if($country == "ALL" && $language == "ALL"){
              $amount = $em->getRepository('App:ProgramMbs')->graduatesDateRangeCount($s_date, $f_date);
            }
            else{
              $amount = $em->getRepository('App:ProgramMbs')->graduatesbyDateCountryLanguageCount($s_date, $f_date, $country, $language);
            }
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(
              'amount' => $amount,
              'month'  => $s_date_desc." - ".$f_date_desc,
              'accumulated' => $accumulate_graduates     
            );

            $t_date->modify( '+1 day' );
            $s_date_desc = $t_date->format('d M');
            $s_date = $t_date->format('Y-m-d');
            if($i == 5){
              $f_date_desc = $current_date_desc;
              $f_date = $final_date;
            }
            else{
              $f_date = $t_date->modify( '+4 day' )->format('Y-m-d');
              $f_date_desc = $t_date->format('d M');
            }
            
            
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_data_range_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          
          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('report_list'))));
  }

  /**
     * @Rest\Post("/graduates/ambassador/lastmonth", name="report_graduates_ambassador_last_month")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     *     
     *
     * @SWG\Parameter(
     *     name="country",
     *     in="path",
     *     type="string",
     *     description="country"
     * )
     * 
     * @SWG\Tag(name="Report")
     */
    public function graduatesAmbassadorLastMonth(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $message = "";
      $ambassador_id = $request->request->get('ambassador_id');

      try {
          $code = 200;
          $error = false;

          $current_date = new \DateTime();
          $t_date = $current_date;
          $current_date_desc = $current_date->format('d M');

          $final_date = $current_date->format('Y-m-d');
          $start_date = $t_date->modify( '-1 month' )->format('Y-m-d');
          

          $s_date = $start_date;
          $s_date_desc = $t_date->format('d M');

          $t_date->modify( '+4 days' );
          $f_date = $t_date->format('Y-m-d');

          $f_date_desc = $t_date->format('d M');

          
          $graduates_list = $em->getRepository('App:ProgramMbs')->graduatesDateRangeByAmbassador($start_date, $final_date, $ambassador_id);
          $total_graduates = $em->getRepository('App:ProgramMbs')->graduatesDateRangeByAmbassadorCount($start_date, $final_date, $ambassador_id);

          $mbs_graduates = $em->getRepository('App:StudentGroup')->studentsMbsStateByEmbassador($ambassador_id, 'state.approved');
        

          $accumulate_graduates = count($mbs_graduates) - $total_graduates;

          $high = 0;

          for ($i=1; $i <=6 ; $i++) { 
            
            $amount = $em->getRepository('App:ProgramMbs')->graduatesbyDateAmbassadorCount($s_date, $f_date, $ambassador_id);
          
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(
              'amount' => $amount,
              'month'  => $s_date_desc." - ".$f_date_desc,
              'accumulated' => $accumulate_graduates     
            );

            $t_date->modify( '+1 day' );
            $s_date_desc = $t_date->format('d M');
            $s_date = $t_date->format('Y-m-d');
            if($i == 5){
              $f_date_desc = $current_date_desc;
              $f_date = $final_date;
            }
            else{
              $f_date = $t_date->modify( '+4 day' )->format('Y-m-d');
              $f_date_desc = $t_date->format('d M');
            }
            
            
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          
          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('report_list'))));
  }

  /**
     * @Rest\Post("/graduates/sa/lastmonth", name="report_sa_graduates_last_month")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     *     
     *
     * @SWG\Parameter(
     *     name="country",
     *     in="path",
     *     type="string",
     *     description="country"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description="language"
     * )
     * 
     * @SWG\Tag(name="Report")
     */
    public function graduatesSaLastMonth(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $graduates_list = [];
      $message = "";
      $country = $request->request->get('country');
      $language = $request->request->get('language');

      try {
          $code = 200;
          $error = false;

          $current_date = new \DateTime();
          $t_date = $current_date;
          $current_date_desc = $current_date->format('d M');

          $final_date = $current_date->format('Y-m-d');
          $start_date = $t_date->modify( '-1 month' )->format('Y-m-d');
          

          $s_date = $start_date;
          $s_date_desc = $t_date->format('d M');

          $t_date->modify( '+4 days' );
          $f_date = $t_date->format('Y-m-d');

          $f_date_desc = $t_date->format('d M');

          if($country == "ALL" && $language == "ALL"){
              $graduates_list = $em->getRepository('App:ProgramSa')->graduatesDateRange($start_date, $final_date);
              $total_data_range_graduates = $em->getRepository('App:ProgramSa')->graduatesDateRangeCount($start_date, $final_date);
    
              $saNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("SA");

              $accumulate_graduates = $saNumbers - $total_data_range_graduates;

          }
          else{
            $graduates_list = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageDateRange($start_date, $final_date, $country, $language);
              $total_data_range_graduates = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageDateRangeCount($start_date, $final_date, $country, $language);
    
              $saInitialNumbers = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("SA", $country, $language);

              $total_graduates = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageCount($country, $language);
              $accumulate_graduates = $saInitialNumbers +  $total_graduates - $total_data_range_graduates;

          }
          

          $high = 0;

          for ($i=1; $i <=6 ; $i++) { 
            
            if($country == "ALL" && $language == "ALL"){
              $amount = $em->getRepository('App:ProgramSa')->graduatesDateRangeCount($s_date, $f_date);
            }
            else{
              $amount = $em->getRepository('App:ProgramSa')->graduatesbyDateCountryLanguageCount($s_date, $f_date, $country, $language);
            }
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(
              'amount' => $amount,
              'month'  => $s_date_desc." - ".$f_date_desc,
              'accumulated' => $accumulate_graduates     
            );

            $t_date->modify( '+1 day' );
            $s_date_desc = $t_date->format('d M');
            $s_date = $t_date->format('Y-m-d');
            if($i == 5){
              $f_date_desc = $current_date_desc;
              $f_date = $final_date;
            }
            else{
              $f_date = $t_date->modify( '+4 day' )->format('Y-m-d');
              $f_date_desc = $t_date->format('d M');
            }
            
            
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_data_range_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          
          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('report_list'))));
  }

  /**
     * @Rest\Post("/graduates/wellness/lastmonth", name="report_wellness_graduates_last_month")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     *     
     *
     * @SWG\Parameter(
     *     name="country",
     *     in="path",
     *     type="string",
     *     description="country"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description="language"
     * )
     * 
     * @SWG\Tag(name="Report")
     */
    public function graduatesWellnessLastMonth(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $graduates_list = [];
      $message = "";
      $country = $request->request->get('country');
      $language = $request->request->get('language');

      try {
          $code = 200;
          $error = false;

          $current_date = new \DateTime();
          $t_date = $current_date;
          $current_date_desc = $current_date->format('d M');

          $final_date = $current_date->format('Y-m-d');
          $start_date = $t_date->modify( '-1 month' )->format('Y-m-d');
          

          $s_date = $start_date;
          $s_date_desc = $t_date->format('d M');

          $t_date->modify( '+4 days' );
          $f_date = $t_date->format('Y-m-d');

          $f_date_desc = $t_date->format('d M');

          if($country == "ALL" && $language == "ALL"){
              $graduates_list = $em->getRepository('App:Wellness')->graduatesDateRange($start_date, $final_date);
              $total_data_range_graduates = $em->getRepository('App:Wellness')->graduatesDateRangeCount($start_date, $final_date);
    
              $saNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("WELLNESS");

              $accumulate_graduates = $saNumbers - $total_data_range_graduates;

          }
          else{
            $graduates_list = $em->getRepository('App:Wellness')->graduatesCountryLanguageDateRange($start_date, $final_date, $country, $language);
              $total_data_range_graduates = $em->getRepository('App:Wellness')->graduatesCountryLanguageDateRangeCount($start_date, $final_date, $country, $language);
    
              $saInitialNumbers = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("WELLNESS", $country, $language);

              $total_graduates = $em->getRepository('App:Wellness')->graduatesCountryLanguageCount($country, $language);
              $accumulate_graduates = $saInitialNumbers +  $total_graduates - $total_data_range_graduates;

          }
          

          $high = 0;

          for ($i=1; $i <=6 ; $i++) { 
            
            if($country == "ALL" && $language == "ALL"){
              $amount = $em->getRepository('App:Wellness')->graduatesDateRangeCount($s_date, $f_date);
            }
            else{
              $amount = $em->getRepository('App:Wellness')->graduatesbyDateCountryLanguageCount($s_date, $f_date, $country, $language);
            }
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(
              'amount' => $amount,
              'month'  => $s_date_desc." - ".$f_date_desc,
              'accumulated' => $accumulate_graduates     
            );

            $t_date->modify( '+1 day' );
            $s_date_desc = $t_date->format('d M');
            $s_date = $t_date->format('Y-m-d');
            if($i == 5){
              $f_date_desc = $current_date_desc;
              $f_date = $final_date;
            }
            else{
              $f_date = $t_date->modify( '+4 day' )->format('Y-m-d');
              $f_date_desc = $t_date->format('d M');
            }
            
            
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_data_range_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          
          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('report_list'))));
  }

  /**
     * @Rest\Post("/graduates/wellnessparticipant/lastmonth", name="report_wellness_participant_graduates_last_month")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets data range groups reports"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all ambassador report."
     * )
     *     
     *
     * @SWG\Parameter(
     *     name="country",
     *     in="path",
     *     type="string",
     *     description="country"
     * )
     * 
     * @SWG\Parameter(
     *     name="language",
     *     in="path",
     *     type="string",
     *     description="language"
     * )
     * 
     * @SWG\Tag(name="Report")
     */
    public function graduatesWellnessParticipantLastMonth(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $reports = [];
      $graduates_list = [];
      $message = "";
      $country = $request->request->get('country');
      $language = $request->request->get('language');

      try {
          $code = 200;
          $error = false;

          $current_date = new \DateTime();
          $t_date = $current_date;
          $current_date_desc = $current_date->format('d M');

          $final_date = $current_date->format('Y-m-d');
          $start_date = $t_date->modify( '-1 month' )->format('Y-m-d');
          

          $s_date = $start_date;
          $s_date_desc = $t_date->format('d M');

          $t_date->modify( '+4 days' );
          $f_date = $t_date->format('Y-m-d');

          $f_date_desc = $t_date->format('d M');

          if($country == "ALL" && $language == "ALL"){
              $graduates_list = $em->getRepository('App:WellnessParticipant')->graduatesDateRange($start_date, $final_date);
              $total_data_range_graduates = $em->getRepository('App:WellnessParticipant')->graduatesDateRangeCount($start_date, $final_date);
    
              $saNumbers = $em->getRepository('App:Certificate')->graduatesTotalNumbers("WELLNESS_PART");

              $accumulate_graduates = $saNumbers - $total_data_range_graduates;

          }
          else{
            $graduates_list = $em->getRepository('App:WellnessParticipant')->graduatesCountryLanguageDateRange($start_date, $final_date, $country, $language);
              $total_data_range_graduates = $em->getRepository('App:WellnessParticipant')->graduatesCountryLanguageDateRangeCount($start_date, $final_date, $country, $language);
    
              $saInitialNumbers = $em->getRepository('App:Certificate')->graduatesByProgramCountryLanguageInitialValues("WELLNESS_PART", $country, $language);

              $total_graduates = $em->getRepository('App:WellnessParticipant')->graduatesCountryLanguageCount($country, $language);
              $accumulate_graduates = $saInitialNumbers +  $total_graduates - $total_data_range_graduates;

          }
          

          $high = 0;

          for ($i=1; $i <=6 ; $i++) { 
            
            if($country == "ALL" && $language == "ALL"){
              $amount = $em->getRepository('App:WellnessParticipant')->graduatesDateRangeCount($s_date, $f_date);
            }
            else{
              $amount = $em->getRepository('App:WellnessParticipant')->graduatesbyDateCountryLanguageCount($s_date, $f_date, $country, $language);
            }
            $accumulate_graduates = $amount + $accumulate_graduates;

            if($high < $amount){
              $high = $amount;
            }

            $graduates_report[] = array(
              'amount' => $amount,
              'month'  => $s_date_desc." - ".$f_date_desc,
              'accumulated' => $accumulate_graduates     
            );

            $t_date->modify( '+1 day' );
            $s_date_desc = $t_date->format('d M');
            $s_date = $t_date->format('Y-m-d');
            if($i == 5){
              $f_date_desc = $current_date_desc;
              $f_date = $final_date;
            }
            else{
              $f_date = $t_date->modify( '+4 day' )->format('Y-m-d');
              $f_date_desc = $t_date->format('d M');
            }
            
            
          }

          $statistics = array(
            'high'             => $this->getHigh($high),
            'accumulated_high' => $this->getHigh($high + $accumulate_graduates),
            'graduates_total'  => $total_data_range_graduates,
            'start_date'       => $start_date,
            'final_date'       => $final_date,
            'graduates_report' => $graduates_report ,
            'graduates_list'   => $graduates_list, 
          );

          
          

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('report_list'))));
  }

  /**
     * @Rest\Get("/graduates/initialvalues", name="report_graduates_initial_values")
     *
     * @SWG\Response(
     *     response=200,
     *     description="Gets initival values of graduates"
     * )
     *
     * @SWG\Response(
     *     response=500,
     *     description="An error has occurred trying to get all graduates initial values."
     * )
     *         
     *
     * @SWG\Tag(name="Report")
     */
    public function graduatesInitialValues(Request $request) {
      $serializer = $this->get('jms_serializer');
      $em = $this->getDoctrine()->getManager();
      $mbs_reports = [];
      $mbs_reports = [];
      $mbs_reports = [];
      $message = "";


      try {
          $code = 200;
          $error = false;

          $numbers = $em->getRepository('App:Certificate')->findBy(array("program" => "MBS"));

          foreach ($numbers as $numb) {
            $country = $numb->getCountry();
            $user = $em->getRepository('App:User')->findOneBy(array("country" => $country));
            $mbsNumber = $em->getRepository('App:ProgramMbs')->graduatesCountryLanguageCount($country, "ALL");
            $saNumber = $em->getRepository('App:ProgramSa')->graduatesCountryLanguageCount($country, "ALL");
            $initialMbs = $em->getRepository('App:Certificate')->findOneBy(array("program" => "MBS", "country" => $country));
            $initialJr = $em->getRepository('App:Certificate')->findOneBy(array("program" => "JR", "country" => $country));
            $initialSa = $em->getRepository('App:Certificate')->findOneBy(array("program" => "SA", "country" => $country));
            if($initialJr){
              $initialJr = $initialJr->getNumber();
            }
            $initialMbs = $initialMbs->getNumber();
            if($initialSa){
              $initialValueSa = $initialSa->getNumber();
              $initialSa->setInitial($initialValueSa - $saNumber);
              $initialSa->setLanguage($user->getLanguage());
              $em->persist($initialSa);
              $em->flush();
            }
            


            
            $numb->setInitial($initialMbs + $initialJr - $mbsNumber);
            $numb->setLanguage($user->getLanguage());
            $em->persist($numb);
            $em->flush();

            $statistics[] = array(
              'country'         => "MBS_INIT_".$country.":".($initialMbs + $initialJr - $mbsNumber),
             
            );
          }

      } catch (Exception $ex) {
          $code = 500;
          $error = true;
          $message = "An error has occurred trying to get all report - Error: {$ex->getMessage()}";
      }

      $response = [
          'code' => $code,
          'error' => $error,
          'data' => $code == 200 ? $statistics : $message,
      ];

      return new Response($serializer->serialize($response, "json", SerializationContext::create()->setGroups(array('report_list'))));
  }

  
  
    private function getFormat($df) {
          //$language = $this->getUser()->getLanguage();
          $language = "es";
  
          $years = 'Years';
          $year = 'Year';
          $months = 'Months';
          $month = 'Month';
          $days = 'Days';
          $day = 'Day';
  
          $str = '';
          $str .= ($df->invert == 1) ? ' - ' : '';
          if ($df->y > 0) {
              // years
              $str .= ($df->y > 1) ? $df->y . ' '. $years .' ' : $df->y . ' '. $year .' ';
          } if ($df->m > 0) {
              // month
              $str .= ($df->m > 1) ? $df->m . ' '. $months .' ' : $df->m . ' '. $month .' ';
          } if ($df->d > 0) {
              // days
              $str .= ($df->d > 1) ? $df->d . ' '. $days .' ' : $df->d . ' '. $day .' ';
          } if ($df->h > 0) {
              // hours
              //$str .= ($df->h > 1) ? $df->h . ' Hours ' : $df->h . ' Hour ';
          } if ($df->i > 0) {
              // minutes
              //$str .= ($df->i > 1) ? $df->i . ' Minutes ' : $df->i . ' Minute ';
          } if ($df->s > 0) {
              // seconds
              //$str .= ($df->s > 1) ? $df->s . ' Seconds ' : $df->s . ' Second ';
          }
  
          return $str;
      }

      private function getHigh($max_high) {
        $numlength = strlen((string)$max_high);
        if($numlength < 3){
          $high = $max_high + 10;
        }
        else{
          $high = $max_high + 100;
        }
        

        return $high;
    }

      private function evaluationReportXAmbassador($ambassador_id){
        $em = $this->getDoctrine()->getManager();
  
        if($ambassador_id != 'null'){
            $studentsGroup1 = $em->getRepository('App:StudentGroup')->studentsMbsByEmbassador($ambassador_id);
            $studentsGroup2 = $em->getRepository('App:StudentAmbassadorGroup')->studentsMbsByEmbassador($ambassador_id);
            $studentsGroup = new ArrayCollection(
              array_merge($studentsGroup1, $studentsGroup2)
            );
        }
        else{
            $studentsGroup1 = $em->getRepository('App:StudentGroup')->findAll();
            $studentsGroup2 = $em->getRepository('App:StudentAmbassadorGroup')->findAll();

            $studentsGroup = new ArrayCollection(
              array_merge($studentsGroup1, $studentsGroup2)
            );
        }
  
  
        $evaluations    = array();
        $evaluationsJr  = array();
        $evaluationsMbs = array();
        foreach ($studentsGroup as $s) {
          $student = $s->getStudent();
            if($student->getEvaluation()){
                if($student->getEvaluation()->getPostquestion1() and $student->getStudentgroup()->getGroup()->getProgram() == 'option.program4'){
                  $evaluationsJr[] = array(
                    'name'             => $student->getFirstName()." ".$student->getLastName(),
                    'question1'        => $this->improvementMeasure($student->getEvaluation()->getQuestion1(), $student->getEvaluation()->getPostquestion1(), 'question1'),
                    'question2'        => $this->improvementMeasure($student->getEvaluation()->getQuestion2(), $student->getEvaluation()->getPostquestion2(), 'question2'),
                    'question3'        => $this->improvementMeasure($student->getEvaluation()->getQuestion3(), $student->getEvaluation()->getPostquestion3(), 'question3'),
                    'question4'        => $this->improvementMeasure($student->getEvaluation()->getQuestion4(), $student->getEvaluation()->getPostquestion4(), 'question4'),
                    'question5'        => $this->improvementMeasure($student->getEvaluation()->getQuestion5(), $student->getEvaluation()->getPostquestion5(), 'question5'),
                    'question6'        => $this->improvementMeasure($student->getEvaluation()->getQuestion6(), $student->getEvaluation()->getPostquestion6(), 'question6'),
                    'question7'        => $this->improvementMeasure($student->getEvaluation()->getQuestion7(), $student->getEvaluation()->getPostquestion7(), 'question7'),
                    'question8'        => $this->improvementMeasure('option1', $student->getEvaluation()->getPostquestion8(), 'question8'),
                    'question9'        => $this->improvementMeasure('option1', $student->getEvaluation()->getPostquestion9(), 'question9'),
                    'questionInitial1' => $this->initialState($student->getEvaluation()->getQuestion1(), 'question1'),
                    'questionInitial2' => $this->initialState($student->getEvaluation()->getQuestion2(), 'question2'),
                    'questionInitial3' => $this->initialState($student->getEvaluation()->getQuestion3(), 'question3'),
                    'questionInitial4' => $this->initialState($student->getEvaluation()->getQuestion4(), 'question4'),
                    'questionInitial5' => $this->initialState($student->getEvaluation()->getQuestion5(), 'question5'),
                    'questionInitial6' => $this->initialState($student->getEvaluation()->getQuestion6(), 'question6'),
                    'questionInitial7' => $this->initialState($student->getEvaluation()->getQuestion7(), 'question7'),
                    'questionFinal1'   => $this->potentialImprovement($student->getEvaluation()->getQuestion1(), $student->getEvaluation()->getPostquestion1(), 'question1'),
                    'questionFinal2'   => $this->potentialImprovement($student->getEvaluation()->getQuestion2(), $student->getEvaluation()->getPostquestion2(), 'question2'),
                    'questionFinal3'   => $this->potentialImprovement($student->getEvaluation()->getQuestion3(), $student->getEvaluation()->getPostquestion3(), 'question3'),
                    'questionFinal4'   => $this->potentialImprovement($student->getEvaluation()->getQuestion4(), $student->getEvaluation()->getPostquestion4(), 'question4'),
                    'questionFinal5'   => $this->potentialImprovement($student->getEvaluation()->getQuestion5(), $student->getEvaluation()->getPostquestion5(), 'question5'),
                    'questionFinal6'   => $this->potentialImprovement($student->getEvaluation()->getQuestion6(), $student->getEvaluation()->getPostquestion6(), 'question6'),
                    'questionFinal7'   => $this->potentialImprovement($student->getEvaluation()->getQuestion7(), $student->getEvaluation()->getPostquestion7(), 'question7'),
                    'questionFinal8'   => $this->potentialImprovement('option1', $student->getEvaluation()->getPostquestion8(), 'question8'),
                    'questionFinal9'   => $this->potentialImprovement('option1', $student->getEvaluation()->getPostquestion9(), 'question9'),
      
                    'group'            => $student->getStudentgroup()->getGroup()->getName(),
                    'ambassador'       => $student->getStudentgroup()->getGroup()->getEmbassador()->getFirstName()." ".$student->getStudentgroup()->getGroup()->getEmbassador()->getLastName()
                  );
              }
              else if($student->getEvaluation()->getPostquestion1()){
                $evaluationsMbs[] = array(
                  'name'             => $student->getFirstName()." ".$student->getLastName(),
                  'question1'        => $this->improvementMeasure($student->getEvaluation()->getQuestion1(), $student->getEvaluation()->getPostquestion1(), 'question1'),
                  'question2'        => $this->improvementMeasure($student->getEvaluation()->getQuestion2(), $student->getEvaluation()->getPostquestion2(), 'question2'),
                  'question3'        => $this->improvementMeasure($student->getEvaluation()->getQuestion3(), $student->getEvaluation()->getPostquestion3(), 'question3'),
                  'question4'        => $this->improvementMeasure($student->getEvaluation()->getQuestion4(), $student->getEvaluation()->getPostquestion4(), 'question4'),
                  'question5'        => $this->improvementMeasure($student->getEvaluation()->getQuestion5(), $student->getEvaluation()->getPostquestion5(), 'question5'),
                  'question6'        => $this->improvementMeasure($student->getEvaluation()->getQuestion6(), $student->getEvaluation()->getPostquestion6(), 'question6'),
                  'question7'        => $this->improvementMeasure($student->getEvaluation()->getQuestion7(), $student->getEvaluation()->getPostquestion7(), 'question7'),
                  'question8'        => $this->improvementMeasure('option1', $student->getEvaluation()->getPostquestion8(), 'question8'),
                  'question9'        => $this->improvementMeasure('option1', $student->getEvaluation()->getPostquestion9(), 'question9'),
                  'questionInitial1' => $this->initialState($student->getEvaluation()->getQuestion1(), 'question1'),
                  'questionInitial2' => $this->initialState($student->getEvaluation()->getQuestion2(), 'question2'),
                  'questionInitial3' => $this->initialState($student->getEvaluation()->getQuestion3(), 'question3'),
                  'questionInitial4' => $this->initialState($student->getEvaluation()->getQuestion4(), 'question4'),
                  'questionInitial5' => $this->initialState($student->getEvaluation()->getQuestion5(), 'question5'),
                  'questionInitial6' => $this->initialState($student->getEvaluation()->getQuestion6(), 'question6'),
                  'questionInitial7' => $this->initialState($student->getEvaluation()->getQuestion7(), 'question7'),
                  'questionFinal1'   => $this->potentialImprovement($student->getEvaluation()->getQuestion1(), $student->getEvaluation()->getPostquestion1(), 'question1'),
                  'questionFinal2'   => $this->potentialImprovement($student->getEvaluation()->getQuestion2(), $student->getEvaluation()->getPostquestion2(), 'question2'),
                  'questionFinal3'   => $this->potentialImprovement($student->getEvaluation()->getQuestion3(), $student->getEvaluation()->getPostquestion3(), 'question3'),
                  'questionFinal4'   => $this->potentialImprovement($student->getEvaluation()->getQuestion4(), $student->getEvaluation()->getPostquestion4(), 'question4'),
                  'questionFinal5'   => $this->potentialImprovement($student->getEvaluation()->getQuestion5(), $student->getEvaluation()->getPostquestion5(), 'question5'),
                  'questionFinal6'   => $this->potentialImprovement($student->getEvaluation()->getQuestion6(), $student->getEvaluation()->getPostquestion6(), 'question6'),
                  'questionFinal7'   => $this->potentialImprovement($student->getEvaluation()->getQuestion7(), $student->getEvaluation()->getPostquestion7(), 'question7'),
                  'questionFinal8'   => $this->potentialImprovement('option1', $student->getEvaluation()->getPostquestion8(), 'question8'),
                  'questionFinal9'   => $this->potentialImprovement('option1', $student->getEvaluation()->getPostquestion9(), 'question9'),

                  'group'            => $student->getStudentgroup()->getGroup()->getName(),
                  'ambassador'       => $student->getStudentgroup()->getGroup()->getEmbassador()->getFirstName()." ".$student->getStudentgroup()->getGroup()->getEmbassador()->getLastName()
                );
              }
 
            }
       }
       $evaluations['mbs'] = $evaluationsMbs;
       $evaluations['jr'] = $evaluationsJr;

       return $evaluations;
        
  
      }

      private function evaluationReportXAmbassadorFull($ambassador_id){
        $em = $this->getDoctrine()->getManager();
  
        if($ambassador_id != 'null'){
            $studentsGroup1 = $em->getRepository('App:StudentGroup')->studentsMbsByEmbassador($ambassador_id);
            $studentsGroup2 = $em->getRepository('App:StudentAmbassadorGroup')->studentsMbsByEmbassador($ambassador_id);
            $studentsGroup = new ArrayCollection(
              array_merge($studentsGroup1, $studentsGroup2)
            );
        }
        else{
            $studentsGroup1 = $em->getRepository('App:StudentGroup')->findAll();
            $studentsGroup2 = $em->getRepository('App:StudentAmbassadorGroup')->findAll();

            $studentsGroup = new ArrayCollection(
              array_merge($studentsGroup1, $studentsGroup2)
            );
        }
  
  
        $evaluations    = array();
        foreach ($studentsGroup as $s) {
          $student = $s->getStudent();
            if($student->getEvaluation()){
                if($student->getEvaluation()->getPostquestion1()){
                  $evaluations[] = array(
                    'name'             => $student->getFirstName()." ".$student->getLastName(),
                    'question1'        => $this->improvementMeasure($student->getEvaluation()->getQuestion1(), $student->getEvaluation()->getPostquestion1(), 'question1'),
                    'question2'        => $this->improvementMeasure($student->getEvaluation()->getQuestion2(), $student->getEvaluation()->getPostquestion2(), 'question2'),
                    'question3'        => $this->improvementMeasure($student->getEvaluation()->getQuestion3(), $student->getEvaluation()->getPostquestion3(), 'question3'),
                    'question4'        => $this->improvementMeasure($student->getEvaluation()->getQuestion4(), $student->getEvaluation()->getPostquestion4(), 'question4'),
                    'question5'        => $this->improvementMeasure($student->getEvaluation()->getQuestion5(), $student->getEvaluation()->getPostquestion5(), 'question5'),
                    'question6'        => $this->improvementMeasure($student->getEvaluation()->getQuestion6(), $student->getEvaluation()->getPostquestion6(), 'question6'),
                    'question7'        => $this->improvementMeasure($student->getEvaluation()->getQuestion7(), $student->getEvaluation()->getPostquestion7(), 'question7'),
                    'question8'        => $this->improvementMeasure('option1', $student->getEvaluation()->getPostquestion8(), 'question8'),
                    'question9'        => $this->improvementMeasure('option1', $student->getEvaluation()->getPostquestion9(), 'question9'),
                    'questionInitial1' => $this->initialState($student->getEvaluation()->getQuestion1(), 'question1'),
                    'questionInitial2' => $this->initialState($student->getEvaluation()->getQuestion2(), 'question2'),
                    'questionInitial3' => $this->initialState($student->getEvaluation()->getQuestion3(), 'question3'),
                    'questionInitial4' => $this->initialState($student->getEvaluation()->getQuestion4(), 'question4'),
                    'questionInitial5' => $this->initialState($student->getEvaluation()->getQuestion5(), 'question5'),
                    'questionInitial6' => $this->initialState($student->getEvaluation()->getQuestion6(), 'question6'),
                    'questionInitial7' => $this->initialState($student->getEvaluation()->getQuestion7(), 'question7'),
                    'questionFinal1'   => $this->potentialImprovement($student->getEvaluation()->getQuestion1(), $student->getEvaluation()->getPostquestion1(), 'question1'),
                    'questionFinal2'   => $this->potentialImprovement($student->getEvaluation()->getQuestion2(), $student->getEvaluation()->getPostquestion2(), 'question2'),
                    'questionFinal3'   => $this->potentialImprovement($student->getEvaluation()->getQuestion3(), $student->getEvaluation()->getPostquestion3(), 'question3'),
                    'questionFinal4'   => $this->potentialImprovement($student->getEvaluation()->getQuestion4(), $student->getEvaluation()->getPostquestion4(), 'question4'),
                    'questionFinal5'   => $this->potentialImprovement($student->getEvaluation()->getQuestion5(), $student->getEvaluation()->getPostquestion5(), 'question5'),
                    'questionFinal6'   => $this->potentialImprovement($student->getEvaluation()->getQuestion6(), $student->getEvaluation()->getPostquestion6(), 'question6'),
                    'questionFinal7'   => $this->potentialImprovement($student->getEvaluation()->getQuestion7(), $student->getEvaluation()->getPostquestion7(), 'question7'),
                    'questionFinal8'   => $this->potentialImprovement('option1', $student->getEvaluation()->getPostquestion8(), 'question8'),
                    'questionFinal9'   => $this->potentialImprovement('option1', $student->getEvaluation()->getPostquestion9(), 'question9'),
      
                    'group'            => $student->getStudentgroup()->getGroup()->getName(),
                    'ambassador'       => $student->getStudentgroup()->getGroup()->getEmbassador()->getFirstName()." ".$student->getStudentgroup()->getGroup()->getEmbassador()->getLastName()
                  );
              }             
 
            }
       }
     

       return $evaluations;
        
  
      }

}